/******************************************************************************
 *
 * Copyright 2008, Rohde & Schwarz, Inc.
 *
 * NAME:        RSCMUC2K.c
 *
 * PURPOSE:     This file contains the routines used to implement the CDMA2000
 *              device driver for the Rohde & Schwarz CMU.
 *
 * DESCRIPTION: There are multiple functions in this file.  
 *              Refer to their corresponding headers for more detailed 
 *              information.
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 * Version:     V4.50.2
 *
 ******************************************************************************
 ******************************************************************************
 * ----------------------------------------------------------------------------
 *                              REVISION HISTORY 
 *  see ChangeLog
 * ----------------------------------------------------------------------------

/* INCLUDE FILES */
//#include <ansi_c.h>
//#include <utility.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <ctype.h>
#include <visa.h>
#include <locale.h>
#include "rscmuc2k.h"


/* DEFINES */
#define RSCMUC2K_REVISION  "Rev 4.50.2 01/2011"  // Instrument Driver Revision

// Structure "RSCMU_CDMA_Globals" is initialized for each Session in an 'init' function
struct RSCMU_CDMA_Globals              
{
  struct RSCMU_SESSION_Globals  RSCMU_tGlobal;
  struct RSCMU_HandOver         RSCMU_tHandOver;
  // JMG 020923
  ViBoolean                     RSCMU_XtndCQU;
  ViBoolean                     RSCMU_XtndOVER;
  ViBoolean                     RSCMU_XtndMOD;
  ViChar                        rdABuf[RD_BUFFER_SIZE_ARRAY];
};

static char *HandoffTargets[] =
   { "\"CDMA2KCellMS\"",           "\"CDMA2KPCSMS\"",          "\"AMPSMS\""
   , "\"CDMA2KCellMSFallback\"",   "\"CDMA2KPCSMSFallback\"",  "\"AMPSMSFallback\""    
   , "\"NONE\""
   , "\"CDMA2KIMT2KMS\"",          "\"CDMA2K450MS\""
   , "\"CDMA2KIMT2KMSFallback\"",  "\"CDMA2K450MSFallback\"" 
   };

/* FUNCTION PROTOTYPES */
static void     checkRange( ViInt32 cmd, ... );
static void     RSCMU_ReturnArrayValues( ViChar[], ViReal64[] );
static ViInt32  RSCMU_SeparateString( ViChar[], ViChar[], ViChar[48][30] );
static ViStatus getBuffers( ViSession, ViChar**, ViChar**, ViChar[] );
static ViStatus RSCMU_ReturnFERResponse( ViInt32, ViChar[669][20], ViReal64 *, ViInt32 *, ViInt32 *, ViReal64 * );
static ViStatus RSCMU_ReturnLimits( ViChar[3][30], ERROR_LIMITS * );
static ViStatus RSCMU_MatchLimits( ViChar[3][30], ERROR_LIMITS * );
static ViStatus RSCMU_MatchOneLimits( ViChar[1][30], ViInt32 * );
static ViStatus RSCMU_GetMeasurementStatus( ViInt32*, ViChar[48][30], ViInt32 );
static ViStatus RSCMU_GetMeasureMatching( ViInt32*, ViChar[48][30], ViInt32 );
static ViStatus RSCMU_CDMA2K_MeasPowXSlot (ViSession instrSession,
                                        ViReal64 results[],
                                        ViInt32 cmdType,
                                        ViChar errorMessage[]);
static ViStatus RSCMU_CDMA2K_MeasArrayModIqan (ViSession instrSession,
                                        ViReal64 results[],
                                        ViInt32 measurementType,
                                        ViInt32 signalType,
                                        ViInt32 cmdType,
                                        ViChar errorMessage[]);
static ViStatus RSCMU_CDMA2K_MeasModIqan (ViSession instrSession,
                                        ViReal64 *EVM_RMS,
                                        ViReal64 *magnitudeError_RMS,
                                        ViReal64 *phaseError_RMS,
                                        ViReal64 *waveformQuality,
                                        ViReal64 *iQImbalance,
                                        ViReal64 *carrierFeedthrough,
                                        ViReal64 *MSPower,
                                        ViInt32 signalType,
                                        ViInt32 cmdType,
                                        ViChar errorMessage[]);
static ViStatus RSCMU_CDMA2K_MeasSpecAcp (ViSession instrSession,
                                            ViReal64 ACP_Current[],
                                            ViReal64 ACP_Average[],
                                            ViReal64 ACP_Maximum[],
                                            ViReal64 channelPower[],
                                            ViReal64 *outOfTolerance,
                                            ViInt32 *currentStatistics,
                                            ViInt32 cmdType,
                                            ViChar errorMessage[]);
static ViStatus RSCMU_CDMA2K_MeasCDPowPoff (ViSession instrSession,
                                            ViReal64    msPower[],
                                            ViReal64    carrierFeedthrough[],
                                            ViReal64    frequencyError[],
                                            ViReal64    rho[],
                                            ViReal64*   outofTolerance,
                                            ViInt32*    currentStatistics,
                                            ViInt32 cmdType,
                                            ViChar errorMessage[]);
static ViStatus RSCMU_CDMA2K_MeasCDPowToff (ViSession instrSession,
                                            ViReal64    msPower[],
                                            ViReal64    carrierFeedthrough[],
                                            ViReal64    frequencyError[],
                                            ViReal64    rho[],
                                            ViReal64*   outofTolerance,
                                            ViInt32*    currentStatistics,
                                            ViInt32 cmdType,
                                            ViChar errorMessage[]);
static ViStatus RSCMU_CDMA2K_MeasArrCDPowPoff (ViSession instrSession,
                                               ViInt32  signalType,
                                               ViInt32  measurementSetting,
                                               ViReal64 result[],
                                               ViInt32 cmdType,
                                               ViChar errorMessage[]);
static ViStatus RSCMU_CDMA2K_MeasArrCDPowToff (ViSession instrSession,
                                               ViInt32  signalType,
                                               ViInt32  measurementSetting,
                                               ViReal64 result[],
                                               ViInt32 cmdType,
                                               ViChar errorMessage[]);
static ViStatus RSCMU_CDMA2K_MeasPing (ViSession instrSession,
                                       ViInt32  ipAddresspart1[],
                                       ViInt32  ipAddresspart2[],
                                       ViInt32  ipAddresspart3[],
                                       ViInt32  ipAddresspart4[],
                                       ViInt32  packetSize[],
                                       ViInt32  pingStatus[],
                                       ViReal64 pingTime[],
                                       ViInt32 cmdType,
                                       ViChar errorMessage[]);




/* EXTERNALLY DEFINED GLOBAL CONSTANTS */
/* NONE */

/* INTERNALLY DEFINED GLOBAL CONSTANTS */
/* NONE */

/* EXTERNALLY DEFINED GLOBAL VARIABLES */
/* NONE */ 

/* INTERNALLY DEFINED GLOBAL VARIABLES */
/* NONE */ 



/* STATIC CONSTANTS */
/* NONE */

/* STATIC VARIABLES */
/* NONE */

//*********************************************************************
// Strings for CDMA2K Remote Commands
//*********************************************************************

#if 0 //unused declarations
static LIST levelType =
    { 5
    , "MIN", "MAX", "DEF", "ON", "OFF"
    };

static LIST freqUnits =
   { 4
   , "HZ", "KHZ", "MHZ", "GHZ"
   };
   
static LIST localControl =
   { 2
   , "NSUP", "SUPP"
   };
   
static LIST sigState =
   { 7
   , "SOFF", "SON", "REG", "ALER", "CEST", "CPEN", "FPEN"
   };
    
static LIST acpSelection =
    { 4
    ,"ACP1","ACP2","ACP3","ACP4"
    };
   
static PARAM_BLOCK MeasMode = 
   { 1 
   , INTEGER_TYPE, 0, 1, &measMode2
   };
   
static PARAM_BLOCK RFchannel = 
   { 1 
   , INTEGER_TYPE, 1, 1199, NULL
   };

static PARAM_BLOCK Application = 
   { 1 
   , INTEGER_TYPE, 0, 3, &measType
   };

static PARAM_BLOCK DefaultFER = 
   { 2 
   , INTEGER_TYPE, 1, 20000, NULL
   , INTEGER_TYPE, 0, 1,     &enable
   };

static PARAM_BLOCK ModStatistic = 
   { 2 
   , INTEGER_TYPE, 0, 3,  &measType
   , INTEGER_TYPE, 1, 1000,   NULL
   };
   
static PARAM_BLOCK ModScope = 
   { 5
   , INTEGER_TYPE, 0, 3,    &measType
   , INTEGER_TYPE, 1, 1000, NULL
   , INTEGER_TYPE, 0, 2,    &repetition
   , INTEGER_TYPE, 0, 1,    &stopCond
   , INTEGER_TYPE, 0, 1,    &stepMode
   };
   
static PARAM_BLOCK ModScope2 = 
   { 6
   , INTEGER_TYPE, 0, 3,    &measType
   , INTEGER_TYPE, 0, 1,    &resultMode
   , INTEGER_TYPE, 1, 1000, NULL
   , INTEGER_TYPE, 0, 2,    &repetition
   , INTEGER_TYPE, 0, 1,    &stopCond
   , INTEGER_TYPE, 0, 1,    &stepMode
   };
   
static PARAM_BLOCK OEMPVal = 
   { 12
   , INTEGER_TYPE,   0,      1,      &measMode2
   , FLOAT_TYPE,     0,      100.0,  NULL
   , FLOAT_TYPE,     0,      100.0,  NULL
   , FLOAT_TYPE,     0,      100.0,  NULL
   , FLOAT_TYPE,     0,      100.0,  NULL
   , FLOAT_TYPE,     0,      45.0,   NULL
   , FLOAT_TYPE,     0,      45.0,   NULL
   , FLOAT_TYPE,     -120.0, -20.0,  NULL
   , FLOAT_TYPE,     -120.0, -20.0,  NULL
   , FLOAT_TYPE,     0,      1000.0, NULL
   , FLOAT_TYPE,     0.0,    10.0,   NULL
   , FLOAT_TYPE,     0,      1.0,    NULL
   };

static PARAM_BLOCK OEMPEnable = 
   { 12
   , INTEGER_TYPE,   0,      1,      &measMode2
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   };

static PARAM_BLOCK MinOutCont = 
   { 4
   , INTEGER_TYPE, 1, 1000, NULL
   , INTEGER_TYPE, 0, 2,    &repetition
   , INTEGER_TYPE, 0, 1,    &stopCond
   , INTEGER_TYPE, 0, 1,    &stepMode
   };
   
static PARAM_BLOCK ConfCont = 
   { 5
   , INTEGER_TYPE, 1, 1000, &measType 
   , INTEGER_TYPE, 1, 1000, NULL
   , INTEGER_TYPE, 0, 2,    &repetition
   , INTEGER_TYPE, 0, 1,    &stopCond
   , INTEGER_TYPE, 0, 1,    &stepMode
   };
   
static PARAM_BLOCK MaxOutCont = 
   { 4
   , INTEGER_TYPE, 1, 1000, NULL
   , INTEGER_TYPE, 0, 2,    &repetition
   , INTEGER_TYPE, 0, 1,    &stopCond
   , INTEGER_TYPE, 0, 1,    &stepMode
   };

static PARAM_BLOCK ModStat = 
   { 1
   , INTEGER_TYPE, 1, 1000, NULL
   };

static PARAM_BLOCK GatedStat = 
   { 2
   , INTEGER_TYPE, 1, 200, NULL
   , INTEGER_TYPE, 1, 1000, NULL
   };
      
static PARAM_BLOCK MaxOutStat = 
   { 1
   , INTEGER_TYPE, 1, 1000, NULL
   };
      
static PARAM_BLOCK SignalRep = 
   { 3 
   , INTEGER_TYPE, 0, 10000, NULL
   , INTEGER_TYPE, 0, 1,     &stopCond
   , INTEGER_TYPE, 0, 1,     &stepMode
   };

static PARAM_BLOCK FreqOffset = 
   { 1 
   , FLOAT_TYPE, -15.0, 15.0, NULL
   };

static PARAM_BLOCK RFlvl = 
   { 5 
   , FLOAT_TYPE, -137.0, 13.0, NULL
   , FLOAT_TYPE, -20.0,  -7.0, NULL
   , FLOAT_TYPE, -20.0,  -7.0, NULL
   , FLOAT_TYPE, -20.0,  -7.0, NULL
   , FLOAT_TYPE, -20.0,  -7.0, NULL
   };
   
static PARAM_BLOCK BSSLvl = 
   { 5 
   , FLOAT_TYPE, -137.0, 13.0, NULL
   , FLOAT_TYPE, -20.0,  -7.0, NULL
   , FLOAT_TYPE, -20.0,  -7.0, NULL
   , FLOAT_TYPE, -20.0,  -7.0, NULL
   , FLOAT_TYPE, -20.0,  -7.0, NULL
   };
   
static PARAM_BLOCK LevelFER = 
   { 4 
   , INTEGER_TYPE, 1,      5,    NULL
   , FLOAT_TYPE,  -137.0,  13.0, NULL
   , FLOAT_TYPE,  -20.0,   -7.0, NULL
   , FLOAT_TYPE,  -20.0,   -7.0, NULL
   };

static PARAM_BLOCK ImpairFER = 
   { 3 
   , INTEGER_TYPE, 1,      5,     NULL
   , FLOAT_TYPE,  -20.0,   6.0,   NULL
   , FLOAT_TYPE,  -625.0,  625.0, NULL
   };

static PARAM_BLOCK LimitFER = 
   { 3 
   , INTEGER_TYPE, 1,    5,     NULL
   , FLOAT_TYPE,   0.0,  100.0, NULL
   , FLOAT_TYPE,   85.0, 99.0,  NULL
   };

static PARAM_BLOCK FERframes = 
   { 1 
   , INTEGER_TYPE, 1, 20000, NULL
   };

static PARAM_BLOCK InConn = 
   { 1 
   , INTEGER_TYPE, 0, 3, &inpConn
   };

static PARAM_BLOCK OutConn = 
   { 1 
   , INTEGER_TYPE, 0, 2, &outpConn
   };

static PARAM_BLOCK Area = 
   { 1 
   , INTEGER_TYPE, 1, 5, NULL
   };

static PARAM_BLOCK ModCfgRep = 
   { 4
   , INTEGER_TYPE, 0, 3, &measType
   , INTEGER_TYPE, 0, 2, &repetition
   , INTEGER_TYPE, 0, 1, &stopCond
   , INTEGER_TYPE, 0, 1, &stepMode
   };

static PARAM_BLOCK CQCfgRep = 
   { 3 
   , INTEGER_TYPE, 0, 2, &repetition
   , INTEGER_TYPE, 0, 1, &stopCond
   , INTEGER_TYPE, 0, 1, &stepMode
   };

static PARAM_BLOCK GatedRep = 
   { 3 
   , INTEGER_TYPE, 0, 2, &repetition
   , INTEGER_TYPE, 0, 1, &stopCond
   , INTEGER_TYPE, 0, 1, &stepMode
   };

static PARAM_BLOCK MinOutRep = 
   { 3 
   , INTEGER_TYPE, 0, 2, &repetition
   , INTEGER_TYPE, 0, 1, &stopCond
   , INTEGER_TYPE, 0, 1, &stepMode
   };

static PARAM_BLOCK MaxOutRep = 
   { 3 
   , INTEGER_TYPE, 0, 2, &repetition
   , INTEGER_TYPE, 0, 1, &stopCond
   , INTEGER_TYPE, 0, 1, &stepMode
   };

static PARAM_BLOCK GatedScope = 
   { 6 
   , INTEGER_TYPE, 0, 1,     &resultMode
   , INTEGER_TYPE, 1, 1000,  NULL
   , INTEGER_TYPE, 0, 2,     &repetition
   , INTEGER_TYPE, 0, 1,     &stopCond
   , INTEGER_TYPE, 0, 1,     &stepMode
   , INTEGER_TYPE, 1, 1000,  NULL   
   };

static PARAM_BLOCK ModMode = 
   { 2 
   , INTEGER_TYPE, 0,   3,    &measType
   , INTEGER_TYPE, 0,   2,    &measMode3
   };

static PARAM_BLOCK ConfSub =
   { 3
   , INTEGER_TYPE, 0,      3,     &measMode3
   , FLOAT_TYPE,   -100,   1400,  NULL
   , INTEGER_TYPE, 0,      3327,  NULL
   };

static PARAM_BLOCK ConfSub2 = 
   { 4
   , INTEGER_TYPE, 0,      3,     &measType
   , INTEGER_TYPE, 0,      3,     &gateMode
   , FLOAT_TYPE,   0,      400,   NULL
   , INTEGER_TYPE, 0,      500,   NULL
   };
   
static PARAM_BLOCK ChanTCH =
   { 1 
   , INTEGER_TYPE, 1, 1999, NULL
   };

static PARAM_BLOCK LevelTCH =
   { 1 
   , FLOAT_TYPE, -131, 3, NULL
   };

static PARAM_BLOCK ChannelTCH = 
   { 1 
   , INTEGER_TYPE, 2, 63, NULL
   };

static PARAM_BLOCK OEMPLev =
   { 3 
   , FLOAT_TYPE, -130, 10,   NULL
   , FLOAT_TYPE, -20, -7.0,  NULL
   , FLOAT_TYPE, -20, -7.0,  NULL
   };

static PARAM_BLOCK NetNID =
   { 1 
   , INTEGER_TYPE, 0, 65534, NULL
   };

static PARAM_BLOCK NetMCC =
   { 1 
   , INTEGER_TYPE, 0, 1023, NULL
   };

static PARAM_BLOCK NetScanInt =
   { 1 
   , INTEGER_TYPE, 1, 16, NULL
   };

static PARAM_BLOCK NetDelay =
   { 1 
   , INTEGER_TYPE, 0, 14, NULL
   };

static PARAM_BLOCK NetRAMIN =
   { 1 
   , INTEGER_TYPE, -111, -51, NULL
   };

static PARAM_BLOCK NetSUFF =
   { 1 
   , INTEGER_TYPE, -111, -51, NULL
   };

static PARAM_BLOCK NetDTCMAC =
   { 1 
   , INTEGER_TYPE, 0, 10, NULL
   };

static PARAM_BLOCK NetDCCMAC =
   { 1 
   , INTEGER_TYPE, 0, 7, NULL
   };

static PARAM_BLOCK NetNumFSlots =
   { 1 
   , INTEGER_TYPE, 5, 10, NULL
   };

static PARAM_BLOCK NetNumESlots =
   { 1 
   , INTEGER_TYPE, 1, 8, NULL
   };

static PARAM_BLOCK NetCCSDVCC =
   { 1 
   , INTEGER_TYPE, 0, 255, NULL
   };

static PARAM_BLOCK OEMPImp =
   { 2
   , FLOAT_TYPE, -20.0,   6.0,    NULL
   , FLOAT_TYPE, -625.0,  625.0,  NULL
   };
   
static PARAM_BLOCK RfgImp = 
   { 2 
   , FLOAT_TYPE, -20.0,  6.0,   NULL
   , FLOAT_TYPE, -625.0, 625.0, NULL
   };

static PARAM_BLOCK RfgTCH = 
   { 1 
   , INTEGER_TYPE, 2, 63, NULL
   };

static PARAM_BLOCK RfgPnof = 
   { 1
   , INTEGER_TYPE, 0, 511, NULL
   };

static PARAM_BLOCK RfgFoff = 
   { 1 
   , INTEGER_TYPE, 0, 15, NULL
   };

static PARAM_BLOCK RfgPcb = 
   { 1 
   , INTEGER_TYPE, 0, 4, &powerCtlBits
   };
   
static PARAM_BLOCK TrnsProt = 
   { 1 
   , INTEGER_TYPE, 1, 3, NULL
   };

static PARAM_BLOCK SlotCycIndex = 
   { 1 
   , INTEGER_TYPE, 0, 1023, NULL
   };

static PARAM_BLOCK CMUOutLvl = 
   { 3 
   , FLOAT_TYPE, -137, 13, NULL
   , FLOAT_TYPE, -20,  -7, NULL
   , FLOAT_TYPE, -20,  -7, NULL
   };
   
static PARAM_BLOCK PilotPow = 
   { 2 
   , FLOAT_TYPE, -10, 0, NULL
   , FLOAT_TYPE, -10, 0, NULL
   };

static PARAM_BLOCK TestSetupLev = 
   { 4 
   , INTEGER_TYPE, 1,   5, NULL 
   , FLOAT_TYPE,  -144, 7, NULL
   , FLOAT_TYPE,  -20,  7, NULL
   , FLOAT_TYPE,  -20,  7, NULL
   };
   
static PARAM_BLOCK RFGenpcb = 
   { 1 
   , INTEGER_TYPE, 0, 5, &powerCtlBits
   };

static PARAM_BLOCK ModLim = 
   { 3 
   , FLOAT_TYPE,  -200.0, 200.0,   NULL
   , FLOAT_TYPE,  0.0   , 10.0,    NULL
   , FLOAT_TYPE,  0.000,  1.000,   NULL
   };
 
static PARAM_BLOCK CQLim =
   { 1
   , FLOAT_TYPE, 0.0, 100.0, NULL
   };
   
static PARAM_BLOCK MinOutLev = 
   { 3 
   , FLOAT_TYPE, -133.0, -19.0, NULL
   , FLOAT_TYPE, -20.0,  -7.0,  NULL
   , FLOAT_TYPE, -20.0,  -7.0,  NULL
   };

static PARAM_BLOCK MaxOutLev = 
   { 3 
   , FLOAT_TYPE, -133.0, -19.0, NULL
   , FLOAT_TYPE, -20.0,  -7.0,  NULL
   , FLOAT_TYPE, -20.0,  -7.0,  NULL
   };
 
static PARAM_BLOCK GatedLev = 
   { 3 
   , FLOAT_TYPE, -133.0, -19.0, NULL
   , FLOAT_TYPE, -20.0,  -7.0,  NULL
   , FLOAT_TYPE, -20.0,  -7.0,  NULL
   };
   
static PARAM_BLOCK RMode2 = 
   { 2
   , INTEGER_TYPE,  0,   3,  &measType
   , INTEGER_TYPE,  0,   1,  &resultMode
   };
   
static PARAM_BLOCK MinLimits = 
   { 2
   , FLOAT_TYPE,  -100.0,  0.0, NULL
   , FLOAT_TYPE,   0.0,    1.0, NULL   
   };

static PARAM_BLOCK MaxLimits = 
   { 4 
   , FLOAT_TYPE,  0.0,    100.0, NULL
   , FLOAT_TYPE,  0.0,    50.0,  NULL   
   , FLOAT_TYPE,  -50.0,  0.0,   NULL   
   , FLOAT_TYPE,  0.0,    1.0,   NULL   
   };
   
static PARAM_BLOCK PowerMeasure = 
   { 2
   , INTEGER_TYPE, 0,  5, &powerStatus
   , INTEGER_TYPE, 0,  1, &signalType 
   };

static PARAM_BLOCK ModCont = 
   { 2 
   , INTEGER_TYPE, 0, 1, &enable
   , INTEGER_TYPE, 0, 1, &signalType   
   };   
   
static PARAM_BLOCK FetchNPow = 
   { 2
   , INTEGER_TYPE, 0, 5,     &powerStatus             
   , INTEGER_TYPE, 1, 1000,  NULL
   };

static LIST powerStatus = 
   { 6
   , "OFF", "RUN", "STOP", "ERR", "STEP", "RDY"
   };   
    
static ViInt16 NUM_CMDS = ( sizeof( CDMA ) / sizeof( COMMAND_INFO ) );
#endif


static LIST repetition =
    { 4
    , "CONT", "SING", "DEF", "ON"
    };
    

static LIST inpConn = 
   { 3
   , "RF1", "RF2", "RF4"
   };

static LIST outpConn = 
   { 3
   , "RF1", "RF2", "RF3"
   };

static LIST inpSrc = 
   { 3
   , "1", "2", "4"
   };

static LIST outpSrc = 
   { 3
   , "1", "2", "3"
   };   
   
static LIST stopCond = 
   { 2
   , "NONE", "SONERROR"
   };

static LIST stopCond2 = 
   { 5
   , "ALEX", "CLEX", "FLEX", "NONE", "DEF"
   };
      
static LIST stopCond3 = 
   { 3
   , "NONE", "SON", "DEF"
   };

static LIST gateMode = 
   { 4
   , "ALL", "ARIT", "MIN", "MAX"
   };
    
static LIST mode =
    { 2
    , "MAN", "AUTO"
    };
// JMG 030110   
static LIST modMode = 
   { 3
   , "AUT", "OFF", "DEF"
   };   
   
static LIST bandwidth =
   { 2
   , "B123", "B180"
   };
   
static LIST measMode = 
   { 4
   , "CURR", "AVER", "MIN", "MAX"
   }; 
   
static LIST measMode2 = 
   { 2
   , "CMM", "AVER"
   };
   
static LIST measMode3 = 
   { 3
   , "CURR", "AVER", "MMAX"
   }; 
   
static LIST frameRateType =
   { 6
   , "EIGH", "QUAR", "HALF", "FULL", "DEF", "RAND"
   };      
   
static LIST resultOrder =
    { 2
    , "HAD", "BITR"
    };
    
static LIST trigSourType =
   { 3
   , "INT", "EXT", "FRUN"
   };   

static LIST IQType =
    { 2
    , "ISIG", "QSIG"
    };
    
static LIST clkFreq =
   { 4
   , "NCD1", "NCD2", "NCD3", "NCD4"
   };   
   
static LIST stepMode = 
   { 3
   , "NONE", "STEP", "DEF"
   };
   
static LIST attenuation = 
   { 3
   , "NORMAL", "LNOISE", "LDISTORTION"
   };
   
static LIST enable = 
   { 2
   , "OFF", "ON"
   };

static LIST eventReport = 
   { 5
   , "OFF" , "SRQ", "SOPC", "SRSQ", "DEF"
   };
   
static LIST modeEnable = 
   { 3
   , "OFF", "ON", "DEF"
   };
                  
static LIST signalType2 =
   { 3
   , "OQPSK", "HPSK", "QPSK"
   };

static LIST signalType =
   { 2
   , "", ":HPSK"
   };
   
static LIST resultMode =
   { 2
   , "SCAL", "ARR"
   };
   
static LIST powerCtlBits =
   { 6
   , "AUTO", "HOLD", "ADOW", "AUP", "RTES", "OFF" 
   };    
   
static LIST service =
   { 3
   , "LOOP", "SPEECH","TDAT" , "WMT"
   };   
   
static LIST powerDir =
   {2
   , "UP", "DOWN"
   };
   
static LIST measType =
   { 4
   , "OVER", "PERR", "MERR", "EVM"
   };   

static LIST pagingChanRate =
   { 3
   , "R4K8", "R9K6", "DEF"
   };
   
static LIST patternGen =
   { 3
   , "RAND", "FIX", "DEF"
   };
   
static LIST serviceOption =
   { 6
   , "S01D", "S03D", "S17D", "S56D", "SX8T", "S68D"
   };
   
static LIST serviceOption2 =
   { 6
   , "S02D", "S09D", "S30D", "S31D", "S55D", "S32D"
   };
   
static LIST serviceOption3 =
   { 2
   , "S06D", "S14D"
   };      

static LIST sigAction =
   { 6
   , "SOFF", "SON", "UNR","CTM", "CREL", "HAND", "SMES"
   };
   
static LIST testSetup =
   { 7
   , "","T1", "T2", "T3", "T4", "T5", "DEF"
   };   
   
static LIST standard = 
   { 19
   , "N45T", "USC", "KCEL", "TACS","JTAC","NA7C", "NA9C","NA8S","NAPC","KPCS","B18M","IM2K","PA4M","PA8M","USPC","IEXT","AWS","U25B","U25F"
   };   
   
static LIST limitLinesMode =
   { 2
   , "CMAX", "AVER"
   };
   
static LIST voiceCoder =
   { 13
   , "ECHO", "V8", "V8E", "V13", "V8L","V8EL","V13L","CCAL", "ECAL", "DCAL","DEF", "ON", "OLOW"
   };
// JMG 030109   
static LIST indicatorBit =
   { 2
   , "\"00\"", "\"11\""
   };
   
static LIST direction = 
   { 2
   , "FORW", "REV"
   };
   
static LIST inpSpeCod =
    { 2
    ,"GEN","HAND"
    };

static LIST outSpeDecod =
    { 4
    ,"ANAL","HAND","ANA2","ABOT"
    };
 
static LIST accessProbeMode =
    { 3
    ,"ACKN","IGN","DEF"
    };
// JMG 020923 useless re-use powerCtlBits List Above
/*
static LIST powerContrlBitMode =
    { 6
    ,"OFF","AUT","HOLD","ADOW","AUP","RTES"
    };
*/

static LIST triggerOutputRouting =
    { 8
    ,"NONE","PP2S","SFR","PFR","SNCF","PCFR","DEF","ETR"
    };
    
static LIST routingPath = 
    { 8
    ,"DEF","BYP","BYIQ","XOIO","IOIO","IOXO","FPAT","UDEF"
    };

static ViString slopeArr[] = {"NEG", "POS", VI_NULL};
static ViString intextArr[] = {"INT", "EXT", VI_NULL};
static ViString triggerThrArr[] = {"LOW", "MED", "HIGH", VI_NULL};
static ViString stateArr[] = {"OFF", "ON", VI_NULL};
static ViString stateDefArr[] = {"OFF", "ON", "DEF", VI_NULL};
static ViString wmtServiceArr[] = {"S06D", "S14D", VI_NULL};
static ViString wmtServiceAllArr[] = {"S06D", "CCON", "S14D", VI_NULL};
static ViString directionArr[] = {"FORW", "REV", VI_NULL};
static ViString codingArr[] = {"CONV", "TURBO", VI_NULL};
static ViString patternArr[] = {"RAND","FIX","DEF", VI_NULL};
static ViString signalTypeArr[] = {"",":HPSK", VI_NULL};
static ViString PCBArr[] = {"AUT","HOLD","ADOW","AUP","RTES","OFF","PATT",VI_NULL};
static ViString frameArr[] = {"EIGH","QUAR","HALF","FULL","DEF",VI_NULL};
static ViString schArr[] = {"ZERO", "ONE", VI_NULL};
static ViString channelArr[] = {"FPIC","FFCH","FSCH:ZERO","FSCH:ONE", VI_NULL};
static ViString phaseArr[] = {"IPH", "QPH", VI_NULL};
static ViString erepArr[] =  {"OFF" , "SRQ", "SOPC", "SRSQ", "DEF", VI_NULL};
static ViString stopConditionArr[] = {"NONE","SON", VI_NULL};
static ViString stepModeArr[] = {"NONE","STEP", VI_NULL};
static ViString repetitionArr[] = {"CONT","SING", VI_NULL};
static ViString resultModeArr[] = {"SCAL","ARR", VI_NULL};
static ViString toleranceArr[] = {"OK","INV", "NMAU","NMAL", VI_NULL};
static ViString polarityArr[] = {"UP","DOWN", VI_NULL};
static ViString powerStepArr[] = {"PREP","PFBA","PFBH",VI_NULL};
static ViString acceptArr[] = {"ALL","SCL1","FSC1","ICAW","ICFW","ICOR",
                               "ROAW","ROFW","ROOR","BUAW","BUFW","IGNR",VI_NULL};
static ViString signalCDPArr[] = {"ISIG", "QSIG", VI_NULL};
static ViString measSettingArr[] = {"CURR", "AVER", "MIN", "MAX", VI_NULL};
static ViString channelRateArr[] = {"R4K8", "R9K6", VI_NULL};
static ViString cmaxAverArr[] = {"CMAX", "AVER", VI_NULL};
static ViString cdpMeasArr[] = {"CURR", "AVER", "MAX",VI_NULL};
static ViString pingStatusArr[] = {"NHOS", "TOUT", "ILNK",VI_NULL};
static ViString pindArr[] = {"PAL","PRES","NNA",VI_NULL};
static ViString rqfChannelArr[] = {"FCH","SCH:ZERO","SCH:ONE",VI_NULL};
static ViString authTypeArr[] = {"NONE","CHAP","PAP",VI_NULL};
static ViString pdsnArr[] = {"UCH","CHAN",VI_NULL};
static ViString ipadrModeArr[] = {"STAT","DYN",VI_NULL};
static ViString rfSelectivityArr[] = {"WIDE","NARR",VI_NULL};
static ViString mipAuthTypeArr[] = {"R02","R02B",VI_NULL};
static ViString rfSelArr[] = {"WIDE","IFL",VI_NULL};
static ViString refPowerModeArr[] = {"ATP","PPOW",VI_NULL};
static ViString syncModeArr[] = {"NONE","PP2S","DEF", VI_NULL};
static ViString syncStateArr[] = {"INT","EXT", VI_NULL};
static ViString encodingRateArr[] = {"R9K3","R8K5","R7K5","R7K0","R6K6",
                                     "R6K2","R5K8","R4K8","DEF", VI_NULL};
static ViString wmtHandleArr[] = {"INT","FILE", VI_NULL};
static ViString esyncSysTimeStatusArr[] = {"NINI","IPRG","RDY","FAIL", VI_NULL};

//*********************************************************************
// Parameter Lists for CDMA Remote Commands
//*********************************************************************
static PARAM_BLOCK InputCodec = 
   { 1 
   , INTEGER_TYPE, 0, 1, &inpSpeCod
   };

static PARAM_BLOCK OutputCodec = 
   { 1 
   , INTEGER_TYPE, 0, 3, &outSpeDecod
   };
   
static PARAM_BLOCK AWGNBandwidth = 
   { 1 
   , INTEGER_TYPE, 0, 1, &bandwidth
   };

static PARAM_BLOCK CDMA2KStandard = 
   { 1 
    , INTEGER_TYPE, 0, 18, &standard
   };

static PARAM_BLOCK Default = 
   { 1 
   , INTEGER_TYPE, 0, 1, &enable
   };

static PARAM_BLOCK ClkMode = 
   { 1 
   , INTEGER_TYPE, 0, 1, &enable
   };

static PARAM_BLOCK DmClkFreq = 
   { 1 
   , INTEGER_TYPE, 0, 3, &clkFreq
   };

static PARAM_BLOCK AttLvl = 
   { 1 
   , INTEGER_TYPE, 0, 2, &attenuation
   };

static PARAM_BLOCK InpLvl = 
   { 1 
   , INTEGER_TYPE, 0, 1, &mode
   };

static PARAM_BLOCK MaxLvl = 
   { 1 
   , FLOAT_TYPE, -80.0, 44.0, NULL
   };

static PARAM_BLOCK SpecEvtReport = 
   { 1 
   , INTEGER_TYPE, 0, 5, &eventReport
   };

static PARAM_BLOCK MinOutEvtReport = 
   { 1 
   , INTEGER_TYPE, 0, 4, &eventReport
   };
   
static PARAM_BLOCK MaxOutEvtReport = 
   { 1 
   , INTEGER_TYPE, 0, 4, &eventReport
   };

static PARAM_BLOCK RfanModEventReport = 
   { 1 
   , INTEGER_TYPE, 0, 4, &eventReport
   };
   
static PARAM_BLOCK RfanModScope = 
   { 4
   , INTEGER_TYPE, 1, 1000, NULL
   , INTEGER_TYPE, 0, 2,    &repetition
   , INTEGER_TYPE, 0, 1,    &stopCond
   , INTEGER_TYPE, 0, 1,    &stepMode
   };
   
static PARAM_BLOCK CQScope = 
   { 4
   , INTEGER_TYPE, 1, 1000, NULL
   , INTEGER_TYPE, 0, 2,    &repetition
   , INTEGER_TYPE, 0, 1,    &stopCond
   , INTEGER_TYPE, 0, 1,    &stepMode
   };
   
static PARAM_BLOCK RfanModStat = 
   { 1
   , INTEGER_TYPE, 1, 1000, NULL
   };
   
static PARAM_BLOCK CQStat = 
   { 1
   , INTEGER_TYPE, 1, 1000, NULL
   };
   
static PARAM_BLOCK MinOutStat = 
   { 1
   , INTEGER_TYPE, 1, 1000, NULL
   };

static PARAM_BLOCK FreqChan = 
   { 1
   , FLOAT_TYPE, 0.2, 2700.0, NULL
   };

static PARAM_BLOCK RFChan = 
   { 1 
   , INTEGER_TYPE, 1, 2047, NULL
   };

static PARAM_BLOCK TestSetupFER = 
   { 1
   , INTEGER_TYPE, 0, 6, &testSetup
   };

static PARAM_BLOCK Input = 
   { 1 
   , INTEGER_TYPE, 0, 2, &inpConn
   };

static PARAM_BLOCK Output = 
   { 1 
   , INTEGER_TYPE, 0, 2, &outpConn
   };

static PARAM_BLOCK InpAtt = 
   { 2 
   , INTEGER_TYPE, 0,     2,    &inpSrc
   , FLOAT_TYPE,   -50.0, 90.0, NULL
   };

static PARAM_BLOCK OutpAtt = 
   { 2 
   , INTEGER_TYPE, 0,     2,    &outpSrc
   , FLOAT_TYPE,   -50.0, 90.0, NULL
   };

static PARAM_BLOCK RfanModRep = 
   { 3 
   , INTEGER_TYPE, 0, 2, &repetition
   , INTEGER_TYPE, 0, 1, &stopCond
   , INTEGER_TYPE, 0, 1, &stepMode
   };
   
static PARAM_BLOCK ModLimits = 
   { 5 
   , FLOAT_TYPE,   0.0,    1.0,   NULL
   , FLOAT_TYPE,   -1000.0, 1000,  NULL
   , FLOAT_TYPE,   0.0,     10.0,    NULL
   , FLOAT_TYPE,   -120.0, -20.0, NULL
   , FLOAT_TYPE,   -120.0, -20.0, NULL
   };

static PARAM_BLOCK SignalAction = 
   { 1 
   , INTEGER_TYPE, 0, 6, &sigAction
   };

static PARAM_BLOCK NetSID =
   { 1 
   , INTEGER_TYPE, 0, 32767, NULL
   };

static PARAM_BLOCK BTSId = 
   { 1 
   , INTEGER_TYPE, 0, 65535, NULL
   };

static PARAM_BLOCK GatedTolLim =
   { 6
   , FLOAT_TYPE, 1.0,    10.0,   NULL
   , FLOAT_TYPE, 1.0,    10.0,   NULL
   , FLOAT_TYPE, -20.0,  -1.0,   NULL
   , FLOAT_TYPE, -25.0,  0.0,    NULL
   , FLOAT_TYPE, -70,    0.0,    NULL
   , FLOAT_TYPE, 1240.0, 1260.0, NULL
   };
   
static PARAM_BLOCK OLTimeResLev = 
   { 2 
   , FLOAT_TYPE, -20.0, -7.0, NULL
   , FLOAT_TYPE, -20.0, -7.0, NULL
   };

static PARAM_BLOCK InitialBSPow = 
   { 1 
   , FLOAT_TYPE, -108.0, 6.0, NULL
   };
   
static PARAM_BLOCK powStep = 
   { 1 
   , FLOAT_TYPE,  0.0, 100.0, NULL
   };
   
static PARAM_BLOCK powerStepDir = 
   { 1
   , INTEGER_TYPE, 0, 1,    &powerDir
   };

static PARAM_BLOCK TrigSour = 
   { 1 
   , INTEGER_TYPE,  0,   2,  &trigSourType
   };
   
static PARAM_BLOCK ModSig =
   { 1
   , INTEGER_TYPE,  0,   2,  &modMode
   };                       
                    
static PARAM_BLOCK GenLevel =
   { 1
   , FLOAT_TYPE,  -20.0,   -1.0,  NULL
   };                       
    
static PARAM_BLOCK RfgGenLevel =
   { 1
   , FLOAT_TYPE,  -20.0,   0.0,  NULL
   };                       

static PARAM_BLOCK PNOffsetLim =
   { 1
   , INTEGER_TYPE,  0,   511,  NULL
   };   
   
static PARAM_BLOCK CDMAPowLvl = 
   { 1 
   , FLOAT_TYPE, -120.0, 50.0, NULL
   };   
   
static PARAM_BLOCK OCNSMode =
   { 1
   , INTEGER_TYPE,  0,   1,  &enable
   };   
   
static PARAM_BLOCK ImpAwgnLevel =
   { 1
   , FLOAT_TYPE,  -20.0,   4.0,  NULL
   };  
   
static PARAM_BLOCK ImpFreqOffset =
   { 1
   , FLOAT_TYPE,  -50.0,   50.0,  NULL
   };     
       
static PARAM_BLOCK FFCHCh = 
   { 1 
   , INTEGER_TYPE, 2, 63, NULL
   };
   
static PARAM_BLOCK FFCHFrameOffset = 
   { 1 
   , INTEGER_TYPE, 0, 15, NULL
   };   
   
static PARAM_BLOCK FFCHFrameRate =
   { 1 
   , INTEGER_TYPE, 0, 5, &frameRateType
   };   
   
static PARAM_BLOCK CDPLev = 
   { 5              
   , FLOAT_TYPE,  -120.0,  7.0,   NULL
   , FLOAT_TYPE,  -20.0,  -7.0,   NULL   
   , FLOAT_TYPE,  -20.0,  -7.0,   NULL   
   , FLOAT_TYPE,  -3000.0, 3000.0, NULL
   , FLOAT_TYPE,  -3000.0, 3000.0, NULL
   };
   
static PARAM_BLOCK CDPContLev = 
   { 4      
   , FLOAT_TYPE,  -20.0,  -7.0,   NULL   
   , FLOAT_TYPE,  -20.0,  -7.0,   NULL   
   , FLOAT_TYPE,  -3000.0, 3000.0, NULL
   , FLOAT_TYPE,  -3000.0, 3000.0, NULL  
   };   
   
static PARAM_BLOCK CDPImpair = 
   { 2 
   , FLOAT_TYPE,  -20.0,  4.0,    NULL   
   , FLOAT_TYPE,  -50.0,  50.0,   NULL  
   };
   
static PARAM_BLOCK CDPAsym = 
   { 4 
   , INTEGER_TYPE, 0,    1,    &limitLinesMode   
   , FLOAT_TYPE,   -120.0, -20.0,  NULL      
   , FLOAT_TYPE,   0.0,    1000.0, NULL
   , FLOAT_TYPE,   0.0,    1.0,    NULL
   };   

static PARAM_BLOCK CDPWCont = 
   { 5 
   , INTEGER_TYPE, 0,    1,    &resultMode  
   , INTEGER_TYPE, 1,    1000, NULL 
   , INTEGER_TYPE, 0,    2,    &repetition
   , INTEGER_TYPE, 0,    2,    &stopCond3
   , INTEGER_TYPE, 0,    2,    &stepMode
   }; 
   
static PARAM_BLOCK CDPWRMode = 
   { 1 
   , INTEGER_TYPE, 0,    1,    &resultMode  
   };    
   
static PARAM_BLOCK CDPWROrder = 
   { 1 
   , INTEGER_TYPE, 0,    1,    &resultOrder  
   };   
   
static PARAM_BLOCK CDPWStats = 
   { 1 
   , INTEGER_TYPE, 1, 1000,    NULL  
   };    
   
static PARAM_BLOCK CDPWRep = 
   { 3 
   , INTEGER_TYPE, 0,    2,    &repetition
   , INTEGER_TYPE, 0,    2,    &stopCond3
   , INTEGER_TYPE, 0,    2,    &stepMode
   }; 

static PARAM_BLOCK CDPWAsym = 
   { 2 
   , INTEGER_TYPE, 0,    1,    &limitLinesMode   
   , FLOAT_TYPE,   -60.0,  0.0,    NULL 
   };   
   
static PARAM_BLOCK ArraySetting = 
   { 2 
   , INTEGER_TYPE, 0,    1,    &IQType      
   , INTEGER_TYPE, 0,    3,    &measMode
   };    
   
static PARAM_BLOCK OverLev = 
   { 3 
   , FLOAT_TYPE,  -120.0,  7.0,   NULL
   , FLOAT_TYPE,  -20.0,  -7.0,   NULL   
   , FLOAT_TYPE,  -20.0,  -7.0,   NULL   
   }; 
   
static PARAM_BLOCK OverContLev = 
   { 2 
   , FLOAT_TYPE,  -20.0,  -7.0,   NULL   
   , FLOAT_TYPE,  -20.0,  -7.0,   NULL   
   };      
   
static PARAM_BLOCK OverPowCtlBits = 
   { 1 
   , INTEGER_TYPE, 0, 5, &powerCtlBits
   };
   
static PARAM_BLOCK OverCont = 
   { 5 
   , INTEGER_TYPE, 0,    1,      &signalType 
   , INTEGER_TYPE, 1,    1000,   NULL 
   , INTEGER_TYPE, 0,    3,      &repetition
   , INTEGER_TYPE, 0,    2,      &stopCond3
   , INTEGER_TYPE, 0,    2,      &stepMode
   };    
   
static PARAM_BLOCK OverRep = 
   { 4 
   , INTEGER_TYPE, 0,    1,    &signalType 
   , INTEGER_TYPE, 0,    2,    &repetition
   , INTEGER_TYPE, 0,    2,    &stopCond3
   , INTEGER_TYPE, 0,    2,    &stepMode
   };    

static PARAM_BLOCK OverStat = 
   { 2 
   , INTEGER_TYPE, 0,    1,    &signalType 
   , INTEGER_TYPE, 1,    1000, NULL 
   };  

static PARAM_BLOCK OverSBSFreqOffset = 
   { 2 
   , INTEGER_TYPE, 0,           1,       &signalType 
   , INTEGER_TYPE, -2000000,    2000000, NULL 
   };
/* JMG 020923   
static PARAM_BLOCK OverSBSFreqOffset = 
   { 3 
   , INTEGER_TYPE, 0,    1,       &signalType 
   , INTEGER_TYPE, 0,    3,       &acpSelection
   , INTEGER_TYPE, 0,    2000000, NULL 
   };  
*/

static PARAM_BLOCK OverDefault = 
   { 2 
   , INTEGER_TYPE, 0,    1,    &signalType 
   , INTEGER_TYPE, 0,    1,    &enable 
   };  
 // JMG 030113
static PARAM_BLOCK OverLimSymm = 
   { 9
   , INTEGER_TYPE, 0,        1,    &signalType
   , INTEGER_TYPE, 0,        1,    &measMode2   
   , FLOAT_TYPE,   0.0, 1000.0, NULL 
   , FLOAT_TYPE,   0.0,   10.0,   NULL 
   , FLOAT_TYPE,   0.0,    1.0,    NULL 
   , FLOAT_TYPE,  -128,      0, NULL 
   , FLOAT_TYPE,  -128,      0, NULL   
   , FLOAT_TYPE,  -128,      0, NULL   
   , FLOAT_TYPE,  -128,      0, NULL      
   };  
   
static PARAM_BLOCK OverLimSymmEnab = 
   { 9
   , INTEGER_TYPE, 0,    1,    &signalType
   , INTEGER_TYPE, 0,    1,    &measMode2   
   , INTEGER_TYPE, 0,    1,    &enable
   , INTEGER_TYPE, 0,    1,    &enable 
   , INTEGER_TYPE, 0,    1,    &enable 
   , INTEGER_TYPE, 0,    1,    &enable 
   , INTEGER_TYPE, 0,    1,    &enable   
   , INTEGER_TYPE, 0,    1,    &enable   
   , INTEGER_TYPE, 0,    1,    &enable   
   };  
   
static PARAM_BLOCK OverSigType = 
   { 1 
   , INTEGER_TYPE, 0,    1,    &signalType 
   };
   
static PARAM_BLOCK OverEventReport = 
   { 2
   , INTEGER_TYPE, 0,    1,    &signalType
   , INTEGER_TYPE, 0,    4,    &eventReport   
   };  
   
static PARAM_BLOCK CQURep = 
   { 3 
   , INTEGER_TYPE, 0,    2,    &repetition
   , INTEGER_TYPE, 0,    4,    &stopCond2
   , INTEGER_TYPE, 0,    2,    &stepMode
   };    

static PARAM_BLOCK CQUFrame = 
   { 1 
   , INTEGER_TYPE,   1,    10000, NULL
   };   
   
static PARAM_BLOCK CQULimSymm = 
   { 1
   , FLOAT_TYPE,   0.1,    5.0,     NULL 
   };     
   
static PARAM_BLOCK CQUEventReport = 
   { 1
   , INTEGER_TYPE, 0,    4,    &eventReport   
   };     
   
static PARAM_BLOCK FPCHCh = 
   { 1 
   , INTEGER_TYPE, 1,  7, NULL
   };
   
static PARAM_BLOCK BSPowerCtrlBits =
   { 1
   // JMG 020923, INTEGER_TYPE, 0, 5, &powerContrlBitMode
   , INTEGER_TYPE, 0, 5, &powerCtlBits
   };

static PARAM_BLOCK IDNumber = 
   { 1 
   , INTEGER_TYPE, 0, 65535, NULL  
   };     
   
static PARAM_BLOCK ProtocolRevision = 
   { 1 
   , INTEGER_TYPE, 1,  6, NULL
   };

static PARAM_BLOCK TimerBase = 
   { 1 
   , FLOAT_TYPE, 0.0,  199515.84, NULL
   };   
   
static PARAM_BLOCK pagingChannelRate = 
   { 1 
   , INTEGER_TYPE, 0,  2, &pagingChanRate
   };   
   
static PARAM_BLOCK SlotCycleIndex = 
   { 1 
   , INTEGER_TYPE, 0,  7,  NULL
   };   
   
static PARAM_BLOCK GatedOutEvtReport = 
   { 1 
   , INTEGER_TYPE, 0, 4, &eventReport
   };

static PARAM_BLOCK ConfCDMAPowLvl = 
   { 1 
   , FLOAT_TYPE, -3000.0, 3000.0, NULL
   }; 
   

static PARAM_BLOCK ConfGatedScope = 
   { 5 
   , INTEGER_TYPE, 0, 1,     &resultMode
   , INTEGER_TYPE, 1, 1000,  NULL
   , INTEGER_TYPE, 0, 3,     &repetition
   , INTEGER_TYPE, 0, 2,     &stopCond3
   , INTEGER_TYPE, 0, 2,     &stepMode
   };   
   

static PARAM_BLOCK ConfRfgImp = 
   { 3 
   , FLOAT_TYPE, -20.0,  4.0,   NULL
   , FLOAT_TYPE, -50.0,  50.0,  NULL
   , INTEGER_TYPE, 0,    1,     &signalType   
   };

static PARAM_BLOCK RfgImp2 = 
   { 2  
   , FLOAT_TYPE, -20.0,  4.0,   NULL
   , FLOAT_TYPE, -50.0,  50.0,  NULL
   };
 
static PARAM_BLOCK ConfGatedRep = 
   { 3 
   , INTEGER_TYPE, 0, 3, &repetition
   , INTEGER_TYPE, 0, 1, &stopCond
   , INTEGER_TYPE, 0, 2, &stepMode
   };   
   
static PARAM_BLOCK ConfOutLvl = 
   { 4 
   , FLOAT_TYPE, -120.0, 7.0, NULL
   , FLOAT_TYPE, -20.0,  -7.0, NULL
   , FLOAT_TYPE, -20.0,  -7.0, NULL
   , INTEGER_TYPE, 0,  1,      &signalType
   };

static PARAM_BLOCK ConfRFGenpcb = 
   { 1 
   , INTEGER_TYPE, 0, 5, &powerCtlBits
   };
   
static PARAM_BLOCK ConfOLTimeResLev = 
   { 3 
   , FLOAT_TYPE, -20.0, -7.0, NULL
   , FLOAT_TYPE, -20.0, -7.0, NULL
   , INTEGER_TYPE, 0,   1,    &signalType     
   };
   
static PARAM_BLOCK ConfMaxOutLev = 
   { 4 
   , FLOAT_TYPE, -120.0, 7.0, NULL
   , FLOAT_TYPE, -20.0,  -7.0,  NULL
   , FLOAT_TYPE, -20.0,  -7.0,  NULL
   , INTEGER_TYPE, 0,   1,    &signalType  
   };
   
static PARAM_BLOCK ConfGatedLev = 
   { 3 
   , FLOAT_TYPE, -3000,  3000,  NULL
   , FLOAT_TYPE, -20.0,  -7.0,  NULL
   , FLOAT_TYPE, -20.0,  -7.0,  NULL
   };

static PARAM_BLOCK CPScope =
   { 5 
   , INTEGER_TYPE, 1, 1000, NULL
   , INTEGER_TYPE, 0, 3,    &repetition
   , INTEGER_TYPE, 0, 2,    &stopCond3
   , INTEGER_TYPE, 0, 2,    &stepMode
   , INTEGER_TYPE, 0, 1,    &signalType
   };

static PARAM_BLOCK ConfMinOutStat = 
   { 2
   , INTEGER_TYPE, 1, 1000, NULL
   , INTEGER_TYPE, 0, 1,    &signalType         
   };

static PARAM_BLOCK ConfSignalRep = 
   { 4 
   , INTEGER_TYPE, 0, 3,     &repetition
   , INTEGER_TYPE, 0, 2,     &stopCond3
   , INTEGER_TYPE, 0, 2,     &stepMode
   , INTEGER_TYPE, 0, 1,     &signalType
   };

static PARAM_BLOCK CDMAPow = 
   { 2
   , FLOAT_TYPE,   -120.0, 7.0, NULL
   , INTEGER_TYPE, 0,      1,    &signalType   
   };

static PARAM_BLOCK DefPowMinCont = 
   { 2
   , INTEGER_TYPE, 0, 2, &modeEnable
   , INTEGER_TYPE, 0, 1, &signalType
   };

static PARAM_BLOCK SigType =
   { 1
   , INTEGER_TYPE, 0, 1, &signalType
   };

static PARAM_BLOCK LimitLevel = 
   { 3
   , FLOAT_TYPE, -128.0, 0.0,   NULL
   , FLOAT_TYPE, 0.0,    0.944, NULL
   , INTEGER_TYPE, 0, 1, &signalType       
   };
   
static PARAM_BLOCK LimitLevel2 = 
   { 5  
   , FLOAT_TYPE, 0.0,  128.0,   NULL
   , FLOAT_TYPE, 0.0,    1.0, NULL
   , INTEGER_TYPE, 0, 1, &signalType       
   , FLOAT_TYPE, 0.0, 128.0, NULL
   , FLOAT_TYPE, -128.0, 10.0, NULL
   };   
   
static PARAM_BLOCK  RMode3 =
   { 1
   , INTEGER_TYPE,  0,   1,  &resultMode   
   };
   
static PARAM_BLOCK StatMode =
   { 1
   , INTEGER_TYPE,  0,  1000,  NULL   
   };

static PARAM_BLOCK SubArrayMode =
   {3
   , INTEGER_TYPE,  0,     4,  &gateMode 
   , FLOAT_TYPE,    -100,  1400, NULL
   , INTEGER_TYPE,  0,     1664, NULL
   };
   
static PARAM_BLOCK GatedContLevel =
   { 2
   , FLOAT_TYPE,  -20.0,   -7.0,  NULL
   , FLOAT_TYPE,  -20.0,   -7.0,  NULL
   };   

static PARAM_BLOCK DefGateCont = 
   { 1
   , INTEGER_TYPE, 0, 2, &modeEnable
   };

static PARAM_BLOCK MeasSubArray = 
   { 1
   , INTEGER_TYPE, 0, 3, &measMode
   };

static PARAM_BLOCK ModQualStat = 
   { 2
   , INTEGER_TYPE, 0, 1000, NULL
   , INTEGER_TYPE, 0, 2,    &signalType2
   };

static PARAM_BLOCK ModQualRep = 
   { 4
   , INTEGER_TYPE, 0, 3,     &repetition
   , INTEGER_TYPE, 0, 2,     &stopCond3 
   , INTEGER_TYPE, 0, 2,     &stepMode
   , INTEGER_TYPE, 0, 2,     &signalType2
   };

static PARAM_BLOCK ModQualSban = 
   { 2
   , FLOAT_TYPE,   0.0,   2000000.0, NULL
   , INTEGER_TYPE, 0,     2,         &signalType2
   };

static PARAM_BLOCK ModQualDefCont = 
   { 2
   , INTEGER_TYPE, 0, 1, &enable   
   , INTEGER_TYPE, 0, 2, &signalType2
   };

static PARAM_BLOCK ModQualLimit = 
   { 7
   , FLOAT_TYPE,   0.0,  1.0,   NULL                   
   , INTEGER_TYPE, 0,    1000,  NULL
   , FLOAT_TYPE,   0.0,  10.0,  NULL
   , INTEGER_TYPE, -120.0, -20, NULL
   , INTEGER_TYPE, -128.0, 0.0, NULL
   , INTEGER_TYPE, 0,    2,     &signalType2
   , INTEGER_TYPE, 0,    1,     &measMode2
   };
     
static PARAM_BLOCK DefModQualLimit = 
   { 3  
   , INTEGER_TYPE, 0,  1,     &enable
   , INTEGER_TYPE, 0,  2,     &signalType2
   , INTEGER_TYPE, 0,  1,     &measMode2
   };

static PARAM_BLOCK ModStandard =
   {1
   , INTEGER_TYPE, 0,  2,  &signalType2
   };
   
static PARAM_BLOCK ModQualErep =
   {2
   , INTEGER_TYPE, 0,  4,  &eventReport
   , INTEGER_TYPE, 0,  2,  &signalType2
   };

static PARAM_BLOCK ModOempLev =
   {4
   , FLOAT_TYPE,   -120.0,  7.0,  NULL
   , FLOAT_TYPE,   -20.0 ,  -7.0, NULL 
   , FLOAT_TYPE,   -20.0 ,  -7.0, NULL 
   , INTEGER_TYPE, 0,       1,    &signalType
   };  
   
static PARAM_BLOCK ModOempCDMA =
   {2
   , FLOAT_TYPE,   -120.0,  7.0,  NULL
   , INTEGER_TYPE, 0,       1,    &signalType
   }; 
   
static PARAM_BLOCK ModOempContLev =
   {3
   , FLOAT_TYPE,   -20.0 ,  -7.0, NULL 
   , FLOAT_TYPE,   -20.0 ,  -7.0, NULL 
   , INTEGER_TYPE, 0,       2,    &signalType2
   };    
   
static PARAM_BLOCK ModImp =
   {3
   , FLOAT_TYPE,   -20.0,   4.0,  NULL 
   , FLOAT_TYPE,   -50.0,   50.0, NULL 
   , INTEGER_TYPE, 0,       1,    &signalType
   };            
   
static PARAM_BLOCK ModOempVal = 
   { 13
   , FLOAT_TYPE,     0,      100.0,  NULL
   , FLOAT_TYPE,     0,      100.0,  NULL
   , FLOAT_TYPE,     0,      100.0,  NULL
   , FLOAT_TYPE,     0,      100.0,  NULL
   , FLOAT_TYPE,     0,      45.0,   NULL
   , FLOAT_TYPE,     0,      45.0,   NULL
   , FLOAT_TYPE,     -120.0, -20.0,  NULL
   , FLOAT_TYPE,     -120.0, -20.0,  NULL
   , FLOAT_TYPE,     0,      1000.0, NULL
   , FLOAT_TYPE,     0.0,    10.0,   NULL
   , FLOAT_TYPE,     0,      1.0,    NULL
   , INTEGER_TYPE,   0,      1,      &measMode2 
   , INTEGER_TYPE,   0,      1,      &signalType
   };   
   
static PARAM_BLOCK ModOempEnable = 
   { 13
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &enable
   , INTEGER_TYPE,   0,      1,      &measMode2
   , INTEGER_TYPE,   0,      1,      &signalType     
   };           
   
static PARAM_BLOCK ModDef = 
   { 2  
   , INTEGER_TYPE, 0, 1, &enable
   , INTEGER_TYPE, 0, 1, &signalType   
   };   
   
static PARAM_BLOCK ModMQualCont = 
   { 5
   , INTEGER_TYPE, 0, 1000,  NULL    
   , INTEGER_TYPE, 0, 3,     &repetition
   , INTEGER_TYPE, 0, 2,     &stopCond3
   , INTEGER_TYPE, 0, 2,     &stepMode
   , INTEGER_TYPE, 0, 2,     &signalType2
   };   

static PARAM_BLOCK ConfModCont  = 
   { 7
   , INTEGER_TYPE, 0, 1,     &resultMode          
   , INTEGER_TYPE, 0, 1000,  NULL    
   , INTEGER_TYPE, 0, 3,     &repetition
   , INTEGER_TYPE, 0, 2,     &stopCond3         
   , INTEGER_TYPE, 0, 2,     &stepMode
   , INTEGER_TYPE, 0, 3,     &measType 
   , INTEGER_TYPE, 0, 1,     &signalType         
   };    

static PARAM_BLOCK ModRmod  = 
   { 3
   , INTEGER_TYPE, 0, 1,  &resultMode    
   , INTEGER_TYPE, 0, 3,  &measType
   , INTEGER_TYPE, 0, 1,  &signalType
   };    
  
static PARAM_BLOCK ConfModStat  = 
   { 3
   , INTEGER_TYPE, 0, 1000,  NULL    
   , INTEGER_TYPE, 0, 3,  &measType
   , INTEGER_TYPE, 0, 1,  &signalType
   };   
   
static PARAM_BLOCK ConfModRep  = 
   { 5
   , INTEGER_TYPE, 0, 3,     &repetition
   , INTEGER_TYPE, 0, 2,     &stopCond3
   , INTEGER_TYPE, 0, 2,     &stepMode
   , INTEGER_TYPE, 0, 3,     &measType 
   , INTEGER_TYPE, 0, 1,     &signalType
   };    
   
static PARAM_BLOCK ConfSubMod  = 
   { 5
   , INTEGER_TYPE, 0, 3,     &gateMode
   , INTEGER_TYPE, 0, 406,   NULL
   , INTEGER_TYPE, 0, 500,   NULL 
   , INTEGER_TYPE, 0, 3,     &measType 
   , INTEGER_TYPE, 0, 1,     &signalType
   };   
   
static PARAM_BLOCK ModOverStandard  = 
   { 2
   , INTEGER_TYPE, 0, 3,     &measType 
   , INTEGER_TYPE, 0, 1,     &signalType
   };    
   
static PARAM_BLOCK ModErep  = 
   { 3
   , INTEGER_TYPE, 0,  4,     &eventReport  
   , INTEGER_TYPE, 0,  3,     &measType 
   , INTEGER_TYPE, 0,  1,     &signalType
   };   

static PARAM_BLOCK ModOverStandard2  = 
   { 3
   , INTEGER_TYPE, 0, 2,     &measMode3
   , INTEGER_TYPE, 0, 3,     &measType 
   , INTEGER_TYPE, 0, 1,     &signalType
   };  
   
static PARAM_BLOCK ConfServ  = 
   { 1
   , INTEGER_TYPE, 0, 3,     &service
   };     
   
static PARAM_BLOCK ConfLoopServ   = 
   { 1
   , INTEGER_TYPE, 0, 5,     &serviceOption2
   };   
  
static PARAM_BLOCK LoopRC  = 
   { 3
   , INTEGER_TYPE, 1, 5,    NULL
   , INTEGER_TYPE, 1, 4,    NULL
   , INTEGER_TYPE, 0, 5,    &serviceOption2  
   };   
   
static PARAM_BLOCK LoopFrat  = 
   { 2
   , INTEGER_TYPE, 0, 4,    &frameRateType
   , INTEGER_TYPE, 0, 5,    &serviceOption2  
   };   
   
static PARAM_BLOCK ConfLoopPattern  = 
   { 2
   , INTEGER_TYPE, 0, 2,    &patternGen
   , INTEGER_TYPE, 0, 5,    &serviceOption2  
   };   
   
static PARAM_BLOCK ConfSpeServ  = 
   { 1
   , INTEGER_TYPE, 0, 5,    &serviceOption  
   };  

static PARAM_BLOCK SpeechRC  = 
   { 3
   , INTEGER_TYPE, 1, 5,    NULL
   , INTEGER_TYPE, 1, 4,    NULL
   , INTEGER_TYPE, 0, 5,    &serviceOption  
   }; 
   
static PARAM_BLOCK BSSChannel  = 
   { 1
   , INTEGER_TYPE, 0, 2047,    NULL
   };   
   
static PARAM_BLOCK ProcFFCHLevel  = 
   { 1
   , FLOAT_TYPE, -20.0, 7.0,  NULL
   };   
   
static PARAM_BLOCK ProcFFCHChannel  = 
   { 1
   , INTEGER_TYPE, 0, 63,  NULL
   };   
   
static PARAM_BLOCK ProcFFCHOffset  = 
   { 1
   , INTEGER_TYPE, 0, 15,  NULL
   };   
   
static PARAM_BLOCK ProcFPCHLev  = 
   { 2
   , FLOAT_TYPE, -20.0, -7.0,  NULL
   , INTEGER_TYPE, 0, 1, &enable
   };   
   
static PARAM_BLOCK ProcFPCHChan = 
   { 1
   , INTEGER_TYPE, 1, 7,  NULL
   };   
   
static PARAM_BLOCK ProcPNOffset = 
   { 1
   , INTEGER_TYPE, 0, 511,  NULL
   };   
   
static PARAM_BLOCK NPowRep =
   { 3
   , INTEGER_TYPE, 1, 10000,     NULL   
   , INTEGER_TYPE, 0, 2,     &stopCond3
   , INTEGER_TYPE, 0, 2,     &stepMode
   };

static PARAM_BLOCK NEPow = 
   { 1
   // JMG 020930, INTEGER_TYPE, -100, 10,  NULL
   , INTEGER_TYPE, 1024, 32768,  NULL
   };

static PARAM_BLOCK EventReport = 
   { 1 
   , INTEGER_TYPE, 0, 4, &eventReport
   };

static PARAM_BLOCK RQFrameCount = 
   { 2
   , INTEGER_TYPE, 1, 5,     NULL
   , INTEGER_TYPE, 1, 10000, NULL
   };

static PARAM_BLOCK RQRep = 
   { 4
   , INTEGER_TYPE, 1, 5,     NULL
   , INTEGER_TYPE, 0, 3,     &repetition
   , INTEGER_TYPE, 0, 4,     &stopCond2
   , INTEGER_TYPE, 0, 2,     &stepMode
   };

static PARAM_BLOCK RQMFerLim = 
   { 2
   , INTEGER_TYPE, 1, 5,     NULL    
   , FLOAT_TYPE, 0.1, 50.0,  NULL
   };

static PARAM_BLOCK RQMCLev = 
   { 2
   , INTEGER_TYPE, 1,    5,     NULL    
   , FLOAT_TYPE,   85.0, 99.99,  NULL
   };
   
static PARAM_BLOCK RQTsetLev = 
   { 4
   , INTEGER_TYPE, 1,     5,   NULL
   , FLOAT_TYPE,  -20.0,  7.0, NULL
   , FLOAT_TYPE,  -20.0,  7.0, NULL    
   , FLOAT_TYPE,  -20.0,  7.0, NULL   
   };

static PARAM_BLOCK RQCDMAPow = 
   { 2
   , INTEGER_TYPE, 1,     5,   NULL               
   , FLOAT_TYPE, -120.0, 7.0,  NULL
   };

static PARAM_BLOCK RQPilotLev = 
   { 2
   , INTEGER_TYPE, 1,     5,   NULL 
   , FLOAT_TYPE, -20.0,  -7.0, NULL              
   };

static PARAM_BLOCK RQFCHLev = 
   { 2
   , INTEGER_TYPE, 1,     5,   NULL  
   , FLOAT_TYPE, -20.0,  -7.0, NULL              
   };

static PARAM_BLOCK RQTsetImp = 
   { 3
   , INTEGER_TYPE, 1,     5,   NULL             
   , FLOAT_TYPE,  -20.0,  4.0,  NULL    
   , FLOAT_TYPE,  -50.0,  50.0, NULL    
   };

static PARAM_BLOCK RQFrameRate =
   { 2
   , INTEGER_TYPE, 1, 5,   NULL                    
   , INTEGER_TYPE, 0, 5,   &frameRateType   
   };

static PARAM_BLOCK RfanFOFF =
   { 1
   , FLOAT_TYPE, -50.0, 50.0,  NULL  
   };   
   
static PARAM_BLOCK  ConfPCG  =  
   { 1
   , INTEGER_TYPE, 1, 200,  NULL  
   };

static PARAM_BLOCK HandOff = 
   { 1
   , INTEGER_TYPE, 0, 10, NULL
   };
 
static PARAM_BLOCK VoiceCoder = 
   { 2
   , INTEGER_TYPE, 0, 5, &serviceOption
   , INTEGER_TYPE, 0, 12, &voiceCoder
   };

static PARAM_BLOCK QPCHUsageMode = 
   { 1
   , INTEGER_TYPE, 0, 1, &enable   
   };
// JMG 030109 
static PARAM_BLOCK QPCHLev =
   { 1
   , FLOAT_TYPE, -20.0, -1.0, NULL
   };
  
static PARAM_BLOCK QPCH =
   { 1
   , INTEGER_TYPE, 1, 7, NULL
   };
   
static PARAM_BLOCK IndicatorBit =
   { 1
   , INTEGER_TYPE, 0, 1, &indicatorBit
   };
   
static PARAM_BLOCK DUTPagingMode =
   { 1
   , INTEGER_TYPE, 0, 1, &enable   
   };
 
static PARAM_BLOCK CallLossDetectTime =
   { 1
   , FLOAT_TYPE, 0.1, 5.0, NULL
   };
   
static PARAM_BLOCK TDATComRC  = 
   { 3
   , INTEGER_TYPE, 0, 5,    &serviceOption2     
   , INTEGER_TYPE, 1, 5,    NULL
   , INTEGER_TYPE, 1, 5,    NULL
   }; 
   
static PARAM_BLOCK TDATpgen = 
   { 3
   , INTEGER_TYPE, 0, 5,    &serviceOption2
   , INTEGER_TYPE, 0, 1,    &direction
   , INTEGER_TYPE, 0, 2,    &patternGen
   };
 
static PARAM_BLOCK TDATconf =
   { 2
   , INTEGER_TYPE, 0, 5,    &serviceOption2
   , INTEGER_TYPE, 0, 1,    &direction
   };
   
static PARAM_BLOCK TDATCBFrame =
   { 3
   , INTEGER_TYPE, 0, 5,    &serviceOption2
   , INTEGER_TYPE, 0, 1,    &direction
   , INTEGER_TYPE, 1, 255,  NULL
   }; 
   
static PARAM_BLOCK TDATtxonoff =
   { 3
   , INTEGER_TYPE, 0, 5,    &serviceOption2
   , INTEGER_TYPE, 0, 1,    &direction
   , INTEGER_TYPE, 0, 255,  NULL
   };
   
static PARAM_BLOCK TDATSchEnable =
   { 3
   , INTEGER_TYPE, 0, 5,    &serviceOption2
   , INTEGER_TYPE, 0, 1,    &direction
   , INTEGER_TYPE, 0, 1,    &enable
   };
  
static PARAM_BLOCK AccessProbeMode =
   { 1
   , INTEGER_TYPE, 0, 2,    &accessProbeMode
   };

static PARAM_BLOCK NominalOffsetPower =
   { 1
   , FLOAT_TYPE, -24.0, -7.0, NULL
   };

static PARAM_BLOCK InitialPowerOffset = 
   { 1
   , FLOAT_TYPE, -16.0, 15.0, NULL
   };

static PARAM_BLOCK PowerIncrement =
   { 1
   , FLOAT_TYPE, 0.0, 7.0, NULL
   };

static PARAM_BLOCK ProbesPerSequence =
   { 1
   , INTEGER_TYPE, 0, 15, NULL
   };
 
static PARAM_BLOCK ProbeSequence = 
   { 1
   , INTEGER_TYPE, 1, 15, NULL
   };
   
static PARAM_BLOCK RxIQSwapEnab  =
   { 1
   , INTEGER_TYPE, 0, 2, &modeEnable
   };

static PARAM_BLOCK GainMultiplier =
   { 1
   , INTEGER_TYPE, 0, 16, NULL
   };

static PARAM_BLOCK TimingControl =
   { 1
   , INTEGER_TYPE, 0, 15, NULL
   };  

static PARAM_BLOCK QuasiOrthogonal =
   { 1
   , INTEGER_TYPE, 0, 3, NULL
   }; 
static PARAM_BLOCK ConfidenceLevelExt =
   { 1
   , INTEGER_TYPE, 0, 2, &modeEnable
   };
static PARAM_BLOCK MaxFERLimit =
   { 1
   , INTEGER_TYPE, 0.10, 50.0, NULL
   };
static PARAM_BLOCK MinConfidenceLevel =
   { 1
   , INTEGER_TYPE, 85.0, 99.9, NULL
   };
static PARAM_BLOCK SidebandSuppressionExt = 
   { 2 
   , INTEGER_TYPE, 0,    1,    &signalType 
   , INTEGER_TYPE, 0,    2,    &modeEnable 
   };  
static PARAM_BLOCK OverviewLimit = 
   { 2 
   , INTEGER_TYPE, 0, 1, &enable
   , INTEGER_TYPE, 0, 1, &signalType   
   };     
// JMG 030110   
static PARAM_BLOCK TriggerOutputRouting =
   { 1  
   , INTEGER_TYPE, 2, 5, NULL
   , INTEGER_TYPE, 0, 6, &triggerOutputRouting  
   };
   
static PARAM_BLOCK ConfWpowCont = 
   { 3 
   , INTEGER_TYPE, 0,    2,    &repetition
   , INTEGER_TYPE, 0,    1,    &stopCond
   , INTEGER_TYPE, 0,    1,    &stepMode
   }; 

static PARAM_BLOCK SidebandSuppressionExt1 = 
   { 2 
   , INTEGER_TYPE, 0,    2,    &signalType2 
   , INTEGER_TYPE, 0,    2,    &modeEnable 
   };
   
static PARAM_BLOCK OverSBSFreqOffset1 = 
   { 2 
   , INTEGER_TYPE, 0,           2,       &signalType2 
   , INTEGER_TYPE, -2000000,    2000000, NULL 
   };   
   
static PARAM_BLOCK ModMquLimlevel =
   { 10
   , INTEGER_TYPE, 0,      2,    &signalType2
   , INTEGER_TYPE, 0,      1,    &measMode2   
   , FLOAT_TYPE,   0.0,    1.0,     NULL 
   , FLOAT_TYPE,   0.0,    1000.0,  NULL
   , FLOAT_TYPE,   0.0,    1E6,     NULL 
   , FLOAT_TYPE, -120.0, -20.0,     NULL 
   , FLOAT_TYPE, -128.0,   0.0,     NULL 
   , FLOAT_TYPE, -128.0,   0.0,     NULL   
   , FLOAT_TYPE, -128.0,   0.0,     NULL   
   , FLOAT_TYPE, -128.0,   0.0,     NULL      
   };  
   
static PARAM_BLOCK ModMquLimEnab = 
   { 11
   , INTEGER_TYPE, 0,    2,    &signalType2
   , INTEGER_TYPE, 0,    1,    &measMode2   
   , INTEGER_TYPE, 0,    1,    &enable
   , INTEGER_TYPE, 0,    1,    &enable 
   , INTEGER_TYPE, 0,    1,    &enable 
   , INTEGER_TYPE, 0,    1,    &enable 
   , INTEGER_TYPE, 0,    1,    &enable   
   , INTEGER_TYPE, 0,    1,    &enable   
   , INTEGER_TYPE, 0,    1,    &enable   
   , INTEGER_TYPE, 0,    1,    &enable   
   , INTEGER_TYPE, 0,    1,    &enable   
   };  
   
static PARAM_BLOCK PreRoutingPath =        
   { 1
   , INTEGER_TYPE, 0,    7,    &routingPath
   };
   
static PARAM_BLOCK RQTestSetEnable =
   {2
   , INTEGER_TYPE, 1, 5, NULL  
   , INTEGER_TYPE, 0, 1, &enable
   };
   
static PARAM_BLOCK RQTestSet =
   {1
   , INTEGER_TYPE, 1, 5, NULL  
   };

static PARAM_BLOCK RQSch0Level =
   {2
   , INTEGER_TYPE, 1, 5, NULL  
   , FLOAT_TYPE, -20, -7.0, NULL
   };
// JMG 030115   
static PARAM_BLOCK RQFpcCont = 
   { 4
   , INTEGER_TYPE, 0, 1000,  NULL    
   , INTEGER_TYPE, 0, 2,     &repetition
   , INTEGER_TYPE, 0, 4,     &stopCond2
   , INTEGER_TYPE, 0, 2,     &stepMode
   };
   
static PARAM_BLOCK RQFpcStat =
   { 1
   , INTEGER_TYPE, 0, 1000,  NULL   
   };
   
static PARAM_BLOCK RQFpcRep = 
   { 3
   , INTEGER_TYPE, 0, 3,     &repetition
   , INTEGER_TYPE, 0, 4,     &stopCond2
   , INTEGER_TYPE, 0, 2,     &stepMode
   };   
   
static PARAM_BLOCK RQFpcMode =
   { 1
   , INTEGER_TYPE, 0, 2,  NULL   
   };   

static PARAM_BLOCK RQFpcRDelay =
   { 1
   , INTEGER_TYPE, 0, 124,  NULL   
   };  
   
static PARAM_BLOCK RQFpcRFrame =
   { 1
   , INTEGER_TYPE, 5, 905,  NULL   
   };   

static PARAM_BLOCK RQFpcTFer =
   { 1
   , FLOAT_TYPE, 0.2, 30.0,  NULL   
   };   

static PARAM_BLOCK RQFpcLSLSetup =
   { 1
   , FLOAT_TYPE, 0.0, 31.625,  NULL   
   };   

static PARAM_BLOCK RQFpcDLMode =
   { 1
   , INTEGER_TYPE, 0, 2,  &modeEnable   
   };   

static PARAM_BLOCK RQFpcUSLSetup =
   { 1
   ,  FLOAT_TYPE, 0.0, 31.750,  NULL   
   };   

static PARAM_BLOCK PilotPowLvl =
   { 1
   , FLOAT_TYPE, -20.0, -7.0,  NULL   
   }; 
 
static PARAM_BLOCK FCHLvl =
   { 1
   , FLOAT_TYPE, -20.0, -7.0,  NULL   
   }; 

static PARAM_BLOCK Sch0Lvl =
   { 1
   , FLOAT_TYPE, -20.0, -7.0,  NULL   
   };  

static PARAM_BLOCK RQFpcImpAwgnLevel =
  { 2
  , FLOAT_TYPE, -20.0, +4.0,  NULL   
  , FLOAT_TYPE, -3000.0, 3000.0,  NULL   
  };

static PARAM_BLOCK EchoDelay = 
   { 2 
   , INTEGER_TYPE, 0, 5, &serviceOption
   , INTEGER_TYPE, 0.04, 5.0, NULL
   };  

static PARAM_BLOCK SMSEnable =
   { 1
   , INTEGER_TYPE, 0, 2,  &modeEnable   
   };   
   
static PARAM_BLOCK WMTOption =
   { 1
   , INTEGER_TYPE, 0, 1,  &serviceOption3   
   };     

static PARAM_BLOCK WMTFchRc =
   {3
   , INTEGER_TYPE, 0, 1,  &serviceOption3    
   , INTEGER_TYPE, 1, 4,  NULL
   , INTEGER_TYPE, 1, 3,  NULL  
   };

static PARAM_BLOCK URData =
   { 1
   , INTEGER_TYPE, 0, 2,  &modeEnable   
   };  
   
static PARAM_BLOCK TriggerSource =
   { 1
   , INTEGER_TYPE, 0, 1,  &trigSourType   
   };     

static PARAM_BLOCK MMIPAddr =
   { 1
   , INTEGER_TYPE, 0, 255,  NULL 
   , INTEGER_TYPE, 0, 255,  NULL   
   , INTEGER_TYPE, 0, 255,  NULL      
   , INTEGER_TYPE, 0, 255,  NULL      
   }; 
   
static PARAM_BLOCK DefModOverStandard  = 
   { 3
   , INTEGER_TYPE, 0, 3,     &measType 
   , INTEGER_TYPE, 0, 1,     &signalType
   , INTEGER_TYPE, 0, 1,     &enable
   };      
   
static PARAM_BLOCK SigFrame  = 
   { 2
   , INTEGER_TYPE, 0, 1,     &signalType
   , INTEGER_TYPE, 0, 4,     &frameRateType
   };  
   
static PARAM_BLOCK LimAVal  = 
   { 1
   , FLOAT_TYPE, 1, 10,    NULL
   };        

static PARAM_BLOCK RefBLimVal  = 
   { 1
   , FLOAT_TYPE, 1240, 1266,    NULL
   }; 
   
static PARAM_BLOCK LimBVal  = 
   { 1
   , FLOAT_TYPE, 1, 10,    NULL
   };        

static PARAM_BLOCK LimCVal  = 
   { 1
   , INTEGER_TYPE, -20.0, -1.0,    NULL
   };    

static PARAM_BLOCK LimDRelVal  = 
   { 1
   , INTEGER_TYPE, -25.0, 10.0,    NULL
   };        

static PARAM_BLOCK LimDAbsVal  = 
   { 1
   , INTEGER_TYPE, -70.0, 0.0,    NULL
   };    
   
static PARAM_BLOCK RefELimVal  = 
   { 1
   , FLOAT_TYPE, 0, 5,    NULL
   };    
   
static PARAM_BLOCK LimEVal  = 
   { 1
   , FLOAT_TYPE, 1240, 1260,    NULL
   };     
   
static PARAM_BLOCK PowGoutLimVal  = 
   { 8
   , INTEGER_TYPE, 1,     10,   NULL
   , INTEGER_TYPE, 1240,  1266, NULL
   , INTEGER_TYPE, 1,     10,   NULL      
   , INTEGER_TYPE, -20.0, -1.0, NULL 
   , INTEGER_TYPE, -25.0, 10.0, NULL       
   , INTEGER_TYPE, -70.0, 0.0,  NULL  
   , INTEGER_TYPE, 0,     5,    NULL 
   , INTEGER_TYPE, 1240,  1260, NULL      
   }; 
   
static PARAM_BLOCK FrameRate  =     
   { 1 
   , INTEGER_TYPE, 0, 4, &frameRateType
   };     
// JMG 030117
static char *SRS[]=
   {"CFM" ,"RFM","LORL","MREG","MINV","AMES","RFNS","MDER","RMES","FCH","PREP","RFIO","RFIU","XTND","E14","E15","NONE"
   };
   
//********************************************************************
// Rohde & Schwarz CMU Command Table for CDMA2000 
//*********************************************************************

COMMAND_INFO CDMA[] =
{ 
  /* 000 */     " ",                                                                  
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL
  /* 001 */   , "INP %s",                                                                  
                   NULL,           
                   NULL,
                   NULL,       
                   &Input,       
                   NULL
  /* 002 */   , "OUTP %s",                                                                 
                   NULL,           
                   NULL,
                   NULL,       
                   &Output,       
                   NULL
  /* 003 */   , "SENS:CORR:LOSS:INP%s %lf", //JMG 020917
                   NULL,           
                   NULL,
                   NULL,       
                   &InpAtt,       
                   NULL
  /* 004 */   , "SOUR:CORR:LOSS:INP%s %lf", //JMG 020917                                        
                   NULL,           
                   NULL,
                   NULL,       
                   &InpAtt,       
                   NULL
  /* 005 */   , "SENS:CORR:LOSS:OUTP%s %lf", //JMG 020917                                        
                   NULL,           
                   NULL,
                   NULL,       
                   &OutpAtt,       
                   NULL
  /* 006 */   , "SOUR:CORR:LOSS:OUTP%s %lf", //JMG 020917                                       
                   NULL,           
                   NULL,
                   NULL,       
                   &OutpAtt,       
                   NULL
  /* 007 */   , "SOURCE:DM:CLOCK:STATE %s",                                                  
                   NULL,           
                   NULL,
                   NULL,       
                   &ClkMode,       
                   NULL 
  /* 008 */   , "SOURCE:DM:CLOCK:FREQ %s",                                              
                   NULL,           
                   NULL,
                   NULL,       
                   &DmClkFreq,       
                   NULL 
  /* 009 */   , "SENS:LEV:MODE %s",                                                       
                   NULL,           
                   NULL,
                   NULL,       
                   &InpLvl,      
                   NULL
  /* 010 */   , "SENS:LEV:MAX %lf",  
                   NULL,           
                   NULL,
                   NULL,       
                   &MaxLvl,      
                   NULL
  /* 011 */   ,  "SENS:LEV:DEFAULT %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL
  /* 012 */   , "SENS:LEV:ATT %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &AttLvl,      
                   NULL
  /* 013  */ , "TRIG:SEQ:SOUR:OQPSK %s",  
                   NULL,
                   NULL,
                   NULL,
                   &TrigSour,
                   NULL   
  /* 014  */ , "TRIG:SEQ:SOUR:HPSK %s",  
                   NULL,
                   NULL,
                   NULL,
                   &TrigSour,
                   NULL          
  /* 015  */ , "TRIG:SEQ:SOUR:QPSK %s",  
                   NULL,
                   NULL,
                   NULL,
                   &TrigSour,
                   NULL   
  /* 016 */   , "SOUR:INT:AWGN:BAND %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &AWGNBandwidth,       
                   NULL                    
  /* 017 */   , "DEF:INT %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL                    
  /* 018 */   , "CONF:EXT:MMON:ENAB %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL                    
  /* 019 */   , "DEF:EXT %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL                    
  /* JMG 030110 020    , "SENS:RFAN:FREQ:UNIT CH;:SENS:RFAN:FREQ %d",  */
  /* 020 */   , "RFAN:FREQ:UNIT CH;:RFAN:FREQ %d",  
                   NULL,
                   NULL,
                   NULL,       
                   &RFChan,       
                   NULL
  /* JMG 030110 021    , "SENS:RFAN:FREQ:UNIT MHZ;:  %lf",   */
  /* 021 */   , "RFAN:FREQ:UNIT MHZ;:RFAN:FREQ %lf",  
                   NULL,           
                   NULL,
                   NULL,       
                   &FreqChan,      
                   NULL
  // JMG 030110
  /* 022 */  ,  "RFAN:FOFF %1f KHZ;:RFAN:FOFF %s",
                   NULL,
                   NULL,
                   NULL,
                   &RfanFOFF,
                   NULL
  /* 023 */  , "CONF:MOD:CONT %s, %s, %s",  
                   NULL,
                   NULL,
                   NULL,
                   &RfanModScope,
                   NULL
  /* 024 */  , "CONF:MOD:CONT:STAT %d",  
                   NULL,
                   NULL,
                   NULL,
                   &RfanModStat,
                   NULL    
  /* 025 */  , "CONF:MOD:CONT:REP %s, %s, %s",  
                   NULL,
                   NULL,
                   NULL,
                   &RfanModRep,
                   NULL 
  /* 026 */  , "DEF:MOD:CONT %s",  
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL 
  /* 027 */  , "CONFIGURE:MODULATION:LIMIT:SCALAR:SYMMETRIC:COMBINED:VALUE %lf, %lf, %lf, %lf, %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   &ModLimits,       
                   NULL 
  /* 028 */  , "DEF:MOD:LIM %s",  
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL               
  /* 029 */   , "INIT:MOD",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 030 */   , "ABOR:MOD",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 031 */  , "STOP:MOD",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 032 */  , "CONT:MOD",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 033 */  , "FETC:MOD:STAT?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 034 */  , "CONF:MOD:EREP %s",
                   NULL,
                   NULL,
                   NULL,
                   &RfanModEventReport,
                   NULL
  /* 035 */  , "READ:MOD?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 036 */  , "FETC:MOD?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 037 */  , "SAMP:MOD?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 038 */  , "CALC:MOD:MATC:LIM?",                                                          
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL
  /* 039 */   , "SOUR:RFG:FREQ:RF:UNIT MHZ;:SOUR:RFG:FREQ:RF %lf",  
                   NULL,           
                   NULL,
                   NULL,       
                   &FreqChan,      
                   NULL                   
  /* 040 */   ,  "SOUR:RFG:FREQ:RF:UNIT CH;:SOUR:RFG:FREQ:RF %d",
                   NULL,
                   NULL,
                   NULL,
                   &RFChan,
                   NULL
  // JMG 030110
  /* 041  */  , "SOUR:RFG:MOD:MODE %s",  
                   NULL,
                   NULL,
                   NULL,
                   &ModSig,
                   NULL    
  // JMG 030110
  /* 042 */   , "SOUR:RFG:LEV:FSYN %lf;:SOUR:RFG:LEV:FSYN %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &RfgGenLevel,      
                   NULL                   
  // JMG 030110
  /* 043 */   , "SOUR:RFG:LEV:FPIC %lf;:SOUR:RFG:LEV:FPIC %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &RfgGenLevel,      
                   NULL                   
  // JMG 030110
  /* 044 */   , "SOUR:RFG:LEV:FPCH %lf;:SOUR:RFG:LEV:FPCH %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &RfgGenLevel,      
                   NULL                   
  /* 045 */   , "SOUR:RFG:PROP:PNOF %d",  
                   NULL,           
                   NULL,
                   NULL,       
                   &PNOffsetLim,      
                   NULL        
  /* 046 */   , "SOUR:RFG:POW:CDMA %1f",  
                   NULL,           
                   NULL,
                   NULL,       
                   &CDMAPowLvl,      
                   NULL                                        
  // JMG 030110
  /* 047 */   , "SOUR:RFG:POW:OUTP?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 048 */   , "SOUR:RFG:LEV:OCNS:VAL?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL 
  /* 049 */   , "SOUR:RFG:LEV:OCNS:ENAB %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &OCNSMode,       
                   NULL   
  /* 050 */   , "SOUR:IMP:LEV:AWGN %lf;:SOUR:IMP:LEV:AWGN %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &ImpAwgnLevel,      
                   NULL       
  /* 051 */   , "SOUR:IMP:FOFF:RF %lf;:SOUR:IMP:FOFF:RF %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &ImpFreqOffset,      
                   NULL                          
  /* 052 */   , "SOUR:RFG:LEV:FFCH %1f;:SOUR:RFG:LEV:FFCH %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &RfgGenLevel,       
                   NULL                      
  /* 053 */   , "SOUR:RFG:CHAN:FFCH %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &FFCHCh,       
                   NULL  
  /* 054 */   , "SOUR:RFG:FROF:FFCH %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &FFCHFrameOffset,       
                   NULL           
  /* 055 */   , "SOUR:RFG:FRAT:FFCH %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &FFCHFrameRate,       
                   NULL                               
  /* 056 */   , "INIT:RFG",                                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL
  /* 057 */   , "ABOR:RFG",                                                         
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL
  /* 058 */   , "FETC:RFG:STAT?",                                                 
                   NULL,
                   NULL,
                   NULL,       
                   NULL,       
                   NULL
  /* 059 */   , "CONF:NPOW:CONT %d, %s, %s, %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &CQScope,       
                   NULL                    
  /* 060 */   , "CONF:NPOW:CONT:STAT %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &CQStat,       
                   NULL                      
  /* 061 */   , "CONF:NPOW:CONT:REP %s, %s, %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &NPowRep,       
                   NULL                     
  /* 062 JMG 020930   , "CONF:NPOW:EPOW %d",                            
  /* 062 */   , "CONF:NPOW:CONT:CBS %d",                              
                   NULL,           
                   NULL,
                   NULL,       
                   &NEPow,       
                   NULL                    
  /* 063 */   , "INIT:NPOW",      
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /* 064 */   , "ABOR:NPOW",      
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL       
  /* 065 */   , "STOP:NPOW",      
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /* 066 */   , "CONT:NPOW",      
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                          
  /* 067 */   , "FETC:NPOW:STAT?",                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL                                       
  /* 068 */   , "CONF:NPOW:EREP %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL                                       
  /* 069 */   , "READ:NPOW?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 070 */   , "FETC:NPOW?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 071 */   , "SAMP:NPOW?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 072 */   , "CONF:POW:MIO%s:CONT %d, %s, %s, %s",              
                   NULL,           
                   NULL,
                   NULL,       
                   &CPScope,       
                   NULL  
  /* 073 */   , "CONF:POW:MIO%s:CONT:STAT %d",              
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfMinOutStat,      
                   NULL   
  /* 074 */   , "CONF:POW:MIO%s:CONT:REP %s, %s, %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfSignalRep,      
                   NULL  
  /* 075 */   , "CONF:POW:MIO%s:LEV %lf, %lf, %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfOutLvl,      
                   NULL    
  /* 076 */   , "CONF:POW:MIO%s:CONT:POW:CDMA %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   &CDMAPow,      
                   NULL
  /* 077 */   , "CONF:POW:MIO%s:CONT:LEV %lf,%f",
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfOLTimeResLev,      
                   NULL
  /* 078 */   , "CONF:POW:MIO%s:CONT:IMP %lf,%lf;:CONF:POW:MIO%s:CONT:IMP %s,%s",
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfRfgImp,      
                   NULL
  /* 079 */   , "DEF:POW:MIO%s:CONT %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &DefPowMinCont,      
                   NULL
  /* 080 */   , "CONF:POW:MIO%s:CAMM:LIM:ASYM:VAL %lf,%lf",                
                   NULL,           
                   NULL,
                   NULL,       
                   &LimitLevel,      
                   NULL
  /* 081 */   , "DEF:POW:MIO%s:LIM %s",   
                   NULL,           
                   NULL,
                   NULL,       
                   &DefPowMinCont,      
                   NULL      
  /* 082 */   , "INIT:POWer:MIO%s",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL  
  /* 083 */   , "ABORT:POW:MIO%s",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL  
  /* 084 */   , "STOP:POW:MIO%s",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL  
  /* 085 */   , "CONT:POW:MIO%s",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL  
  /* 086 */   , "FETCH:POW:MIO%s:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL  
  /* 087 */   , "CONF:POW:MIO%s:EREP %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &MinOutEvtReport,       
                   NULL  
  /* 088 */   , "READ:POW:MIO%s?",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL 
  /* 089 */   , "FETCH:POW:MIO%s?",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL 
  /* 090 */   , "SAMP:POW:MIO%s?",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL 
  /* 091 */   , "CALC:POW:MIO%s:MATC:LIM?",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL 
  /* 092 */   , "CONF:POW:MAO%s:CONT %d, %s, %s, %s",              
                   NULL,           
                   NULL,
                   NULL,       
                   &CPScope,       
                   NULL  
  /* 093 */   , "CONF:POW:MAO%s:CONT:STAT %d",              
                   NULL,           
                   NULL,
                   NULL,       
                   &MinOutStat,      
                   NULL               
  /* 094 */   , "CONF:POW:MAO%s:CONT:REP %s, %s, %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfSignalRep,      
                   NULL  
  /* 095 */   , "CONF:POW:MAO%s:LEV %lf, %lf, %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfMaxOutLev,      
                   NULL 
  /* 096 */   , "CONF:POW:MAO%s:CONT:POW:CDMA %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   &CDMAPow,      
                   NULL                 
  /* 097 */   , "CONF:POW:MAO%s:CONT:LEV %lf, %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfOLTimeResLev,      
                   NULL                 
  /* 098 */   , "CONF:POW:MAO%s:CONT:IMP %lf, %lf;:CONF:POW:MAO%s:CONT:IMP %s,%s",
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfRfgImp,      
                   NULL
  /* 099 */   , "DEF:POW:MAO%s:CONT %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &DefPowMinCont,      
                   NULL                 
  /* 100 */  , "CONF:POW:MAO%s:CAMM:LIM:ASYM:VAL %lf,%lf,%lf,%lf",                
                   NULL,           
                   NULL,
                   NULL,       
                   &LimitLevel2,      
                   NULL                 
  /* 101 */   , "DEF:POW:MAO%s:LIM %s",   
                   NULL,           
                   NULL,
                   NULL,       
                   &DefPowMinCont,      
                   NULL
  /* 102 */   , "INIT:POW:MAO%s",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,      
                   NULL 
  /* 103 */   , "ABOR:POW:MAO%s",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL                   
  /* 104 */   , "STOP:POW:MAO%s",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL                  
  /* 105 */   , "CONT:POW:MAO%s",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL                  
  /* 106 */   , "FETCH:POW:MAO%s:STAT?",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL                    
  /* 107 */   , "CONF:POW:MAO%s:EREP %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &MaxOutEvtReport,       
                   NULL                   
  /* 108 */   , "READ:POW:MAO%s?",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL                  
  /* 109 */   , "FETCH:POW:MAO%s?",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL                  
  /* 110 */   , "SAMP:POW:MAO%s?",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL                  
  /* 111 */   , "CALC:POW:MAO%s:MATC:LIM?",
                   NULL,           
                   NULL,
                   NULL,       
                   &SigType,       
                   NULL 
  /* 112 */   , "CONF:POW:GOUT:CONT %s, %d, %s, %s, %s",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfGatedScope,       
                   NULL                
  /* 113 */   , "CONF:POW:GOUT:CONT:RMOD %s",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &RMode3,       
                   NULL                     
  /* 114 */   , "CONF:POW:GOUT:CONT:STAT %d",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &StatMode,       
                   NULL                   
  /* 115 */   , "CONF:POW:GOUT:CONT:REP %s, %s, %s",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfGatedRep,       
                   NULL                     
  /* 116 */   , "CONF:SUB:POW:GOUT %s, %lf, %d",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &SubArrayMode,       
                   NULL                     
  /* 117 */   , "CONF:POW:GOUT:LEV %lf, %lf, %lf",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfGatedLev,       
                   NULL      
  /* 118 */   , "CONF:POW:GOUT:CONT:POW:CDMA %lf",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &CDMAPowLvl,       
                   NULL                       
  /* 119 */   , "CONF:POW:GOUT:CONT:LEV %lf, %lf",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &GatedContLevel,       
                   NULL      
  /* 120 */   , "CONF:POW:GOUT:CONT:IMP %lf, %lf;:CONF:POW:GOUT:CONT:IMP %s,%s",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &RfgImp2,       
                   NULL                         
  /* 121 */   , "CONF:POW:GOUT:CONT:PCGC %d",
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfPCG,       
                   NULL
  /* 122 */   , "DEF:POW:GOUT:CONT %s",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &DefGateCont,       
                   NULL                         
  /* 123 */   , "INIT:POW:GOUT",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL                         
  /* 124 */   , "ABORT:POW:GOUT",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL                                                                      
  /* 125 */   , "STOP:POW:GOUT",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL                    
  /* 126 */   , "CONT:POW:GOUT",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL                      
  /* 127 */   , "FETCH:POW:GOUT:STAT?",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL                      
  /* 128 */   , "CONF:POW:GOUT:EREP %s",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &GatedOutEvtReport,       
                   NULL                      
  /* 129 */   , "READ:POW:GOUT?",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL                                           
  /* 130 */   , "FETCH:POW:GOUT?",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL                    
  /* 131 */   , "SAMPLE:POW:GOUT?",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL    
  /* 132 */   , "CALC:POW:GOUT:MATC:RAMP?",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL    
  /* 133 */   , "READ:ARR:POW:GOUT:%s?",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &MeasSubArray,       
                   NULL    
  /* 134 */   , "FETCH:ARR:POW:GOUT:%s?",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &MeasSubArray,       
                   NULL    
  /* 135 */   , "SAMP:ARR:POW:GOUT:%s?",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &MeasSubArray,       
                   NULL    
  /* 136 */   , "CALC:ARR:POW:GOUT:MATC:LIM?",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,     
                   NULL                                                  
  /* 137 */   , "READ:SUB:POW:GOUT:%s?",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &MeasSubArray,       
                   NULL    
  /* 138 */   , "FETCH:SUB:POW:GOUT:%s?",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &MeasSubArray,       
                   NULL    
  /* 139 */   , "SAMP:SUB:POW:GOUT:%s?",                                                            
                   NULL,           
                   NULL,
                   NULL,       
                   &MeasSubArray,       
                   NULL    
  /* 140 */   , "CONF:CDP:CPCC:LEV %1f, %1f, %1f, %1f, %1f",                                             
                   NULL,
                   NULL,
                   NULL,       
                   &CDPLev,       
                   NULL     
  /* 141 */   , "CONF:CDP:CPCC:CONT:POW:CDMA %1f",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &CDMAPowLvl,       
                   NULL               
  /* 142 */   , "CONF:CDP:CPCC:CONT:LEV %1f, %1f, %lf, %lf",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &CDPContLev,       
                   NULL                
  /* 143 */   , "CONF:CDP:CPCC:IMP %1f, %1f;:CONF:CDP:CPCC:IMP %s,%s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &CDPImpair,       
                   NULL
  /* 144 */   , "DEF:CDP:CPCC:CONT %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL 
  /* 145 */   , "CONF:CDP:CPCC:%s:LIM:ASYM %1f, %1f, %1f",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &CDPAsym,       
                   NULL
  /* 146 */   , "CONF:CDP:CDPW:CONT %s, %d, %s, %s, %s",
                   NULL,
                   NULL,
                   NULL,
                   &CDPWCont,
                   NULL
  /* 147 */   , "CONF:CDP:CDPW:CONT:RMODE %s",
                   NULL,
                   NULL,
                   NULL,
                   &CDPWRMode,
                   NULL             
  /* 148 */   , "CONF:CDP:CDPW:CONT:RORD %s",
                   NULL,
                   NULL,
                   NULL,
                   &CDPWROrder,
                   NULL 
  /* 149 */   , "CONF:CDP:CDPW:CONT:STAT %d",
                   NULL,
                   NULL,
                   NULL,
                   &CDPWStats,
                   NULL     
  /* 150 */   , "CONF:CDP:CDPW:CONT:REP %s, %s, %s",
                   NULL,
                   NULL,
                   NULL,
                   &CDPWRep,
                   NULL  
  /* 151 */   , "DEF:CDP:CDPW:CONT %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL         
  /* 152 */   , "CONF:CDP:CDPW:%s:LIM:ASYM %1f",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &CDPWAsym,       
                   NULL   
  /* 153 */   , "INIT:CDP:CDPW",                                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 154 */   , "ABOR:CDP:CDPW",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /* 155 */   , "STOP:CDP:CDPW",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL         
  /* 156 */   , "CONT:CDP:CDPW",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
  /* 157 */  , "FETC:CDP:CDPW:STAT?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
  /* 158 */  , "CONF:CDP:CDPW:EREP %s",
                   NULL,
                   NULL,
                   NULL,
                   &RfanModEventReport,
                   NULL         
  /* 159 */  , "READ:SCAL:CDP:CDPW?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                     
  /* 160 */  , "FETC:SCAL:CDP:CDPW?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                     
  /* 161 */  , "SAMP:SCAL:CDP:CDPW?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
  /* 162 */  , "CALC:SCAL:CDP:CDPW:MATC:LIM?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                      
  /* 163 */   , "READ:ARR:CDP:CDPW:%s:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &ArraySetting,
                   NULL
  /* 164 */   , "FETC:ARR:CDP:CDPW:%s:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &ArraySetting,
                   NULL
  /* 165 */   , "SAMP:ARR:CDP:CDPW:%s:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &ArraySetting,
                   NULL    
  /* 166 */   , "CALC:ARR:CDP:CDPW:%s:%s:MATC:LIM?",
                   NULL,
                   NULL,
                   NULL,       
                   &ArraySetting,
                   NULL      
  /* 167 */   , "CONF:CDP:PCDEP:CONT %s, %d, %s, %s, %s",
                   NULL,
                   NULL,
                   NULL,
                   &CDPWCont,
                   NULL
  /* 168 */   , "CONF:CDP:PCDEP:CONT:RMODE %s",
                   NULL,
                   NULL,
                   NULL,
                   &CDPWRMode,
                   NULL             
  /* 169 */   , "CONF:CDP:PCDEP:CONT:RORD %s",
                   NULL,
                   NULL,
                   NULL,
                   &CDPWROrder,
                   NULL 
  /* 170 */   , "CONF:CDP:PCD:CONT:STAT %d",
                   NULL,
                   NULL,
                   NULL,
                   &CDPWStats,
                   NULL     
  /* 171 */   , "CONF:CDP:PCD:CONT:REP %s, %s, %s",
                   NULL,
                   NULL,
                   NULL,
                   &CDPWRep,
                   NULL  
  /* 172 */   , "DEF:CDP:PCDEP:CONT %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL         
  /* 173 */   , "CONF:CDP:PCDEP:%s:LIM:ASYM %1f",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &CDPWAsym,       
                   NULL   
  /* 174 */   , "INIT:CDP:PCDEP",                                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 175 */   , "ABOR:CDP:PCDEP",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /* 176 */   , "STOP:CDP:PCDEP",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL         
  /* 177 */   , "CONT:CDP:PCDEP",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
  /* 178 */  , "FETC:CDP:PCDEP:STAT?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
  /* 179 */  , "CONF:CDP:PCDEP:EREP %s",
                   NULL,
                   NULL,
                   NULL,
                   &RfanModEventReport,
                   NULL         
  /* 180 */  , "READ:SCAL:CDP:PCDEP?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                     
  /* 181 */  , "FETC:SCAL:CDP:PCDEP?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                     
  /* 182 */  , "SAMP:SCAL:CDP:PCDEP?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
  /* 183 */  , "CALC:SCAL:CDP:PCDEP:MATC:LIM?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                      
  /* 184 */   , "READ:ARR:CDP:PCDEP:%s:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &ArraySetting,
                   NULL
  /* 185 */   , "FETC:ARR:CDP:PCDEP:%s:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &ArraySetting,
                   NULL
  /* 186 */   , "SAMP:ARR:CDP:PCDEP:%s:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &ArraySetting,
                   NULL    
  /* 187 */   , "CALC:ARR:CDP:PCDEP:%s:%s:MATC:LIM?",
                   NULL,
                   NULL,
                   NULL,       
                   &ArraySetting,
                   NULL 
  /* 188 */   , "CONF:CDP:CHPW:CONT %s, %d, %s, %s, %s",
                   NULL,
                   NULL,
                   NULL,
                   &CDPWCont,
                   NULL
  /* 189 */   , "CONF:CDP:CHPW:CONT:RMODE %s",
                   NULL,
                   NULL,
                   NULL,
                   &CDPWRMode,
                   NULL             
  /* 190 */   , "CONF:CDP:CHPW:CONT:STAT %d",
                   NULL,
                   NULL,
                   NULL,
                   &CDPWStats,
                   NULL     
  /* 191 */   , "CONF:CDP:CHPW:CONT:REP %s, %s, %s",
                   NULL,
                   NULL,
                   NULL,
                   &CDPWRep,
                   NULL  
  /* 192 */   , "DEF:CDP:CHPW:CONT %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL         
  /* 193 */   , "CONF:CDP:CHPW:%s:LIM:ASYM %1f",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &CDPWAsym,       
                   NULL   
  /* 194 */   , "INIT:CDP:CHPW",                                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 195 */   , "ABOR:CDP:CHPW",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /* 196 */   , "STOP:CDP:CHPW",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL         
  /* 197 */   , "CONT:CDP:CHPW",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
  /* 198 */  , "FETC:CDP:CHPW:STAT?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
  /* 199 */  , "CONF:CDP:CHPW:EREP %s",
                   NULL,
                   NULL,
                   NULL,
                   &RfanModEventReport,
                   NULL         
  /* 200 */  , "READ:SCAL:CDP:CHPW?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                     
  /* 201 */  , "FETC:SCAL:CDP:CHPW?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                     
  /* 202 */  , "SAMP:SCAL:CDP:CHPW?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
  /* 203 */  , "CALC:SCAL:CDP:CHPW:MATC:LIM?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                      
  /* 204 */   , "READ:ARR:CDP:CHPW:%s:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &ArraySetting,
                   NULL
  /* 205 */   , "FETC:ARR:CDP:CHPW:%s:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &ArraySetting,
                   NULL
  /* 206 */   , "SAMP:ARR:CDP:CHPW:%s:%s?",
                   NULL,
                   NULL,
                   NULL,       
                   &ArraySetting,
                   NULL    
  /* 207 */   , "CALC:ARR:CDP:CHPW:%s:%s:MATC:LIM?",
                   NULL,
                   NULL,
                   NULL,       
                   &ArraySetting,
                   NULL 
  /* 208 */   , "CONF:OVER:MCQ:LEV %1f, %1f, %1f",                                                 
                   NULL,
                   NULL,
                   NULL,       
                   &OverLev,       
                   NULL    
  /* 209 */   , "CONF:OVER:MCQ:CONT:POW:CDMA %1f",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfCDMAPowLvl,       
                   NULL                                  
  /* 210 */   , "CONF:OVER:MCQ:CONT:LEV %1f, %1f",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &OverContLev,       
                   NULL  
  /* 211 */   , "CONF:OVER:MCQ:IMP %1f, %1f;:CONF:OVER:MCQ:IMP %s,%s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &CDPImpair,       
                   NULL
  /* 212 */   , "CONF:OVER:MCQ:PCB %s",
                   NULL,
                   NULL,
                   NULL,
                   &OverPowCtlBits,
                   NULL 
  /* 213 */   , "CONF:OVER:OVER%s:CONT %d, %s, %s, %s",
                   NULL,
                   NULL,
                   NULL,
                   &OverCont,
                   NULL                    
  /* 214 */   , "CONF:OVER:OVER%s:CONT:REP %s, %s, %s",
                   NULL,
                   NULL,
                   NULL,
                   &OverRep,
                   NULL     
  /* 215 */   , "CONF:OVER:OVER%s:CONT:STAT %d",
                   NULL,
                   NULL,
                   NULL,
                   &OverStat,
                   NULL     
  /* 216 JMG 020923   , "CONF:OVER:OVER%s:CONT:FOFF:SBS:%s %s;:CONF:OVER:OVER%s:CONT:FOFF:SBS:%s %d", 
                        Keep compatibility with the 3.09 driver
  */
  /* 216 */   , "CONF:OVER:OVER%s:CONT:FOFF:SBS %s;:CONF:OVER:OVER%s:CONT:FOFF:SBS %d",  
                   NULL,
                   NULL,
                   NULL,
                   &OverSBSFreqOffset,
                   NULL         
  /* 217 */   , "CONF:OVER:PPOW:ENAB %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL               
  /* 218 */   , "DEF:OVER:OVER%s:CONT %s",
                   NULL,
                   NULL,
                   NULL,
                   &OverDefault,
                   NULL  
  // JMG 030113
  /* 219 */   , "CONF:OVER:OVER%s:%s:LIM:SYMM:VAL %1f, %1f, %1f, %lf, %lf, %lf, %lf",
                   NULL,
                   NULL,
                   NULL,
                   &OverLimSymm,
                   NULL                                        
  /* 220 */   , "CONF:OVER:OVER%s:%s:LIM:SYMM:ENAB %s,%s,%s,%s,%s,%s,%s",
                   NULL,
                   NULL,
                   NULL,
                   &OverLimSymmEnab,
                   NULL                 
  /* 221 */   , "INIT:OVER:OVER%s",
                   NULL,
                   NULL,
                   NULL,
                   &OverSigType,
                   NULL         
  /* 222 */   , "ABOR:OVER:OVER%s",
                   NULL,
                   NULL,
                   NULL,
                   &OverSigType,
                   NULL     
  /* 223 */   , "STOP:OVER:OVER%s",
                   NULL,
                   NULL,
                   NULL,
                   &OverSigType,
                   NULL     
  /* 224 */   , "CONT:OVER:OVER%s",
                   NULL,
                   NULL,
                   NULL,
                   &OverSigType,
                   NULL                                
  /* 225 */   , "FETC:OVER:OVER%s:STAT?",
                   NULL,
                   NULL,
                   NULL,
                   &OverSigType,
                   NULL                                
  /* 226 */   , "CONF:OVER:OVER%s:EREP %s",
                   NULL,
                   NULL,
                   NULL,
                   &OverEventReport,
                   NULL     
  /* 227 */   , "READ:OVER:OVER%s?",
                   NULL,
                   NULL,
                   NULL,
                   &OverSigType,
                   NULL     
  /* 228 */   , "FETC:OVER:OVER%s?",
                   NULL,
                   NULL,
                   NULL,
                   &OverSigType,
                   NULL
  /* 229 */   , "SAMP:OVER:OVER%s?",
                   NULL,
                   NULL,
                   NULL,
                   &OverSigType,
                   NULL
  /* 230 */   , "CALC:OVER:OVER%s:MATC:LIM?",
                   NULL,
                   NULL,
                   NULL,
                   &OverSigType,
                   NULL      
  /* 231 */   , "CONF:OVER:CQU:CONT:REP %s, %s, %s",
                   NULL,
                   NULL,
                   NULL,
                   &CQURep,
                   NULL                        
  /* 232 */   , "CONF:OVER:CQU:CONT:FRAM %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &CQUFrame,       
                   NULL        
  /* 233 */   , "DEF:OVER:CQU:CONT %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL   
  /* 234 */   , "CONF:OVER:CQU:CAMM:LIM:SYMM:VAL %1f",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &CQULimSymm,       
                   NULL     
  /* 235 */   , "DEF:OVER:CQU:LIM %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL   
  /* 236 */   , "INIT:OVER:CQU",                                                      
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 237 */   , "ABOR:OVER:CQU",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /* 238 */   , "STOP:OVER:CQU",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL         
  /* 239 */   , "CONT:OVER:CQU",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                    
  /* 240 */  , "FETC:OVER:CQU:STAT?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
  /* 241 */  , "CONF:OVER:CQU:EREP %s",
                   NULL,
                   NULL,
                   NULL,
                   &CQUEventReport,
                   NULL   
  /* 242 */  , "READ:OVER:CQU?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                     
  /* 243 */  , "FETC:OVER:CQU?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                     
  /* 244 */  , "SAMP:OVER:CQU?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
  /* 245 */  , "CALC:OVER:CQU:MATC:LIM?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL    
  /* 246 */   , "CONF:MOD:MQU:PCB %s",                 
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfRFGenpcb,       
                   NULL
  /* 247 */   , "DEF:MOD:MQU:CONT %s",                     
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL                 
  /* 248 */   , "DEF:MOD:MQU:LIM %s",              
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL                   
  /* 249 */   , "CONF:MOD:MQU:%s:CONT %d,%s,%s,%s",
                   NULL,           
                   NULL,
                   NULL,       
                   &ModMQualCont,       
                   NULL
  /* 250 */   , "CONF:MOD:MQU:%s:CONT:REP %s,%s,%s",
                   NULL,           
                   NULL,
                   NULL,       
                   &ModQualRep,       
                   NULL  
  /* 251 */   , "CONF:MOD:MQU:%s:CONT:STAT %d",
                   NULL,           
                   NULL,
                   NULL,       
                   &ModQualStat,       
                   NULL  
  /* 252 */   , "CONF:MOD:MQU:%s:CONT:SBAN:FOFF %s;:CONF:MOD:MQU:%s:CONT:SBAN:FOFF %lf",  
                   NULL,           
                   NULL,
                   NULL,       
                   &ModQualSban,       
                   NULL 
  /* 253 */   , "DEF:MOD:MQU:%s:CONT %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &ModQualDefCont,       
                   NULL                  
  /* 254 */   , "CONF:MOD:MQU:%s:%s:LIM %s,%s,%s,%s,%d,%s;:CONF:MOD:MQU:%s:%s:LIM %lf,%d,%lf,%d,%d,%d",  
                   NULL,           
                   NULL,
                   NULL,       
                   &ModQualLimit,       
                   NULL                  
  /* 255 */   , "DEF:MOD:MQU:%s:%s:LIM %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &DefModQualLimit,       
                   NULL                     
  /* 256 */   , "INIT:MOD:MQU:%s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &ModStandard,       
                   NULL                     
  /* 257 */   , "ABOR:MOD:MQU:%s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &ModStandard,       
                   NULL                     
  /* 258 */   , "STOP:MOD:MQU:%s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &ModStandard,       
                   NULL                     
  /* 259 */   , "CONT:MOD:MQU:%s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &ModStandard,       
                   NULL                     
  /* 260 */   , "FETCH:MOD:MQU:%s:STAT?",  
                   NULL,           
                   NULL,
                   NULL,       
                   &ModStandard,       
                   NULL                     
  /* 261 */   , "CONF:MOD:MQU:%s:EREP %s",                                         
                   NULL,           
                   NULL,
                   NULL,       
                   &ModQualErep,       
                   NULL 
  /* 262 */   , "READ:MOD:MQU:%s?",                                         
                   NULL,           
                   NULL,
                   NULL,       
                   &ModStandard,       
                   NULL                  
  /* 263 */   , "FETCH:MOD:MQU:%s?",                                         
                   NULL,           
                   NULL,
                   NULL,       
                   &ModStandard,       
                   NULL                    
  /* 264 */   , "SAMP:MOD:MQU:%s?",                                         
                   NULL,           
                   NULL,
                   NULL,       
                   &ModStandard,       
                   NULL                    
  /* 265 */   , "CALC:MOD:MQU:%s:MATC:LIM?",                                         
                   NULL,           
                   NULL,
                   NULL,       
                   &ModStandard,       
                   NULL                  
  /* 266 */   , "CONF:MOD:OEMP%s:LEV %lf,%lf,%lf",                                         
                   NULL,           
                   NULL,
                   NULL,       
                   &ModOempLev,       
                   NULL 
                   
  /* 267 */   , "CONF:MOD:OEMP:%s:CONT:POW:CDMA %lf",                                         
                   NULL,           
                   NULL,
                   NULL,       
                   &ModOempCDMA,       
                   NULL         
  /* 268 */   , "CONF:MOD:OEMP:%s:CONT:LEV %lf, %lf;:CONF:MOD:OEMP:%s:CONT:LEV %s,%s",                                         
                   NULL,           
                   NULL,
                   NULL,       
                   &ModOempContLev,       
                   NULL                    
  /* 269 */   , "CONF:MOD:OEMP%s:IMP %lf, %lf;:CONF:MOD:OEMP%s:IMP %s,%s",                                         
                   NULL,           
                   NULL,
                   NULL,       
                   &ModImp,       
                   NULL                   
  /* 270 */   , "CONF:MOD:OEMP%s:%s:LIM:SYMM:VAL %lf, %lf, %lf, %lf, %lf, %lf, %lf, %lf, %lf, %lf, %lf",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOempVal,
                   NULL                     
  /* 271 */   , "CONF:MOD:OEMP%s:%s:LIM:SYMM:COMB:ENAB %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOempEnable,
                   NULL                  
  /* 272 */   , "DEF:MOD:OEMP%s:LIM %s",  
                   NULL,
                   NULL,
                   NULL,
                   &ModDef,
                   NULL                  
  /* 273 */   , "CONF:MOD:%s%s:CONT %s %d,%s,%s,%s",     
                   NULL,
                   NULL,
                   NULL,
                   &ConfModCont,
                   NULL       
  /* 274 */   , "CONF:MOD:%s%s:CONT:RMOD %s",  
                   NULL,
                   NULL,
                   NULL,
                   &ModRmod,
                   NULL  
  /* 275 */   , "CONF:MOD:%s%s:CONT:STAT %d",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfModStat,
                   NULL         
  /* 276 */   , "CONF:MOD:%s%s:CONT:REP %s,%s,%s",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfModRep,
                   NULL 
  /* 277 */   , "CONF:SUB:MOD:%s%s %s,%lf,%d",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfSubMod,
                   NULL 
  /* 278 */   , "INIT:MOD:%s%s",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard,
                   NULL         
  /* 279 */   , "ABORT:MOD:%s%s",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard,
                   NULL         
  /* 280 */   , "STOP:MOD:%s%s",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard,
                   NULL     
  /* 281 */   , "CONT:MOD:%s%s",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard,
                   NULL         
  /* 282 */   , "FETC:MOD:%s%s:STAT?",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard,
                   NULL         
  /* 283 */   , "CONF:MOD:%s%s:EREP %s",  
                   NULL,
                   NULL,
                   NULL,
                   &ModErep,
                   NULL         
  /* 284 */   , "READ:MOD:%s%s?",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard,
                   NULL         
  /* 285 */   , "FETCH:MOD:%s%s?",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard,
                   NULL         
  /* 286 */   , "SAMP:MOD:%s%s?",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard,
                   NULL         
  /* 287 */   , "CALC:MOD:%s%s:MATC:LIM?",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard,
                   NULL     
  /* 288 */   , "READ:ARR:MOD:%s%s:%s?",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard2,
                   NULL         
  /* 289 */   , "FETC:ARR:MOD:%s%s:%s?",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard2,
                   NULL     
  /* 290 */   , "SAMP:ARR:MOD:%s%s:%s?",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard2,
                   NULL         
  /* 291 */   , "READ:SUB:MOD:%s%s:%s?",            
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard2,
                   NULL         
  /* 292 */   , "FETC:SUB:MOD:%s%s:%s?",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard2,
                   NULL     
  /* 293 */   , "SAMP:SUB:MOD:%s%s:%s?",  
                   NULL,
                   NULL,
                   NULL,
                   &ModOverStandard2,
                   NULL         
  /* 294 */   , "CONF:RXQ:FER:FCH:CONT:TSET%d:FRAM %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &RQFrameCount,       
                   NULL  
  /* 295 */   , "CONF:RXQ:FER:FCH:CONT:TSET%d:REP %s, %s, %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &RQRep,       
                   NULL  
  /* 296 */   , "CONF:RXQ:FER:FCH:LIM:TSET%d:MFER %lf;:CONF:RXQ:FER:FCH:LIM:TSET%d:MFER %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &RQMFerLim,       
                   NULL    
  /* 297 */   , "CONF:RXQ:FER:FCH:LIM:TSET%d:CLEV %lf;:CONF:RXQ:FER:FCH:LIM:TSET%d:CLEV %s",                           
                   NULL,           
                   NULL,
                   NULL,       
                   &RQMCLev,       
                   NULL      
  /* 298 */   , "CONF:RXQ:FER:FSSC:TSET %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &TestSetupFER,       
                   NULL        
  /* 299 */   , "CONF:RXQ:FER:FSSC:CONT:TSET%d:LEV %lf, %lf, %lf",               
                   NULL,           
                   NULL,
                   NULL,       
                   &RQTsetLev,       
                   NULL          
  /* 300 */   , "CONF:RXQ:FER:FSSC:CONT:TSET%d:POW:CDMA %lf",                        
                   NULL,           
                   NULL,
                   NULL,       
                   &RQCDMAPow,       
                   NULL          
  /* 301 */   , "CONF:RXQ:FER:FSSC:CONT:TSET%d:LEV:FPIC %lf",                       
                   NULL,           
                   NULL,
                   NULL,       
                   &RQPilotLev,       
                   NULL          
  /* 302 */   , "CONF:RXQ:FER:FSSC:CONT:TSET%d:LEV:FFCH %lf",                         
                   NULL,           
                   NULL,
                   NULL,       
                   &RQFCHLev,       
                   NULL            
  /* 303 */   , "CONF:RXQ:FER:FSSC:CONT:TSET%d:IMP %lf, %lf;:CONF:RXQ:FER:FSSC:CONT:TSET%d:IMP %s,%s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &RQTsetImp,       
                   NULL          
  /* 304 */   , "CONF:RXQ:FER:FSSC:CONT:TSET%d:FRAT:FFCH %s",                          
                   NULL,           
                   NULL,
                   NULL,       
                   &RQFrameRate,       
                   NULL            
  /* 305 */   , "INIT:RXQ:FER:FCH",   
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /* 306 */   , "ABOR:RXQ:FER:FCH",   
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL       
  /* 307 */   , "STOP:RXQ:FER:FCH",   
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /* 308 */   , "CONT:RXQ:FER:FCH",   
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                      
  /* 309 */   , "FETC:RXQ:FER:FCH:STAT?",                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL                                       
  /* 310 */   , "CONF:RXQ:FER:FCH:EREP %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL                                       
  /* 311 */   , "READ:SCALar:RXQuality:FER:FCH?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 312 */   , "FETC:RXQ:FER:FCH?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 313 */   , "SAMP:RXQ:FER:FCH?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                
  /* 314 */   , "CALC:RXQ:FER:FCH:MATC:LIM?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                              
  /* 315 */   , "PROC:SIGN:ACT %s",
                   NULL,
                   NULL,
                   NULL,
                   &SignalAction,
                   NULL  
  /* 316 */   , "SIGN:STAT?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /* 317 */  , "CONF:NETW:STAN %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &CDMA2KStandard,      
                   NULL     
  /* 318 */  ,  "UNIT:BSS:CHAN:RF CH;:CONF:BSS:CHAN:RF %d",
                   NULL,
                   NULL,
                   NULL,
                   &RFChan,
                   NULL
  /* 319 */   , "UNIT:BSS:CHAN:RF MHZ;:CONF:BSS:CHAN:RF %lf",  
                   NULL,           
                   NULL,
                   NULL,       
                   &FreqChan,      
                   NULL         
  /* 320 */   , "CONF:BSS:POW:CDMA %1f",  
                   NULL,           
                   NULL,
                   NULL,       
                   &CDMAPowLvl,      
                   NULL            
  // JMG 030109
  /* 321 */   , "CONF:BSS:POW:OUTP?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL   
  // JMG 030109
  /* 322 */   , "CONF:BSS:LEV:FSYN %lf;:CONF:BSS:LEV:FSYN %s;",
                   NULL,           
                   NULL,
                   NULL,       
                   &GenLevel,      
                   NULL  
  // JMG 030109
  /* 323 */   , "CONF:BSS:LEV:FPIC %lf;:CONF:BSS:LEV:FPIC %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &GenLevel,      
                   NULL           
  // JMG 030109
  /* 324 */   , "CONF:BSS:LEV:FFCH %1f;:CONF:BSS:LEV:FFCH %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &GenLevel,       
                   NULL   
  /* 325 */   , "CONF:BSS:CHAN:FFCH %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &FFCHCh,       
                   NULL 
  /* 326 */   , "CONF:BSS:FROF:FFCH %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &FFCHFrameOffset,       
                   NULL        
  // JMG 030109
  /* 327 */   , "CONF:IMP:LEV:AWGN %lf;:CONF:IMP:LEV:AWGN %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &ImpAwgnLevel,      
                   NULL                          
  // JMG 030109
  /* 328 */   , "CONF:IMP:FOFF:RF %lf;:CONF:IMP:FOFF:RF %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &ImpFreqOffset,      
                   NULL                   
  /* 329 */   , "CONF:BSS:LEV:OCNS:VAL?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL         
  /* 330 */   , "CONF:BSS:LEV:OCNS:ENAB %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &OCNSMode,       
                   NULL     
  // JMG 030109
  /* 331 */   , "CONF:BSS:LEV:FPCH %1f;:CONF:BSS:LEV:FPCH %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &GenLevel,       
                   NULL                  
  /* 332 */   , "CONF:BSS:CHAN:FPCH %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &FPCHCh,       
                   NULL   
  /* 333 */   ,  "CONF:BSS:PCB %s",  
                   NULL,
                   NULL,
                   NULL,
                   &BSPowerCtrlBits,
                   NULL                               
  /* 334 */   , "CONF:BSS:PROP:PNOF %d",  
                   NULL,           
                   NULL,
                   NULL,       
                   &PNOffsetLim,      
                   NULL    
  /* 335 */   , "CONF:BSS:PROP:IDN %d",  
                   NULL,           
                   NULL,
                   NULL,       
                   &IDNumber,      
                   NULL                       
  /* 336 */   , "CONF:NETW:IDEN:MCC \'%s\'",  
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,
                   NULL      
  /* 337 */   , "CONF:NETW:IDEN:NID %d",  
                   NULL,           
                   NULL,
                   NULL,       
                   &IDNumber,      
                   NULL 
  /* 338 */   , "CONF:MSS:ID \'%s\'",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                    
  /* 339 */   , "CONF:MSS:MCC \'%s\'",  
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,
                   NULL     
  /* 340 */   , "CONF:NETW:SYST:BSID %d",  
                   NULL,
                   NULL,
                   NULL,
                   &BTSId,
                   NULL
  /* 341 */   , "CONF:NETW:SYST:PREV %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &ProtocolRevision,       
                   NULL              
  /* 342 */   , "CONF:NETW:SYST:MPR %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &ProtocolRevision,       
                   NULL   
  // JMG 030109
  /* 343 */   , "CONF:NETW:SYST:IMSI:ETW \'%s\'",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
  /* 344 */   , "CONF:NETW:SYST:UWC %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL                  
  /* 345 */   , "CONF:NETW:SYST:AUTH %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL      
  /* 346 */   , "CONF:NETW:REG:TBAS %10.2lf",  
                   NULL,
                   NULL,
                   NULL,
                   &TimerBase,
                   NULL    
  /* 347 */   , "CONF:NETW:REG:HOME %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL                
  /* 348 */   , "CONF:NETW:REG:FSID %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL                 
  /* 349 */   , "CONF:NETW:REG:FNID %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL                 
  /* 350 */   , "CONF:NETW:REG:PUP %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL                 
  /* 351 */   , "CONF:NETW:REG:PDOW %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL                                    
  /* 352 */   , "CONF:NETW:REG:PAR %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,       
                   NULL                 
  /* 353 */   , "CONF:NETW:PCH:RATE %s",  
                   NULL,           
                   NULL,
                   NULL,       
                   &pagingChannelRate,      
                   NULL      
  /* 354 */   , "CONF:NETW:PCH:SCIN %d",  
                   NULL,
                   NULL,
                   NULL,
                   &SlotCycleIndex,
                   NULL                 
  /* 355 */   , "CONF:NETW:PCH:MSC %d",  
                   NULL,
                   NULL,
                   NULL,
                   &SlotCycleIndex,
                   NULL 
  // JMG 030109
  /*356*/   ,   "CONF:NETW:SYST:ACH \'%s\'",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /*357*/   ,   "CONF:BSS:QOF:FFCH %d",  
                   NULL,
                   NULL,
                   NULL,
                   &QuasiOrthogonal,
                   NULL 
  /* 358 */   , "PROC:BSS:QOF:FFCH %d", 
                   NULL,
                   NULL,
                   NULL,
                   &QuasiOrthogonal,
                   NULL                   
  /* 359 */   , "CONF:SCON:SCL:SPE:%s:VCOD %s",
                   NULL,
                   NULL,
                   NULL,
                   &VoiceCoder,
                   NULL
  /* 360 */   , "CONF:SCON:SCL:SERV %s",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfServ,
                   NULL 
  /* 361 */   , "CONF:SCON:SCL:LOOP:SOPT %s",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfLoopServ,
                   NULL                   
  /* 362 */   , "CONF:SCON:SCL:LOOP:%s:FCH? ",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfLoopServ,
                   NULL                  
  /* 363 */   , "CONF:SCON:SCL:LOOP:%s:FCH:RC %d,%d",  
                   NULL,
                   NULL,
                   NULL,
                   &LoopRC,
                   NULL                  
  /* 364 */   , "CONF:SCON:SCL:LOOP:%s:FCH:FRAT %s",  
                   NULL,
                   NULL,
                   NULL,
                   &LoopFrat,
                   NULL                  
  // JMG 030109
  /* 365 */   , "CONF:SCON:SCL:LOOP:%s:FCH:PATT \'%s\'",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfLoopServ,
                   NULL                  
  /* 366 */   , "CONF:SCON:SCL:LOOP:%s:FCH:PGEN %s",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfLoopPattern,
                   NULL                  
  /* 367 */   , "CONF:SCON:SCL:SPE:SOPT %s",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfSpeServ,
                   NULL                      
  /* 368 */   , "CONF:SCON:SCL:SPE:%s:FCH?",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfSpeServ,
                   NULL                    
  /* 369 */   , "CONF:SCON:SCL:SPE:%s:FCH:RC %d,%d",  
                   NULL,
                   NULL,
                   NULL,
                   &SpeechRC,
                   NULL                  
  /* 370 */   , "UNIT:BSS:CHAN CH;:PROC:BSSignal:Channel %d",  
                   NULL,
                   NULL,
                   NULL,
                   &BSSChannel,
                   NULL                            
  /* 371 */   , "UNIT:BSS:CHAN MHZ;:PROC:BSS:CHAN %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL                     
  /* 372 */   , "PROC:BSS:POW:CDMA %lf",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL                          
  /* 373 */   , "PROC:BSS:LEV:FFCH %lf;:PROC:BSS:LEV:FFCH %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &ProcFFCHLevel,       
                   NULL                          
  /* 374 */   , "PROC:BSS:CHAN:FFCH %d",
                   NULL,           
                   NULL,
                   NULL,       
                   &ProcFFCHChannel,       
                   NULL                     
                   
  /* 375 */   , "PROC:BSS:FROF:FFCH %d",
                   NULL,           
                   NULL,
                   NULL,       
                   &ProcFFCHOffset,       
                   NULL                     
  /* 376 */   , "PROC:BSS:LEV:FPCH %lf;:PROC:BSS:LEV:FPCH %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &ProcFPCHLev,       
                   NULL                  
  /* 377 */   , "PROC:BSS:CHAN:FPCH %d",
                   NULL,           
                   NULL,
                   NULL,       
                   &ProcFPCHChan,       
                   NULL                 
  /* 378 */   , "PROC:BSS:PROP:PNOF %d",
                   NULL,           
                   NULL,
                   NULL,       
                   &ProcPNOffset,       
                   NULL                    
  /* 379 */   , "PROC:SCON:SCL:SERV %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &ConfServ,       
                   NULL                  
  /* 380 */   , "PROC:SCON:SCL:LOOP:SOPT %s",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfLoopServ,
                   NULL                   
  /* 381 */   , "PROC:SCON:SCL:LOOP:%s:FCH? ",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfLoopServ,
                   NULL                  
  /* 382 */   , "PROC:SCON:SCL:LOOP:%s:FCH:RC %d,%d",  
                   NULL,
                   NULL,
                   NULL,
                   &LoopRC,
                   NULL                  
  /* 383 */   , "PROC:SCON:SCL:LOOP:%s:FCH:FRAT %s",  
                   NULL,
                   NULL,
                   NULL,
                   &LoopFrat,
                   NULL                  
  // JMG 0301009
  /* 384 */   , "PROC:SCON:SCL:LOOP:%s:FCH:PATT \'%s\'",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfLoopServ,
                   NULL                  
  /* 385 */   , "PROC:SCON:SCL:LOOP:%s:FCH:PGEN %s",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfLoopPattern,
                   NULL                  
  /* 386 */   , "PROC:SCON:SCL:SPE:SOPT %s",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfSpeServ,
                   NULL                      
  /* 387 */   , "PROC:SCON:SCL:SPE:%s:FCH?",  
                   NULL,
                   NULL,
                   NULL,
                   &ConfSpeServ,
                   NULL                    
  /* 388 */   , "PROC:SCON:SCL:SPE:%s:FCH:RC %d,%d",  
                   NULL,
                   NULL,
                   NULL,
                   &SpeechRC,
                   NULL 
  /* 389 */   , "CONF:HAND:TARG %s",  
                   NULL,
                   NULL,
                   NULL,
                   &HandOff,
                   NULL                  
  /* 390 */   , "SENS:MSS?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /* 391 */   , "MSS:PREV?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL    
  /* 392 */   , "MSS:BCLS?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /* 393 */   , "MSS:SCLS?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /* 394 */   , "MSS:TERM?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                  
  /* 395 */   , "OVER:PPOW?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                  
  /* 396 */   , "CONF:NETW:SYST:SID %d",  
                   NULL,
                   NULL,
                   NULL,
                   &NetSID,
                   NULL 
  /*397 */    ,  "DEF:POW:GOUT:LIM %s",   
                   NULL,           
                   NULL,
                   NULL,       
                   &DefGateCont,      
                   NULL 
  /*398*/    ,   "CONF:SAPPower:EREP %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,      
                   NULL  
  /*399*/   ,    "INITiate:SAPP",      
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /*400*/   ,    "ABORt:SAPPower",      
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL       
  /*401*/   ,    "STOP:SAPPower",      
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /*402*/   ,    "CONTinue:SAPPower",      
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                          
  /*403*/   ,    "FETCh:SAPPower:STAT?",                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL                                       
  /*404*/   ,    "READ:SAPPower?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL    
  /*405*/   ,    "FETCh:SAPPower?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL                                       
  /*406*/   ,    "SAMPle:SAPPower?",
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL   
  /*407*/   ,    "CONF:POW:GOUT:CAMM:LIM:LINE:SYMM:VAL %lf, %lf, %lf, %lf, %lf, %lf", 
                   NULL,
                   NULL,
                   NULL,
                   &GatedTolLim,
                   NULL
  /*408*/   ,    "INIT:POW:OLTR",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL   
  /*409*/   ,    "ABOR:POW:OLTR",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
  /*410*/   ,   "STOP:POW:OLTR",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL   
  /*411*/   ,   "CONT:POW:OLTR",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL   
  /*412*/   ,   "FETC:POW:OLTR:STAT?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL   
  /*413*/   ,   "CONF:POW:OLTR:EREP %s",  
                   NULL,
                   NULL,
                   NULL,
                   &SpecEvtReport,
                   NULL            
  /*414*/   , "CONF:POW:OLTR:LEV %lf, %lf",  
                   NULL,
                   NULL,
                   NULL,
                   &OLTimeResLev,
                   NULL 
  /*415*/   , "DEF:POW:OLTR %s",  
                   NULL,
                   NULL,
                   NULL,
                   &Default,    
                   NULL   
  /*416*/   , "CONF:POW:OLTR:CONT:IMP %lf, %lf;:CONF:POW:OLTR:CONT:IMP %s,%s",
                   NULL,
                   NULL,
                   NULL,
                   &RfgImp2, 
                   NULL
  /*417*/   , "CONF:POW:OLTR:IBSP %lf",  
                   NULL,
                   NULL,
                   NULL,
                   &InitialBSPow,
                   NULL
  /*418*/   , "CONF:POW:OLTR:PST %lf",  
                   NULL,
                   NULL,
                   NULL,
                   &powStep,
                   NULL   
  /*419*/   , "CONF:POW:OLTR:PSD %s",  
                   NULL,
                   NULL,
                   NULL,
                   &powerStepDir,
                   NULL   
  /*420*/   , "READ:POW:OLTR?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL    
  /*421*/   , "FETC:POW:OLTR?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL 
  /*422*/   , "SAMP:POW:OLTR?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL   
  /*423*/   , "READ:ARR:POW:OLTR?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL 
  /*424*/   , "FETC:ARR:POW:OLTR?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL 
  /*425*/   , "SAMP:ARR:POW:OLTR?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL 
  /*426*/   ,  "CINFo:DNUMber?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*427*/   ,   "CINFo:GECall?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*428*/   ,   "CINFo:SOPTion?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*429*/   ,   "CINFo:FCH:MOPTions?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*430*/   ,   "CINFo:SCH:ZERO:MOPTions?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*431*/   ,   "CINFo:FCH:RC?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*432*/   ,   "CINFo:SCH:ZERO:RC?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*433*/   ,   "CONF:BSS:USAG:FQPC %s",
                   NULL,
                   NULL,
                   NULL,
                   &QPCHUsageMode,
                   NULL
  // JMG 030109
  /*434*/   ,   "CONF:BSS:LEV:FQPC %lf;:CONF:BSS:LEV:FQPC %s",
                   NULL,
                   NULL,
                   NULL,
                   &QPCHLev,
                   NULL
  /*435*/   ,   "CONF:BSS:CHAN:FQPC?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*436*/   ,   "CONF:BSS:IBIT:FQPC %s",
                   NULL,
                   NULL,
                   NULL,
                   &IndicatorBit,
                   NULL
  /*437*/   ,   "CONF:BSS:DUTP:FQPCh %s",
                   NULL,
                   NULL,
                   NULL,
                   &DUTPagingMode,
                   NULL
  /* JMG 030109 438 ,   "CONF:BSS:PROP:CLDT %s;:CONF:BSS:PROP:CLDT %d",   */
  /*438*/   ,   "CONF:BSS:PROP:CLDT %lf",  
                   NULL,
                   NULL,
                   NULL,
                   &CallLossDetectTime,
                   NULL
  /*439*/   ,   "PROC:BSS:USAG:FQPC %s",
                   NULL,
                   NULL,
                   NULL,
                   &QPCHUsageMode,
                   NULL
  /*440*/   ,   "PROC:BSS:LEV:FQPC %s;:PROC:BSS:LEV:FQPC %lf",
                   NULL,
                   NULL,
                   NULL,
                   &QPCHLev,
                   NULL
  /*441*/   ,   "PROC:BSS:CHAN:FQPC %d",
                   NULL,
                   NULL,
                   NULL,
                   &QPCH,
                   NULL
  /*442*/   ,   "PROC:BSS:IBIT:FQPC %s",
                   NULL,
                   NULL,
                   NULL,
                   &IndicatorBit,
                   NULL
  /*443*/   ,   "PROC:BSS:DUTP:FQPCh %s",
                   NULL,
                   NULL,
                   NULL,
                   &DUTPagingMode,
                   NULL
  /*444*/   ,   "CONF:SCON:SCL:TDAT:SOPT %s",
                   NULL,
                   NULL,
                   NULL,
                   &ConfLoopServ,
                   NULL
  /*445*/   ,   "CONF:SCON:SCL:TDAT:%s:FSC:RC %d, %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATComRC,
                   NULL
  /*446*/   ,   "CONF:SCON:SCL:TDAT:%s:FCH?",
                   NULL,
                   NULL,
                   NULL,
                   &ConfLoopServ,
                   NULL
  /*JMG 030109 447  ,   "CONF:SCON:SCL:TDAT:%s:FCH:RC %d, %d", */
  /*447*/   ,   "CONF:SCON:SCL:TDAT:%s:FCH:RC?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*448*/   ,   "CONF:SCON:SCL:TDAT:%s:FCH:%s:PGEN %s",
                   NULL,
                   NULL,
                   NULL,
                   &TDATpgen,
                   NULL
  // JMG 030109
  /*449*/   ,   "CONF:SCON:SCL:TDAT:%s:FCH:%s:PATT \'%s\'",
                   NULL,
                   NULL,
                   NULL,
                   &TDATconf,
                   NULL
  /*450*/   ,   "CONF:SCON:SCL:TDAT:%s:FCH:%s:CBFR %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATCBFrame,
                   NULL
  /*451*/   ,   "CONF:SCON:SCL:TDAT:%s:FCH:%s:TXON %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATtxonoff,
                   NULL
  /*452*/   ,   "CONF:SCON:SCL:TDAT:%s:FCH:%s:TXOF %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATtxonoff,
                   NULL
  /*453*/   ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:%s:ENAB %s",
                   NULL,
                   NULL,
                   NULL,
                   &TDATSchEnable,
                   NULL
  /*454*/   ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO?",
                   NULL,
                   NULL,
                   NULL,
                   &ConfLoopServ,
                   NULL
  /*JMG 455 ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:RC %d,%d", */
  /*455*/   ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:RC?",  
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*456*/   ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:%s:PGEN %s",
                   NULL,
                   NULL,
                   NULL,
                   &TDATpgen,
                   NULL
  // JMG 030109
  /*457*/   ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:%s:PATT \'%s\'",
                   NULL,
                   NULL,
                   NULL,
                   &TDATconf,
                   NULL
  /*458*/   ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:%s:CBFR %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATCBFrame,
                   NULL
  /*459*/   ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:%s:TXON %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATtxonoff,
                   NULL
  /*460*/   ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:%s:TXOF %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATtxonoff,
                   NULL
  /*461*/   ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:%s:FSIZ?",
                   NULL,
                   NULL,
                   NULL,
                   &TDATconf,
                   NULL
  /* JMG 020926 462 ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:%s:MPPL?",*/
  /*462*/   ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:%s:MPPL %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATconf,
                   NULL            
  /* JMG 020926 463 ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:%s:FTYP?", */
  /*463*/   ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:%s:FRTY %d",  
  
                   NULL,
                   NULL,
                   NULL,
                   &TDATconf,
                   NULL   
  /*464*/   ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:%s:COD?",
                   NULL,
                   NULL,
                   NULL,
                   &TDATconf,
                   NULL   
  /*465*/   ,   "CONF:SCON:SCL:TDAT:%s:SCH:ZERO:%s:DRAT?",
                   NULL,
                   NULL,
                   NULL,
                   &TDATconf,
                   NULL   
  /*466*/   ,   "PROC:SCON:SCL:TDAT:SOPT %s",
                   NULL,
                   NULL,
                   NULL,
                   &ConfLoopServ,
                   NULL
  /*467*/   ,   "PROC:SCON:SCL:TDAT:%s:FSC:RC %d, %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATComRC,
                   NULL
  /*468*/   ,   "PROC:SCON:SCL:TDAT:%s:FCH?",
                   NULL,
                   NULL,
                   NULL,
                   &ConfLoopServ,
                   NULL
  // 030113
  /*469*/   ,   "CONF:OVER:OVER%s:%s:LIM:SYMM:VAL %1f, %1f, %1f, %lf",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*470*/   ,   "PROC:SCON:SCL:TDAT:%s:FCH:%s:PGEN %s",
                   NULL,
                   NULL,
                   NULL,
                   &TDATpgen,
                   NULL
  /*471*/   ,   "PROC:SCON:SCL:TDAT:%s:FCH:%s:PATT \'%s\'",
                   NULL,
                   NULL,
                   NULL,
                   &TDATconf,
                   NULL
  /*472*/   ,   "PROC:SCON:SCL:TDAT:%s:FCH:%s:CBFR %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATCBFrame,
                   NULL
  /*473*/   ,   "PROC:SCON:SCL:TDAT:%s:FCH:%s:TXON %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATtxonoff,
                   NULL
  /*474*/   ,   "PROC:SCON:SCL:TDAT:%s:FCH:%s:TXOF %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATtxonoff,
                   NULL
  /*475*/   ,   "PROC:SCON:SCL:TDAT:%s:SCH:ZERO:%s:ENAB %s",
                   NULL,
                   NULL,
                   NULL,
                   &TDATSchEnable,
                   NULL
  /*476*/   ,   "PROC:SCON:SCL:TDAT:%s:SCH:ZERO?",
                   NULL,
                   NULL,
                   NULL,
                   &ConfLoopServ,
                   NULL
 /* 477 */   ,     "",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*478*/   ,   "PROC:SCON:SCL:TDAT:%s:SCH:ZERO:%s:PGEN %s",
                   NULL,
                   NULL,
                   NULL,
                   &TDATpgen,
                   NULL
  /*479*/   ,   "PROC:SCON:SCL:TDAT:%s:SCH:ZERO:%s:PATT \'%s\'",
                   NULL,
                   NULL,
                   NULL,
                   &TDATconf,
                   NULL
  /*480*/   ,   "PROC:SCON:SCL:TDAT:%s:SCH:ZERO:%s:CBFR %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATCBFrame,
                   NULL
  /*481*/   ,   "PROC:SCON:SCL:TDAT:%s:SCH:ZERO:%s:TXON %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATtxonoff,
                   NULL
  /*482*/   ,   "PROC:SCON:SCL:TDAT:%s:SCH:ZERO:%s:TXOF %d",
                   NULL,
                   NULL,
                   NULL,
                   &TDATtxonoff,
                   NULL
  /*483*/   ,   "",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /*484*/   ,   "",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL            
  /*485*/   ,   "",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL   
  /*486*/   ,   "",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL   
  /*487*/   ,   "PROC:SCON:SCL:TDAT:%s:SCH:ZERO:%s:DRAT?",
                   NULL,
                   NULL,
                   NULL,
                   &TDATconf,
                   NULL  
  /* JMG 030115 488   , "PROC:SCON:SCL:SPE:%s:VCOD %s", */
                   ,"",
                   NULL,
                   NULL,
                   NULL,
                   NULL, /*&VoiceCoder,*/
                   NULL  
  /*489*/       ,"ROUT:SPEN %s",                                                             
                   NULL,           
                   NULL,
                   NULL,       
                   &InputCodec,       
                   NULL  
  /*490*/       ,"ROUT:SPD %s",                                                             
                   NULL,           
                   NULL,
                   NULL,       
                   &OutputCodec,       
                   NULL     
  /*491*/       ,"CONF:NETW:APR:MODE %s",
                   NULL,
                   NULL,
                   NULL,
                   &AccessProbeMode,
                   NULL
  /*492*/       ,"CONF:NETW:APR:NOFF %lf",
                   NULL,
                   NULL,
                   NULL,
                   &NominalOffsetPower,
                   NULL
  /*493*/       ,"CONF:NETW:APR:IOFF %lf",
                   NULL,
                   NULL,
                   NULL,
                   &InitialPowerOffset,
                   NULL
  /*494*/       ,"CONF:NETW:APR:PINC %lf",
                   NULL,
                   NULL,
                   NULL,
                   &PowerIncrement,
                   NULL
  /*495*/       ,"CONF:NETW:APR:PPSequence %d",
                  NULL,
                  NULL,
                  NULL,
                  &ProbesPerSequence,
                  NULL
  /*496*/       ,"CONF:NETW:APR:SPAT %d",
                  NULL,
                  NULL,
                  NULL,
                  &ProbeSequence,
                  NULL
  /*497*/       ,"CONF:IQAC:RXSW %s",
                  NULL,
                  NULL,
                  NULL,
                  &RxIQSwapEnab,
                  NULL
  /*498*/       ,"CONF:IQAC:GMUL %d",
                  NULL,
                  NULL,
                  NULL,
                  &GainMultiplier,
                  NULL
  /*499*/       ,"CONF:IQAC:TCON %d",
                  NULL,
                  NULL,
                  NULL,
                  &TimingControl,
                  NULL
  /*500*/       ,"INIT:IQAC",
                  NULL,
                  NULL,
                  NULL,
                  NULL,
                  NULL
  /*501*/       ,"ABOR:IQAC",
                  NULL,
                  NULL,
                  NULL,
                  NULL,
                  NULL
  /*502*/       ,"FETC:IQAC:STAT?",
                  NULL,
                  NULL,
                  NULL,
                  NULL,
                  NULL 
  // JMG 030109
  /* 503 */   , "CONF:BSS:LEV:FSCH:ZERO %1f;:CONF:BSS:LEV:FSCH:ZERO %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &GenLevel,       
                   NULL           
  /* 504 */   , "CONF:BSS:CHAN:FSCH:ZERO %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &FFCHCh,       
                   NULL 
  /* 505 */   , "CONF:BSS:FROF:FSCH:ZERO %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &FFCHFrameOffset,       
                   NULL 
  /*506*/   ,   "CONF:BSS:QOF:FSCH:ZERO %d",  
                   NULL,
                   NULL,
                   NULL,
                   &QuasiOrthogonal,
                   NULL  
  /*507*/   , "PROC:BSS:LEV:FSCH:ZERO %1f;:PROC:BSS:LEV:FSCH:ZERO %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &GenLevel,       
                   NULL           
  /*508*/   , "PROC:BSS:CHAN:FSCH:ZERO %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &FFCHCh,       
                   NULL 
  /*509*/   , "PROC:BSS:FROF:FSCH:ZERO %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &FFCHFrameOffset,       
                   NULL 
  /*510*/   , "PROC:BSS:QOF:FSCH:ZERO %d",  
                   NULL,
                   NULL,
                   NULL,
                   &QuasiOrthogonal,
                   NULL  
  // JMG 030113
  /* 511 */   , "CONF:RXQ:FER:SCHS:EREP %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &EventReport,       
                   NULL   
  /* 512 */   , "CONF:RXQ:FER:SCHS:CONT:TSET%d:FRAM %d",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &RQFrameCount,       
                   NULL  
  /* 513 */   , "CONF:RXQ:FER:SCHS:CONT:TSET%d:REP %s, %s, %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &RQRep,       
                   NULL  
  /* 514 */   , "CONF:RXQ:FER:SCHS:LIM:TSET%d:MFER %lf;:CONF:RXQ:FER:SCHS:LIM:TSET%d:MFER %s",                            
                   NULL,           
                   NULL,
                   NULL,       
                   &RQMFerLim,       
                   NULL    
  /* 515 */   , "CONF:RXQ:FER:SCHS:LIM:TSET%d:CLEV %lf;:CONF:RXQ:FER:SCHS:LIM:TSET%d:CLEV %s",                           
                   NULL,           
                   NULL,
                   NULL,       
                   &RQMCLev,       
                   NULL                         
  /* 516 */   , "INIT:RXQ:FER:SCHS",   
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /* 517 */   , "ABOR:RXQ:FER:SCHS",   
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL       
  /* 518 */   , "STOP:RXQ:FER:SCHS",   
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                   
  /* 519 */   , "CONT:RXQ:FER:SCHS",   
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                      
  /* 520 */   , "FETC:RXQ:FER:SCHS:STAT?",                            
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL   
 /* 521 */   , "READ:SCALar:RXQuality:FER:SCHS?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 522 */   , "FETC:RXQ:FER:SCHS?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
  /* 523 */   , "SAMP:RXQ:FER:SCHS?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                
  /* 524 */   , "CALC:RXQ:FER:SCHS:MATC:LIM?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL        
  /* 525 */   , "XTND:OVER:CQU:CLEV %s",
                   NULL,
                   NULL,
                   NULL,
                   &ConfidenceLevelExt,
                   NULL                                 
  // JMG 030113
  /* 526 */   , "CONF:OVER:CQU:CAMM:LIM:MFER %lf;:CONF:OVER:CQU:CAMM:LIM:MFER %s",                     
                   NULL,
                   NULL,
                   NULL,
                   &MaxFERLimit,
                   NULL
  // JMG 030113                    
  /* 527 */   , "CONF:OVER:CQU:CAMM:LIM:CLEV %lf;:CONF:OVER:CQU:CAMM:LIM:CLEV %s",    
                   NULL,
                   NULL,
                   NULL,
                   &MinConfidenceLevel,
                   NULL
  // JMG 030110
  /* 528 */       , "XTND:OVER:OVER%s:SBS %s",
                   NULL,
                   NULL,
                   NULL,
                   &SidebandSuppressionExt,
                   NULL
  /* 529 */  , "DEF:OVER:OVER%s:LIM %s",
                   NULL,
                   NULL,
                   NULL,
                   &OverviewLimit,
                   NULL
  // JMG 020923                    
  /* 530 */   , "XTND:OVER:OVER%s:SBS ON;:CONF:OVER:OVER%s:CONT:FOFF:SBS:ACP1 %d;ACP1 %s;ACP2 %d;ACP2 %s;ACP3 %d;ACP3 %s;ACP4 %d;ACP4 %s",
                   NULL,
                   NULL,
                   NULL,
                   &OverSBSFreqOffset,
                   NULL         
  // JMG 021002                    
  /* 531 */   , "CONF:MOD:OEMP%s:PCB %s",
                   NULL,
                   NULL,
                   NULL,
                   &OverPowCtlBits,
                   NULL 
                   
  // JMG 021002                    
  /* 532 */   , "CONF:CDP:CPCC:PCB %s",
                   NULL,
                   NULL,
                   NULL,
                   &OverPowCtlBits,
                   NULL 
                   
  /* 533 */   , "SYST:VERS:SW:MMI?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL 
  
  /* 534 */   , "DEF:RFAN %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL 

  /* 535 */   , "DEF:TRIG:SOUR %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL
                   
  /* 536 */   , "DEF:TRIG %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL
                   
  // JMG 030110
  /* 537 */   ,  "TRIG:OUTP:PIN%1d:SIGN %s",
                   NULL,
                   NULL,
                   NULL,
                   &TriggerOutputRouting,
                   NULL                 

  /* 538 */   ,  "DEF:RFG %s",                  
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL
                   
  /* 539 */   ,  "CONF:WPOW:CONT:REP %s, %s, %s",
                   NULL,
                   NULL,
                   NULL,        
                   &ConfWpowCont,
                   NULL

  /* 540 */   ,  "CONF:WPOW:EREP %s", 
                   NULL,
                   NULL,
                   NULL,        
                   &EventReport,
                   NULL
                   
  /* 541 */   ,  "INIT:WPOW",
                   NULL,
                   NULL,
                   NULL,        
                   NULL,
                   NULL 

  /* 542 */   ,  "ABOR:WPOW",
                   NULL,
                   NULL,
                   NULL,        
                   NULL,
                   NULL
                   
  /* 543 */   ,  "STOP:WPOW",
                   NULL,
                   NULL,
                   NULL,        
                   NULL,
                   NULL                    
                            
  /* 544 */   ,  "CONT:WPOW",
                   NULL,
                   NULL,
                   NULL,        
                   NULL,
                   NULL                 
                   
  /* 545 */   ,  "FETC:WPOW:STAT?",
                   NULL,
                   NULL,
                   NULL,        
                   NULL,
                   NULL  

  /* 546 */  ,   "READ:WPOW?",
                   NULL,
                   NULL,
                   NULL,        
                   NULL,
                   NULL  
                   
  /* 547 */  ,   "FETC:WPOW?",
                   NULL,
                   NULL,
                   NULL,        
                   NULL,
                   NULL  
                   
  /* 548 */  ,   "SAMP:WPOW?",
                   NULL,
                   NULL,
                   NULL,        
                   NULL,
                   NULL  
                   
  /* 549 */  ,   "DEF:IQAC:CONT %s",
                   NULL,
                   NULL,
                   NULL,        
                   &Default,
                   NULL    
                   
  /* 550 */  ,   "SYST:RES:CURR",
                   NULL,
                   NULL,
                   NULL,        
                   NULL,
                   NULL  

 /* 551 */  ,    "XTND:MOD:MQU:%s:SBS %s",
                   NULL,
                   NULL,
                   NULL,        
                   &SidebandSuppressionExt1, 
                   NULL     
                   
 /* 552 */  ,    "XTND:MOD:MQU:%s:SBS ON;:CONF:MOD:MQU:%s:CONT:FOFF:SBS:ACP1 %d;ACP1 %s;ACP2 %d;ACP2 %s;ACP3 %d;ACP3 %s;ACP4 %d;ACP4 %s",                      
                   NULL,
                   NULL,
                   NULL,
                   &OverSBSFreqOffset1,
                   NULL  
                   
  // JMG 030110
  /* 553 */   , "CONF:MOD:MQU:%s:%s:LIM %7.4lf, %d, %8.6lf, %6.2lf, %d, %7.2lf, %7.2lf, %7.2lf, %7.2lf",
                   NULL,
                   NULL,
                   NULL,
                   &ModMquLimlevel,
                   NULL                                        
  /* 554 */   , "CONF:MOD:MQU:%s:%s:LIM %s,%s,%s,%s,%s,%s,%s,%s,%s",
                   NULL,
                   NULL,
                   NULL,
                   &ModMquLimEnab,
                   NULL                    
  // JMG 030110
  /* 555 */   , "CONF:IQIF:RXTX %s",  
                   NULL,
                   NULL,
                   NULL,
                   &PreRoutingPath,
                   NULL 
  /* 556 */   , "CONF:IQIF:RXP %s",
                   NULL,
                   NULL,
                   NULL,
                   &PreRoutingPath,
                   NULL 
  /* 557 */   , "CONF:IQIF:TXP %s",
                   NULL,
                   NULL,
                   NULL,
                   &PreRoutingPath,
                   NULL                    
  // JMG 030113
  /* 558 */   , "DEF:RXQ:FER:FSSC:TSET%d %s",
                   NULL,
                   NULL,
                   NULL,
                   &RQTestSetEnable,
                   NULL
  // JMG 030113
  /* 559 */   , "CONF:RXQ:FER:FSSC:CONT:TSET%d:LEV:FSCH:ZERO %lf",
                   NULL,
                   NULL,
                   NULL,
                   &RQSch0Level,
                   NULL 
  /* 560 */   , "CALC:RXQ:FER:FSSC:TSET%d:EBNT:FFCH?",
                   NULL,
                   NULL,
                   NULL,
                   &RQTestSet,
                   NULL             

  /* 561 */   , "CALC:RXQ:FER:FSSC:TSET%d:EBNT:FSCH:ZERO?",
                   NULL,
                   NULL,
                   NULL,
                   &RQTestSet,
                   NULL
                   
  /* 562 */   , "CALC:RXQ:FER:FSSC:TSET%d:EBNT:FSCH:ONE?",
                   NULL,
                   NULL,
                   NULL,
                   &RQTestSet,
                   NULL  
                   
  /* 563 */   , "DEF:RXQ:FER:FCH:CONT:TSET%d %s",
                   NULL,
                   NULL,
                   NULL,
                   &RQTestSetEnable,
                   NULL    

  /* 564 */   , "DEF:RXQ:FER:FCH:LIM:TSET%d %s",
                   NULL,
                   NULL,
                   NULL,
                   &RQTestSetEnable,
                   NULL         
                   
  /* 565 */   , "DEF:RXQ:FER:SCHS:CONT:TSET%d %s",
                   NULL,
                   NULL,
                   NULL,
                   &RQTestSetEnable,
                   NULL  

  /* 566 */   , "DEF:RXQ:FER:SCHS:LIM:TSET%d %s",
                   NULL,
                   NULL,
                   NULL,
                   &RQTestSetEnable,
                   NULL  
                   
  /* 567 */   , "CONF:RXQ:FPC:EREP %s",
                   NULL,
                   NULL,
                   NULL,
                   &EventReport,
                   NULL     
                   
  /* 568 */   , "DEF:RXQ:FPC:CONT %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL                        
                   
  /* 569 */   , "CONF:RXQ:FPC:CONT %d, %s, %s, %s",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcCont,
                   NULL   
                   
  /* 570 */   , "CONF:RXQ:FPC:CONT:STAT %d",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcStat,
                   NULL    
                   
  /* 571 */   , "CONF:RXQ:FPC:CONT:REP %s, %s,%s",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcRep,
                   NULL  
                   
  /* 572 */   , "CONF:RXQ:FPC:CONT:FPCM %d",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcMode,
                   NULL    
                   
  /* 573 */   , "CONF:RXQ:FPC:CONT:RDEL %d",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcRDelay,
                   NULL                        
                   
  /* 574 */   , "CONF:RXQ:FPC:CONT:RFR %d",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcRFrame,
                   NULL   
                   
  /* 575 */   , "CONF:RXQ:FPC:CONT:CPR %d",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
                   
  /* 576 */   , "CONF:RXQ:FPC:CONT:CSEC %d",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
                   
  /* 577 */   , "CONF:RXQ:FPC:CONT:FCH:TFER %lf",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcTFer,
                   NULL     
                   
  /* 578 */   , "CONF:RXQ:FPC:CONT:FCH:LSP:STT:LOW %lf",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcLSLSetup,
                   NULL
                   
  /* 579 */   , "CONF:RXQ:FPC:CONT:FCH:LSP:DYN:LOW %s",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcDLMode,
                   NULL
                   
  /* 580 */   , "CONF:RXQ:FPC:CONT:FCH:LSP:STT:UPP %lf",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcUSLSetup,
                   NULL
                   
  /* 581 */   , "CONF:RXQ:FPC:CONT:FCH:LSP:DYN:UPP %s",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcDLMode,
                   NULL     
                   
  /* 582 */   , "CONF:RXQ:FPC:CONT:SCH:ZERO:TFER %lf",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcTFer,
                   NULL     
                   
  /* 583*/   , "CONF:RXQ:FPC:CONT:SCH:ZERO:LSP:STT:LOW %lf",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcLSLSetup,
                   NULL
                   
  /* 584 */   , "CONF:RXQ:FPC:CONT:SCH:ZERO:LSP:DYN:LOW %s",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcDLMode,
                   NULL
                   
  /* 585 */   , "CONF:RXQ:FPC:CONT:SCH:ZERO:LSP:STT:UPP %lf",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcUSLSetup,
                   NULL
                   
  // JMG 030113
  /* 586 */   , "CONF:RXQ:FPC:CONT:SCH:ZERO:LSP:DYN:UPP %s",
                   NULL,
                   NULL,
                   NULL,
                   &RQFpcDLMode,
                   NULL  
                         
  /* 587 */   , "CONF:RXQ:FPC:CONT:POW:CDMA %lf",
                   NULL,
                   NULL,
                   NULL,
                   &CDMAPowLvl,
                   NULL  
                         
  /* 588 */   , "CONF:RXQ:FPC:CONT:LEV:FPIC %lf",
                   NULL,
                   NULL,
                   NULL,
                   &PilotPowLvl,
                   NULL  
                         
  /* 589 */   , "CONF:RXQ:FPC:CONT:LEV:FFCH %lf",
                   NULL,
                   NULL,
                   NULL,
                   &FCHLvl,
                   NULL  
                         
  /* 590 */   , "CONF:RXQ:FPC:CONT:LEV:FSCH:ZERO %lf",
                   NULL,
                   NULL,
                   NULL,
                   &Sch0Lvl,
                   NULL                                        

  // JMG 030113
  /* 591 */   , "CONF:RXQ:FPC:CONT:IMP %lf, %lf;:CONF:RXQ:FPC:CONT:IMP %s,%s",                            
                   NULL,           
                   NULL,
                   NULL,   
                   &RQFpcImpAwgnLevel,
                   NULL 
                         
  /* 592 */   , "CONF:RXQ:FPC:CONT:FRAT:FFCH %s",
                   NULL,
                   NULL,
                   NULL,
                   &FrameRate,
                   NULL     
                         
  /* 593 */   , "INIT:RXQ:FPC",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
                         
  /* 594 */   , "ABOR:RXQ:FPC",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                        
                         
  /* 595 */   , "STOP:RXQ:FPC",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                        
                         
  /* 596 */   , "CONT:RXQ:FPC",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
                         
  /* 597 */   , "FETC:RXQ:FPC:STAT?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                        
                         
  /* 598 */   , "READ:RXQ:FPC?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL     
                         
  /* 599 */   , "FETC:RXQ:FPC?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                    

  /* 600 */   , "SAMP:RXQ:FPC?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL 
  // JMG 030113
  /* 601 */   , "CALC:OVER:MCQ:EBNT:FFCH?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  

  /* 602 */   , "CONF:OVER:MCQ:CONT:FRAT:FFCH %s",
                   NULL,
                   NULL,
                   NULL,
                   &FrameRate,
                   NULL   
                   
  /* 603 */   , "SCIN?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL     

  /* 604 */   , "MSS:AUTH?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  

  /* 605 */   , "MINF:SMS:LOUT:TSTA?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL         
                   
  /* 606 */   , "MINF:SMS:LOUT:ACKN?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                        
                   
  /* 607 */   , "MINF:SMS:LOUT:CCOD?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL  
                   
  /* 608 */   , "MINF:SMS:LREC:TST?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL         
                   
  /* 609 */   , "MINF:SMS:LREC:TEX?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL    
                   
  /* 610 */   , "DEF:SCON %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL     
                         
  /* 611 */   , "CONF:SCON:SCL:SPE:%s:EDEL %lf",
                   NULL,
                   NULL,
                   NULL,
                   &EchoDelay,
                   NULL
                   
  /* 612 */   , "CONF:SCON:SCL:WMT:SOPT?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL
                   
  /* 613 */   , "CONF:SCON:SCL:WMT:SMS:TEXT \'%s\'",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL     
                   
  /* 614 */   , "CONF:SCON:SCL:WMT:SMS:ACKN:ENAB %s",
                   NULL,
                   NULL,
                   NULL,
                   &SMSEnable,
                   NULL 
                   
  /* 615 */   , "CONF:SCON:SCL:WMT:SMS:TSTAMP:ENAB %s",
                   NULL,
                   NULL,
                   NULL,
                   &SMSEnable,
                   NULL  
                   
  /* 616 */   , "CONF:SCON:SCL:WMT:%s:FCH?",
                   NULL,
                   NULL,
                   NULL,
                   &WMTOption,
                   NULL  
                   
  /* 617 */   , "CONF:SCON:SCL:WMT:%s:FCH:RC %d, %d",
                   NULL,
                   NULL,
                   NULL,
                   &WMTFchRc,
                   NULL  
                   
  /* 618 */   , "DEF:BSS %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL    
                   
  /* 619 */   , "CALC:BSS:EBNT:FFCH?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL 
                   
  /* 620 */   , "CALC:BSS:EBNT:FSCH:ZERO?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL    
                   
  /* JMG 030109 621    , "CALC:MSS:ID:URD %s", */
  /* 621 */   , "CONF:MSS:ID:URD %s",  
                   NULL,
                   NULL,
                   NULL,
                   &URData,
                   NULL    
                   
  /* 622 */   , "TRIG:SOUR %s",
                   NULL,
                   NULL,
                   NULL,
                   &TriggerSource,
                   NULL     
                   
  /* 623 */   , "DEF:MMON %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL 
                   
  /* 624 */   , "CONF:MMON:IPAD %d, %d, %d, %d",
                   NULL,
                   NULL,
                   NULL,
                   &MMIPAddr,
                   NULL     
                   
  /* 625 */   , "CONF:MMON:SMAS %d, %d, %d, %d",
                   NULL,
                   NULL,
                   NULL,
                   &MMIPAddr,
                   NULL  
                   
  /* 626 */   , "CONF:MMON:SGAT %d, %d, %d, %d",
                   NULL,
                   NULL,
                   NULL,
                   &MMIPAddr,
                   NULL    
                   
  /* 627 */   , "CALC:MOD:OEMP%s:EBNT:FFCH?",
                   NULL,
                   NULL,
                   NULL,
                   &SigType,
                   NULL          
                   
  /* 628 */   , "CONF:MOD:OEMP%s:CONT:FRAT:FFCH %s",
                   NULL,
                   NULL,
                   NULL,
                   &SigFrame,
                   NULL         
                   
  /* 629 */   , "DEF:MOD:%s%s:CONT %s",
                   NULL,
                   NULL,
                   NULL,
                   &DefModOverStandard,
                   NULL   
                   
  /* 630 */   , "CALC:POW:MIO%s:EBNT:FFCH?",
                   NULL,
                   NULL,
                   NULL,
                   &SigType,
                   NULL 
                   
  /* 631 */   , "CONF:POW:MIO%s:CONT:FRAT:FFCH %s",
                   NULL,
                   NULL,
                   NULL,
                   &SigFrame,
                   NULL                        
                   
  /* 632 */   , "CALC:POW:MAO%s:EBNT:FFCH?",
                   NULL,
                   NULL,
                   NULL,
                   &SigType,
                   NULL 
                   
  /* 633 */   , "CONF:POW:MAO%s:CONT:FRAT:FFCH %s",
                   NULL,
                   NULL,
                   NULL,
                   &SigFrame,
                   NULL  
                   
  /* 634 */   , "CALC:POW:GOUT:EBNT:FFCH?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL 
                   
  /* 635 */   , "CONF:POW:GOUT:CONT:FRAT:FFCH %s",
                   NULL,
                   NULL,
                   NULL,
                   &FrameRate,
                   NULL     
                   
  /* 636 */   , "CONF:POW:GOUT:CAMM:LIM:A:VAL %lf",
                   NULL,
                   NULL,
                   NULL,
                   &LimAVal,
                   NULL   
                   
  /* 637 */   , "CONF:POW:GOUT:CAMM:LIM:BREF:VAL %lf",
                   NULL,
                   NULL,
                   NULL,
                   &RefBLimVal,
                   NULL 
                   
  /* 638 */   , "CONF:POW:GOUT:CAMM:LIM:B:VAL %lf",
                   NULL,
                   NULL,
                   NULL,
                   &LimBVal,
                   NULL   
                   
  /* 639 */   , "CONF:POW:GOUT:CAMM:LIM:C:VAL %lf",
                   NULL,
                   NULL,
                   NULL,
                   &LimCVal,
                   NULL     
                   
  /* 640 */   , "CONF:POW:GOUT:CAMM:LIM:D:REL:VAL %lf",
                   NULL,
                   NULL,
                   NULL,
                   &LimDRelVal,
                   NULL                        
                   
  /* 641 */   , "CONF:POW:GOUT:CAMM:LIM:D:ABS:VAL %lf",
                   NULL,
                   NULL,
                   NULL,
                   &LimDAbsVal,
                   NULL 
                   
  /* 642 */   , "CONF:POW:GOUT:CAMM:LIM:EREF:VAL %lf",
                   NULL,
                   NULL,
                   NULL,
                   &RefELimVal,
                   NULL   
                   
  /* 643 */   , "CONF:POW:GOUT:CAMM:LIM:E:VAL %lf",
                   NULL,
                   NULL,
                   NULL,
                   &LimEVal,
                   NULL     
                   
  /* 644 */   , "CONF:POW:GOUT:CAMM:LIM:VAL %lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf",
                   NULL,
                   NULL,
                   NULL,
                   &PowGoutLimVal,
                   NULL 

  /* 645 */   , "CALC:POW:OLTR:EBNT:FFCH?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL 
                   
  /* 646 */   , "CONF:POW:OLTR:CONT:FRAT:FFCH %s",
                   NULL,
                   NULL,
                   NULL,
                   &FrameRate,
                   NULL   
                   
  /* 647 */   , "CALC:CDP:CPCC:EBNT:FFCH?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                    
                   
  /* 648 */   , "CALC:CDP:CPCC:EBNT:FSCH:ZERO?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL   
                   
  /* 649 */   , "CALC:CDP:CPCC:EBNT:FSCH:ONE?",
                   NULL,
                   NULL,
                   NULL,
                   NULL,
                   NULL                        
                   
  /* 650 */   , "CONF:CDP:CPCC:CONT:FRAT:FFCH %s",
                   NULL,
                   NULL,
                   NULL,
                   &FrameRate,
                   NULL  

  /* 651 */   , "DEF:CDP:CPCC:LIM %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL 
                   
  /* 652 */   , "DEF:CDP:CDPW:LIM %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL 
                   
  /* 653 */   , "DEF:CDP:PCD:LIM %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL 
                   
  /* 654 */   , "DEF:CDP:CHPW:LIM %s",
                   NULL,
                   NULL,
                   NULL,
                   &Default,
                   NULL                    
  /* 655 */  , "STAT:OPER:SYMB:ENAB %s",                                  
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL 
  /* 656 */  , "STAT:OPER:SYMB?;*CLS",                                  
                   NULL,           
                   NULL,
                   NULL,       
                   NULL,       
                   NULL             
  /* 657 */  , "CONF:ALL:ENV:ENAB %s",
                   NULL,           
                   NULL,
                   NULL,       
                   &Default,          
                   NULL                    
};



/**************************************************************************
 *
 * NAME:        RSCMU_Init_CDMA2K
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_Init_CDMA2K (ViSession instrSessionBase,
                                     ViSession *instrSessionCDMA,
                                     ViInt32 CDMA2KFunctionGroup,
                                     ViChar errorMessage[])

{
   ViStatus    RSCMU_Status      = VI_SUCCESS;  
   ViInt32     secondAddr = RSCMU_SECONDARY_ADDRESS_INVALID, comp = 1, 
               firstFreeSecAddr = RSCMU_SECONDARY_ADDRESS_INVALID;
   ViChar      FctGrpBuffer[128] = "";
   ViChar      resource[25]      = "";
   ViBoolean   Flag              = RSCMU_OFF;
   ViSession   DefaultRM;
  
   struct RSCMU_Base_Globals  *p_globalvarBase;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

    /* --- Set standard "C" locale --- */
    {
       char *locale;

       locale = setlocale(LC_ALL, "C");
    }

   // Get a copy of the global data for this session.
   if( (RSCMU_Status = viGetAttribute( instrSessionBase
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarBase
                                     )) < 0 )
   {
      return RSCMU_Base_errorMessage( instrSessionBase, RSCMU_Status, errorMessage );
   }
   DefaultRM = p_globalvarBase->RSCMU_tGlobal.RSCMU_RmSessionDefault;

   // Verify that the VISA Resource Manager has been opened.
   if( DefaultRM != 0 )
   {
      // Which Function Group does the User want?
      switch( CDMA2KFunctionGroup )
      {
      
      case RSCMU_CDMA2K450MS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2K450MS_NSig\"" );
         break;
         
      case RSCMU_CDMA2K450MS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2K450MS_Sig\"" );
         break;  
                     
      case RSCMU_CDMA2KCELLMS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KCellMS_NSig\"" );
         break;
         
      case RSCMU_CDMA2KCELLMS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KCellMS_Sig\"" );
         break;

      case RSCMU_CDMA2KPCSMS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KPCSMS_NSig\"" );
         break;

      case RSCMU_CDMA2KPCSMS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KPCSMS_Sig\"" );
         break;

      case RSCMU_CDMA2KIMT2KMS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KIMT2KMS_NSig\"" );
         break;   

      case RSCMU_CDMA2KIMT2KMS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KIMT2KMS_Sig\"" );
         break;

      default:
         break;
      }

      // Init the Error Message  
      strcpy( errorMessage, "No Error" );

      // Find the Secondary address
      while ((comp != 0) && (secondAddr <= RSCMU_SECONDARY_ADDRESS_MAX))
      {
          secondAddr++;
          comp = strncmp (  p_globalvarBase->RSCMU_tSecAddr[secondAddr].FctGrp, 
                            FctGrpBuffer,
                            strlen(FctGrpBuffer));  
          if (comp == 0) 
          {
            Flag = RSCMU_ON;
          } 
          else
          {
            ViInt32 comp1;
            comp1 = strncmp (p_globalvarBase->RSCMU_tSecAddr[secondAddr].FctGrp, "NONE", 4);  
            if (comp1 == 0 && firstFreeSecAddr == -1)
            {
                firstFreeSecAddr = secondAddr;
            }   
        }
      }
      
      if (Flag == RSCMU_OFF)
      {
        if ((RSCMU_Status = RSCMU_Base_SystRemAddrSec (instrSessionBase, firstFreeSecAddr, CDMA2KFunctionGroup, errorMessage)) < 0)
            return RSCMU_Base_errorMessage (instrSessionBase, RSCMU_ERROR_INVALID_FCT_GRP, errorMessage);
        Flag = RSCMU_ON;        
        secondAddr = firstFreeSecAddr;
      }
    
      // Hardware Connection
      if (strncmp ("GPIB",p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection, 4) == 0)
          sprintf (resource, "%s::%d::%d::INSTR",p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection, p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address, secondAddr);
      else
          sprintf (resource, "%s::INSTR",p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection);
       
      // Open instrument session 
      if( (RSCMU_Status = viOpen (DefaultRM, resource, VI_NULL, 5000,
                           instrSessionCDMA)) < 0 )
      {
         if( (RSCMU_Status = viClose( DefaultRM )) < 0 )
         {
            return( RSCMU_Status );
         }
      }

      // Allocate space for "struct RSCMU_SESSION_Globals" 
      if( (p_globalvarCDMA =
            (struct RSCMU_CDMA_Globals *)
            malloc(sizeof(struct RSCMU_CDMA_Globals))) == 0 )
      {
         return RSCMU_initCleanUp( DefaultRM
                                 , *instrSessionCDMA
                                 , RSCMU_Status
                                 );
      }
       
      if( (RSCMU_Status = viSetAttribute( *instrSessionCDMA
                                        , VI_ATTR_USER_DATA
                                        , (ViAttrState)p_globalvarCDMA
                                        )) < 0 )
      {
         return RSCMU_initCleanUp( DefaultRM
                                 , *instrSessionCDMA
                                 , RSCMU_Status
                                 );
      }                        

      // Set initial values of variables for function Group 'CDMA'
      p_globalvarCDMA->RSCMU_XtndCQU    = VI_FALSE; // JMG 020923
      p_globalvarCDMA->RSCMU_XtndOVER   = VI_FALSE; // JMG 020923
      p_globalvarCDMA->RSCMU_XtndMOD    = VI_FALSE;      
      
      strcpy( p_globalvarCDMA->RSCMU_tGlobal.FGrp_Name, FctGrpBuffer );
      strcpy (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_SCPIConnection, p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection);
      
      p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version =    
         p_globalvarBase->RSCMU_tGlobal.RSCMU_FW_Version;

      // JMG 030107
      // Driver version 
      strcpy (p_globalvarCDMA->RSCMU_tGlobal.DrvVersion, RSCMUC2K_REVISION);
         
      // FW version char mode
      strcpy (p_globalvarCDMA->RSCMU_tGlobal.CmuVersion, p_globalvarBase->RSCMU_tGlobal.CmuVersion);

      // CMU type     
      p_globalvarCDMA->RSCMU_tGlobal.RSCMU_Type = p_globalvarBase->RSCMU_tGlobal.RSCMU_Type;         
      
      p_globalvarCDMA->RSCMU_tGlobal.RSCMU_primary_address   = 
         p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address;

      p_globalvarCDMA->RSCMU_tGlobal.RSCMU_secondary_address = secondAddr;

      // js 9/4/2001
      p_globalvarCDMA->RSCMU_tGlobal.RSCMU_SessionNb = *instrSessionCDMA;
      
      p_globalvarCDMA->RSCMU_tGlobal.RSCMU_TRACE             = 
         p_globalvarBase->RSCMU_tGlobal.RSCMU_TRACE;
   
      //*** ht 22/09/2000
      //*** If the RSCMU_Trace_ON has already been executed, record the characteristics of
      //*** the trace file, then the base can trace what's appening on the secondary address
      //*** initialized in THIS function (It was not the case before: we were obliged to 
      //*** set the trace to ON after, and only after initialization of All the secondary addresses
      //*** we want to trace)
      p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FileHandle        =
         p_globalvarBase->RSCMU_tGlobal.RSCMU_FileHandle;
      
      p_globalvarCDMA->RSCMU_tGlobal.RSCMU_AddrTargetFile    =
         (ViAddr) p_globalvarBase->RSCMU_tGlobal.RSCMU_AddrTargetFile;
      
      p_globalvarCDMA->RSCMU_tGlobal.RSCMU_StateTraceFile    =
         p_globalvarBase->RSCMU_tGlobal.RSCMU_StateTraceFile;
      //*** ht 22/09/2000
      
      // Record the execution of this Init Function.    
      p_globalvarBase->RSCMU_tSecAddr[secondAddr].SessionNb = 
         *instrSessionCDMA;  
  
      
      if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10)
        // Timeout changed from 3s to 35 seconds 
        RSCMU_Status = viSetAttribute( *instrSessionCDMA , VI_ATTR_TMO_VALUE , 35000);
      else
        // Tiemout set to 3 TIMEOUT basic value
        RSCMU_Status = viSetAttribute( *instrSessionCDMA , VI_ATTR_TMO_VALUE , 3 * RSCMU_TMO_VALUE);
   }
   else
   {
      RSCMU_Status = -1;
   }
   
   p_globalvarCDMA->RSCMU_tGlobal.RSCMU_Stb = 2;
                  
   return( RSCMU_Status );

} // end of RSCMU_Init_CDMA2K()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InpState
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_InpState (ViSession instrSession,
                                         ViInt32 selectionOfInputConnector,
                                         ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   
   checkRange( 1, &selectionOfInputConnector );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[1].instrCommand
          , inpConn.list[selectionOfInputConnector]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
  
   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_InpState()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_OutpState
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_CDMA2K_OutpState( ViSession instrSession
                      , ViInt32   selectionOfOutputConnector
                      , ViChar    errorMessage[]
                      )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 2, &selectionOfOutputConnector );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[2].instrCommand
          , outpConn.list[selectionOfOutputConnector]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_OutpState()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SenseCorrLossInp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_CDMA2K_SenseCorrLossInp( ViSession instrSession
                              , ViInt32   selectionOfInputConnector
                              , ViReal64  externalAttenuationdB
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 3, &selectionOfInputConnector, &externalAttenuationdB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[3].instrCommand
          , inpSrc.list[selectionOfInputConnector]
          , externalAttenuationdB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SenseCorrLossInp()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourceCorrLossOutp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_CDMA2K_SourceCorrLossOutp( ViSession instrSession
                                , ViInt32   selectionOfOutputConnector
                                , ViReal64  externalAttenuationdB
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 6, &selectionOfOutputConnector, &externalAttenuationdB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[6].instrCommand
          , outpSrc.list[selectionOfOutputConnector]
          , externalAttenuationdB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourceCorrLossOutp()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CorrLossInpOutp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

// JMG 020917
ViStatus _VI_FUNC RSCMU_CDMA2K_CorrLossInpOutp (ViSession instrSession,
                                                ViInt32 selection_ofOutputConnector,
                                                ViReal64 Output_Attenuation_dB,
                                                ViInt32 selection_ofInputConnector,
                                                ViReal64 Input_Attenuation_dB,
                                                ViChar errorMessage[])
{
    
   ViStatus  RSCMU_Status   = VI_SUCCESS; 
   ViChar    Format[80]     = {NULL};
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   
   checkRange( 5, &selection_ofOutputConnector, &Output_Attenuation_dB );
   checkRange( 3, &selection_ofInputConnector, &Input_Attenuation_dB );
   
   getBuffers( instrSession
                 , &wrtBuf
                 , &rdBuf
                 , errorMessage
                 );
                                 
   
   strcpy(Format,CDMA[6].instrCommand );
   strcat(Format,";:\0");
   strcat(Format,CDMA[3].instrCommand);
   strcat(Format,"\0");
   
   sprintf( wrtBuf
                  , Format
                  , outpSrc.list[selection_ofOutputConnector]
                  , Output_Attenuation_dB
                  , inpSrc.list[selection_ofInputConnector]
                  , Input_Attenuation_dB
                  
                  );

   
     
   
   RSCMU_Status = RSCMU_Query( instrSession
                 , wrtBuf
                 , rdBuf
                 , RSCMU_STB_ON
                 , errorMessage
                 );

   return( RSCMU_Status );


}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_RoutSpenInp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_RoutSpenInp (ViSession instrSession,
                                            ViInt32 speechEncoder,
                                            ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA; 

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_08)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_08, errorMessage); 

   checkRange( 489, &speechEncoder );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[489].instrCommand
          , inpSpeCod.list[speechEncoder]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_RoutSpenInp()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_RoutSpdOutp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_RoutSpdOutp (ViSession instrSession,
                                            ViInt32 speechDecoder,
                                            ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;  

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_08)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_08, errorMessage); 

  checkRange( 490, &speechDecoder );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[490].instrCommand
          , outSpeDecod.list[speechDecoder]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

}  //end of RSCMU_CDMA2K_RoutSpdOutp()

/**************************************************************************
 *
 * NAME:        RSCMU_CMDA2K_ConfIQIFRxTxPath
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      routingPathForRXTXPath
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIQIFRxTxPath (ViSession  instrSession,
                                                 ViInt32    routingPathForRXTXPath,
                                                 ViChar     errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;  

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

  checkRange( 555, &routingPathForRXTXPath );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[555].instrCommand
          , routingPath.list[routingPathForRXTXPath]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of RSCMU_CMDA2K_ConfIQIFRxTxPath

/**************************************************************************
 *
 * NAME:        RSCMU_CMDA2K_ConfIQIFRxPath
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      routingPathForRXPath
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIQIFRxPath (ViSession instrSession,
                                                 ViInt32 routingPathForRXPath,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;  

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

  checkRange( 556, &routingPathForRXPath );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[556].instrCommand
          , routingPath.list[routingPathForRXPath]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );        
}//end of RSCMU_CMDA2K_ConfIQIFRxPath

/**************************************************************************
 *
 * NAME:        RSCMU_CMDA2K_ConfIQIFTxPath
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      routingPathForTXPath
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIQIFTxPath (ViSession instrSession,
                                               ViInt32 routingPathForTXPath,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;  

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

  checkRange( 557, &routingPathForTXPath );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[557].instrCommand
          , routingPath.list[routingPathForTXPath]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );        
} //end of RSCMU_CMDA2K_ConfIQIFTxPath 

/*****************************************************************************
 * Function: IF Level
 * Purpose:  This function reads the IF output level in the TX path relative 
 *           to the maximum IF input/output level (PEP) cited in the data 
 *           sheet. The value is equal to the I/Q output level in the TX path 
 *           relative to the maximum I/Q input voltage cited in the data sheet.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SensIQIFIfl(
    ViSession   instrSession,
    ViReal64*   ifLevel,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_getViReal64 (instrSession,
                               "SENS:IQIF:IFL?",
                               ifLevel,
                               RSCMU_ERROR_PARAMETER2));
                               
}

/*****************************************************************************
 * Function: RX, TX Frequency Coupling
 * Purpose:  This function enables or disables Rx/Tx Frequency Coupling. If
 *           coupling is enabled while the Rx channels
 *           ([SENSe]:RFANalyzer:FREQuency) and Tx channels
 *           (SOURce:RFGenerator:FREQuency[:RF]) are different, the RF
 *           analyzer (Rx) channel is adjusted.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfFreqCoupRxTx (ViSession instrSession,
                                                 ViInt32 frequencyCoupling,
                                                 ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession, 
                           "CONF:FREQ:COUP:RXTX",
                           frequencyCoupling,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: RF Selectivity
 * Purpose:  This function selects the bandwidth of the analog receiver
 *           filter.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseRfanSel (ViSession instrSession,
                                             ViInt32 selectivity,
                                             ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession, 
                           "SENS:RFAN:SEL",
                           selectivity,
                           rfSelArr,
                           RSCMU_ERROR_PARAMETER2));
}
/***************************************************************************** 
 * Function: Low spur mode
 * Purpose:  This function sets the Low Spur Mode.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfLsm (ViSession instrumentHandle,
                                             ViBoolean mode, ViChar errorMessage[])
{
    RETMSG ( RSCMU_setEnum(instrumentHandle,
                           "CONF:LSM",
                           (ViInt32)mode,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
    
}
/***************************************************************************** 
 * Function: Handoff phase relationship
 * Purpose:  This function specifies whether the phase relationship.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SystMiscB83T (ViSession instrumentHandle,
                                             ViBoolean phase_relationship,
                                             ViChar errorMessage[])
{
    RETMSG ( RSCMU_setEnum(instrumentHandle,
                              "SYST:MISC:B83T",
                              phase_relationship,
                              stateArr,
                              RSCMU_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourceDmClockState
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_CDMA2K_SourceDmClockState( ViSession instrSession
                                , ViBoolean referenceFreqAtREFOUT2
                                , ViChar    errorMessage[]
                                )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 7, &referenceFreqAtREFOUT2 );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[7].instrCommand
          , enable.list[referenceFreqAtREFOUT2]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourceDmClockState()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourceDmClockFreq
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_CDMA2K_SourceDmClockFreq( ViSession instrSession
                               , ViInt32   referenceFrequency
                               , ViChar    errorMessage[]
                               )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 8, &referenceFrequency );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[8].instrCommand
          , clkFreq.list[referenceFrequency]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourceDmClockFreq()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SenseLevMode
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC
   RSCMU_CDMA2K_SenseLevMode( ViSession instrSession
                          , ViInt32   inputLevelSetting
                          , ViChar    errorMessage[]
                          )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 9, &inputLevelSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[9].instrCommand
          , mode.list[inputLevelSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SenseLevMode()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SenseLevMax
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC
   RSCMU_CDMA2K_SenseLevMax( ViSession instrSession
                         , ViReal64  inputLevelMaximumdBm
                         , ViChar    errorMessage[]
                         )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 10, &inputLevelMaximumdBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[10].instrCommand
          , inputLevelMaximumdBm
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SenseLevMax()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SenseLevModeMax
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

// JMG 020917
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseLevModeMax (ViSession   instrSession,
                                                ViReal64    inputLevelMaximum_dBm,
                                                ViInt32     setRFAnalMode,
                                                ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    Format[80]  = {NULL};
   
   checkRange( 9, &setRFAnalMode );
   checkRange( 10, &inputLevelMaximum_dBm );
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   
   strcpy( Format,CDMA[10].instrCommand);
   strcat( Format,";:\0");
   strcat( Format, CDMA[9].instrCommand);
   strcat( Format,"\0");
   
   sprintf( wrtBuf
          , Format
          , inputLevelMaximum_dBm
          , mode.list[setRFAnalMode]
          );
          
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefRfAnalyzer
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      RFAnalyzerState
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefRfAnalyzer (ViSession instrSession,
                                              ViInt32 RFAnalyzerState,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 534, &RFAnalyzerState);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[534].instrCommand
          , enable.list[RFAnalyzerState]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_DefRfAnalyzer

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_TrigSeqSourOQPSK
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC 
   RSCMU_CDMA2K_TrigSeqSourOQPSK (ViSession instrSession
                                 , ViInt32 triggerSource
                                 , ViChar errorMessage[]
                                 )
                                 
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 13, &triggerSource );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[13].instrCommand
          , trigSourType.list[triggerSource]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_TrigSeqSourOQPSK()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_TrigSeqSourHPSK
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_TrigSeqSourHPSK (ViSession instrSession,
                                                ViInt32 triggerSource,
                                                ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 14, &triggerSource );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[14].instrCommand
          , trigSourType.list[triggerSource]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_TrigSeqSourHQSK()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_TrigSeqSourQPSK
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/



ViStatus _VI_FUNC RSCMU_CDMA2K_TrigSeqSourQPSK (ViSession instrSession,
                                                ViInt32 triggerSource,
                                                ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 15, &triggerSource );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[15].instrCommand
          , trigSourType.list[triggerSource]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_TrigSeqSourQPSK()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SenseRfanChan
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_CDMA2K_SenseRfanChan( ViSession instrSession
                           , ViInt32   channel
                           , ViChar    errorMessage[]
                           )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 20, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[20].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SenseRfanChan()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SenseRfanFreq
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_CDMA2K_SenseRfanFreq( ViSession instrSession
                              , ViReal64  frequency
                              , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   // checkRange routine is not used due to bug in how unions are
   // handled when initializing float types.
   if( frequency < 0.2 )  frequency = 0.2;
   if( frequency > 2700 ) frequency = 2700;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[21].instrCommand
          , frequency
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SenseRfanFreq()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SenseRfanFOffset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SenseRfanFOffset (ViSession instrSession,
                                                 ViReal64 freqOffset,
                                                 ViBoolean Enable,
                                                 ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 22, &freqOffset );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
              , CDMA[22].instrCommand
              , freqOffset 
              , enable.list[Enable]);
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end ofRSCMU_CDMA2K_SenseRfanFOffset()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_TrigSour
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      triggerSource
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_TrigSour (ViSession instrSession,
                                         ViInt32 triggerSource,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 622, &triggerSource );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[622].instrCommand
          , trigSourType.list[triggerSource]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );        
}//end of RSCMU_CDMA2K_TrigSour

/*****************************************************************************
 * Function: Trigger Slope
 * Purpose:  This command qualifies whether the trigger event occurs on the 
 *           Rising Edge or on the Falling Edge of the trigger signal.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_TrigSlop (ViSession instrSession,
                                         ViInt32 slope, ViChar errorMessage[])
{
    return RSCMU_setEnum (instrSession,
                          "TRIG:SLOP",
                          slope,
                          slopeArr,
                          VI_ERROR_PARAMETER2);
}

/*****************************************************************************
 * Function: RF Power Trigger Threshold
 * Purpose:  This function sets the RF input signal level at which the 
 *           measurement is triggered relative to the maximum RF input level. 
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_TrigThrRfp (ViSession instrSession,
                                           ViInt32 threshold,
                                           ViChar errorMessage[])
{
    return RSCMU_setEnum (instrSession,
                          "TRIG:THR:RFP",
                          threshold,
                          triggerThrArr,
                          VI_ERROR_PARAMETER2);
}

/*****************************************************************************
 * Function: IF Power Trigger Threshold
 * Purpose:  This function sets the IF signal level at which the measurement 
 *           is triggered. The IF power threshold is defined relative to the 
 *           maximum RF input level.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_TrigThrIfp (ViSession instrSession,
                                           ViReal64 threshold,
                                           ViChar errorMessage[])
{
    return RSCMU_setViReal64 (instrSession,
                              "TRIG:THR:IFP",
                              threshold,
                              -47.0, 0.0,
                              VI_ERROR_PARAMETER2);
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefTrigSource
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      triggerSourceState
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefTrigSource (ViSession instrSession,
                                              ViInt32 triggerSourceState,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 535, &triggerSourceState);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[535].instrCommand
          , enable.list[triggerSourceState]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );       
}//end of RSCMU_CDMA2K_DefTrigSource

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_TrigOutpPinSignal
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      triggerSourceState
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_TrigOutpPinSignal (ViSession instrSession,
                                                  ViInt32   Pin,
                                                  ViInt32   triggerOutpRouting,
                                                  ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 537, &triggerOutputRouting, &Pin);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[537].instrCommand
          , Pin
          , triggerOutputRouting.list[triggerOutpRouting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );        
}//end of RSCMU_CDMA2K_TrigOutpPinSignal 

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefTrigSet
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      triggerSourceState
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
    
ViStatus _VI_FUNC RSCMU_CDMA2K_DefTrigSet (ViSession instrSession,
                                           ViInt32 defaultAllTriggerSet,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 536, &defaultAllTriggerSet);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[536].instrCommand
          , enable.list[defaultAllTriggerSet]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );     
}//end of RSCMU_CDMA2K_DefTrigSet

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRfGenRfFrequency
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRfFrequency (ViSession instrSession,
                                                     ViReal64 frequency,
                                                     ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   // checkRange routine is not used due to bug in how unions are
   // handled when initializing float types.
   if( frequency < 0.2 )  frequency = 0.2;
   if( frequency > 2700 ) frequency = 2700;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[39].instrCommand
          , frequency
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourRfGenRfFrequency()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRfGenRfChannel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRfChannel (ViSession instrSession,
                                                   ViInt32 channel,
                                                   ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 40, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[40].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourRfGenRfChannel()    


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRfGenModMode
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/



ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenModMode (ViSession instrSession,
                                                 ViInt32 modulationMode,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 41, &modulationMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[41].instrCommand
          , modMode.list[modulationMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_SourRfGenModMode()
 
  
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRFGenFSyncLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SourRFGenFSyncLev (ViSession instrSession,
                                                    ViReal64 syncLevel,
                                                    ViBoolean Enable, 
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 42, &syncLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[42].instrCommand
          , syncLevel
          , enable.list[Enable]
          );
       
   
    
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourRfGenFSyncLevel()

   
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRFGenFPilotChLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SourRFGenFPilotChLev (ViSession instrSession,
                                                       ViReal64 pilotLevel,
                                                       ViBoolean Enable,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 43, &pilotLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
    sprintf( wrtBuf
          , CDMA[43].instrCommand
          , pilotLevel
          , enable.list[Enable]
          );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourRfGenFPilotChLevel()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRFGenFPagingChLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SourRFGenFPagingChLev (ViSession instrSession,
                                                        ViReal64 pagingLevel,
                                                        ViBoolean Enable, 
                                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 44, &pagingLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[44].instrCommand
          , pagingLevel
          , enable.list[Enable]
          );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourRfGenFPagingChLevel()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRFGenProPNOffset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenProPNOffset (ViSession instrSession,
                                                     ViInt32 PNOffset,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 45, &PNOffset );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
              , CDMA[45].instrCommand
              , PNOffset
              );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourRfGenProPNOffset()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRfGenRfPowCDMA
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRfPowCDMA (ViSession instrSession,
                                                   ViReal64 CDMAPower_dBm,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 46, &CDMAPower_dBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
              , CDMA[46].instrCommand
              , CDMAPower_dBm
              );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourRfGenRfPowCDMA()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRfGenRfPowOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/



ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRfPowOut (ViSession instrSession,
                                                  ViReal64 *outputPower_dB,
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[47].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", outputPower_dB );
   }
   else
   {
      *outputPower_dB = RSCMU_NAN;
   }

   return( RSCMU_Status );

    
} // end of RSCMU_CDMA2K_SourRfGenRfPowOut() 


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRfGenRfLevOCNSValue
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/



ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRfLevOCNSValue (ViSession instrSession,
                                                        ViReal64 *OCNSValue,
                                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[48].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", OCNSValue );
   }
   else
   {
      *OCNSValue = RSCMU_NAN;
   }

   return( RSCMU_Status );

    
} // end of RSCMU_CDMA2K_SourRfGenRfLevOCNSValue() 


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRfGenRfLevOCNSEnable
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRfLevOCNSEnable (ViSession instrSession,
                                                         ViInt32 OCNSEnable,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 49, &OCNSEnable );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[49].instrCommand
          , modeEnable.list[OCNSEnable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourceRfGOCNS()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourImpairmentsRfLevAWGN
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SourImpairRfLevAWGN (ViSession instrSession,
                                                       ViReal64 AWGNLevel,
                                                       ViBoolean Enable,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 50, &AWGNLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[50].instrCommand
          , AWGNLevel
          , enable.list[Enable]
          );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourImpairmentsRfLevAWGN()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourImpairmentsRfFreqOff
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SourImpairRfFreqOffset (ViSession instrSession,
                                                         ViReal64 freqOffset,
                                                         ViBoolean Enable,
                                                         ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 51, &freqOffset );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
    sprintf( wrtBuf
          , CDMA[51].instrCommand
          , freqOffset
          , enable.list[Enable]
          );
 
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourImpairmentsRfFreqOff()

/*****************************************************************************
 * Function: Radio Configuration
 * Purpose:  This function selects the radio configuration for the (forward) 
 *           RF generator signal.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRc(
    ViSession   instrSession,
    ViInt32 radioConfiguration,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "SOUR:RFG:RC",
                              radioConfiguration,
                              1, 5,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Rate Set
 * Purpose:  This function returns the rate set which is determined by the 
 *           selected radio configuration for the (forward) RF generator signal 
 *           (SOURce:RFGenerator:RC).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenRset(
    ViSession   instrSession,
    ViReal64*   rateSet,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_getViReal64 (instrSession,
                               "SOUR:RFG:RSET?",
                               rateSet,
                               RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: System ID Number
 * Purpose:  This function defines the system identification for the CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenSid(
    ViSession   instrSession,
    ViInt32 sid,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "SOUR:RFG:SID",
                              sid,
                              0, 32767,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Protocol Revision
 * Purpose:  This function defines the preferred version of the protocol for 
 *           the CMU to use.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenPrev(
    ViSession   instrSession,
    ViInt32 protocolRevision,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "SOUR:RFG:PREV",
                              protocolRevision,
                              1, 6,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Minimum Protocol Revision
 * Purpose:  This function defines the minimum protocol revision capability of 
 *           the mobile station.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenMprev(
    ViSession   instrSession,
    ViInt32 minimumProtocolRevision,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "SOUR:RFG:MPR",
                              minimumProtocolRevision,
                              1, 6,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Network ID Number
 * Purpose:  This function defines the 16-bit network identity code.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenNid(
    ViSession   instrSession,
    ViInt32 nid,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "SOUR:RFG:NID",
                              nid,
                              0, 65535,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Paging Channel Rate
 * Purpose:  This function defines data rate of the base station’s paging 
 *           channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenPchRate(
    ViSession   instrSession,
    ViInt32 pagingChannelRate,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "SOUR:RFG:PCH:RATE",
                           pagingChannelRate,
                           channelRateArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: ESN
 * Purpose:  This function defines the Electronic Serial Number of the mobile 
 *           station. The number must be entered as an 8-digit hex string.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenEsn(
    ViSession   instrSession,
    ViString    esn,
 ViChar errorMessage[]
)
{
    ViChar  command[40];
    
    if (strlen (esn) > 8)
        return RSCMU_ERROR_PARAMETER2;
    
    sprintf (command, "SOUR:RFG:ESN '%s'", esn);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Zero Long Code Mask
 * Purpose:  This function enables or disables the zero long code mask. If 
 *           this parameter is set to ON, then the calculated long code mask is 
 *           replaced by an all zero sequence.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenZlcm(
    ViSession   instrSession,
    ViBoolean   zeroLongCodeMask,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "SOUR:RFG:ZLCM",
                           zeroLongCodeMask,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefRfGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefRfGenerator (ViSession instrSession,
                                               ViInt32 RFGeneratorState,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 538, &RFGeneratorState);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[538].instrCommand
          , enable.list[RFGeneratorState]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );      
}//end of RSCMU_CDMA2K_DefRfGenerator

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRfGenFFCHLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenFFCHLev (ViSession instrSession,
                                                   ViReal64 FFCHLevel,
                                                   ViBoolean Enable, 
                                                   ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 52, &FFCHLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
    sprintf( wrtBuf
          , CDMA[52].instrCommand
          , FFCHLevel
          , enable.list[Enable]
          );
 
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end ofRSCMU_CDMA2K_SourRfGenFFCHLevel()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRfGenFFCHCh
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/



ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenFFCHCh (ViSession instrSession,
                                                ViInt32 FFCHChannel,
                                                ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 53, &FFCHChannel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[53].instrCommand
          , FFCHChannel
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourRfGenFFCHCh()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRfGenFFCHFrameOffset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/



ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenFFCHFrameOffset (ViSession instrSession,
                                                         ViInt32 FFCHFrameOffset,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 54, &FFCHFrameOffset );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[54].instrCommand
          , FFCHFrameOffset
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_SourRfGenFFCHFrameOffset()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SourRfGenFFCHFrameRate
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/



ViStatus _VI_FUNC RSCMU_CDMA2K_SourRfGenFFCHFrameRate (ViSession instrSession,
                                                       ViInt32 frameRate,
                                                       ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 55, &frameRate );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
    
   sprintf( wrtBuf
          , CDMA[55].instrCommand
          , frameRateType.list[frameRate]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SourRfGenFFCHFrameRate()



/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitRfGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_CDMA2K_InitRfGenerator( ViSession instrSession
                             , ViChar    errorMessage[]
                             )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[56].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_InitRfGenerator()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortRfGenerator
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_CDMA2K_AbortRfGenerator( ViSession instrSession
                              , ViChar    errorMessage[]
                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[57].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_AbortRfGenerator()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchRfGeneratorStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC 
   RSCMU_CDMA2K_FetchRfGeneratorStatus( ViSession  instrSession
                                    , ViInt32   *generatorStatus
                                    , ViChar     errorMessage[]
                                    )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  
   // Fetch the generator status:
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[58].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
      // Get the generator status:
      if( strncmp( "OFF", rdBuf, 3 ) == 0 ) 
      {
         *generatorStatus = RSCMU_GEN_STAT_OFF;
      }
      else if( strncmp( "RUN", rdBuf, 3 ) == 0 )
      {
         *generatorStatus = RSCMU_GEN_STAT_RUN;
      }
      else if( strncmp( "ERR", rdBuf, 3 ) == 0 )
      {
         *generatorStatus = RSCMU_GEN_STAT_ERR;
      }
   }

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_FetchRfGeneratorStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCpcCLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCLev (ViSession instrSession,
                                                 ViReal64 CDMAPower,
                                                 ViReal64 FCHLevel,
                                                 ViReal64 pilotLevel,
                                                 ViReal64 SCH1Level,
                                                 ViReal64 SCH2Level,
                                                 ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 140 
            , &CDMAPower
            , &FCHLevel
            , &pilotLevel
            , &SCH1Level
            , &SCH2Level
            );
            
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
              , CDMA[140].instrCommand
              , CDMAPower
              , FCHLevel
              , pilotLevel
              , SCH1Level
              , SCH2Level
              );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfCDPowCpcCLev()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCpcCContPCDMA
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCContPCDMA (ViSession instrSession,
                                                       ViReal64 CDMAPower,
                                                       ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 141, &CDMAPower );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[141].instrCommand
          , CDMAPower
          );
     
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfCDPowCpcCContPCDMA()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCpcCContLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCContLev (ViSession instrSession,
                                                     ViReal64 FCHLevel,
                                                     ViReal64 pilotLevel,
                                                     ViReal64 SCH1Level,
                                                     ViReal64 SCH2Level,
                                                     ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 142 
            , &FCHLevel
            , &pilotLevel
            , &SCH1Level
            , &SCH2Level
            );
            
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
              , CDMA[142].instrCommand
              , FCHLevel
              , pilotLevel
              , SCH1Level
              , SCH2Level
              );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfCDPowCpcCContLev()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCpcCImpairments
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCImpairments (ViSession instrSession,
                                                         ViReal64 AWGNLevel,
                                                         ViBoolean AWGNEnable, 
                                                         ViReal64 BSFreqOffset,
                                                         ViBoolean BSFreqOffsetEnable,    
                                                         ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 143 
            , &AWGNLevel
            , &BSFreqOffset
            );
            
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
              , CDMA[143].instrCommand
              , AWGNLevel
              , BSFreqOffset
              , enable.list[AWGNEnable]
              , enable.list[BSFreqOffsetEnable]
              );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfCDPowCpcCImpairments()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCpcCPCBits
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

// JMG 021002
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCPCBits (ViSession   instrSession,
                                                    ViInt32     PowerControlBits,
                                                    ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 532
             , &PowerControlBits
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[532].instrCommand
          , powerCtlBits.list[PowerControlBits]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowCpcCPCBits()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowContFratFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      frameRate
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowContFratFFCH (ViSession instrSession,
                                                      ViInt32 frameRate,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 650, &frameRate );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[650].instrCommand
          , frameRateType.list[frameRate] 
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );              
}//end of RSCMU_CDMA2K_ConfCDPowContFratFFCH
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalCDPowCpccEbntFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     calculatedEbNtFFCH
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalCDPowCpccEbntFFCH (ViSession instrSession,
                                                     ViReal64 *calculatedEbNtFFCH,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];   
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar*)CDMA[647].instrCommand  
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", calculatedEbNtFFCH );
   }
   else
   {
      *calculatedEbNtFFCH = RSCMU_NAN;
   }
                             

   return( RSCMU_Status );         
}//end of RSCMU_CDMA2K_CalCDPowCpccEbntFFCH
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalCDPowCpccEbntFSCHZero
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     calculatedEbNtFSCH0
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *                                                 
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalCDPowCpccEbntFSCHZero (ViSession instrSession,
                                                         ViReal64 *calculatedEbNtFSCH0,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];   
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar*)CDMA[648].instrCommand  
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", calculatedEbNtFSCH0 );
   }
   else
   {
      *calculatedEbNtFSCH0 = RSCMU_NAN;
   }
                             

   return( RSCMU_Status );      
}//end of RSCMU_CDMA2K_CalCDPowCpccEbntFSCHZero
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalCDPowCpccEbntFSCHOne
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     calculatedEbNtFSCH1
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalCDPowCpccEbntFSCHOne (ViSession instrSession,
                                                        ViReal64 *calculatedEbNtFSCH1,
                                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];   
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar*)CDMA[649].instrCommand  
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", calculatedEbNtFSCH1 );
   }
   else
   {
      *calculatedEbNtFSCH1 = RSCMU_NAN;
   }
                             

   return( RSCMU_Status );     
}//end of RSCMU_CDMA2K_CalCDPowCpccEbntFSCHOne

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCpcCCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
       
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCCont (ViSession instrSession,
                                                  ViBoolean commonControlSetting,
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 144, &commonControlSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[144].instrCommand
          , enable.list[commonControlSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ConfCDPowCpcCCont()


/*****************************************************************************
 * Function: Power Control Bits
 * Purpose:  This function selects the power control bit sequence that the CMU 
 *           sends to the mobile station to control its output power.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCEnvPCBits (ViSession instrSession,
                                                       ViInt32 powerControlBits,
                                                       ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:CDP:CPCC:ENV:PCB",
                           powerControlBits,
                           PCBArr,
                           VI_ERROR_PARAMETER2));
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCpcCLimAsym
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/



ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCLimAsym (ViSession instrSession,
                                                     ViInt32 limitLinesSetting,
                                                     ViReal64 carrierFeedthroughLimit,
                                                     ViReal64 freqErrorLimit,
                                                     ViReal64 rhoLimit,
                                                     ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 145
             , &limitLinesSetting
             , &carrierFeedthroughLimit
             , &freqErrorLimit
             , &rhoLimit
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[145].instrCommand
          , limitLinesMode.list[limitLinesSetting]
          , carrierFeedthroughLimit
          , freqErrorLimit
          , rhoLimit
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ConfCDPowCpcCCont()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefCDPowCpccLimit
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      commonLimitSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowCpccLimit (ViSession instrSession,
                                                  ViBoolean commonLimitSetting,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 651, &commonLimitSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[651].instrCommand
          , enable.list[commonLimitSetting] 
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );                  
}
//end of RSCMU_CDMA2K_DefCDPowCpccLimit

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCDPWCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWCont  (ViSession instrSession,
                                                   ViInt32 ResultMode,
                                                   ViInt32 Statistics,
                                                   ViInt32 Rep,
                                                   ViInt32 StopCondition,
                                                   ViInt32 StepMode,
                                                   ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 146
             , &ResultMode
             , &Statistics
             , &Rep
             , &StopCondition 
             , &StepMode 
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[146].instrCommand
          , resultMode.list[ResultMode]
          , Statistics
          , repetition.list[Rep]
          , stopCond3.list[StopCondition]
          , stepMode.list[StepMode]
          );

       RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   
   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowCDPWCont()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCDPWRMode
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWRMode (ViSession instrSession,
                                                   ViInt32 ResultMode,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 147
             , &ResultMode
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[147].instrCommand
          , resultMode.list[ResultMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowCDPWRMode()

/*****************************************************************************
 * Function: Spreading Factor
 * Purpose:  This function defines the code class in which the uplink CDMA 
 *           signal is evaluated.  
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWSfac (ViSession instrSession,
                                                  ViInt32 spreadingFactor,
                                                  ViChar errorMessage[])
{
    if ((spreadingFactor != 16) && (spreadingFactor !=32))
        RETMSG (VI_ERROR_PARAMETER2);
        
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:CDP:CDPW:CONT:SFAC",
                              spreadingFactor,
                              16,32,
                              0));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCDPWROrder
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWROrder (ViSession instrSession,
                                                    ViInt32 ResultOrder,
                                                    ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 148
             , &ResultOrder
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[148].instrCommand
          , resultOrder.list[ResultOrder]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowCDPWROrder()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCDPWContStats
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWContStats (ViSession instrSession,
                                                       ViInt32 Statistics,
                                                       ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 149
             , &Statistics
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[149].instrCommand
          , Statistics
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowCDPWContStats()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCDPWContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWContRep (ViSession instrSession,
                                                     ViInt32 Repetition,
                                                     ViInt32 StopCondition,
                                                     ViInt32 StepMode,
                                                     ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 150
             , &Repetition
             , &StopCondition 
             , &StepMode 
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[150].instrCommand
          , repetition.list[Repetition]
          , stopCond3.list[StopCondition]
          , stepMode.list[StepMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowCDPWContRep()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefCDPowCDPWCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowCDPWCont (ViSession instrSession,
                                                 ViBoolean state,
                                                 ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 151, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[151].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_DefCDPowCDPWCont()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCDPWLimAsym
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWLimAsym (ViSession instrSession,
                                                     ViInt32 limitLinesSetting,
                                                     ViReal64 CDPLimitY,
                                                     ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 152
             , &limitLinesSetting
             , &CDPLimitY
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[152].instrCommand
          , limitLinesMode.list[limitLinesSetting]
          , CDPLimitY
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ConfCDPowCDPWLimAsym()

/*****************************************************************************
 * Function: IQ Leakage Check
 * Purpose:  This function couples or decouples the limit check in the I and Q 
 *           branches.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWLimIql (ViSession instrSession,
                                                    ViBoolean IQLeakageCheck,
                                                    ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:CDP:CDPW:LIM:IQLC",
                           IQLeakageCheck,
                           stateArr,
                           VI_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefCDPowCDPWLimit
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      limitSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowCDPWLimit (ViSession instrSession,
                                                  ViBoolean limitSetting,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 652, &limitSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[652].instrCommand
          , enable.list[limitSetting] 
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );                      
}//end of RSCMU_CDMA2K_DefCDPowCDPWLimit

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitCDPowCDPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_InitCDPowCDPW (ViSession instrSession,
                                              ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[153].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_InitCDPowCDPW()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortCDPowCDPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_AbortCDPowCDPW (ViSession instrSession,
                                               ViChar errorMessage[])
                                               
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[154].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_AbortCDPowCDPW()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StopCDPowCDPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_StopCDPowCDPW (ViSession instrSession,
                                              ViChar errorMessage[])
                                              
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[155].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_StopCDPowCDPW()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ContinueCDPowCDPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueCDPowCDPW (ViSession instrSession,
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[156].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ContinueCDPowCDPW()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchCDPowCDPWStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchCDPowCDPWStatus (ViSession instrSession,
                                                     ViInt32 *measurementStatus,
                                                     ViInt32 *counter_forStatisticsCycle,
                                                     ViInt32 *counter_forEvaluationPeriod,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[157].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

       // Get the counter for current statistics cycle
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", counter_forStatisticsCycle );
       }
       else
       {
          *counter_forStatisticsCycle = RSCMU_OFF;
       }

   }

   return RSCMU_Status;
          
} // end of RSCMU_CDMA2K_FetchCDPowCDPWStatus()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCDPWErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCDPWErep (ViSession instrSession,
                                                  ViInt32 measurementEventReporting,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 158, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[158].instrCommand
          , eventReport.list[measurementEventReporting]      
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ConfCDPowCDPWErep()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadScalCDPowCDPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowCDPW (ViSession instrSession,   
                                                  CODE_DOMAIN_POWER *CDPW,
                                                  ViChar errorMessage[])   
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[159].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
  
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW->msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW->CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW->FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW->rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW->OutOfTolerance);
   }
   else
   {
      CDPW->OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW->CurrentStatistics );
   }
   else
   {
      CDPW->CurrentStatistics = RSCMU_NAN;
   }
     
   return( RSCMU_Status );    
} //end of RSCMU_CDMA2K_ReadScalCDPowCDPW()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchScalCDPowCDPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowCDPW (ViSession instrSession, 
                                                    CODE_DOMAIN_POWER *CDPW,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[160].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW->msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW->CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW->FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW->rho
                                       );
   
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW->OutOfTolerance );
   }
   else
   {
      CDPW->OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW->CurrentStatistics );
   }
   else
   {
      CDPW->CurrentStatistics = RSCMU_NAN;
   }
     
   return( RSCMU_Status );  
   
} //end of RSCMU_CDMA2K_FetchScalCDPowCDPW()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleScalCDPowCDPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowCDPW (ViSession instrSession,  
                                                    CODE_DOMAIN_POWER *CDPW,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[161].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get mobile power    
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW->msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW->CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW->FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW->rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW->OutOfTolerance );
   }
   else
   {
      CDPW->OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW->CurrentStatistics );
   }
   else
   {
      CDPW->CurrentStatistics = RSCMU_NAN;
   }
     
   return( RSCMU_Status );  
   
} //end of RSCMU_CDMA2K_SampleScalCDPowCDPW()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalcScalCDPowCDPWMatcLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalCDPowCDPWMatcLim (ViSession instrSession,  
                                                         CODE_DOMAIN_POWER *CDPW,
                                                         ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
      
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[162].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                          
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   RSCMU_Status = RSCMU_MatchLimits( &tab[0]
                                       , &CDPW->CarrierFeedthrough
                                       );
   RSCMU_Status = RSCMU_MatchLimits( &tab[3]                        
                                       , &CDPW->FrequencyError
                                       );
   RSCMU_Status = RSCMU_MatchLimits( &tab[6]
                                       , &CDPW->rho
                                       );

   return( RSCMU_Status );  
   
} // end of RSCMU_CDMA2K_CalcScalCDPowCDPWMatcLim()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadArrCDPowCDPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

// JMG 020926
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrCDPowCDPW (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViInt32 measurementSetting,
                                                 ViReal64 measuredPower[],
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        


   checkRange( 163, &signalType, &measurementSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[163].instrCommand
          , IQType.list[signalType]
          , measMode.list[measurementSetting]
          );

      
   // JMG 020930
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                          
   // Separate the CMU response:
   RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , measuredPower
                             );
      
/*                                
#if 0
      
      
      RSCMU_Status = RSCMU_Query_Array( instrSession
                                , wrtBuf 
                                , buffin
                                , RSCMU_STB_ON
                                , errorMessage
                                );
                                
      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( buffin
                             , measuredPower
                             );

    
    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )

      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( buffin
                             , measuredPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/   
   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ReadArrCDPowCDPW()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchArrCDPowCDPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

// JMG 020926
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchArrCDPowCDPW (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViInt32 measurementSetting,
                                                  ViReal64 measuredPower[],
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        


   checkRange( 164, &signalType, &measurementSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[164].instrCommand
          , IQType.list[signalType]
          , measMode.list[measurementSetting]
          );

      
   // JMG 020930
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                          
   // Separate the CMU response:
   RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , measuredPower
                             );  

    
/*                                
#if 0
    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )

      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( buffin
                             , measuredPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/   
   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_FetchArrCDPowCDPW()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleArrCDPowCDPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

// JMG 020926
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleArrCDPowCDPW (ViSession instrSession,
                                                   ViInt32 signalType,
                                                   ViInt32 measurementSetting,
                                                   ViReal64 measuredPower[],
                                                   ViChar errorMessage[])


{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        


   checkRange( 165, &signalType, &measurementSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[165].instrCommand
          , IQType.list[signalType]
          , measMode.list[measurementSetting]
          );

      
   // JMG 020930
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                          
   // Separate the CMU response:
   RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , measuredPower
                             );   

    
/*                                
#if 0
    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )

      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( buffin
                             , measuredPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/   
   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SampleArrCDPowCDPW()

/*****************************************************************************
 * Function: Signal State
 * Purpose:  This function returns the signal state values of selected signal.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowCDPWStat (ViSession instrSession,
                                                     ViInt32 signalType,
                                                     ViInt32 signalState[],
                                                     ViChar errorMessage[])
{
    ViChar      command[128];
    ViChar      response [2048];
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar*     str;
    ViInt32     i;
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, RSCMU_ERROR_PARAMETER9, errorMessage);
    
    sprintf (command, "FETC:ARR:CDP:CDPW:%s:STAT?",
             signalCDPArr [signalType]);
    
    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   command,
                                   response,
                                   2048,
                                   0));

    GET_VI_REAL64(signalState[0],response);

    i = 1;
    while (str)
    {
        GET_VI_REAL64(signalState[i++],NULL);
    }
    
    RETMSG (RSCMU_Status);
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalcArrCDPowCDPWMatcLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_CalcArrCDPowCDPWMatcLim (ViSession instrSession,
                                                        ViInt32 signalType,
                                                        ViInt32 measurementSetting,
                                                        ViInt32 *ISignalTolerance, 
                                                        ViChar errorMessage[])


{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];      
      
   checkRange( 166, &signalType, &measurementSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[166].instrCommand
          , IQType.list[signalType]
          , measMode.list[measurementSetting]
          );
   
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
          
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%d", ISignalTolerance );
   }
   
   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_CalcArrCDPowCDPWMatcLim()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowPCDEPCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPCont (ViSession instrSession,
                                                   ViInt32 ResultMode,
                                                   ViInt32 Statistics,
                                                   ViInt32 Rep,
                                                   ViInt32 StopCondition,
                                                   ViInt32 StepMode,
                                                   ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   
   checkRange( 167
             , &ResultMode
             , &Statistics
             , &Rep
             , &StopCondition 
             , &StepMode 
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[167].instrCommand
          , resultMode.list[ResultMode]
          , Statistics
          , repetition.list[Rep]
          , stopCond3.list[StopCondition]
          , stepMode.list[StepMode]
          );


       RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   
 
   
   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowPCDEPCont()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowPCDEPRMode
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPRMode (ViSession instrSession,
                                                    ViInt32 ResultMode,
                                                    ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 168
             , &ResultMode
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[168].instrCommand
          , resultMode.list[ResultMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowPCDEPRMode()

/*****************************************************************************
 * Function: Spreading Factor
 * Purpose:  This function defines the code class in which the uplink CDMA 
 *           signal is evaluated.  
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPSfac (ViSession instrSession,
                                                   ViInt32 spreadingFactor,
                                                   ViChar errorMessage[])
{
    if ((spreadingFactor != 16) && (spreadingFactor !=32))
        RETMSG (VI_ERROR_PARAMETER2);
        
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:CDP:PCD:CONT:SFAC",
                              spreadingFactor,
                              16,32,
                              0));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowPCDEPROrder
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPROrder (ViSession instrSession,
                                                     ViInt32 ResultOrder,
                                                     ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 169
             , &ResultOrder
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[169].instrCommand
          , resultOrder.list[ResultOrder]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowPCDEPROrder()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowPCDEPContStats
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPContStats (ViSession instrSession,
                                                        ViInt32 Statistics,
                                                        ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 170
             , &Statistics
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[170].instrCommand
          , Statistics
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowPCDEPContStats()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowPCDEPContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPContRep (ViSession instrSession,
                                                      ViInt32 Repetition,
                                                      ViInt32 StopCondition,
                                                      ViInt32 StepMode,
                                                      ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 171
             , &Repetition
             , &StopCondition 
             , &StepMode 
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[171].instrCommand
          , repetition.list[Repetition]
          , stopCond3.list[StopCondition]
          , stepMode.list[StepMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowPCDEPContRep()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefCDPowPCDEPCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowPCDEPCont (ViSession instrSession,
                                                  ViBoolean state,
                                                  ViChar errorMessage[])


{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 172, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[172].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_DefCDPowPCDEPCont()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowPCDEPLimAsym
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPLimAsym (ViSession instrSession,
                                                      ViInt32 limitLinesSetting,
                                                      ViReal64 CDPLimitY,
                                                      ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 173
             , &limitLinesSetting
             , &CDPLimitY
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[173].instrCommand
          , limitLinesMode.list[limitLinesSetting]
          , CDPLimitY
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ConfCDPowPCDEPLimAsym()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefCDPowPCDEPLimit
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      limitSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowPCDEPLimit (ViSession instrSession,
                                                   ViBoolean limitSetting,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 653, &limitSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[653].instrCommand
          , enable.list[limitSetting] 
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );                          
}
//end  of RSCMU_CDMA2K_DefCDPowPCDEPLimit

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitCDPowPCDEP
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_InitCDPowPCDEP (ViSession instrSession,
                                               ViChar errorMessage[])


{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[174].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_InitCDPowPCDEP()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortCDPowPCDEP
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_AbortCDPowPCDEP (ViSession instrSession,
                                                ViChar errorMessage[])


{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[175].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_AbortCDPowPCDEP()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StopCDPowPCDEP
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_StopCDPowPCDEP (ViSession instrSession,
                                               ViChar errorMessage[])
                                              
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[176].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_StopCDPowPCDEP()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ContinueCDPowPCDEP
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueCDPowPCDEP (ViSession instrSession,
                                                   ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[177].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ContinueCDPowPCDEP()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchCDPowPCDEPStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchCDPowPCDEPStatus (ViSession instrSession,
                                                      ViInt32 *measurementStatus,
                                                      ViInt32 *counter_forStatisticsCycle,
                                                      ViInt32 *counter_forEvaluationPeriod,
                                                      ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[178].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

       // Get the counter for current statistics cycle
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", counter_forStatisticsCycle );
       }
       else
       {
          *counter_forStatisticsCycle = RSCMU_OFF;
       }
       
       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", counter_forEvaluationPeriod );
       }
       else
       {
          *counter_forEvaluationPeriod = RSCMU_OFF;
       }

   }

   return RSCMU_Status;
          
} // end of RSCMU_CDMA2K_FetchCDPowPCDEPStatus()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowPCDEPErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPCDEPErep (ViSession instrSession,
                                                   ViInt32 measurementEventReporting,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 179, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[179].instrCommand
          , eventReport.list[measurementEventReporting]      
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ConfCDPowPCDEPErep()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadScalCDPowPCDEP
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowPCDEP (ViSession instrSession,
                                                    CODE_DOMAIN_POWER *CDPW,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[180].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
  
   // Get mobile power 
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW->msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW->CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW->FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW->rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW->OutOfTolerance);
   }
   else
   {
      CDPW->OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW->CurrentStatistics );
   }
   else
   {
      CDPW->CurrentStatistics = RSCMU_NAN;
   }
     
   return( RSCMU_Status );    
} //end of RSCMU_CDMA2K_ReadScalCDPowPCDEP()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchScalCDPowPCDEP
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowPCDEP (ViSession instrSession, 
                                                    CODE_DOMAIN_POWER *CDPW,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[181].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
      
   // Get mobile power             
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW->msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW->CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW->FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW->rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW->OutOfTolerance);
   }
   else
   {
      CDPW->OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW->CurrentStatistics );
   }
   else
   {
      CDPW->CurrentStatistics = RSCMU_NAN;
   }
     
   return( RSCMU_Status );  
   
} //end of RSCMU_CDMA2K_FetchScalCDPowPCDEP()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleScalCDPowPCDEP
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowPCDEP (ViSession instrSession,  
                                                    CODE_DOMAIN_POWER *CDPW,
                                                     ViChar errorMessage[]) 
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[182].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get mobile power      
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW->msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW->CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW->FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW->rho
                                     );
   
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW->OutOfTolerance );
   }
   else
   {
      CDPW->OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW->CurrentStatistics );
   }
   else
   {
      CDPW->CurrentStatistics = RSCMU_NAN;
   }
     
   return( RSCMU_Status );  
   
} //end of RSCMU_CDMA2K_SampleScalCDPowPCDEP()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalcScalCDPowPCDEPMatLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalCDPowPCDEPMatLim (ViSession instrSession,  
                                                        CODE_DOMAIN_POWER *CDPW,
                                                        ViChar errorMessage[]) 
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
      
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[183].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                          
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
      
   RSCMU_Status = RSCMU_MatchLimits( &tab[0]
                                       , &CDPW->CarrierFeedthrough
                                       );
   RSCMU_Status = RSCMU_MatchLimits( &tab[3]                        
                                       , &CDPW->FrequencyError
                                       );
   RSCMU_Status = RSCMU_MatchLimits( &tab[6]
                                       , &CDPW->rho
                                       );
   return( RSCMU_Status );  
   
} // end of RSCMU_CDMA2K_CalcScalCDPowPCDEPMatLim()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadArrCDPowPCDEP
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

// JMG 020926
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrCDPowPCDEP (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViInt32 measurementSetting,
                                                  ViReal64 measuredPower[],
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        


   checkRange( 184, &signalType, &measurementSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[184].instrCommand
          , IQType.list[signalType]
          , measMode.list[measurementSetting]
          );

      RSCMU_Status = RSCMU_Query_Array( instrSession
                                , wrtBuf 
                                , &p_globalvarCDMA->rdABuf[0]
                                , RSCMU_STB_ON
                                , errorMessage
                                );
                                
      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , measuredPower
                             );

    
/*                                
#if 0
    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )

      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( buffin
                             , measuredPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/   
   return( RSCMU_Status );
} // end of RSCMU_CDMA2K_ReadArrCDPowPCDEP()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchArrCDPowPCDEP
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchArrCDPowPCDEP (ViSession instrSession,
                                                   ViInt32 signalType,
                                                   ViInt32 measurementSetting,
                                                   ViReal64 measuredPower[],
                                                   ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        


   checkRange( 185, &signalType, &measurementSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[185].instrCommand
          , IQType.list[signalType]
          , measMode.list[measurementSetting]
          );

      RSCMU_Status = RSCMU_Query_Array( instrSession
                                , wrtBuf 
                                , &p_globalvarCDMA->rdABuf[0]
                                , RSCMU_STB_ON
                                , errorMessage
                                );
                                
      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , measuredPower
                             );

    
/*                                
#if 0
    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )

      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( buffin
                             , measuredPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/   
   return( RSCMU_Status );
   
} // end of RSCMU_CDMA2K_FetchArrCDPowPCDEP()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleArrCDPowPCDEP
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SampleArrCDPowPCDEP (ViSession instrSession,
                                                    ViInt32 signalType,
                                                    ViInt32 measurementSetting,
                                                    ViReal64 measuredPower[],
                                                    ViChar errorMessage[])


{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        


   checkRange( 186, &signalType, &measurementSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[186].instrCommand
          , IQType.list[signalType]
          , measMode.list[measurementSetting]
          );

      RSCMU_Status = RSCMU_Query_Array( instrSession
                                , wrtBuf 
                                , &p_globalvarCDMA->rdABuf[0]
                                , RSCMU_STB_ON
                                , errorMessage
                                );
                                
      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , measuredPower
                             );

    
/*                                
#if 0
    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )

      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( buffin
                             , measuredPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/   
   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SampleArrCDPowPCDEP()


/*****************************************************************************
 * Function: Signal State
 * Purpose:  This function returns the signal state values of selected signal.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowPCDEPStat (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViInt32 signalState[],
                                                      ViChar errorMessage[])
{
    ViChar      command[128];
    ViChar      response [2048];
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar*     str;
    ViInt32     i;
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, RSCMU_ERROR_PARAMETER9, errorMessage);
    
    sprintf (command, "FETC:ARR:CDP:PCDEP:%s:STAT?",
             signalCDPArr [signalType]);
    
    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   command,
                                   response,
                                   2048,
                                   0));

    GET_VI_REAL64(signalState[0],response);

    i = 1;
    while (str)
    {
        GET_VI_REAL64(signalState[i++],NULL);
    }
    
    RETMSG (RSCMU_Status);
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalcArrCDPowPCDEPMatcLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_CalcArrCDPowPCDEPMatcLim (ViSession instrSession,
                                                         ViInt32 signalType,
                                                         ViInt32 measurementSetting,
                                                         ViInt32 *ISignalTolerance,  
                                                         ViChar errorMessage[])


{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];  

   checkRange( 187, &signalType, &measurementSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[187].instrCommand
          , IQType.list[signalType]
          , measMode.list[measurementSetting]
          );
          
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
          
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%d", ISignalTolerance );
   }
   else
       *ISignalTolerance = RSCMU_NAN;
 
   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_CalcArrCDPowPCDEPMatcLim()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCHPWCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCHPWCont (ViSession instrSession,
                                                  ViInt32 ResultMode,
                                                  ViInt32 Statistics,
                                                  ViInt32 Repetition,
                                                  ViInt32 StopCondition,
                                                  ViInt32 StepMode,
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   
   checkRange( 188
             , &ResultMode
             , &Statistics
             , &Repetition
             , &StopCondition 
             , &StepMode 
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[188].instrCommand
          , resultMode.list[ResultMode]
          , Statistics
          , repetition.list[Repetition]
          , stopCond3.list[StopCondition]
          , stepMode.list[StepMode]
          );

      RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowCHPWCont()

                                                         
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCHPWRMode
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCHPWRMode (ViSession instrSession,
                                                   ViInt32 ResultMode,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 189
             , &ResultMode
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[189].instrCommand
          , resultMode.list[ResultMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowCHPWRMode()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCHPWContStats
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCHPWContStats (ViSession instrSession,
                                                       ViInt32 Statistics,
                                                       ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 190
             , &Statistics
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[190].instrCommand
          , Statistics
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowCHPWContStats()



/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCHPWContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCHPWContRep (ViSession instrSession,
                                                     ViInt32 Repetition,
                                                     ViInt32 StopCondition,
                                                     ViInt32 StepMode,
                                                     ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 191
             , &Repetition
             , &StopCondition 
             , &StepMode 
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[191].instrCommand
          , repetition.list[Repetition]
          , stopCond3.list[StopCondition]
          , stepMode.list[StepMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfCDPowCHPWContRep()


/*****************************************************************************
 * Function: Reference Power Mode
 * Purpose:  This function sets the reference power mode for the measurement,
 *           either pilot power or AT power measurement mode.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCHPWContPrm (ViSession instrSession,
                                                     ViInt32 referencePowerMode,
                                                     ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession, 
                           "CONF:CDP:CHPW:CONT:PRM",
                           referencePowerMode,
                           refPowerModeArr,
                           RSCMU_ERROR_PARAMETER2));

}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefCDPowCHPWCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowCHPWCont (ViSession instrSession,
                                                 ViBoolean state,
                                                 ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 192, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[192].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_DefCDPowCHPWCont()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCHPWLimAsym
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCHPWLimAsym (ViSession instrSession,
                                                     ViInt32 limitLinesSetting,
                                                     ViReal64 CDPLimitY,
                                                     ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 193
             , &limitLinesSetting
             , &CDPLimitY
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[193].instrCommand
          , limitLinesMode.list[limitLinesSetting]
          , CDPLimitY
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ConfCDPowCHPWLimAsym()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefCDPowCHPWLimit
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      limitSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowCHPWLimit (ViSession instrSession,
                                                  ViBoolean limitSetting,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 654, &limitSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[654].instrCommand
          , enable.list[limitSetting] 
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );                          
}
//end of RSCMU_CDMA2K_DefCDPowCHPWLimit

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitCDPowCHPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_InitCDPowCHPW (ViSession instrSession,
                                              ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[194].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_InitCDPowCHPW()



/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortCDPowCHPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_AbortCDPowCHPW (ViSession instrSession,
                                               ViChar errorMessage[])
                                               
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[195].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_AbortCDPowCHPW()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StopCDPowCHPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_StopCDPowCHPW (ViSession instrSession,
                                              ViChar errorMessage[])
                                              
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[196].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_StopCDPowCHPW()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ContinueCDPowCHPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueCDPowCHPW (ViSession instrSession,
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[197].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ContinueCDPowCHPW()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchCDPowCHPWStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchCDPowCHPWStatus (ViSession instrSession,
                                                     ViInt32 *measurementStatus,
                                                     ViInt32 *counter_forStatisticsCycle,
                                                     ViInt32 *counter_forEvaluationPeriod,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[198].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

       // Get the counter for current statistics cycle
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", counter_forStatisticsCycle );
       }
       else
       {
          *counter_forStatisticsCycle = RSCMU_OFF;
       }
       
       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", counter_forEvaluationPeriod );
       }
       else
       {
          *counter_forEvaluationPeriod = RSCMU_OFF;
       }

   }

   return RSCMU_Status;
          
} // end of RSCMU_CDMA2K_FetchCDPowCHPWStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfCDPowCHPWErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCHPWErep (ViSession instrSession,
                                                  ViInt32 measurementEventReporting,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 199, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[199].instrCommand
          , eventReport.list[measurementEventReporting]      
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ConfCDPowCHPWErep()
         

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadScalCDPowCHPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowCHPW (ViSession instrSession, 
                                                    CODE_DOMAIN_POWER *CDPW,
                                                    ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[200].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get mobile power        
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW->msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW->CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW->FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW->rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW->OutOfTolerance );
   }
   else
   {
      CDPW->OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW->CurrentStatistics );
   }
   else
   {
      CDPW->CurrentStatistics  = RSCMU_NAN;
   }
     
   return( RSCMU_Status );    
} //end of RSCMU_CDMA2K_ReadScalCDPowCHPW()



/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchScalCDPowCHPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowCHPW (ViSession instrSession,
                                                    CODE_DOMAIN_POWER *CDPW,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[201].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get mobile power
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW->msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW->CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW->FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW->rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW->OutOfTolerance );
   }
   else
   {
      CDPW->OutOfTolerance= RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW->CurrentStatistics );
   }
   else
   {
      CDPW->CurrentStatistics = RSCMU_NAN;
   }
     
   return( RSCMU_Status );  
   
} //end of RSCMU_CDMA2K_FetchScalCDPowCHPW()



/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleScalCDPowCHPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowCHPW (ViSession instrSession,
                                                    CODE_DOMAIN_POWER *CDPW,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[202].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get mobile power    
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW->msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW->CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW->FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW->rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW->OutOfTolerance );
   }
   else
   {
      CDPW->OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW->CurrentStatistics );
   }
   else
   {
      CDPW->CurrentStatistics = RSCMU_NAN;
   }
     
   return( RSCMU_Status );  
   
} //end of RSCMU_CDMA2K_SampleScalCDPowCHPW()



/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalcScalCDPowCHPWMatcLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalCDPowCHPWMatcLim (ViSession instrSession,
                                                        CODE_DOMAIN_POWER *CDPW,
                                                          ViChar errorMessage[])    
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
      
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[203].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                          
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   RSCMU_Status = RSCMU_MatchLimits( &tab[0]
                                       , &CDPW->CarrierFeedthrough
                                       );
   RSCMU_Status = RSCMU_MatchLimits( &tab[3]                        
                                       , &CDPW->FrequencyError
                                       );
   RSCMU_Status = RSCMU_MatchLimits( &tab[6]
                                       , &CDPW->rho
                                       );
   return( RSCMU_Status );  
   
} // end of RSCMU_CDMA2K_CalcScalCDPowCHPWMatcLim()
         


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadArrCDPowCHPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrCDPowCHPW (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViInt32 measurementSetting,
                                                 ViReal64 measuredPower[],
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 204, &signalType, &measurementSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[204].instrCommand
          , IQType.list[signalType]
          , measMode.list[measurementSetting]
          );

    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      RSCMU_Status = RSCMU_Query( instrSession
                                , wrtBuf
                                , rdBuf
                                , RSCMU_STB_ON
                                , errorMessage
                                );
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , measuredPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
   
   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ReadArrCDPowCHPW()



/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchArrCDPowCHPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchArrCDPowCHPW (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViInt32 measurementSetting,
                                                  ViReal64 measuredPower[],
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 205, &signalType, &measurementSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[205].instrCommand
          , IQType.list[signalType]
          , measMode.list[measurementSetting]
          );

    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      RSCMU_Status = RSCMU_Query( instrSession
                                , wrtBuf
                                , rdBuf
                                , RSCMU_STB_ON
                                , errorMessage
                                );
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , measuredPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
   
   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_FetchArrCDPowCHPW()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleArrCDPowCHPW
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SampleArrCDPowCHPW (ViSession instrSession,
                                                   ViInt32 signalType,
                                                   ViInt32 measurementSetting,
                                                   ViReal64 measuredPower[],
                                                   ViChar errorMessage[])


{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 206, &signalType, &measurementSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[206].instrCommand
          , IQType.list[signalType]
          , measMode.list[measurementSetting]
          );

    // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      RSCMU_Status = RSCMU_Query( instrSession
                                , wrtBuf
                                , rdBuf
                                , RSCMU_STB_ON
                                , errorMessage
                                );
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , measuredPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
   
   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_SampleArrCDPowCHPW()

/*****************************************************************************
 * Function: Signal State
 * Purpose:  This function returns the signal state values of selected signal.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowCHPWStat (ViSession instrSession,
                                                     ViInt32 signalType,
                                                     ViInt32 signalState[],
                                                     ViChar errorMessage[])
{
    ViChar      command[128];
    ViChar      response [2048];
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar*     str;
    ViInt32     i;
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, RSCMU_ERROR_PARAMETER9, errorMessage);
    
    sprintf (command, "FETC:ARR:CDP:CHPW:%s:STAT?",
             signalCDPArr [signalType]);
    
    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   command,
                                   response,
                                   2048,
                                   0));

    GET_VI_REAL64(signalState[0],response);

    i = 1;
    while (str)
    {
        GET_VI_REAL64(signalState[i++],NULL);
    }
    
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Calculate Matching Limit
 * Purpose:  This function returns the I signal or Q signal limit matching in 
 *           code channel 0 (least significant bit) to 31 for the current, 
 *           average and maximum displays.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcArrCDPowCHPWMatcLim (ViSession instrSession,
                                                        ViInt32 signalType,
                                                        ViInt32 measurementSetting,
                                                        ViUInt32 *iQLimitMatching,
                                                        ViChar errorMessage[])
{
    ViChar      command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, measurementSetting, 0, 3, VI_ERROR_PARAMETER3, errorMessage);
    if (measurementSetting == 2)
        RETMSG (VI_ERROR_PARAMETER3);

    sprintf (command, "CALC:ARR:CDP:CHPW:%s:%s:MATC:LIM?",
             signalCDPArr [signalType],
             measSettingArr [measurementSetting]);
    
    RETMSG (RSCMU_getViInt32 (instrSession,
                              command,
                              (ViInt32*) iQLimitMatching,
                              VI_ERROR_PARAMETER4));
}

/*****************************************************************************
 * Function: Result Mode
 * Purpose:  This function specifies the type of measured values.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPoffRmode(
    ViSession   instrSession,
    ViInt32 mode,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:CDP:POFF:CONT:RMOD",
                           mode,
                           resultModeArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Statistics
 * Purpose:  This function defines the number of bursts forming a statistics 
 *           cycle. 
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPoffStats(
    ViSession   instrSession,
    ViInt32 statistics,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:CDP:POFF:CONT:STAT",
                              statistics,
                              1, 1000,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Repetition
 * Purpose:  This function determines the number of statistics cycles, the 
 *           stop condition and the stepping mode for the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPoffContRep(
    ViSession   instrSession,
    ViInt32 repetition,
    ViInt32 nbRepetition,
    ViInt32 stopCondition,
    ViInt32 stepMode,
 ViChar errorMessage[]
)
{
    ViChar  command[256];
    
    CHECK_VI_INT32_RANGE (instrSession, repetition, 0, 2, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, nbRepetition, 1, 10000, VI_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, stopCondition, 0, 1, VI_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, stepMode, 0, 1, VI_ERROR_PARAMETER5, errorMessage);

    switch (repetition)
        {
        case RSCMU_MULTIPLE:
            sprintf (command, "CONF:CDP:POFF:CONT:REP %ld,%s,%s",
                     nbRepetition,
                     stopConditionArr[stopCondition],
                     stepModeArr[stepMode]);
            break;
        default:
            sprintf (command, "CONF:CDP:POFF:CONT:REP %s,%s,%s",
                     repetitionArr[repetition],
                     stopConditionArr[stopCondition],
                     stepModeArr[stepMode]);
            break;
        }

    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Default
 * Purpose:  This function sets all parameters of the subsystem to default 
 *           values.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowPoffCont(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "DEF:CDP:POFF:CONT ON"));
}

/*****************************************************************************
 * Function: Limit Lines Level
 * Purpose:  This function defines the upper limit for the phase offset 
 *           (symmetric value; the absolute phase offset must not exceed the 
 *           limit). The keywords CMAX and AVERage refer to the Current and 
 *           Max. display and for the Average display, respectively.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPoffLim(
    ViSession   instrSession,
    ViInt32 limitLinesSetting,
    ViReal64    phaseOffsetLimit,
 ViChar errorMessage[]
)
{
    ViChar  command[100];
    
    CHECK_VI_INT32_RANGE (instrSession, limitLinesSetting, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command,"CONF:CDP:POFF:%s:LIM",cmaxAverArr[limitLinesSetting]);
    
    RETMSG (RSCMU_setViReal64 (instrSession,
                               command,
                               phaseOffsetLimit,
                               0.0, 0.2,
                               RSCMU_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Default
 * Purpose:  This function sets all parameters of the subsystem 
 *           CDPower:POFFset:LIMit to their default values.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowPoffLim(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "DEF:CDP:POFF:LIM ON"));
}

/*****************************************************************************
 * Function: Init
 * Purpose:  This function starts the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitCDPowPoff(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "INIT:CDP:POFF"));
}

/*****************************************************************************
 * Function: Abort
 * Purpose:  This function aborts running of the measurement and switches it 
 *           off.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_AborCDPowPoff(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "ABOR:CDP:POFF"));
}

/*****************************************************************************
 * Function: Stop
 * Purpose:  This function stops the measurement after the current stat. 
 *           cycle.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_StopCDPowPoff(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "STOP:CDP:POFF"));
}

/*****************************************************************************
 * Function: Continue
 * Purpose:  This function runs the next measurement step (only stepping 
 *           mode).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ContCDPowPoff(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "CONT:CDP:POFF"));
}

/*****************************************************************************
 * Function: Fetch Status
 * Purpose:  This function returns the status of the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchCDPowPoffStatus(
    ViSession   instrSession,
    ViInt32*    measurementstatus,
    ViInt32*    counterforStatisticsCycle,
    ViInt32*    counterforCurrentEvalPer,
 ViChar errorMessage[]
)
{
    ViChar  response [256];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar    tab[48][30];   

    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   "FETC:CDP:POFF:STAT?",
                                   response,
                                   256,
                                   0));

    RSCMU_SeparateString( response, ",", tab );

    RSCMU_Status = RSCMU_GetMeasurementStatus( measurementstatus, tab, 0 );

    if( strcmp( tab[1], "NONE" ) != 0 )
    {
        sscanf( tab[1], "%d", counterforStatisticsCycle );
    }
    else
    {
        *counterforStatisticsCycle = RSCMU_OFF;
    }

    if( strcmp( tab[2], "NONE" ) != 0 )
    {
        sscanf( tab[2], "%d", counterforCurrentEvalPer );
    }
    else
    {
        *counterforCurrentEvalPer = RSCMU_OFF;
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Set Event Reporting Mode
 * Purpose:  This function defines the events generated when the measurement 
 *           is terminated or stopped.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowPoffErep(
    ViSession   instrSession,
    ViInt32 measurementEventReporting,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:CDP:POFF:EREP",
                           measurementEventReporting,
                           erepArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Read
 * Purpose:  This function start a measurement and output all scalar 
 *           measurement results.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadCDPowPoff(
    ViSession   instrSession,
    ViReal64    msPower[],
    ViReal64    carrierFeedthrough[],
    ViReal64    frequencyError[],
    ViReal64    rho[],
    ViReal64*   outofTolerance,
    ViInt32*    currentStatistics,
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasCDPowPoff (instrSession,
                                       msPower,
                                       carrierFeedthrough,
                                       frequencyError,
                                       rho,
                                       outofTolerance,
                                       currentStatistics,
                                       0,
                                       errorMessage);
}

/*****************************************************************************
 * Function: Fetch
 * Purpose:  This function reads out measurement results (unsynchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcCDPowPoff(
    ViSession   instrSession,
    ViReal64    msPower[],
    ViReal64    carrierFeedthrough[],
    ViReal64    frequencyError[],
    ViReal64    rho[],
    ViReal64*   outofTolerance,
    ViInt32*    currentStatistics,
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasCDPowPoff (instrSession,
                                       msPower,
                                       carrierFeedthrough,
                                       frequencyError,
                                       rho,
                                       outofTolerance,
                                       currentStatistics,
                                       1,
                                       errorMessage);
}

/*****************************************************************************
 * Function: Sample *
 * Purpose:  This function reads out measurement results (synchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SampCDPowPoff(
    ViSession   instrSession,
    ViReal64    msPower[],
    ViReal64    carrierFeedthrough[],
    ViReal64    frequencyError[],
    ViReal64    rho[],
    ViReal64*   outofTolerance,
    ViInt32*    currentStatistics,
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasCDPowPoff (instrSession,
                                       msPower,
                                       carrierFeedthrough,
                                       frequencyError,
                                       rho,
                                       outofTolerance,
                                       currentStatistics,
                                       2,
                                       errorMessage);
}

static ViStatus RSCMU_CDMA2K_MeasCDPowPoff (ViSession instrSession,
                                            ViReal64    msPower[],
                                            ViReal64    carrierFeedthrough[],
                                            ViReal64    frequencyError[],
                                            ViReal64    rho[],
                                            ViReal64*   outofTolerance,
                                            ViInt32*    currentStatistics,
                                            ViInt32 cmdType,
                                            ViChar errorMessage[])
{
    ViChar  command[128];
    ViChar  *hugeBuf = VI_NULL;
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViString cmds[] = {"READ","FETC","SAMP"};
    ViInt32 i;
    ViChar* str;
    
    CHECK_VI_INT32_RANGE (instrSession, cmdType, 0, 2, VI_ERROR_PARAMETER5, errorMessage);
    
    sprintf (command, "%s:CDP:POFF?", cmds[cmdType]);
    
    CHECKRETMSG (RSCMU_viWrite(instrSession, command, strlen(command)));

    CHECKERR(RSCMU_ReadDataUnknownLength(instrSession, &hugeBuf, VI_NULL));
    
    if (RSCMU_Status < VI_SUCCESS)
        if (hugeBuf) free(hugeBuf);

    GET_VI_REAL64 (msPower[0], hugeBuf);
    
    for (i=1; i < 3;i++)
    {
        GET_VI_REAL64 (msPower[i], VI_NULL);
    }
    
    for (i=0; i < 3;i++)
    {
        GET_VI_REAL64 (carrierFeedthrough[i], VI_NULL);
    }

        for (i=0; i < 3;i++)
    {
        GET_VI_REAL64 (frequencyError[i], VI_NULL);
    }

    for (i=0; i < 3;i++)
    {
        GET_VI_REAL64 (rho[i], VI_NULL);
    }

    GET_VI_REAL64 (*outofTolerance, VI_NULL);
    GET_VI_INT32 (*currentStatistics, VI_NULL,",");


    if (hugeBuf) 
        free(hugeBuf);

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Matching Limit
 * Purpose:  This function indicates whether and in which way the (fixed) 
 *           limit have been exceeded.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcCDPowPoffMatcLimt(
    ViSession   instrSession,
    ViInt32 carrierFeedthrough[],
    ViInt32 frequencyError[],
    ViInt32 rho[],
 ViChar errorMessage[]
)
{
    ViChar  response [2048];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar*     str;
    ViInt32 i;
    
    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   "CALC:CDP:POFF:MATC:LIM?",
                                   response,
                                   2048,
                                   0));

    str = strtok (response, ",");
    for (i = 0; i < 3; i++)
    {
        if (carrierFeedthrough)
        {
            CHECKRETMSG (RSCMU_getIndexFromString (instrSession, str, toleranceArr, carrierFeedthrough + i));
        }
        strtok (NULL, ",");
    }

    for (i = 0; i < 3; i++)
    {
        if (frequencyError)
        {
            CHECKRETMSG (RSCMU_getIndexFromString (instrSession, str, toleranceArr, frequencyError + i));
        }
        strtok (NULL, ",");
    }

    for (i = 0; i < 3; i++)
    {
        if (rho)
        {
            CHECKRETMSG (RSCMU_getIndexFromString (instrSession, str, toleranceArr, rho + i));
        }
        strtok (NULL, ",");
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Read
 * Purpose:  This function start a measurement and output all selected array 
 *           of measurement results.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrCDPowPoff(
    ViSession   instrSession,
    ViInt32 signalType,
    ViInt32 measurementSetting,
    ViReal64    result[],
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasArrCDPowPoff (instrSession,
                                          signalType,
                                          measurementSetting,
                                          result,
                                          0,
                                          errorMessage);
}

/*****************************************************************************
 * Function: Fetch
 * Purpose:  This function reads selected array of measurement results 
 *           (unsynchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowPoff(
    ViSession   instrSession,
    ViInt32 signalType,
    ViInt32 measurementSetting,
    ViReal64    result[],
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasArrCDPowPoff (instrSession,
                                          signalType,
                                          measurementSetting,
                                          result,
                                          1,
                                          errorMessage);
}

/*****************************************************************************
 * Function: Sample
 * Purpose:  This function reads selected array of measurement results 
 *           (synchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SampArrCDPowPoff(
    ViSession   instrSession,
    ViInt32 signalType,
    ViInt32 measurementSetting,
    ViReal64    result[],
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasArrCDPowPoff (instrSession,
                                          signalType,
                                          measurementSetting,
                                          result,
                                          2,
                                          errorMessage);
}

static ViStatus RSCMU_CDMA2K_MeasArrCDPowPoff (ViSession instrSession,
                                               ViInt32  signalType,
                                               ViInt32  measurementSetting,
                                               ViReal64 result[],
                                               ViInt32 cmdType,
                                               ViChar errorMessage[])
{
    ViChar  command[128];
    ViChar  *hugeBuf = VI_NULL;
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViString cmds[] = {"READ","FETC","SAMP"};
    
    CHECK_VI_INT32_RANGE (instrSession, measurementSetting, 0, 2, VI_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, cmdType, 0, 2, VI_ERROR_PARAMETER5, errorMessage);
    
    sprintf (command, "%s:ARR:CDP:POFF:%s:%s?", cmds[cmdType],
             signalCDPArr [signalType],
             cdpMeasArr [measurementSetting]);
    
    CHECKRETMSG (RSCMU_viWrite(instrSession, command, strlen(command)));

    CHECKERR(RSCMU_ReadDataUnknownLength(instrSession, &hugeBuf, VI_NULL));
    
    if (RSCMU_Status < VI_SUCCESS)
        if (hugeBuf) free(hugeBuf);

    if (hugeBuf) 
    {
        RSCMU_atofArray (hugeBuf,result);
        free(hugeBuf);
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Active Channels I Branch
 * Purpose:  This function the channel states in the I branch.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowPoffIsigStat(
    ViSession   instrSession,
    ViInt32*    r_pich,
    ViInt32*    r_dcch,
    ViInt32*    r_sch1,
    ViInt32*    reserved,
 ViChar errorMessage[]
)
{
    ViChar  response [2048];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar*     str;
    
    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   "FETC:ARR:CDP:POFF:ISIG:STAT?",
                                   response,
                                   2048,
                                   0));

    GET_VI_INT32 (*r_pich, response, ",");
    GET_VI_INT32 (*r_dcch, VI_NULL, ",");
    GET_VI_INT32 (*r_sch1, VI_NULL, ",");
    
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Active Channels Q Branch
 * Purpose:  This function the channel states in the Q branch.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowPoffQsigStat(
    ViSession   instrSession,
    ViInt32*    r_fch,
    ViInt32*    r_sch0,
    ViInt32*    r_each,
    ViInt32*    r_ccch,
    ViInt32*    r_ackch,
    ViInt32*    r_cqich,
    ViInt32*    reserved1,
    ViInt32*    reserved2,
    ViInt32*    reserved3,
 ViChar errorMessage[]
)
{
    ViChar  response [2048];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar*     str;
    
    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   "FETC:ARR:CDP:POFF:QSIG:STAT?",
                                   response,
                                   2048,
                                   0));

    GET_VI_INT32 (*r_fch, response, ",");
    GET_VI_INT32 (*r_sch0, VI_NULL, ",");
    GET_VI_INT32 (*r_each, VI_NULL, ",");
    GET_VI_INT32 (*r_ccch, VI_NULL, ",");
    GET_VI_INT32 (*r_ackch, VI_NULL, ",");
    GET_VI_INT32 (*r_cqich, VI_NULL, ",");
    
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Matching Limit
 * Purpose:  This function queries the selected signal tolerance.If a bit is 
 *           set in the returned value the selected signal limit in the 
 *           corresponding code channel is exceeded.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcArrCDPowPoffMatcLimt(
    ViSession   instrSession,
    ViInt32 signalType,
    ViInt32 measurementSetting,
    ViUInt32*   signalTolerance,
 ViChar errorMessage[]
)
{
    ViChar  command[256];
    
    CHECK_VI_INT32_RANGE (instrSession, measurementSetting, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf (command,"CALC:ARR:CDP:POFF:%s:%s:MATC:LIM?", signalCDPArr [signalType], cdpMeasArr [measurementSetting]);
    
    RETMSG (RSCMU_getViInt32 (instrSession,
                              command,
                              (ViInt32*)signalTolerance,
                              RSCMU_ERROR_PARAMETER4));
}

/*****************************************************************************
 * Function: Result Mode
 * Purpose:  This function specifies the type of measured values.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowToffRmode(
    ViSession   instrSession,
    ViInt32 mode,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:CDP:TOFF:CONT:RMOD",
                           mode,
                           resultModeArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Statistics
 * Purpose:  This function defines the number of bursts forming a statistics 
 *           cycle. 
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowToffStats(
    ViSession   instrSession,
    ViInt32 statistics,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:CDP:TOFF:CONT:STAT",
                              statistics,
                              1, 1000,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Repetition
 * Purpose:  This function determines the number of statistics cycles, the 
 *           stop condition and the stepping mode for the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowToffContRep(
    ViSession   instrSession,
    ViInt32 repetition,
    ViInt32 nbRepetition,
    ViInt32 stopCondition,
    ViInt32 stepMode,
 ViChar errorMessage[]
)
{
    ViChar  command[256];
    
    CHECK_VI_INT32_RANGE (instrSession, repetition, 0, 2, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, nbRepetition, 1, 10000, VI_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, stopCondition, 0, 1, VI_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, stepMode, 0, 1, VI_ERROR_PARAMETER5, errorMessage);

    switch (repetition)
        {
        case RSCMU_MULTIPLE:
            sprintf (command, "CONF:CDP:TOFF:CONT:REP %ld,%s,%s",
                     nbRepetition,
                     stopConditionArr[stopCondition],
                     stepModeArr[stepMode]);
            break;
        default:
            sprintf (command, "CONF:CDP:TOFF:CONT:REP %s,%s,%s",
                     repetitionArr[repetition],
                     stopConditionArr[stopCondition],
                     stepModeArr[stepMode]);
            break;
        }

    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Default
 * Purpose:  This function sets all parameters of the subsystem to default 
 *           values.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowToffCont(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "DEF:CDP:TOFF:CONT ON"));
}

/*****************************************************************************
 * Function: Limit Lines Level
 * Purpose:  This function defines the upper limit for the time offset 
 *           (symmetric value; the absolute phase offset must not exceed the 
 *           limit). The keywords CMAX and AVERage refer to the Current and 
 *           Max. display and for the Average display, respectively.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowToffLim(
    ViSession   instrSession,
    ViInt32 limitLinesSetting,
    ViReal64    timeOffsetLimit,
 ViChar errorMessage[]
)
{
    ViChar  command[100];
    
    CHECK_VI_INT32_RANGE (instrSession, limitLinesSetting, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command,"CONF:CDP:TOFF:%s:LIM",cmaxAverArr[limitLinesSetting]);
    
    RETMSG (RSCMU_setViReal64 (instrSession,
                               command,
                               timeOffsetLimit*1.0e-9,
                               0.0, 40.0e-9,
                               RSCMU_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Default
 * Purpose:  This function sets all parameters of the subsystem 
 *           CDPower:TOFFset:LIMit to their default values.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_DefCDPowToffLim(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "DEF:CDP:TOFF ON"));
}

/*****************************************************************************
 * Function: Init
 * Purpose:  This function starts the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitCDPowToff(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "INIT:CDP:TOFF"));
}

/*****************************************************************************
 * Function: Abort
 * Purpose:  This function aborts running of the measurement and switches it 
 *           off.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_AborCDPowToff(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "ABOR:CDP:TOFF"));
}

/*****************************************************************************
 * Function: Stop
 * Purpose:  This function stops the measurement after the current stat. 
 *           cycle.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_StopCDPowToff(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "STOP:CDP:TOFF"));
}

/*****************************************************************************
 * Function: Continue
 * Purpose:  This function runs the next measurement step (only stepping 
 *           mode).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ContCDPowToff(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "CONT:CDP:TOFF"));
}

/*****************************************************************************
 * Function: Fetch Status
 * Purpose:  This function returns the status of the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchCDPowToffStatus(
    ViSession   instrSession,
    ViInt32*    measurementstatus,
    ViInt32*    counterforStatisticsCycle,
    ViInt32*    counterforCurrentEvalPer,
 ViChar errorMessage[]
)
{
    ViChar  response [256];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar    tab[48][30];   

    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   "FETC:CDP:TOFF:STAT?",
                                   response,
                                   256,
                                   0));

    RSCMU_SeparateString( response, ",", tab );

    RSCMU_Status = RSCMU_GetMeasurementStatus( measurementstatus, tab, 0 );

    if( strcmp( tab[1], "NONE" ) != 0 )
    {
        sscanf( tab[1], "%d", counterforStatisticsCycle );
    }
    else
    {
        *counterforStatisticsCycle = RSCMU_OFF;
    }

    if( strcmp( tab[2], "NONE" ) != 0 )
    {
        sscanf( tab[2], "%d", counterforCurrentEvalPer );
    }
    else
    {
        *counterforCurrentEvalPer = RSCMU_OFF;
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Set Event Reporting Mode
 * Purpose:  This function defines the events generated when the measurement 
 *           is terminated or stopped.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowToffErep(
    ViSession   instrSession,
    ViInt32 measurementEventReporting,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:CDP:TOFF:EREP",
                           measurementEventReporting,
                           erepArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Read
 * Purpose:  This function start a measurement and output all scalar 
 *           measurement results.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadCDPowToff(
    ViSession   instrSession,
    ViReal64    msPower[],
    ViReal64    carrierFeedthrough[],
    ViReal64    frequencyError[],
    ViReal64    rho[],
    ViReal64*   outofTolerance,
    ViInt32*    currentStatistics,
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasCDPowToff (instrSession,
                                       msPower,
                                       carrierFeedthrough,
                                       frequencyError,
                                       rho,
                                       outofTolerance,
                                       currentStatistics,
                                       0,
                                       errorMessage);
}

/*****************************************************************************
 * Function: Fetch
 * Purpose:  This function reads out measurement results (unsynchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcCDPowToff(
    ViSession   instrSession,
    ViReal64    msPower[],
    ViReal64    carrierFeedthrough[],
    ViReal64    frequencyError[],
    ViReal64    rho[],
    ViReal64*   outofTolerance,
    ViInt32*    currentStatistics,
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasCDPowToff (instrSession,
                                       msPower,
                                       carrierFeedthrough,
                                       frequencyError,
                                       rho,
                                       outofTolerance,
                                       currentStatistics,
                                       1,
                                       errorMessage);
}

/*****************************************************************************
 * Function: Sample
 * Purpose:  This function reads out measurement results (synchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SampCDPowToff(
    ViSession   instrSession,
    ViReal64    msPower[],
    ViReal64    carrierFeedthrough[],
    ViReal64    frequencyError[],
    ViReal64    rho[],
    ViReal64*   outofTolerance,
    ViInt32*    currentStatistics,
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasCDPowToff (instrSession,
                                       msPower,
                                       carrierFeedthrough,
                                       frequencyError,
                                       rho,
                                       outofTolerance,
                                       currentStatistics,
                                       2,
                                       errorMessage);
}

static ViStatus RSCMU_CDMA2K_MeasCDPowToff (ViSession instrSession,
                                            ViReal64    msPower[],
                                            ViReal64    carrierFeedthrough[],
                                            ViReal64    frequencyError[],
                                            ViReal64    rho[],
                                            ViReal64*   outofTolerance,
                                            ViInt32*    currentStatistics,
                                            ViInt32 cmdType,
                                            ViChar errorMessage[])
{
    ViChar  command[128];
    ViChar  *hugeBuf = VI_NULL;
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViString cmds[] = {"READ","FETC","SAMP"};
    ViInt32 i;
    ViChar* str;
    
    CHECK_VI_INT32_RANGE (instrSession, cmdType, 0, 2, VI_ERROR_PARAMETER5, errorMessage);
    
    sprintf (command, "%s:CDP:TOFF?", cmds[cmdType]);
    
    CHECKRETMSG (RSCMU_viWrite(instrSession, command, strlen(command)));

    CHECKERR(RSCMU_ReadDataUnknownLength(instrSession, &hugeBuf, VI_NULL));
    
    if (RSCMU_Status < VI_SUCCESS)
        if (hugeBuf) free(hugeBuf);

    GET_VI_REAL64 (msPower[0], hugeBuf);
    
    for (i=1; i < 3;i++)
    {
        GET_VI_REAL64 (msPower[i], VI_NULL);
    }
    
    for (i=0; i < 3;i++)
    {
        GET_VI_REAL64 (carrierFeedthrough[i], VI_NULL);
    }

        for (i=0; i < 3;i++)
    {
        GET_VI_REAL64 (frequencyError[i], VI_NULL);
    }

    for (i=0; i < 3;i++)
    {
        GET_VI_REAL64 (rho[i], VI_NULL);
    }

    GET_VI_REAL64 (*outofTolerance, VI_NULL);
    GET_VI_INT32 (*currentStatistics, VI_NULL,",");


    if (hugeBuf) 
        free(hugeBuf);

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Matching Limit
 * Purpose:  This function indicates whether and in which way the (fixed) 
 *           limit have been exceeded.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcCDPowToffMatcLimt(
    ViSession   instrSession,
    ViInt32 carrierFeedthrough[],
    ViInt32 frequencyError[],
    ViInt32 rho[],
 ViChar errorMessage[]
)
{
    ViChar  response [2048];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar*     str;
    ViInt32 i;
    
    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   "CALC:CDP:TOFF:MATC:LIM?",
                                   response,
                                   2048,
                                   0));

    str = strtok (response, ",");
    for (i = 0; i < 3; i++)
    {
        if (carrierFeedthrough)
        {
            CHECKRETMSG (RSCMU_getIndexFromString (instrSession, str, toleranceArr, carrierFeedthrough + i));
        }
        strtok (NULL, ",");
    }

    for (i = 0; i < 3; i++)
    {
        if (frequencyError)
        {
            CHECKRETMSG (RSCMU_getIndexFromString (instrSession, str, toleranceArr, frequencyError + i));
        }
        strtok (NULL, ",");
    }

    for (i = 0; i < 3; i++)
    {
        if (rho)
        {
            CHECKRETMSG (RSCMU_getIndexFromString (instrSession, str, toleranceArr, rho + i));
        }
        strtok (NULL, ",");
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Read
 * Purpose:  This function start a measurement and output all selected array 
 *           of measurement results.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrCDPowToff(
    ViSession   instrSession,
    ViInt32 signalType,
    ViInt32 measurementSetting,
    ViReal64    result[],
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasArrCDPowToff (instrSession,
                                          signalType,
                                          measurementSetting,
                                          result,
                                          0,
                                          errorMessage);
}

/*****************************************************************************
 * Function: Fetch
 * Purpose:  This function reads selected array of measurement results 
 *           (unsynchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowToff(
    ViSession   instrSession,
    ViInt32 signalType,
    ViInt32 measurementSetting,
    ViReal64    result[],
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasArrCDPowToff (instrSession,
                                          signalType,
                                          measurementSetting,
                                          result,
                                          1,
                                          errorMessage);
}

/*****************************************************************************
 * Function: Sample
 * Purpose:  This function reads selected array of measurement results 
 *           (synchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SampArrCDPowToff(
    ViSession   instrSession,
    ViInt32 signalType,
    ViInt32 measurementSetting,
    ViReal64    result[],
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasArrCDPowToff (instrSession,
                                          signalType,
                                          measurementSetting,
                                          result,
                                          2,
                                          errorMessage);
}

static ViStatus RSCMU_CDMA2K_MeasArrCDPowToff (ViSession instrSession,
                                               ViInt32  signalType,
                                               ViInt32  measurementSetting,
                                               ViReal64 result[],
                                               ViInt32 cmdType,
                                               ViChar errorMessage[])
{
    ViChar  command[128];
    ViChar  *hugeBuf = VI_NULL;
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViString cmds[] = {"READ","FETC","SAMP"};
    
    CHECK_VI_INT32_RANGE (instrSession, measurementSetting, 0, 2, VI_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, cmdType, 0, 2, VI_ERROR_PARAMETER5, errorMessage);
    
    sprintf (command, "%s:ARR:CDP:TOFF:%s:%s?", cmds[cmdType],
             signalCDPArr [signalType],
             cdpMeasArr [measurementSetting]);
    
    CHECKRETMSG (RSCMU_viWrite(instrSession, command, strlen(command)));

    CHECKERR(RSCMU_ReadDataUnknownLength(instrSession, &hugeBuf, VI_NULL));
    
    if (RSCMU_Status < VI_SUCCESS)
        if (hugeBuf) free(hugeBuf);

    if (hugeBuf) 
    {
        RSCMU_atofArray (hugeBuf,result);
        free(hugeBuf);
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Active Channels I Branch
 * Purpose:  This function the channel states in the I branch.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowToffIsigStat(
    ViSession   instrSession,
    ViInt32*    r_pich,
    ViInt32*    r_dcch,
    ViInt32*    r_sch1,
    ViInt32*    reserved,
 ViChar errorMessage[]
)
{
    ViChar  response [2048];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar*     str;
    
    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   "FETC:ARR:CDP:TOFF:ISIG:STAT?",
                                   response,
                                   2048,
                                   0));

    GET_VI_INT32 (*r_pich, response, ",");
    GET_VI_INT32 (*r_dcch, VI_NULL, ",");
    GET_VI_INT32 (*r_sch1, VI_NULL, ",");
    
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Active Channels Q Branch
 * Purpose:  This function the channel states in the Q branch.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrCDPowToffQsigStat(
    ViSession   instrSession,
    ViInt32*    r_fch,
    ViInt32*    r_sch0,
    ViInt32*    r_each,
    ViInt32*    r_ccch,
    ViInt32*    r_ackch,
    ViInt32*    r_cqich,
    ViInt32*    reserved1,
    ViInt32*    reserved2,
    ViInt32*    reserved3,
 ViChar errorMessage[]
)
{
    ViChar  response [2048];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar*     str;
    
    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   "FETC:ARR:CDP:TOFF:QSIG:STAT?",
                                   response,
                                   2048,
                                   0));

    GET_VI_INT32 (*r_fch, response, ",");
    GET_VI_INT32 (*r_sch0, VI_NULL, ",");
    GET_VI_INT32 (*r_each, VI_NULL, ",");
    GET_VI_INT32 (*r_ccch, VI_NULL, ",");
    GET_VI_INT32 (*r_ackch, VI_NULL, ",");
    GET_VI_INT32 (*r_cqich, VI_NULL, ",");
    
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Matching Limit
 * Purpose:  This function queries the selected signal tolerance.If a bit is 
 *           set in the returned value the selected signal limit in the 
 *           corresponding code channel is exceeded.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcArrCDPowToffMatcLimt(
    ViSession   instrSession,
    ViInt32 signalType,
    ViInt32 measurementSetting,
    ViUInt32*   signalTolerance,
 ViChar errorMessage[]
)
{
    ViChar  command[256];
    
    CHECK_VI_INT32_RANGE (instrSession, measurementSetting, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf (command,"CALC:ARR:CDP:TOFF:%s:%s:MATC:LIM?", signalCDPArr [signalType], cdpMeasArr [measurementSetting]);
    
    RETMSG (RSCMU_getViInt32 (instrSession,
                              command,
                              (ViInt32*)signalTolerance,
                              RSCMU_ERROR_PARAMETER4));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverMCQLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMCQLev (ViSession instrSession,
                                               ViReal64 CDMAPower_dBm,
                                               ViReal64 FCHLevel_dB,
                                               ViReal64 pilotLevel_dB,
                                               ViChar errorMessage[])
                                               
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 208 
            , &CDMAPower_dBm
            , &FCHLevel_dB
            , &pilotLevel_dB
            );
            
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
              , CDMA[208].instrCommand
              , CDMAPower_dBm
              , FCHLevel_dB
              , pilotLevel_dB
              );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfOverMCQLev()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverMCQContPowCDMA
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMCQContPowCDMA (ViSession instrSession,
                                                       ViReal64 CDMAPower_dBm,
                                                       ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 209, &CDMAPower_dBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[209].instrCommand
          , CDMAPower_dBm
          );
     
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfOverMCQContPowCDMA()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverMCQContLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMCQContLev (ViSession instrSession,
                                                   ViReal64 FCHLevel_dB,
                                                   ViReal64 pilotLevel_dB,
                                                   ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 210 
            , &FCHLevel_dB
            , &pilotLevel_dB
            );
            
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
              , CDMA[210].instrCommand
              , FCHLevel_dB
              , pilotLevel_dB
              );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // eend of RSCMU_CDMA2K_ConfOverMCQContLev()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverMCQImpairment
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMCQImpairment (ViSession instrSession,
                                                      ViReal64  AWGN_level_dB,
                                                      ViBoolean AWGNEnable,
                                                      ViReal64  BSFreqOffset_kHz,
                                                      ViBoolean BSFreqEnable,
                                                      ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 211 
            , &AWGN_level_dB
            , &BSFreqOffset_kHz
            );
            
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
              , CDMA[211].instrCommand
              , AWGN_level_dB
              , BSFreqOffset_kHz
              , enable.list[AWGNEnable]
              , enable.list[BSFreqEnable]
              );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfOverMCQImpairment()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverMCQPCBits
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMCQPCBits (ViSession instrSession,
                                                  ViInt32 PowerControlBits,
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 212
             , &PowerControlBits
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[212].instrCommand
          , powerCtlBits.list[PowerControlBits]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfOverMCQPCBits()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverMCQContFratFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMCQContFratFFCH (ViSession   instrSession,
                                                        ViInt32     frameRate,
                                                        ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 602, &frameRate );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[602].instrCommand
          , frameRateType.list[frameRate] 
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );          
}//end of RSCMU_CDMA2K_ConfOverMCQContFratFFCH
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalOverMCQEbntFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalOverMCQEbntFFCH (ViSession instrSession,
                                                   ViReal64 *calculatedEbNtFFCH,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];   
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar*)CDMA[601].instrCommand  
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", calculatedEbNtFFCH );
   }
   else
   {
      *calculatedEbNtFFCH = RSCMU_NAN;
   }
                             

   return( RSCMU_Status );     
}//end of RSCMU_CDMA2K_CalOverMCQEbntFFCH

/*****************************************************************************
 * Function: State
 * Purpose:  This function enables or disables the environment for all 
 *           Overview measurement applications.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMcqEnvEnab (ViSession instrSession,
                                                   ViBoolean enable,
                                                   ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:OVER:MCQ:ENV:ENAB",
                           enable,
                           stateArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: CDMA Output Power
 * Purpose:  This function determines the total CDMA output power (absolute 
 *           value, in dBm) of the CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMcqEnvPowCdma (ViSession instrSession,
                                                      ViReal64 CDMAPower,
                                                      ViChar errorMessage[])
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                               "CONF:OVER:MCQ:ENV:POW:CDMA",
                               CDMAPower,
                               -120.0, 7.0,
                               VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Level
 * Purpose:  This function determines the level in the selected channel of the 
 *           CMU. The channel power is in units relative to the total CDMA 
 *           power.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMcqEnvLev (ViSession instrSession,
                                                  ViInt32 channel,
                                                  ViBoolean state,
                                                  ViReal64 level,
                                                  ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, channel, 0, 3, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:OVER:MCQ:ENV:LEV:%s", channelArr [channel]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                state,
                                stateArr,
                                VI_ERROR_PARAMETER3));

    if (state)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    level,
                                    -20.0, -7.0,
                                    VI_ERROR_PARAMETER4));
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Calculated EbNt FFCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the forward FCH. This quantity is undefined unless the AWGN 
 *           generator is turned on.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcOverMcqEnvEbntFfch (ViSession instrSession,
                                                       ViReal64 *calculatedEbNtFFCH,
                                                       ViChar errorMessage[])
{
    RETMSG (RSCMU_getViReal64 (instrSession,
                               "CALC:OVER:MCQ:ENV:EBNT:FFCH?",
                               calculatedEbNtFFCH,
                               VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Calculated EbNt FSCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the selected forward SCH channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcOverMcqEnvEbntFsch (ViSession instrSession,
                                                       ViInt32 forwardSCH,
                                                       ViReal64 *calculatedEbNtFSCH,
                                                       ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, forwardSCH, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    
    sprintf (command, "CALC:OVER:MCQ:ENV:EBNT:FSCH:%s?",
             schArr[forwardSCH]);
    RETMSG (RSCMU_getViReal64 (instrSession,
                               command,
                               calculatedEbNtFSCH,
                               VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Frame Rate
 * Purpose:  This function sets the frame rate for the variable rate traffic 
 *           channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMcqEnvFratFfch (ViSession instrSession,
                                                       ViInt32 frameRate,
                                                       ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:OVER:MCQ:ENV:FRAT:FFCH",
                           frameRate,
                           frameArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Impairments
 * Purpose:  This function determines an Additional White Gaussian Noise 
 *           level, a frequency offset to impair the CMU output signal and 
 *           injected Tx FER.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMcqEnvImpairment (ViSession instrSession,
                                                         ViReal64 AWGN_level_dB,
                                                         ViBoolean AWGNEnable,
                                                         ViReal64 BSFreqOffset_kHz,
                                                         ViBoolean BSFreqEnable,
                                                         ViReal64 txFER,
                                                         ViBoolean txFEREnable,
                                                         ViChar errorMessage[])
{
    ViStatus RSCMU_Status;
    
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:OVER:MCQ:ENV:IMP:LEV:AWGN",
                                AWGNEnable,
                                stateArr,
                                VI_ERROR_PARAMETER3));

    if (AWGNEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:OVER:MCQ:ENV:IMP:LEV:AWGN",
                                    AWGN_level_dB,
                                    -20.0, 4.0,
                                    VI_ERROR_PARAMETER2));
    }

    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:OVER:MCQ:ENV:IMP:FOFF",
                                BSFreqEnable,
                                stateArr,
                                VI_ERROR_PARAMETER5));

    if (BSFreqEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:OVER:MCQ:ENV:IMP:FOFF",
                                    BSFreqOffset_kHz,
                                    -5.0E+3, 5.0E+3,
                                    VI_ERROR_PARAMETER4));
    }

    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:OVER:MCQ:ENV:IMP:ITF",
                                txFEREnable,
                                stateArr,
                                VI_ERROR_PARAMETER7));
    if (txFEREnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:OVER:MCQ:ENV:IMP:ITF",
                                    txFER,
                                    0.0, 50.0,
                                    VI_ERROR_PARAMETER6));
    }
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Power Control Bits
 * Purpose:  This function selects the power control bit sequence that the CMU 
 *           sends to the mobile station to control its output power.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverMcqEnvPCBits (ViSession instrSession,
                                                     ViInt32 powerControlBits,
                                                     ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:OVER:MCQ:ENV:PCB",
                           powerControlBits,
                           PCBArr,
                           VI_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverCont (ViSession instrSession,
                                             ViInt32 SignalType,
                                             ViInt32 Statistics,
                                             ViInt32 Repetition,
                                             ViInt32 StopCondition,
                                             ViInt32 StepMode,
                                             ViChar errorMessage[])
                                             
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   
   checkRange( 213
             , &SignalType
             , &Statistics
             , &Repetition
             , &StopCondition 
             , &StepMode 
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[213].instrCommand
          , signalType.list[SignalType]
          , Statistics
          , repetition.list[Repetition]
          , stopCond3.list[StopCondition]
          , stepMode.list[StepMode]
          );

        RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   
   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfOverCont()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverContRep (ViSession instrSession,
                                                ViInt32 SignalType,
                                                ViInt32 Repetition,
                                                ViInt32 StopCondition,
                                                ViInt32 StepMode,
                                                ViChar errorMessage[])
                                                
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 214
             , &SignalType
             , &Repetition
             , &StopCondition 
             , &StepMode 
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[214].instrCommand
          , signalType.list[SignalType]
          , repetition.list[Repetition]
          , stopCond3.list[StopCondition]
          , stepMode.list[StepMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfOverContRep()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverContStats
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverContStats (ViSession instrSession,
                                                  ViInt32 SignalType,
                                                  ViInt32 Statistics,
                                                  ViChar errorMessage[])
                                                  
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 215
             , &SignalType
             , &Statistics
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[215].instrCommand
          , signalType.list[SignalType]
          , Statistics
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfOverContStats()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_XtndOverOverSBS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
                                        
ViStatus _VI_FUNC RSCMU_CDMA2K_XtndOverOverSBS (ViSession instrSession,
                                                ViInt32 signaltype,
                                                ViInt32 SBSuppressionExtensionMode,
                                                ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020923
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10)
     return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);
     
   checkRange(528, &signaltype, &SBSuppressionExtensionMode );
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[528].instrCommand
          , signalType.list[signaltype]
          , modeEnable.list[SBSuppressionExtensionMode]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
   
   if ( SBSuppressionExtensionMode == RSCMU_MODE_ON )
    p_globalvarCDMA->RSCMU_XtndOVER = VI_TRUE;
   else
    p_globalvarCDMA->RSCMU_XtndOVER = VI_FALSE;
   
   
   
   return( RSCMU_Status );    
}  //end of RSCMU_CDMA2K_XtndOverOverSBS()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverContFOffSBS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverContFOffSBS (ViSession instrSession,
                                                    ViInt32 SignalType,
                                                    ViInt32 SBSuppressionFreqOffset_Hz,
                                                    ViBoolean Enable, 
                                                    ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_08) && (SBSuppressionFreqOffset_Hz > 1600000))
   
   
   // set max offset limit to 16000 Khz
    SBSuppressionFreqOffset_Hz = 1600000;
   else   
    checkRange( 216
             , &SignalType
             , &SBSuppressionFreqOffset_Hz
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[216].instrCommand
          , signalType.list[SignalType]
          , enable.list[Enable]
          , signalType.list[SignalType]
          , SBSuppressionFreqOffset_Hz
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   
   p_globalvarCDMA->RSCMU_XtndOVER = VI_FALSE;
   
   return( RSCMU_Status );
           
} // endof RSCMU_CDMA2K_ConfOverContFOffSBS()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverExtFOffSBS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

// JMG 020919
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverExtFOffSBS (ViSession    instrSession,
                                                                           ViInt32      SignalType,
                                                                           ViInt32      ACPFreqOffset_1,
                                                                           ViBoolean    enable_1,
                                                                           ViInt32      ACPFreqOffset_2,
                                                                           ViBoolean    enable_2,
                                                                           ViInt32      ACPFreqOffset_3,
                                                                           ViBoolean    enable_3,
                                                                           ViInt32      ACPFreqOffset_4,
                                                                           ViBoolean    enable_4,
                                                                           ViChar       errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10)
     return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
   
   //YH change signalType to SignalType
   checkRange( 530
             , &SignalType
             , &ACPFreqOffset_1
             );
             
   checkRange( 530
             , &SignalType
             , &ACPFreqOffset_2
             );
   checkRange( 530
             , &SignalType
             , &ACPFreqOffset_3
             );
   checkRange( 530
             , &SignalType
             , &ACPFreqOffset_4
             );
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[530].instrCommand
          , signalType.list[SignalType]
          , signalType.list[SignalType]
          , ACPFreqOffset_1
          , enable.list[enable_1]
          , ACPFreqOffset_2
          , enable.list[enable_2]
          , ACPFreqOffset_3
          , enable.list[enable_3]
          , ACPFreqOffset_4
          , enable.list[enable_4]
         );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   if (RSCMU_Status == VI_SUCCESS) 
    p_globalvarCDMA->RSCMU_XtndOVER = VI_TRUE;
   else
    p_globalvarCDMA->RSCMU_XtndOVER = VI_FALSE;
   
   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ConfOverExtFOffSBS

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverPilotPowEnable
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverPilotPowEnable (ViSession instrSession,
                                                      ViBoolean Enable,
                                                      ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 217, &Enable );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[217].instrCommand
          , enable.list[Enable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfOverPilotPowEnable()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefOverCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030110
ViStatus _VI_FUNC RSCMU_CDMA2K_DefOverCont (ViSession instrSession,
                                            ViInt32 SignalType, 
                                            ViBoolean Enable,
                                            ViChar errorMessage[])
                                            
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;  

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        

   checkRange( 218, &SignalType, &Enable );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[218].instrCommand
          , signalType.list[SignalType]
          , enable.list[Enable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   

   return( RSCMU_Status );
} // end of RSCMU_CDMA2K_DefOverCont()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverLimSymVal
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030113
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverLimSymVal (ViSession instrSession,
                                                  ViInt32 SignalType,
                                                  ViInt32 limitType,
                                                  ViReal64 carrierFreqErr_Hz,
                                                  ViReal64 transmitTimeErr_Usec,
                                                  ViReal64 waveformQuality,
                                                  ViReal64 SBSuppressionLimit,
                                                  ViReal64 SBSuppressionACP2Limit,
                                                  ViReal64 SBSuppressionACP3Limit,
                                                  ViReal64 SBSuppressionACP4Limit,  
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  

   checkRange( 219
            , &SignalType
            , &limitType
            , &carrierFreqErr_Hz
            , &transmitTimeErr_Usec
            , &waveformQuality
            , &SBSuppressionLimit
            , &SBSuppressionACP2Limit
            , &SBSuppressionACP3Limit
            , &SBSuppressionACP4Limit
            );
   
   transmitTimeErr_Usec = transmitTimeErr_Usec * 0.000001;          
            
            
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  if (p_globalvarCDMA->RSCMU_XtndCQU == VI_FALSE)
   sprintf( wrtBuf
          , CDMA[469].instrCommand
          , signalType.list[SignalType]
          , measMode2.list[limitType]
          , carrierFreqErr_Hz
          , transmitTimeErr_Usec
          , waveformQuality
          , SBSuppressionLimit
          );
  else
   sprintf( wrtBuf
          , CDMA[219].instrCommand
          , signalType.list[SignalType]
          , measMode2.list[limitType]
          , carrierFreqErr_Hz
          , transmitTimeErr_Usec
          , waveformQuality
          , SBSuppressionLimit
          , SBSuppressionACP2Limit
          , SBSuppressionACP3Limit
          , SBSuppressionACP4Limit          
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfOverLimSymVal()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverLimSymEnable
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverLimSymEnable (ViSession instrSession,
                                                     ViInt32 SignalType,
                                                     ViInt32 limitType,
                                                     ViBoolean carrieFreqErrorEnable,
                                                     ViBoolean txTimeErrorEnable,
                                                     ViBoolean waveformQualEnable,
                                                     ViBoolean sidebandSuppEnable,
                                                     ViBoolean sidebandSuppAC2Enable,
                                                     ViBoolean sidebandSuppAC3Enable,  
                                                     ViBoolean sidebandSuppAC4Enable,  
                                                     ViChar errorMessage[])
                                                     
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 220
            , &SignalType
            , &limitType
            , &carrieFreqErrorEnable
            , &txTimeErrorEnable
            , &waveformQualEnable
            , &sidebandSuppEnable
            , &sidebandSuppAC2Enable
            , &sidebandSuppAC3Enable
            , &sidebandSuppAC4Enable
            );
            
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[220].instrCommand
          , signalType.list[SignalType]
          , measMode2.list[limitType]
          , enable.list[carrieFreqErrorEnable]
          , enable.list[txTimeErrorEnable]  
          , enable.list[waveformQualEnable]  
          , enable.list[sidebandSuppEnable]  
          , enable.list[sidebandSuppAC2Enable]
          , enable.list[sidebandSuppAC3Enable]  
          , enable.list[sidebandSuppAC4Enable]  
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfOverLimSymEnable()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefOverOverLimits
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_DefOverOverLimits (ViSession instrSession,
                                                  ViInt32 signaltype,
                                                  ViInt32 defaultSetting,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 529, &defaultSetting, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[529].instrCommand
          , signalType.list[signaltype]
          , modeEnable.list[defaultSetting]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}  //end of RSCMU_CDMA2K_DefOverOverLimits()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitOverview
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_InitOverview (ViSession instrSession,
                                             ViInt32 SignalType,
                                             ViChar errorMessage[])
                                             
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   checkRange( 221, &SignalType);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[221].instrCommand
          , signalType.list[SignalType]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_InitOverview()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortOverview
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_AbortOverview (ViSession instrSession,
                                              ViInt32 SignalType,
                                              ViChar errorMessage[])
                                             
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   checkRange( 222, &SignalType);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[222].instrCommand
          , signalType.list[SignalType]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_AbortOverview()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StopOverview
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_StopOverview (ViSession instrSession,
                                             ViInt32 SignalType,
                                             ViChar errorMessage[])
                                             
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   checkRange( 223, &SignalType);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[223].instrCommand
          , signalType.list[SignalType]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_StopOverview()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ContinueOverview
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueOverview (ViSession instrSession,
                                                 ViInt32 SignalType,
                                                 ViChar errorMessage[])
                                             
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   checkRange( 224, &SignalType);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[224].instrCommand
          , signalType.list[SignalType]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ContinueOverview()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchCDPowCDPWStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchOverStatus (ViSession instrSession,
                                                ViInt32 SignalType,
                                                ViInt32 *measurementStatus,
                                                ViInt32 *counter_forStatisticsCycle,
                                                ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   checkRange( 225, &SignalType);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[225].instrCommand
          , signalType.list[SignalType]
          );          

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );
          
              // Get the counter for current statistics cycle
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", counter_forStatisticsCycle );
       }
       else
       {
          *counter_forStatisticsCycle = RSCMU_OFF;
       }
    }
   return RSCMU_Status;
          
} // end of RSCMU_CDMA2K_FetchCDPowCDPWStatus()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverErep (ViSession instrSession,
                                             ViInt32 SignalType,
                                             ViInt32 measurementEventReporting,
                                             ViChar errorMessage[])
                                             
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 226
            , &SignalType
            , &measurementEventReporting 
            );
            
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[226].instrCommand
          , signalType.list[SignalType]
          , eventReport.list[measurementEventReporting]      
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ConfOverErep()



/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadOverview
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadOverview (ViSession instrSession,
                                             ViInt32 signaltype,
                                             OVERVIEW_C2K *Overview,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ViInt32  index;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

  // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
   
   checkRange( 227, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
    
    
   sprintf( wrtBuf
          , CDMA[227].instrCommand
          , signalType.list[signaltype]
          );
          
   // JMG 020930
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                          
/*  JMG 030113
   index = strcspn (p_globalvarCDMA->rdABuf, "\n");
   p_globalvarCDMA->rdABuf[index] = '\0'; */
   
   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   
   // retreive the expected power
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                      , &Overview->expectedMSPower
                                       );
                                       
                                       
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    Overview->expectedMSPower.Average = Overview->expectedMSPower.Current;
    Overview->expectedMSPower.MaxMin = Overview->expectedMSPower.Current;       
    index = 1;
   }
   else
    index = 3;
   
   // retreive the MS power
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->measuredMSPower
                                       );
                                       
   // retreive the expected carrier frequency
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
    index = 4;
   else 
    index = 6;
    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->expectedCarrierFreq
                                       );

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    Overview->expectedCarrierFreq.Average = Overview->expectedCarrierFreq.Current;
    Overview->expectedCarrierFreq.MaxMin  = Overview->expectedCarrierFreq.Current;
    index = 5;
   }
   else 
    index = 9;

   // retreive the frequency error
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->carrierFreqError
                                       );

   // retreive the transmit time error
   index = index + 3;                                       
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->transmitTimeErr
                                       );
   // retreive the waveform quality
   index = index + 3;                                    
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->waveformQuality
                                       );
   // retreive the low sideband suppression 
   index = index + 3;                                    
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionLower
                                       );
   // retreive the right sideband suppression    
   index = index + 3;                                    
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionUpper
                                       );
                                                        
   //JMG 020923  
   // Enure backward compatibility with older FW 
   // Index is only incremented is FW is ate least 3.10 and Extended OverOverview is set to ON
   // ACP 2
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
       index = index + 3; 
   else
       index = index - 3; 
       
    // retreive 2nd the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionLower2
                                       );
    index = index + 3; 
    // retreive 2nd the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                           , &Overview->sidebandSuppressionUpper2
                                            );
   
   // ACP 3
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
       index = index + 3; 
   else
       index = index - 3; 

    // retreive 3rd the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionLower3
                                       );

    index = index + 3; 
    
    // retreive 3rd the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionUpper3
                                       );


   // ACP 4
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
       index = index + 3; 
   else
       index = index - 3; 

    // retreive 4th the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionLower4
                                       );


    index = index + 3; 


    // retreive 4th the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionUpper4
                                       );
   
   return( RSCMU_Status );  
}//RSCMU_CDMA2K_ReadOverview

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchOverview
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchOverview (ViSession instrSession,
                                              ViInt32 signaltype,
                                              OVERVIEW_C2K *Overview,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ViInt32  index;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;     
 
   // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status; 
    
   checkRange( 228, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[228].instrCommand
          , signalType.list[signaltype]
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                          
   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );

   // retreive the expected power   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Overview->expectedMSPower
                                       );
                                       
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    Overview->expectedMSPower.Average = Overview->expectedMSPower.Current;
    Overview->expectedMSPower.MaxMin = Overview->expectedMSPower.Current;       
    index = 1;
   }
   else
    index = 3;
   
   // retreive the MS power
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->measuredMSPower
                                       );
                                       
   // retreive the expected carrier frequency
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
    index = 4;
   else 
    index = 6;
    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->expectedCarrierFreq
                                       );

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    Overview->expectedCarrierFreq.Average = Overview->expectedCarrierFreq.Current;
    Overview->expectedCarrierFreq.MaxMin  = Overview->expectedCarrierFreq.Current;
    index = 5;
   }
   else 
    index = 9;

   // retreive the frequency error
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->carrierFreqError
                                       );

   // retreive the transmit time error
   index = index + 3;                                       
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->transmitTimeErr
                                       );
   // retreive the waveform quality
   index = index + 3;                                    
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->waveformQuality
                                       );
   // retreive the low sideband suppression 
   index = index + 3;                                    
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionLower
                                       );
   // retreive the right sideband suppression    
   index = index + 3;                                    
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionUpper
                                       );
                                       
   //JMG 020923  
   // Enure backward compatibility with older FW 
   // Index is only incremented is FW is ate least 3.10 and Extended OverOverview is set to ON
   // ACP 2
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
       index = index + 3; 
   else
       index = index - 3; 
       
    // retreive 2nd the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionLower2
                                       );
    index = index + 3; 
    // retreive 2nd the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                           , &Overview->sidebandSuppressionUpper2
                                            );
   
   // ACP 3
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
       index = index + 3; 
   else
       index = index - 3; 

    // retreive 3rd the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionLower3
                                       );

    index = index + 3; 
    
    // retreive 3rd the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionUpper3
                                       );


   // ACP 4
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
       index = index + 3; 
   else
       index = index - 3; 

    // retreive 4th the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionLower4
                                       );


    index = index + 3; 


    // retreive 4th the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionUpper4
                                       );
   
   return( RSCMU_Status );  
}


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleOverview
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SampleOverview (ViSession instrSession,
                                               ViInt32 signaltype,
                                               OVERVIEW_C2K *Overview,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ViInt32  index;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;     
   
   // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;                                        
  
   checkRange( 229, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[229].instrCommand
          , signalType.list[signaltype]
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                          
   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );

   // retreive the expected power       
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Overview->expectedMSPower
                                       );
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    Overview->expectedMSPower.Average = Overview->expectedMSPower.Current;
    Overview->expectedMSPower.MaxMin = Overview->expectedMSPower.Current;       
    index = 1;
   }
   else
    index = 3;
   
   // retreive the MS power
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->measuredMSPower
                                       );
                                       
   // retreive the expected carrier frequency
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
    index = 4;
   else 
    index = 6;
    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->expectedCarrierFreq
                                       );

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    Overview->expectedCarrierFreq.Average = Overview->expectedCarrierFreq.Current;
    Overview->expectedCarrierFreq.MaxMin  = Overview->expectedCarrierFreq.Current;
    index = 5;
   }
   else 
    index = 9;

   // retreive the frequency error
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->carrierFreqError
                                       );

   // retreive the transmit time error
   index = index + 3;                                       
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->transmitTimeErr
                                       );
   // retreive the waveform quality
   index = index + 3;                                    
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->waveformQuality
                                       );
   // retreive the low sideband suppression 
   index = index + 3;                                    
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionLower
                                       );
   // retreive the right sideband suppression    
   index = index + 3;                                    
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionUpper
                                       );
   //JMG 020923  
   // Enure backward compatibility with older FW 
   // Index is only incremented is FW is ate least 3.10 and Extended OverOverview is set to ON
   // ACP 2
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
       index = index + 3; 
   else
       index = index - 3; 
       
    // retreive 2nd the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionLower2
                                       );
    index = index + 3; 
    // retreive 2nd the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                           , &Overview->sidebandSuppressionUpper2
                                            );
   
   // ACP 3
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
       index = index + 3; 
   else
       index = index - 3; 

    // retreive 3rd the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionLower3
                                       );

    index = index + 3; 
    
    // retreive 3rd the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionUpper3
                                       );


   // ACP 4
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
       index = index + 3; 
   else
       index = index - 3; 

    // retreive 4th the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionLower4
                                       );


    index = index + 3; 


    // retreive 4th the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &Overview->sidebandSuppressionUpper4
                                       );
   
   return( RSCMU_Status );  
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalcOverviewMatcLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalcOverviewMatcLim (ViSession instrSession,
                                                    ViInt32 signaltype,
                                                    OVERVIEW_C2K *Overview,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ViInt32  index;      
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;     
   
   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status; 


   checkRange( 230, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[230].instrCommand
          , signalType.list[signaltype]
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                          
   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );

   RSCMU_Status = RSCMU_MatchLimits( &tab[0]
                                       , &Overview->carrierFreqError
                                       );

   RSCMU_Status = RSCMU_MatchLimits( &tab[2]                        
                                       , &Overview->transmitTimeErr
                                       );
   
   RSCMU_Status = RSCMU_MatchLimits( &tab[6]
                                       , &Overview->waveformQuality
                                       );
                                       

   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
    ;
   else
    for (index=9;index<48;index++) strcpy(tab[index],"NAN");
    
   RSCMU_Status = RSCMU_MatchLimits( &tab[9]
                                , &Overview->sidebandSuppressionLower
                                );

   RSCMU_Status = RSCMU_MatchLimits( &tab[12], &Overview->sidebandSuppressionUpper
                                    );

                                    
   RSCMU_Status = RSCMU_MatchLimits( &tab[15]
                                    , &Overview->sidebandSuppressionLower2
                                    );
   
   RSCMU_Status = RSCMU_MatchLimits( &tab[18]
                                    , &Overview->sidebandSuppressionUpper2
                                    );           
                                    
   RSCMU_Status = RSCMU_MatchLimits( &tab[21]
                                    , &Overview->sidebandSuppressionLower3
                                    );
   
   RSCMU_Status = RSCMU_MatchLimits( &tab[24]
                                    , &Overview->sidebandSuppressionUpper3
                                    ); 


   RSCMU_Status = RSCMU_MatchLimits( &tab[27]
                                    , &Overview->sidebandSuppressionLower4
                                    );

   RSCMU_Status = RSCMU_MatchLimits( &tab[30]
                                    , &Overview->sidebandSuppressionUpper4
                                    ); 


   
   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_CalcOverviewMatcLim

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverCQualContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

// JMG 020923
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverCQualContRep (ViSession instrSession,
                                                     ViInt32 Repetition,
                                                     ViInt32 StopCondition,
                                                     ViInt32 StepMode,
                                                     ViChar errorMessage[])
                                                     
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    Format[80] = {NULL};
   ViInt16   Enable     = 0;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

  // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
   checkRange( 231
             , &Repetition
             , &StopCondition 
             , &StepMode 
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
  
  

  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_09) 
  {
        if ((StopCondition == RSCMU_STOP2_ALEX) || (StopCondition == RSCMU_STOP2_CLEX) || (StopCondition == RSCMU_STOP2_FLEX))
            StopCondition = RSCMU_STOP2_DEF;
            
        sprintf( wrtBuf
          , CDMA[231].instrCommand
          , repetition.list[Repetition]
          , stopCond2.list[StopCondition]
          , stepMode.list[StepMode]
          );
            
        p_globalvarCDMA->RSCMU_XtndCQU = VI_FALSE;
        
  } 
  else
  {
  
  
  
      if ((StopCondition == RSCMU_STOP2_ALEX) || (StopCondition == RSCMU_STOP2_CLEX) || (StopCondition == RSCMU_STOP2_FLEX))
      {
        p_globalvarCDMA->RSCMU_XtndCQU = VI_TRUE;
        Enable = RSCMU_ON;
      }
      else
      {
        p_globalvarCDMA->RSCMU_XtndCQU = VI_FALSE;
        Enable = RSCMU_OFF;
      }
      
      sprintf( Format
             , CDMA[525].instrCommand
             , modeEnable.list[Enable]
            );

      sprintf( wrtBuf
          , CDMA[231].instrCommand
          , repetition.list[Repetition]
          , stopCond2.list[StopCondition]
          , stepMode.list[StepMode]
          );
      
      
      strcat(wrtBuf,";:\0");
      strcat(wrtBuf,Format);
      strcat(wrtBuf,"\0");
   
  }
  

  RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfOverCQualContRep()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_XTNDOverCQualClev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      confidenceLevelExtension
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

//JMG 020917
ViStatus _VI_FUNC RSCMU_CDMA2K_XTNDOverCQualClev (ViSession instrSession,
                                                  ViInt32 confidenceLevelExtension,   
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

  // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  

  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_09) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_09, errorMessage); 

   checkRange( 525, &confidenceLevelExtension );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[525].instrCommand
          , modeEnable.list[confidenceLevelExtension]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   switch (confidenceLevelExtension)
   {
   case 0:
    p_globalvarCDMA->RSCMU_XtndCQU = VI_FALSE;
   break;
   case 1:
    p_globalvarCDMA->RSCMU_XtndCQU = VI_TRUE;
   break;
   case 2:
    p_globalvarCDMA->RSCMU_XtndCQU = VI_FALSE;
   break;
   }
        
   
   return( RSCMU_Status );
    
} // RSCMU_CDMA2K_XTNDOverCQualClev()         

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverCQualContFrame
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverCQualContFrame (ViSession instrSession,
                                                       ViInt32 maxFrames,
                                                       ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 232, &maxFrames );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[232].instrCommand
          , maxFrames
          );
     
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfOverCQualContFrame()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefOverCQualCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_DefOverCQualCont (ViSession instrSession,
                                                 ViBoolean Enable,
                                                 ViChar errorMessage[])
                                            
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 233, &Enable );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[233].instrCommand
          , enable.list[Enable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_DefOverCQualCont()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverCQualLimMaxFER
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      maxFrameErrorRateLimit_
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverCQualLimMaxFER (ViSession instrSession,
                                                       ViReal64 maxFrameErrorRateLimit_,
                                                       ViBoolean Enable,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   // JMG 020923 
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

  // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  

  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_09) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_09, errorMessage); 
   checkRange( 526, &maxFrameErrorRateLimit_ );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
    sprintf( wrtBuf
          , CDMA[526].instrCommand
          ,maxFrameErrorRateLimit_
          , enable.list[Enable]
          );
 
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfOverCQualLimMaxFER()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverCQualLimCLEV
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      minConfidenceLevel
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverCQualLimCLEV (ViSession instrSession,
                                                     ViReal64 minConfidenceLevel,
                                                     ViBoolean Enable,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   // JMG 020923
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

  // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  

  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_09) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_09, errorMessage); 

   checkRange( 527, &minConfidenceLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   checkRange( 527, &minConfidenceLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
    sprintf( wrtBuf
          , CDMA[527].instrCommand
          , minConfidenceLevel
          , enable.list[Enable]
          );
 
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfOverCQualLimCLEV()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverCQualLimSymVal
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverCQualLimSymVal (ViSession instrSession,
                                                       ViReal64 maxFrameErrorRate_,
                                                       ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 234, &maxFrameErrorRate_ );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[234].instrCommand
          , maxFrameErrorRate_
          );
     
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfOverCQualLimSymVal()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefOverCQualLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_DefOverCQualLim (ViSession instrSession,
                                                ViBoolean Enable,
                                                ViChar errorMessage[])
                                            
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 235, &Enable );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[235].instrCommand
          , enable.list[Enable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_DefOverCQualLim()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitOverCQuality
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_InitOverCQuality (ViSession instrSession,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[236].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_IniRSCMU_CDMA2K_InitOverCQuality()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortOverCQuality
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_AbortOverCQuality (ViSession instrSession,
                                                  ViChar errorMessage[])
                                               
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[237].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_AbortOverCQuality()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StopOverCQuality
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_StopOverCQuality (ViSession instrSession,
                                                 ViChar errorMessage[])
                                              
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[238].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_StopOverCQuality()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ContinueOverCQuality
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueOverCQuality (ViSession instrSession,
                                                     ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[239].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ContinueOverCQuality()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchOverCQualStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchOverCQualStatus (ViSession instrSession,
                                                     ViInt32 *measurementStatus,
                                                     ViInt32 *CurrentStatCycleCount,
                                                     ViInt32 *CurrentEvaluationPeriod,
                                                     ViChar errorMessage[])
                                                     
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[240].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );
          
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", CurrentStatCycleCount );
       }
       else
       {
          *CurrentStatCycleCount = RSCMU_OFF;
       }
       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", CurrentEvaluationPeriod );
       }
       else
       {
          *CurrentEvaluationPeriod = RSCMU_OFF;
       }
   }

   return RSCMU_Status;
          
} // end of RSCMU_CDMA2K_FetchOverCQualStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfOverCQualErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfOverCQualErep (ViSession instrSession,
                                                  ViInt32 measurementEventReporting,
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 241, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[241].instrCommand
          , eventReport.list[measurementEventReporting]      
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ConfOverCQualErep()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadOverCQuality
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ReadOverCQuality (ViSession instrSession,
                                                 ViInt32 *framesTransmitted,
                                                 ViReal64 *frameErrorRate_,
                                                 ViReal64 *confidenceLevel,
                                                 ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   // JMG 020923
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA; 

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
  RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[242].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );       
          
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get Frame Transmitted
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%d", framesTransmitted );
   }
   else
   {
      *framesTransmitted = RSCMU_NAN;
   }
   
   // Get Frame Error Rate
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", frameErrorRate_ );
   }
   else
   {
      *frameErrorRate_ = RSCMU_NAN;
   }
   
   // JMG 020923
   //Get Confidence Level
   *confidenceLevel = RSCMU_NAN;
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version >= RSCMU200_V3_09) 
   {
       if   (p_globalvarCDMA->RSCMU_XtndCQU == VI_TRUE) 
       {
           //Get Confidence Level
           if( strcmp( tab[2], "NAN" ) != 0 )
           {
              sscanf( tab[2], "%lf", confidenceLevel );
           }
           else
           {
              *confidenceLevel = RSCMU_NAN;
           }
        }
   }

   
   return( RSCMU_Status );    
} //end of RSCMU_CDMA2K_ReadOverCQuality()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchOverCQuality
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchOverCQuality (ViSession instrSession,
                                                  ViInt32 *framesTransmitted,
                                                  ViReal64 *frameErrorRate_,
                                                  ViReal64 *confidenceLevel, 
                                                  ViChar errorMessage[])


{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];  
   // JMG 020923
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA; 

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[243].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get Frame Transmitted
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%d", framesTransmitted );
   }
   else
   {
      *framesTransmitted = RSCMU_NAN;
   }
   
   // Get Frame Error Rate
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", frameErrorRate_ );
   }
   else
   {
      *frameErrorRate_ = RSCMU_NAN;
   }
 
   // Get Confidence Leve
   //JMG 020923
   *confidenceLevel = RSCMU_NAN;
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version >= RSCMU200_V3_09) 
   {
       if   (p_globalvarCDMA->RSCMU_XtndCQU == VI_TRUE) 
       {
           //Get Confidence Level
           if( strcmp( tab[2], "NAN" ) != 0 )
           {
              sscanf( tab[2], "%lf", confidenceLevel );
           }
           else
           {
              *confidenceLevel = RSCMU_NAN;
           }
        }
   }
   return( RSCMU_Status );    
} //end of RSCMU_CDMA2K_FetchOverCQuality()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleOverCQuality
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SampleOverCQuality (ViSession instrSession,
                                                   ViInt32 *framesTransmitted,
                                                   ViReal64 *frameErrorRate_,
                                                   ViReal64 *confidenceLevel,                                                     
                                                   ViChar errorMessage[])


{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   // JMG 020923
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA; 

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status; 
       
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[244].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get Frame Transmitted
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%d", framesTransmitted );
   }
   else
   {
      *framesTransmitted = RSCMU_NAN;
   }
   
   // Get Frame Error Rate
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", frameErrorRate_ );
   }
   else
   {
      *frameErrorRate_ = RSCMU_NAN;
   }
 
   // JMG 020923
   // Get Confidence Level
   *confidenceLevel = RSCMU_NAN;
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version >= RSCMU200_V3_09) 
   {
       if   (p_globalvarCDMA->RSCMU_XtndCQU == VI_TRUE) 
       {
           //Get Confidence Level
           if( strcmp( tab[2], "NAN" ) != 0 )
           {
              sscanf( tab[2], "%lf", confidenceLevel );
           }
           else
           {
              *confidenceLevel = RSCMU_NAN;
           }
        }
   }
   
   return( RSCMU_Status );    
} //end of RSCMU_CDMA2K_SampleOverCQuality()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalcOverCQualMatcLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_CalcOverCQualMatcLim (ViSession instrSession,
                                                     ViInt32 *FERLimit,
                                                     ViInt32 *confidenceLevel,                                                     
                                                     ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   // JMG 020923
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA; 

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;       
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[245].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                          
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Check tolerance for FERLimit
   if( strncmp( "NMAU", tab[0], 4 ) == 0 )
   {
      *FERLimit = RSCMU_NMAU;
   }
   else if( strncmp( "NMAL", tab[0], 4 ) == 0 )  
   {
      *FERLimit = RSCMU_NMAL;
   }
   else if( strncmp( "INV", tab[0], 3 ) == 0 ) 
   {
      *FERLimit = RSCMU_INV;  
   }
   else if( strncmp( "OK", tab[0], 2 ) == 0 ) 
   {
      *FERLimit = RSCMU_OK;  
   }  
   
   // Check tolerance for Confidence Level Limit
   // JMG 020923
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version >= RSCMU200_V3_09) 
   {
       if   (p_globalvarCDMA->RSCMU_XtndCQU == VI_TRUE) 
       {
   
           // Check tolerance for Confidence Level Limit
           if( strncmp( "NMAU", tab[1], 4 ) == 0 )
           {
              *confidenceLevel = RSCMU_NMAU;
           }
           else if( strncmp( "NMAL", tab[1], 4 ) == 0 )  
           {
              *confidenceLevel = RSCMU_NMAL;
           }
           else if( strncmp( "INV", tab[1], 3 ) == 0 ) 
           {
              *confidenceLevel = RSCMU_INV;  
           }
           else if( strncmp( "OK", tab[1], 2 ) == 0 ) 
           {
              *confidenceLevel = RSCMU_OK;  
           }   
   
       }
   }
   
   
   return( RSCMU_Status );  
   
} // end of RSCMU_CDMA2K_CalcOverCQualMatcLim()
      
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchRQFpc
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     actualOutputPower,FCHResult, DCCHResult, SCH0Result, SCH1Result
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchRQFpc (ViSession instrSession,
                                           tFPC     *FPC,
                                           ViChar errorMessage[])
{
   ViStatus                   RSCMU_Status          = VI_SUCCESS;  
   ViChar                     *wrtBuf;
   ViChar                     *rdBuf;
   ViChar                     tab[48][30]; 
   ViInt32                    i;   
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;


     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
  
  getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

  RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[599].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
  
   // Get actual output power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", &FPC->actualOutputPower);
   }
   else
   {
      FPC->actualOutputPower = RSCMU_NAN;
   }

   for(i =0;i<25; i+=8 )   
   {
       
     switch (i)
     {
     case 0:  // FCH
      
       
       //Get FER measurement
       if( strcmp( tab[1+i], "NAN" ) != 0 )
       {
          sscanf( tab[1+i], "%lf", &FPC->FCH.FER );
       }
       else
       {
          FPC->FCH.FER = RSCMU_NAN;
       }
       //Get FrameError measurement
       if( strcmp( tab[2+i], "NAN" ) != 0 )
       {
          sscanf( tab[2+i], "%d", &FPC->FCH.FrameError );
       }
       else
       {
          FPC->FCH.FrameError = RSCMU_NAN_VI_INT32;
       }  
       //Get Transmit Frame measurement
       if( strcmp( tab[3+i], "NAN" ) != 0 )
       {
          sscanf( tab[3+i], "%d", &FPC->FCH.TransmitFrame );
       }
       else
       {
          FPC->FCH.TransmitFrame = RSCMU_NAN_VI_INT32;
       }
       //Get Confidence Level measurement
       if( strcmp( tab[4+i], "NAN" ) != 0 )
       {
          sscanf( tab[4+i], "%lf", &FPC->FCH.ConfidenceLevel );
       }
       else
       {
          FPC->FCH.ConfidenceLevel = RSCMU_NAN;
       }    
       //Get Adjusted Level measurement
       if( strcmp( tab[5+i], "NAN" ) != 0 )
       {
          sscanf( tab[5+i], "%lf", &FPC->FCH.AdjustLevel );
       }
       else
       {
          FPC->FCH.AdjustLevel= RSCMU_NAN;
       }
       //Get Forward Channel Level measurement
       if( strcmp( tab[6+i], "NAN" ) != 0 )
       {
          sscanf( tab[6+i], "%lf", &FPC->FCH.FwdChLevel );
       }
       else
       {
          FPC->FCH.FwdChLevel= RSCMU_NAN;
       }  
       //Get Current Set Point value
       if( strcmp( tab[7+i], "NAN" ) != 0 )
       {
          sscanf( tab[7+i], "%lf", &FPC->FCH.CurrentSetPoint );
       }
       else
       {
          FPC->FCH.CurrentSetPoint = RSCMU_NAN;
       }
       //Get BS Calculate Eb/Nt measurement
       if( strcmp( tab[8+i], "NAN" ) != 0 )
       {                                                                
          sscanf( tab[8+i], "%lf", &FPC->FCH.BSCalEbNt );
       }
       else                                                                 
       {
         FPC->FCH.BSCalEbNt  = RSCMU_NAN;
       }
       
     break;
     
     case 8: // DCCH
     
       //Get FER measurement
       if( strcmp( tab[1+i], "NAN" ) != 0 )
       {
          sscanf( tab[1+i], "%lf", &FPC->DCCH.FER );
       }
       else
       {
          FPC->DCCH.FER = RSCMU_NAN;
       }
       //Get FrameError measurement
       if( strcmp( tab[2+i], "NAN" ) != 0 )
       {
          sscanf( tab[2+i], "%d", &FPC->DCCH.FrameError );
       }
       else
       {
          FPC->DCCH.FrameError = RSCMU_NAN_VI_INT32;
       }  
       //Get Transmit Frame measurement
       if( strcmp( tab[3+i], "NAN" ) != 0 )
       {
          sscanf( tab[3+i], "%d", &FPC->DCCH.TransmitFrame );
       }
       else
       {
          FPC->DCCH.TransmitFrame = RSCMU_NAN_VI_INT32;
       }
       //Get Confidence Level measurement
       if( strcmp( tab[4+i], "NAN" ) != 0 )
       {
          sscanf( tab[4+i], "%lf", &FPC->DCCH.ConfidenceLevel );
       }
       else
       {
          FPC->DCCH.ConfidenceLevel = RSCMU_NAN;
       }    
       //Get Adjusted Level measurement
       if( strcmp( tab[5+i], "NAN" ) != 0 )
       {
          sscanf( tab[5+i], "%lf", &FPC->DCCH.AdjustLevel );
       }
       else
       {
          FPC->DCCH.AdjustLevel= RSCMU_NAN;
       }
       //Get Forward Channel Level measurement
       if( strcmp( tab[6+i], "NAN" ) != 0 )
       {
          sscanf( tab[6+i], "%lf", &FPC->DCCH.FwdChLevel );
       }
       else
       {
          FPC->DCCH.FwdChLevel= RSCMU_NAN;
       }  
       //Get Current Set Point value
       if( strcmp( tab[7+i], "NAN" ) != 0 )
       {
          sscanf( tab[7+i], "%lf", &FPC->DCCH.CurrentSetPoint );
       }
       else
       {
          FPC->DCCH.CurrentSetPoint = RSCMU_NAN;
       }
       //Get BS Calculate Eb/Nt measurement
       if( strcmp( tab[8+i], "NAN" ) != 0 )
       {                                                                
          sscanf( tab[8+i], "%lf", &FPC->DCCH.BSCalEbNt );
       }
       else                                                                 
       {
         FPC->DCCH.BSCalEbNt  = RSCMU_NAN;
       }
     
     break;
     
     case 16: // SCH0
     
       //Get FER measurement
       if( strcmp( tab[1+i], "NAN" ) != 0 )
       {
          sscanf( tab[1+i], "%lf", &FPC->SCH0.FER );
       }
       else
       {
          FPC->SCH0.FER = RSCMU_NAN;
       }
       //Get FrameError measurement
       if( strcmp( tab[2+i], "NAN" ) != 0 )
       {
          sscanf( tab[2+i], "%d", &FPC->SCH0.FrameError );
       }
       else
       {
          FPC->SCH0.FrameError = RSCMU_NAN_VI_INT32;
       }  
       //Get Transmit Frame measurement
       if( strcmp( tab[3+i], "NAN" ) != 0 )
       {
          sscanf( tab[3+i], "%d", &FPC->SCH0.TransmitFrame );
       }
       else
       {
          FPC->SCH0.TransmitFrame = RSCMU_NAN_VI_INT32;
       }
       //Get Confidence Level measurement
       if( strcmp( tab[4+i], "NAN" ) != 0 )
       {
          sscanf( tab[4+i], "%lf", &FPC->SCH0.ConfidenceLevel );
       }
       else
       {
          FPC->SCH0.ConfidenceLevel = RSCMU_NAN;
       }    
       //Get Adjusted Level measurement
       if( strcmp( tab[5+i], "NAN" ) != 0 )
       {
          sscanf( tab[5+i], "%lf", &FPC->SCH0.AdjustLevel );
       }
       else
       {
          FPC->SCH0.AdjustLevel= RSCMU_NAN;
       }
       //Get Forward Channel Level measurement
       if( strcmp( tab[6+i], "NAN" ) != 0 )
       {
          sscanf( tab[6+i], "%lf", &FPC->SCH0.FwdChLevel );
       }
       else
       {
          FPC->SCH0.FwdChLevel= RSCMU_NAN;
       }  
       //Get Current Set Point value
       if( strcmp( tab[7+i], "NAN" ) != 0 )
       {
          sscanf( tab[7+i], "%lf", &FPC->SCH0.CurrentSetPoint );
       }
       else
       {
          FPC->SCH0.CurrentSetPoint = RSCMU_NAN;
       }
       //Get BS Calculate Eb/Nt measurement
       if( strcmp( tab[8+i], "NAN" ) != 0 )
       {                                                                
          sscanf( tab[8+i], "%lf", &FPC->SCH0.BSCalEbNt );
       }
       else                                                                 
       {
         FPC->SCH0.BSCalEbNt  = RSCMU_NAN;
       }
     
     break;
     
     case 24: // SCH1
     
       //Get FER measurement
       if( strcmp( tab[1+i], "NAN" ) != 0 )
       {
          sscanf( tab[1+i], "%lf", &FPC->SCH1.FER );
       }
       else
       {
          FPC->SCH1.FER = RSCMU_NAN;
       }
       //Get FrameError measurement
       if( strcmp( tab[2+i], "NAN" ) != 0 )
       {
          sscanf( tab[2+i], "%d", &FPC->SCH1.FrameError );
       }
       else
       {
          FPC->SCH1.FrameError = RSCMU_NAN_VI_INT32;
       }  
       //Get Transmit Frame measurement
       if( strcmp( tab[3+i], "NAN" ) != 0 )
       {
          sscanf( tab[3+i], "%d", &FPC->SCH1.TransmitFrame );
       }
       else
       {
          FPC->SCH1.TransmitFrame = RSCMU_NAN_VI_INT32;
       }
       //Get Confidence Level measurement
       if( strcmp( tab[4+i], "NAN" ) != 0 )
       {
          sscanf( tab[4+i], "%lf", &FPC->SCH1.ConfidenceLevel );
       }
       else
       {
          FPC->SCH1.ConfidenceLevel = RSCMU_NAN;
       }    
       //Get Adjusted Level measurement
       if( strcmp( tab[5+i], "NAN" ) != 0 )
       {
          sscanf( tab[5+i], "%lf", &FPC->SCH1.AdjustLevel );
       }
       else
       {
          FPC->SCH1.AdjustLevel= RSCMU_NAN;
       }
       //Get Forward Channel Level measurement
       if( strcmp( tab[6+i], "NAN" ) != 0 )
       {
          sscanf( tab[6+i], "%lf", &FPC->SCH1.FwdChLevel );
       }
       else
       {
          FPC->SCH1.FwdChLevel= RSCMU_NAN;
       }  
       //Get Current Set Point value
       if( strcmp( tab[7+i], "NAN" ) != 0 )
       {
          sscanf( tab[7+i], "%lf", &FPC->SCH1.CurrentSetPoint );
       }
       else
       {
          FPC->SCH1.CurrentSetPoint = RSCMU_NAN;
       }
       //Get BS Calculate Eb/Nt measurement
       if( strcmp( tab[8+i], "NAN" ) != 0 )
       {                                                                
          sscanf( tab[8+i], "%lf", &FPC->SCH1.BSCalEbNt );
       }
       else                                                                 
       {
         FPC->SCH1.BSCalEbNt  = RSCMU_NAN;
       }
     
     break;
     
     }
 
  }  
   return( RSCMU_Status );       
}//end of RSCMU_CDMA2K_FetchRQFpc

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleRQFpc
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     actualOutputPower,FCHResult, DCCHResult, SCH0Result, SCH1Result
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SampleRQFpc (ViSession   instrSession,
                                            tFPC        *FPC,
                                            ViChar      errorMessage[])
{
 ViStatus   RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViInt32 i;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
  
  getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

  RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[600].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
  
   // Get actual output power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", &FPC->actualOutputPower);
   }
   else
   {
      FPC->actualOutputPower = RSCMU_NAN;
   }

   for(i =0;i<25; i+=8 )   
   {
       
     switch (i)
     {
     case 0:  // FCH
      
       
       //Get FER measurement
       if( strcmp( tab[1+i], "NAN" ) != 0 )
       {
          sscanf( tab[1+i], "%lf", &FPC->FCH.FER );
       }
       else
       {
          FPC->FCH.FER = RSCMU_NAN;
       }
       //Get FrameError measurement
       if( strcmp( tab[2+i], "NAN" ) != 0 )
       {
          sscanf( tab[2+i], "%d", &FPC->FCH.FrameError );
       }
       else
       {
          FPC->FCH.FrameError = RSCMU_NAN_VI_INT32;
       }  
       //Get Transmit Frame measurement
       if( strcmp( tab[3+i], "NAN" ) != 0 )
       {
          sscanf( tab[3+i], "%d", &FPC->FCH.TransmitFrame );
       }
       else
       {
          FPC->FCH.TransmitFrame = RSCMU_NAN_VI_INT32;
       }
       //Get Confidence Level measurement
       if( strcmp( tab[4+i], "NAN" ) != 0 )
       {
          sscanf( tab[4+i], "%lf", &FPC->FCH.ConfidenceLevel );
       }
       else
       {
          FPC->FCH.ConfidenceLevel = RSCMU_NAN;
       }    
       //Get Adjusted Level measurement
       if( strcmp( tab[5+i], "NAN" ) != 0 )
       {
          sscanf( tab[5+i], "%lf", &FPC->FCH.AdjustLevel );
       }
       else
       {
          FPC->FCH.AdjustLevel= RSCMU_NAN;
       }
       //Get Forward Channel Level measurement
       if( strcmp( tab[6+i], "NAN" ) != 0 )
       {
          sscanf( tab[6+i], "%lf", &FPC->FCH.FwdChLevel );
       }
       else
       {
          FPC->FCH.FwdChLevel= RSCMU_NAN;
       }  
       //Get Current Set Point value
       if( strcmp( tab[7+i], "NAN" ) != 0 )
       {
          sscanf( tab[7+i], "%lf", &FPC->FCH.CurrentSetPoint );
       }
       else
       {
          FPC->FCH.CurrentSetPoint = RSCMU_NAN;
       }
       //Get BS Calculate Eb/Nt measurement
       if( strcmp( tab[8+i], "NAN" ) != 0 )
       {                                                                
          sscanf( tab[8+i], "%lf", &FPC->FCH.BSCalEbNt );
       }
       else                                                                 
       {
         FPC->FCH.BSCalEbNt  = RSCMU_NAN;
       }
       
     break;
     
     case 8: // DCCH
     
       //Get FER measurement
       if( strcmp( tab[1+i], "NAN" ) != 0 )
       {
          sscanf( tab[1+i], "%lf", &FPC->DCCH.FER );
       }
       else
       {
          FPC->DCCH.FER = RSCMU_NAN;
       }
       //Get FrameError measurement
       if( strcmp( tab[2+i], "NAN" ) != 0 )
       {
          sscanf( tab[2+i], "%d", &FPC->DCCH.FrameError );
       }
       else
       {
          FPC->DCCH.FrameError = RSCMU_NAN_VI_INT32;
       }  
       //Get Transmit Frame measurement
       if( strcmp( tab[3+i], "NAN" ) != 0 )
       {
          sscanf( tab[3+i], "%d", &FPC->DCCH.TransmitFrame );
       }
       else
       {
          FPC->DCCH.TransmitFrame = RSCMU_NAN_VI_INT32;
       }
       //Get Confidence Level measurement
       if( strcmp( tab[4+i], "NAN" ) != 0 )
       {
          sscanf( tab[4+i], "%lf", &FPC->DCCH.ConfidenceLevel );
       }
       else
       {
          FPC->DCCH.ConfidenceLevel = RSCMU_NAN;
       }    
       //Get Adjusted Level measurement
       if( strcmp( tab[5+i], "NAN" ) != 0 )
       {
          sscanf( tab[5+i], "%lf", &FPC->DCCH.AdjustLevel );
       }
       else
       {
          FPC->DCCH.AdjustLevel= RSCMU_NAN;
       }
       //Get Forward Channel Level measurement
       if( strcmp( tab[6+i], "NAN" ) != 0 )
       {
          sscanf( tab[6+i], "%lf", &FPC->DCCH.FwdChLevel );
       }
       else
       {
          FPC->DCCH.FwdChLevel= RSCMU_NAN;
       }  
       //Get Current Set Point value
       if( strcmp( tab[7+i], "NAN" ) != 0 )
       {
          sscanf( tab[7+i], "%lf", &FPC->DCCH.CurrentSetPoint );
       }
       else
       {
          FPC->DCCH.CurrentSetPoint = RSCMU_NAN;
       }
       //Get BS Calculate Eb/Nt measurement
       if( strcmp( tab[8+i], "NAN" ) != 0 )
       {                                                                
          sscanf( tab[8+i], "%lf", &FPC->DCCH.BSCalEbNt );
       }
       else                                                                 
       {
         FPC->DCCH.BSCalEbNt  = RSCMU_NAN;
       }
     
     break;
     
     case 16: // SCH0
     
       //Get FER measurement
       if( strcmp( tab[1+i], "NAN" ) != 0 )
       {
          sscanf( tab[1+i], "%lf", &FPC->SCH0.FER );
       }
       else
       {
          FPC->SCH0.FER = RSCMU_NAN;
       }
       //Get FrameError measurement
       if( strcmp( tab[2+i], "NAN" ) != 0 )
       {
          sscanf( tab[2+i], "%d", &FPC->SCH0.FrameError );
       }
       else
       {
          FPC->SCH0.FrameError = RSCMU_NAN_VI_INT32;
       }  
       //Get Transmit Frame measurement
       if( strcmp( tab[3+i], "NAN" ) != 0 )
       {
          sscanf( tab[3+i], "%d", &FPC->SCH0.TransmitFrame );
       }
       else
       {
          FPC->SCH0.TransmitFrame = RSCMU_NAN_VI_INT32;
       }
       //Get Confidence Level measurement
       if( strcmp( tab[4+i], "NAN" ) != 0 )
       {
          sscanf( tab[4+i], "%lf", &FPC->SCH0.ConfidenceLevel );
       }
       else
       {
          FPC->SCH0.ConfidenceLevel = RSCMU_NAN;
       }    
       //Get Adjusted Level measurement
       if( strcmp( tab[5+i], "NAN" ) != 0 )
       {
          sscanf( tab[5+i], "%lf", &FPC->SCH0.AdjustLevel );
       }
       else
       {
          FPC->SCH0.AdjustLevel= RSCMU_NAN;
       }
       //Get Forward Channel Level measurement
       if( strcmp( tab[6+i], "NAN" ) != 0 )
       {
          sscanf( tab[6+i], "%lf", &FPC->SCH0.FwdChLevel );
       }
       else
       {
          FPC->SCH0.FwdChLevel= RSCMU_NAN;
       }  
       //Get Current Set Point value
       if( strcmp( tab[7+i], "NAN" ) != 0 )
       {
          sscanf( tab[7+i], "%lf", &FPC->SCH0.CurrentSetPoint );
       }
       else
       {
          FPC->SCH0.CurrentSetPoint = RSCMU_NAN;
       }
       //Get BS Calculate Eb/Nt measurement
       if( strcmp( tab[8+i], "NAN" ) != 0 )
       {                                                                
          sscanf( tab[8+i], "%lf", &FPC->SCH0.BSCalEbNt );
       }
       else                                                                 
       {
         FPC->SCH0.BSCalEbNt  = RSCMU_NAN;
       }
     
     break;
     
     case 24: // SCH1
     
       //Get FER measurement
       if( strcmp( tab[1+i], "NAN" ) != 0 )
       {
          sscanf( tab[1+i], "%lf", &FPC->SCH1.FER );
       }
       else
       {
          FPC->SCH1.FER = RSCMU_NAN;
       }
       //Get FrameError measurement
       if( strcmp( tab[2+i], "NAN" ) != 0 )
       {
          sscanf( tab[2+i], "%d", &FPC->SCH1.FrameError );
       }
       else
       {
          FPC->SCH1.FrameError = RSCMU_NAN_VI_INT32;
       }  
       //Get Transmit Frame measurement
       if( strcmp( tab[3+i], "NAN" ) != 0 )
       {
          sscanf( tab[3+i], "%d", &FPC->SCH1.TransmitFrame );
       }
       else
       {
          FPC->SCH1.TransmitFrame = RSCMU_NAN_VI_INT32;
       }
       //Get Confidence Level measurement
       if( strcmp( tab[4+i], "NAN" ) != 0 )
       {
          sscanf( tab[4+i], "%lf", &FPC->SCH1.ConfidenceLevel );
       }
       else
       {
          FPC->SCH1.ConfidenceLevel = RSCMU_NAN;
       }    
       //Get Adjusted Level measurement
       if( strcmp( tab[5+i], "NAN" ) != 0 )
       {
          sscanf( tab[5+i], "%lf", &FPC->SCH1.AdjustLevel );
       }
       else
       {
          FPC->SCH1.AdjustLevel= RSCMU_NAN;
       }
       //Get Forward Channel Level measurement
       if( strcmp( tab[6+i], "NAN" ) != 0 )
       {
          sscanf( tab[6+i], "%lf", &FPC->SCH1.FwdChLevel );
       }
       else
       {
          FPC->SCH1.FwdChLevel= RSCMU_NAN;
       }  
       //Get Current Set Point value
       if( strcmp( tab[7+i], "NAN" ) != 0 )
       {
          sscanf( tab[7+i], "%lf", &FPC->SCH1.CurrentSetPoint );
       }
       else
       {
          FPC->SCH1.CurrentSetPoint = RSCMU_NAN;
       }
       //Get BS Calculate Eb/Nt measurement
       if( strcmp( tab[8+i], "NAN" ) != 0 )
       {                                                                
          sscanf( tab[8+i], "%lf", &FPC->SCH1.BSCalEbNt );
       }
       else                                                                 
       {
         FPC->SCH1.BSCalEbNt  = RSCMU_NAN;
       }
     
     break;
     
     }
 
  }  
   return( RSCMU_Status );             
}//End of RSCMU_CDMA2K_SampleRQFpc

/*****************************************************************************
 * Function: Refresh Interval
 * Purpose:  This function defines the time after which all results of the 
 *           RLPStatistic measurement are updated.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRLPSRint(
    ViSession   instrSession,
    ViReal64    refreshInterval,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                               "CONF:RLPS:CONT:RINT",
                               refreshInterval,
                               1.0, 100.0,
                               RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Init
 * Purpose:  This command has no query form. It starts the measurement, 
 *           setting it to the RUN status.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitRLPS(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "INIT:RLPS"));
}

/*****************************************************************************
 * Function: Abort
 * Purpose:  This command has no query form. It stops the measurement, setting 
 *           it to the OFF status.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_AborRLPS(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "ABOR:RLPS"));
}

/*****************************************************************************
 * Function: Stop
 * Purpose:  This function stops running measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_StopRLPS(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "STOP:RLPS"));
}

/*****************************************************************************
 * Function: Continue
 * Purpose:  This function continues stopped measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ContRLPS(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "CONT:RLPS"));
}

/*****************************************************************************
 * Function: Fetch Status
 * Purpose:  This function returns the status of the measurement and
 *           the statistical results (see chapters 3 and 5 of the operating 
 *           manual).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcRLPSStat(
    ViSession   instrSession,
    ViInt32*    measurementStatus,
    ViInt32 statResult[],
 ViChar errorMessage[]
)
{
    ViChar  response [256];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar    tab[48][30];
    ViInt32 i;

    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   "FETC:RLPS:STAT?",
                                   response,
                                   256,
                                   0));

    RSCMU_SeparateString( response, ",", tab );

    RSCMU_Status = RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

    for (i = 0; i < 4; i++)
    {
        if( strcmp( tab[i+1], "NAN" ) != 0 )
        {
            sscanf( tab[i+1], "%d", &statResult[i] );
        }
        else
        {
            statResult[i] = RSCMU_NAN_VI_INT32;
        }
    }
    
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Fetch
 * Purpose:  This function returns the results for all RLP frame types.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcRLPS(
    ViSession   instrSession,
    ViReal64    rx[],
    ViReal64    rxTotal[],
    ViReal64    tx[],
    ViReal64    txTotal[],
    ViReal64*   rxPPPTotalBytes,
    ViReal64*   rxDataRate,
    ViReal64*   txPPPTotalBytes,
    ViReal64*   txDataRate,
 ViChar errorMessage[]
)
{
    ViChar  command[20];
    ViChar  *hugeBuf = VI_NULL;
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViInt32 i;
    ViChar* str;
    
    sprintf (command, "FETC:RLPS?");
    
    CHECKRETMSG (RSCMU_viWrite(instrSession, command, strlen(command)));

    CHECKERR(RSCMU_ReadDataUnknownLength(instrSession, &hugeBuf, VI_NULL));
    
    if (RSCMU_Status < VI_SUCCESS)
        if (hugeBuf) free(hugeBuf);

    str = strtok (hugeBuf,",");
    
    for (i=0; i < 15; i++)
    {
        GET_VI_REAL64 (rx[i], VI_NULL);
        GET_VI_REAL64 (rxTotal[i], VI_NULL);
        GET_VI_REAL64 (tx[i], VI_NULL);
        GET_VI_REAL64 (txTotal[i], VI_NULL);
    }
    
    GET_VI_REAL64 (*rxPPPTotalBytes, VI_NULL);
    GET_VI_REAL64 (*rxDataRate, VI_NULL);
    GET_VI_REAL64 (*txPPPTotalBytes, VI_NULL);
    GET_VI_REAL64 (*txDataRate, VI_NULL);

    if (hugeBuf) 
        free(hugeBuf);

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Ping Count
 * Purpose:  This function defines the number of pings in a statistics cycle.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingContPco(
    ViSession   instrSession,
    ViInt32 pingCount,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:PING:CONT:PCO",
                              pingCount,
                              1,255,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Repeat Interval
 * Purpose:  This function defines the time between two consecutive echo 
 *           requests.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingContRint(
    ViSession   instrSession,
    ViReal64    repeatInterval,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                               "CONF:PING:CONT:RINT",
                               repeatInterval,
                               1.0,100.0,
                               RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Ping Timout
 * Purpose:  This function defines the timeout to wait for each reply.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingContTout(
    ViSession   instrSession,
    ViReal64    pingTimeout,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                               "CONF:PING:CONT:TOUT",
                               pingTimeout,
                               0.001,10.0,
                               RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Packet Size
 * Purpose:  This function defines the number of bytes in the send buffer.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingContPsiz(
    ViSession   instrSession,
    ViInt32 packetSize,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:PING:CONT:PSIZ",
                              packetSize,
                              1,1520,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Use MS IP Address
 * Purpose:  This function qualifies whether the pings are sent to the MS IP 
 *           address used for establishing the MIP/PPP connection or to a 
 *           different address reserved for pings.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingContMsip(
    ViSession   instrSession,
    ViBoolean   useMSIPAddress,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:PING:CONT:MSIP",
                           useMSIPAddress,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: IP Address Ping
 * Purpose:  This function defines the IP address used for the ping 
 *           measurement if CONFigure:PING:CONTrol:MSIP OFF is set.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingContIpad(
    ViSession   instrSession,
    ViInt32 ipAddresspart1,
    ViInt32 ipAddresspart2,
    ViInt32 ipAddresspart3,
    ViInt32 ipAddresspart4,
 ViChar errorMessage[]
)
{
    ViChar  command[50];
    
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart1, 0, 255, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart2, 0, 255, RSCMU_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart3, 0, 255, RSCMU_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart4, 0, 255, RSCMU_ERROR_PARAMETER5, errorMessage);

    sprintf (command, "CONF:PING:CONT:IPAD %ld,%ld,%ld,%ld", ipAddresspart1, ipAddresspart2, ipAddresspart3, ipAddresspart4);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Default Settings
 * Purpose:  This function sets all parameters of the subsystem to their 
 *           default values.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_DefPingCont(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "DEF:PING:CONT ON"));
}

/*****************************************************************************
 * Function: Repetition mode
 * Purpose:  This function determines the number of statistics cycles, the 
 *           stop condition and the stepping mode for the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingContRep(
    ViSession   instrSession,
    ViInt32 repetition,
    ViInt32 nbRepetition,
    ViInt32 stopCondition,
    ViInt32 stepMode,
 ViChar errorMessage[]
)
{
    ViChar  command[256];
    
    CHECK_VI_INT32_RANGE (instrSession, repetition, 0, 2, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, nbRepetition, 1, 10000, VI_ERROR_PARAMETER3, errorMessage);
//  CHECK_VI_INT32_RANGE (instrSession, stopCondition, 0, 1, VI_ERROR_PARAMETER4, errorMessage);
//  CHECK_VI_INT32_RANGE (instrSession, stepMode, 0, 1, VI_ERROR_PARAMETER5, errorMessage);

    switch (repetition)
        {
        case RSCMU_MULTIPLE:
            sprintf (command, "CONF:PING:CONT:REP %ld,NONE,NONE",
                     nbRepetition);
            break;
        default:
            sprintf (command, "CONF:PING:CONT:REP %s,NONE,NONE",
                     repetitionArr[repetition]);
            break;
        }

    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Init
 * Purpose:  This command has no query form. It starts the measurement, 
 *           setting it to the RUN status.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitPing(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG(RSCMU_sendCmd (instrSession, "INIT:PING"));
}

/*****************************************************************************
 * Function: Abort
 * Purpose:  This command has no query form. It stops the measurement, setting 
 *           it to the OFF status.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_AborPing(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG(RSCMU_sendCmd (instrSession, "ABOR:PING"));
}

/*****************************************************************************
 * Function: Stop
 * Purpose:  This function stops running measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_StopPing(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG(RSCMU_sendCmd (instrSession, "STOP:PING"));
}

/*****************************************************************************
 * Function: Continue
 * Purpose:  This function continues stopped measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ContPing(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG(RSCMU_sendCmd (instrSession, "CONT:PING"));
}

/*****************************************************************************
 * Function: Fetch Status
 * Purpose:  This function returns the status of the measurement (see Chapters 
 *           3 and 5) and the statistical results. A statistics cycle comprises 
 *           the number of pings defined by means of 
 *           CONFigure:PING:CONTrol:PCOunt.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcPingStat(
    ViSession   instrSession,
    ViInt32*    measurementStatus,
    ViInt32*    counterforcurrentstatcycle,
    ViInt32*    counterforcurrentping,
 ViChar errorMessage[]
)
{
    ViChar  response [256];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar    tab[48][30];   

    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   "FETC:PING:STAT?",
                                   response,
                                   256,
                                   0));

    RSCMU_SeparateString( response, ",", tab );

    RSCMU_Status = RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

    if( strcmp( tab[1], "NONE" ) != 0 )
    {
        sscanf( tab[1], "%d", counterforcurrentstatcycle );
    }
    else
    {
        *counterforcurrentstatcycle = RSCMU_OFF;
    }

    if( strcmp( tab[2], "NONE" ) != 0 )
    {
        sscanf( tab[2], "%d", counterforcurrentping );
    }
    else
    {
        *counterforcurrentping = RSCMU_OFF;
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Set Event Reporting Mode
 * Purpose:  This function defines the events generated when the measurement 
 *           is terminated or stopped.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPingErep(
    ViSession   instrSession,
    ViInt32 measurementEventReporting,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:PING:EREP",
                           measurementEventReporting,
                           erepArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Read
 * Purpose:  This function starts single shot measurement and returns results.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadPing(
    ViSession   instrSession,
    ViInt32 ipAddresspart1[],
    ViInt32 ipAddresspart2[],
    ViInt32 ipAddresspart3[],
    ViInt32 ipAddresspart4[],
    ViInt32 packetSize[],
    ViInt32 pingStatus[],
    ViReal64    pingTime[],
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasPing (instrSession,
                                  ipAddresspart1,
                                  ipAddresspart2,
                                  ipAddresspart3,
                                  ipAddresspart4,
                                  packetSize,
                                  pingStatus,
                                  pingTime,
                                  0,
                                  errorMessage);
}

/*****************************************************************************
 * Function: Fetch
 * Purpose:  This function reads out measurement results (unsynchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcPing(
    ViSession   instrSession,
    ViInt32 ipAddresspart1[],
    ViInt32 ipAddresspart2[],
    ViInt32 ipAddresspart3[],
    ViInt32 ipAddresspart4[],
    ViInt32 packetSize[],
    ViInt32 pingStatus[],
    ViReal64    pingTime[],
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasPing (instrSession,
                                  ipAddresspart1,
                                  ipAddresspart2,
                                  ipAddresspart3,
                                  ipAddresspart4,
                                  packetSize,
                                  pingStatus,
                                  pingTime,
                                  1,
                                  errorMessage);
}

/*****************************************************************************
 * Function: Sample
 * Purpose:  This function reads out measurement results (synchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SampPing(
    ViSession   instrSession,
    ViInt32 ipAddresspart1[],
    ViInt32 ipAddresspart2[],
    ViInt32 ipAddresspart3[],
    ViInt32 ipAddresspart4[],
    ViInt32 packetSize[],
    ViInt32 pingStatus[],
    ViReal64    pingTime[],
 ViChar errorMessage[]
)
{
    return RSCMU_CDMA2K_MeasPing (instrSession,
                                  ipAddresspart1,
                                  ipAddresspart2,
                                  ipAddresspart3,
                                  ipAddresspart4,
                                  packetSize,
                                  pingStatus,
                                  pingTime,
                                  2,
                                  errorMessage);
}

static ViStatus RSCMU_CDMA2K_MeasPing (ViSession instrSession,
                                       ViInt32  ipAddresspart1[],
                                       ViInt32  ipAddresspart2[],
                                       ViInt32  ipAddresspart3[],
                                       ViInt32  ipAddresspart4[],
                                       ViInt32  packetSize[],
                                       ViInt32  pingStatus[],
                                       ViReal64 pingTime[],
                                       ViInt32 cmdType,
                                       ViChar errorMessage[])
{
    ViChar  command[128];
    ViChar  *hugeBuf = VI_NULL;
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViString cmds[] = {"READ","FETC","SAMP"};
    ViInt32 i;
    ViChar* str;
    
    CHECK_VI_INT32_RANGE (instrSession, cmdType, 0, 2, VI_ERROR_PARAMETER5, errorMessage);
    
    sprintf (command, "%s:PING?", cmds[cmdType]);
    
    CHECKRETMSG (RSCMU_viWrite(instrSession, command, strlen(command)));

    CHECKERR(RSCMU_ReadDataUnknownLength(instrSession, &hugeBuf, VI_NULL));
    
    if (RSCMU_Status < VI_SUCCESS)
        if (hugeBuf) free(hugeBuf);

    str = strtok (hugeBuf,",");
    
    for (i=0; i < 5;i++)
    {
        sscanf (str,"'%ld.%ld.%ld.%ld'",&ipAddresspart1[i],
                                        &ipAddresspart2[i],
                                        &ipAddresspart3[i],
                                        &ipAddresspart4[i]);
        
        GET_VI_INT32 (packetSize[i], VI_NULL, ",");
        GET_VI_INT32 (pingStatus[i], VI_NULL, ",");
        if (!sscanf (str, "%Le", &pingTime[i]))
        {
            CHECKRETMSG (RSCMU_getIndexFromString (instrSession,
                                                   str,
                                                   pingStatusArr,
                                                   &pingStatus[i]));
        }
        else
        {
            pingStatus[i] = 0;
        }
    }

    if (hugeBuf) 
        free(hugeBuf);

    RETMSG (RSCMU_Status);
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ProcSigAction
 *
 * DESCRIPTION: This function changes between the different signalling 
 *              states of the CMU.   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSigAction (ViSession instrSession,
                                              ViInt32 signallingAction,
                                              ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViInt32   currState;
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;        
   

     // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;     
   if( (RSCMU_Status = RSCMU_CDMA2K_ProcSigState( instrSession
                                              , &currState
                                              , errorMessage
                                              )) < 0 )
   {
      return( RSCMU_Status );
   }

   checkRange( 315, &signallingAction );
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   switch( signallingAction )
   {
   case RSCMU_SIG_ACT_SON:
      // Be sure that CMU is in SOFF
      if(( currState != RSCMU_SIG_STATE_SOFF )&&(currState != RSCMU_SIG_STATE_SON)&&(currState != RSCMU_SIG_STATE_REG))
      {
         // do nothing
         return RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage );
      }
      break;

   case RSCMU_SIG_ACT_SOFF:
      break;
      
   case RSCMU_SIG_ACT_UNR:
      //Make sure that CMU is in SON
      if(currState != RSCMU_SIG_STATE_REG)
      {
        // do nothing
         return RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage );         
      }

   case RSCMU_SIG_ACT_CTM:   // Call to mobile
      // Be sure that CMU is in SON, REG and not in CEST.
      if( ((currState != RSCMU_SIG_STATE_SON) && (currState != RSCMU_SIG_STATE_REG)) || 
          (currState == RSCMU_SIG_STATE_CEST) )
      {
         return RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage );
      }
      break;

   case RSCMU_SIG_ACT_CREL:  // Release the call
      // Be sure that CMU is in CEST.//or VCES
      if (!(( currState == RSCMU_SIG_STATE_CEST ))) //|| ( currState == RSCMU_CDMA_STATE_VCES )))
      {
        return RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      }
      break;

   case RSCMU_SIG_ACT_HAND:  // Handoff
      // Be sure that CMU is in CEST.//or VCES
      if (!(( currState == RSCMU_SIG_STATE_CEST ))) //|| ( currState == RSCMU_CDMA_STATE_VCES )))
      {
        return RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      }
      break;
      
   case RSCMU_SIG_ACT_SMES:  //SMS Message
       
      if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
            return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);        
      break;      
      
   default:
        return RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
   }

                             
   // Send command ONLY if no errors in the signalling state were detected!
   sprintf( wrtBuf
          , CDMA[315].instrCommand
          , sigAction.list[signallingAction]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ProcSigAction()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ProcSigState
 *
 * DESCRIPTION: This routine reads the current signalling state of the CMU.
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSigState (ViSession instrSession,
                                             ViInt32 *state,
                                             ViChar errorMessage[])
                                             
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[316].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Get signalling state
   if( strncmp( "SOFF", rdBuf, 4 ) == 0 )
   {                                                   
     *state = RSCMU_SIG_STATE_SOFF;
   }
   else if( strncmp( "SON", rdBuf, 3 ) == 0 )  
   {
      *state = RSCMU_SIG_STATE_SON;
   }
   else if( strncmp( "REG", rdBuf, 3 ) == 0 ) 
   {
      *state = RSCMU_SIG_STATE_REG;  
   }
   else if( strncmp( "ALER", rdBuf, 4 ) == 0 ) 
   {
      *state = RSCMU_SIG_STATE_ALER;  
   }   
   else if( strncmp( "CEST", rdBuf, 4 ) == 0 ) 
   {
      *state = RSCMU_SIG_STATE_CEST;
   }
   else if( strncmp( "CPEN", rdBuf, 4 ) == 0 ) 
   {
      *state = RSCMU_SIG_STATE_CPEN;
   }   
   else if( strncmp( "FPEN", rdBuf, 4 ) == 0 ) 
   {
      *state = RSCMU_SIG_STATE_FPEN;
   }
       
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) 
  {
   if( strncmp( "SMES", rdBuf, 4 ) == 0 ) 
   {
      *state = RSCMU_SIG_STATE_SMES;
   }
  } 
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V4_50) 
  {
   if( strncmp( "PAG", rdBuf, 3 ) == 0 ) 
   {
      *state = RSCMU_SIG_STATE_PAG;
   }
  } 
  
   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ProcSigState()
                                                                    
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNstandard
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNstandard (ViSession instrSession,
                                              ViInt32 CDMA2KStandard,
                                              ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 317 , &CDMA2KStandard );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[317].instrCommand
          , standard.list[CDMA2KStandard]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfNstandard()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SenseSCInfo
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     forwardRC,reverseRC,serviceOption
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SenseSCInfo (ViSession instrSession,
                                            ViInt32 *forwardRC,
                                            ViInt32 *reverseRC,
                                            ViChar serviceOption[],
                                            ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];        

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
  RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[603].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );       
          
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get Frame Transmitted
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%d", forwardRC );
   }
   else
   {
      *forwardRC = RSCMU_NAN;
   }
   
   // Get Frame Error Rate
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%d", reverseRC );
   }
   else
   {
      *reverseRC = RSCMU_NAN;
   }
   
   if( strcmp( tab[2], "INV" ) != 0 )
   {
      sscanf( tab[2], "%s", serviceOption );
   }
   else
   {
      *serviceOption = RSCMU_NAN;
   }

   return( RSCMU_Status );        
    
}//end of RSCMU_CDMA2K_SenseSCInfo
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefSCON
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      defaultServiceConfiguration
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefSCON (ViSession instrSession,
                                        ViBoolean defaultServiceConfiguration,
                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 610, &defaultServiceConfiguration );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[610].instrCommand
          , enable.list[defaultServiceConfiguration]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of RSCMU_CDMA2K_DefSCON

/*****************************************************************************
 * Function: Accpet MS Originated Calls
 * Purpose:  This function selects the types of Mobile Station Originated 
 *           Calls (MOC) that the CMU will accept.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconAmoc (ViSession instrSession,
                                             ViInt32 service,
                                             ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:SCON:AMOC",
                           service,
                           acceptArr,
                           VI_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSRfChannel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSRfChannel (ViSession instrSession,
                                                 ViInt32 channel,
                                                 ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 318, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[318].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfBSSRfChannel()    

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSRfFrequency
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSRfFrequency (ViSession instrSession,
                                                   ViReal64 frequency,
                                                   ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   // checkRange routine is not used due to bug in how unions are
   // handled when initializing float types.
   if( frequency < 0.2 )  frequency = 0.2;
   if( frequency > 2700 ) frequency = 2700;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[319].instrCommand
          , frequency
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfBSSRfFrequency()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSRfPowCDMA
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSRfPowCDMA (ViSession instrSession,
                                                 ViReal64 CDMAPower_dBm,
                                                 ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 320, &CDMAPower_dBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
              , CDMA[320].instrCommand
              , CDMAPower_dBm
              );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfBSSRfPowCDMA()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSRfPowOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSRfPowOut (ViSession instrSession,
                                                ViReal64 *outputPower_dB,
                                                ViChar errorMessage[])


{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[321].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", outputPower_dB );
   }
   else
   {
      *outputPower_dB = RSCMU_NAN;
   }

   return( RSCMU_Status );

    
} // end of RSCMU_CDMA2K_ConfBSSRfPowOut() 

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSFSyncLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFSyncLevel (ViSession instrSession,
                                                  ViReal64 syncLevel,
                                                  ViBoolean Enable,
                                                  ViChar errorMessage[])
 
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 322, &syncLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[322].instrCommand
          , syncLevel
          , enable.list[Enable]
          );
       
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSFSyncLevel()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSFPilotChLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFPilotChLevel (ViSession  instrSession,
                                                     ViReal64   pilotLevel,
                                                     ViBoolean  Enable,
                                                     ViChar errorMessage[])
 
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 323, &pilotLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
    sprintf( wrtBuf
          , CDMA[323].instrCommand
          , pilotLevel
          , enable.list[Enable]
          );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSFPilotChLevel()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSPowerCntrlBit
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

// JMG 020923
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSPowerCntrlBit (ViSession instrSession,
                                                     ViInt32 BSPowerControlBitsMode,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
  
   checkRange( 333, &BSPowerControlBitsMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[333].instrCommand
          // JMG 020923 , BSPowerControlBitsMode
          , powerCtlBits.list[BSPowerControlBitsMode]
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of RSCMU_CDMA2K_ConfBSSPowerCntrlBit()    

/*****************************************************************************
 * Function: Sequence Mode
 * Purpose:  This function selects the algorithm to construct the complete 
 *           user-defined pattern from the single bit pattern defined by means 
 *           of the CONFigure:BSSignal:PCBits:PATTern:AREA<nr> commands.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSPCBPattSqm (ViSession instrSession,
                                                  ViInt32 powerStepSize,
                                                  ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:BSS:PCB:PATT:SQM",
                           powerStepSize,
                           powerStepArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Number Of Bits
 * Purpose:  This function defines the number of bits in each of the 4 areas 
 *           of the user-defined single pattern.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSPCBPattAreaNob (ViSession instrSession,
                                                      ViInt32 area,
                                                      ViInt32 numberOfBits,
                                                      ViChar errorMessage[])
{
    ViChar      command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, area, 1, 4, VI_ERROR_PARAMETER2, errorMessage);

    sprintf (command, "CONF:BSS:PCB:PATT:AREA%ld:NOB", area);
    
    RETMSG (RSCMU_setViInt32 (instrSession,
                              command,
                              numberOfBits,
                              1, 128,
                              VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Last Hold Bit
 * Purpose:  This function defines the bit polarity in area no. 1 of the 
 *           user-defined single pattern.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSPCBPattAreaLhb (ViSession instrSession,
                                                      ViInt32 lastHoldBit,
                                                      ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:BSS:PCB:PATT:AREA1:LHB",
                           lastHoldBit,
                           polarityArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Polarity
 * Purpose:  This function defines the bit polarity in areas 2 to 4 of the 
 *           user-defined single pattern.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSPCBPattAreaPol (ViSession instrSession,
                                                      ViInt32 area,
                                                      ViInt32 polarity,
                                                      ViChar errorMessage[])
{
    ViChar      command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, area, 2, 4, VI_ERROR_PARAMETER2, errorMessage);

    sprintf (command, "CONF:BSS:PCB:PATT:AREA%ld:POL", area);
    
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           polarity,
                           polarityArr,
                           VI_ERROR_PARAMETER3));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSFFCHLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFFCHLevel (ViSession instrSession,
                                                 ViReal64 FFCHLevel,
                                                 ViBoolean Enable, 
                                                 ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 324, &FFCHLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
    sprintf( wrtBuf
          , CDMA[324].instrCommand
          , FFCHLevel
          , enable.list[Enable]
          );
 
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSFFCHLevel()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSFFCHChannel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFFCHChannel (ViSession instrSession,
                                                   ViInt32 FFCHChannel,
                                                   ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 325, &FFCHChannel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[325].instrCommand
          , FFCHChannel
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSFFCHChannel()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSFFCHFrameOffset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFFCHFrameOffset (ViSession instrSession,
                                                       ViInt32 FFCHFrameOffset,
                                                       ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 326, &FFCHFrameOffset );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[326].instrCommand
          , FFCHFrameOffset
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSFFCHFrameOffset()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSQofFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSQofFFCH (ViSession instrSession,
                                               ViInt32 QOF,
                                               ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 357, &QOF );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[357].instrCommand
          , QOF
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSQofFFCH()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalBSSEbntFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_CalBSSEbntFFCH (ViSession instrSession,
                                               ViReal64 *calculatedEbNtFFCH,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30]; 
   

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *) CDMA[619].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%lf", calculatedEbNtFFCH );
     }
     else
       *calculatedEbNtFFCH = RSCMU_NAN;
     
   return( RSCMU_Status );          
}//end of RSCMU_CDMA2K_CalBSSEbntFFCH

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSFSCHLevelZero
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFSCHLevelZero (ViSession instrSession,
                                                     ViReal64 FSCHLevel,
                                                     ViBoolean Enable,
                                                     ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 503, &FSCHLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
    sprintf( wrtBuf
          , CDMA[503].instrCommand
          , FSCHLevel
          , enable.list[Enable]
          );
 
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSFSCHLevelZero()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSFSCHChannelZero
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFSCHChannelZero (ViSession instrSession,
                                                       ViInt32 FSCHChannel,
                                                       ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 504, &FSCHChannel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[504].instrCommand
          , FSCHChannel
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSFSCHChannelZero()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSFSCHFrameOffZero
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFSCHFrameOffZero (ViSession instrSession,
                                                        ViInt32 FSCHFrameOffset,
                                                        ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 505, &FSCHFrameOffset );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[505].instrCommand
          , FSCHFrameOffset
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSFSCHFrameOffZero()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSQofFSCHZero
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSQofFSCHZero (ViSession instrSession,
                                                   ViInt32 QOF,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;                             

   checkRange( 506, &QOF );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[506].instrCommand
          , QOF
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSQofFSCHZero()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfImpairRfLevAWGNLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfImpairRfLevAWGNLev (ViSession    instrSession,
                                                        ViReal64    AWGNLevel,
                                                        ViBoolean   Enable,
                                                        ViChar      errorMessage[])


{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 327, &AWGNLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[327].instrCommand
          , AWGNLevel
          , enable.list[Enable]
          );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfImpairRfLevAWGNLev()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfImpairRfFreqOffset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfImpairRfFreqOffset (ViSession instrSession,
                                                  ViReal64 freqOffset,
                                                  ViBoolean Enable, 
                                                  ViChar errorMessage[])


{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 328, &freqOffset );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
    sprintf( wrtBuf
          , CDMA[328].instrCommand
          , freqOffset
          , enable.list[Enable]
          );
 
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfImpairRfFreqOffset()

/*****************************************************************************
 * Function: Impairments Injected FER
 * Purpose:  This function defines a percentage of faulty (i.e. erasure) 
 *           frames that the CMU injects into all traffic channels of its BS 
 *           Signal.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfImpItf (ViSession instrSession,
                                           ViReal64 injectedTxFER,
                                           ViBoolean enable,
                                           ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                              "CONF:IMP:ITF",
                              enable,
                              stateArr,
                              VI_ERROR_PARAMETER3));
    if (enable)
    {
        RETMSG (RSCMU_setViReal64 (instrSession,
                                  "CONF:IMP:ITF",
                                  injectedTxFER,
                                  0.0,50.0,
                                  VI_ERROR_PARAMETER2));
    }
    else
    {
        RETMSG (RSCMU_Status);
    }
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSRfLevOCNSValue
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSRfLevOCNSValue (ViSession instrSession,
                                                      ViReal64 *OCNSValue,
                                                      ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[329].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", OCNSValue );
   }
   else
   {
      *OCNSValue = RSCMU_NAN;
   }

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfBSSRfLevOCNSValue() 

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSRfLevOCNSEnable
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSRfLevOCNSEnable (ViSession instrSession,
                                                       ViBoolean OCNSEnable,
                                                       ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 330, &OCNSEnable );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[330].instrCommand
          , enable.list[OCNSEnable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfBSSRfLevOCNSEnable()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalBSSEbntFSCHZ
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     calculatedEbNtFFCH
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalBSSEbntFSCHZ (ViSession instrSession,
                                                ViReal64 *calculatedEbNtFSCH0,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30]; 
   

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *) CDMA[620].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%lf", calculatedEbNtFSCH0 );
     }
     else
       *calculatedEbNtFSCH0 = RSCMU_NAN;
     
   return( RSCMU_Status );             
}//end of RSCMU_CDMA2K_CalBSSEbntFSCHZ

/*****************************************************************************
 * Function: FSCH Level
 * Purpose:  This function determines the signal level of the supplemental 
 *           traffic channel 1 in the forward CDMA channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFSCHLevelOne (ViSession instrSession,
                                                    ViReal64 FSCHLevel,
                                                    ViBoolean enable,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                              "CONF:BSS:LEV:FSCH:ONE",
                              enable,
                              stateArr,
                              VI_ERROR_PARAMETER3));
    if (enable)
    {
        RETMSG (RSCMU_setViReal64 (instrSession,
                                  "CONF:BSS:LEV:FSCH:ONE",
                                  FSCHLevel,
                                  -20.0,7.0,
                                  VI_ERROR_PARAMETER2));
    }
    else
    {
        RETMSG (RSCMU_Status);
    }
}

/*****************************************************************************
 * Function: FSCH Channel
 * Purpose:  This function determines the forward supplemental traffic channel 
 *           number.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFSCHChannelOne (ViSession instrSession,
                                                      ViInt32 FSCHChannel,
                                                      ViChar errorMessage[])
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:BSS:CHAN:FSCH:ONE",
                              FSCHChannel,
                              0,63,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: FSCH Frame Offset
 * Purpose:  This function determines an offset for the traffic channel timing 
 *           in CDMA frames.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFSCHFrameOffOne (ViSession instrSession,
                                                       ViInt32 FSCHFrameOffset,
                                                       ViChar errorMessage[])
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:BSS:FROF:FSCH:ONE",
                              FSCHFrameOffset,
                              0,15,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: FSCH Quasi Orthogonal Function
 * Purpose:  This function sets the Qasi-Orthogonal Function that the 
 *           Supplemental Channels uses in the forward CDMA channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSQofFSCHOne (ViSession instrSession,
                                                  ViInt32 QOF,
                                                  ViChar errorMessage[])
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:BSS:QOF:FSCH:ONE",
                              QOF,
                              0,3,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Calculated Eb/Nt FSCH1
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the forward SCH1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalBSSEbntFSCHO (ViSession instrSession,
                                                ViReal64 *calculatedEbNtFSCH0,
                                                ViChar errorMessage[])
{
    RETMSG (RSCMU_getViReal64 (instrSession,
                               "CALC:BSS:EBNT:FSCH:ONE?",
                               calculatedEbNtFSCH0,
                               VI_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSFPCHLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFPCHLevel (ViSession instrSession,
                                                 ViReal64 FPCHLevel,
                                                 ViBoolean Enable,
                                                 ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 331, &FPCHLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
    sprintf( wrtBuf
          , CDMA[331].instrCommand
          , FPCHLevel
          , enable.list[Enable]
          );
 
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSFPCHLevel()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSFPCHChannel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSFPCHChannel (ViSession instrSession,
                                                   ViInt32 FPCHChannel,
                                                   ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 332, &FPCHChannel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[332].instrCommand
          , FPCHChannel
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSFPCHChannel()
      
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfBSSUsageFQPCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      QPCHUsage
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSUsageFQPCH (ViSession instrSession,
                                                  ViBoolean QPCHUsage,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 433, &QPCHUsage);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[433].instrCommand
          , enable.list[QPCHUsage]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ConfBSSUsageFQPCH

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSLevFQPCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      QPCHLevel,enable
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSLevFQPCH (ViSession   instrSession,
                                                ViReal64    QPCHLevel,
                                                ViBoolean   Enable,
                                                ViChar      errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 434, &QPCHLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[434].instrCommand
          , QPCHLevel
          , enable.list[Enable]
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSLevFQPCH()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSChFQPCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      quickPagingChannel
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSChFQPCH (ViSession    instrSession,
                                               ViInt32      *quickPagingChannel,
                                               ViChar       errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   //checkRange( 435, &quickPagingChannel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *) CDMA[435].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( strcmp( rdBuf, "NAN" ) != 0 )
     {
       sscanf( rdBuf, "%d", quickPagingChannel );
     }
     else
       *quickPagingChannel = RSCMU_NAN_VI_INT32;

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSChFQPCH()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSIbitsFQPCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      indicatorBits
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSIbitsFQPCH (ViSession instrSession,
                                                  ViInt32 IndicatorBits,
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 436, &IndicatorBits );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[436].instrCommand
          , indicatorBit.list[IndicatorBits]
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSIbitsFQPCH()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSDutPagingFQPCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      DUTPaging
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSDutPagingFQPCH (ViSession instrSession,
                                                      ViBoolean DUTPaging,
                                                      ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 437, &DUTPaging );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[437].instrCommand
          , enable.list[DUTPaging]
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSDutPagingFQPCH()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSPropCLDTime
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      DUTPaging
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSPropCLDTime (ViSession    instrSession,
                                                   ViReal64     callLossDetectTime,
                                                   ViBoolean    Enable,
                                                   ViChar       errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 438, &callLossDetectTime);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[438].instrCommand
          , callLossDetectTime
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSPropCLDTime()

/*****************************************************************************
 * Function: Page Response Timeout
 * Purpose:  This function sets the timeout value of the page timer (in 
 *           increments of 1 seconds) to define the maximum time the CMU will 
 *           attempt to page the mobile.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSProPrt(
    ViSession   instrSession,
    ViReal64    pageResponseTimeout,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                               "CONF:BSS:PROP:PRT",
                               pageResponseTimeout,
                               5.0, 15.0,
                               RSCMU_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcBSSUsageFQPCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      QPCHUsage
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSUsageFQPCH (ViSession instrSession,
                                                  ViBoolean QPCHUsage,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 439, &QPCHUsage);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[439].instrCommand
          , enable.list[QPCHUsage]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ProcBSSUsageFQPCH

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ProcBSSLevFQPCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      QPCHLevel,enable
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSLevFQPCH (ViSession instrSession,
                                                ViReal64 QPCHLevel,
                                                ViBoolean Enable,
                                                ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 440, &QPCHLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[440].instrCommand
          , enable.list[Enable], QPCHLevel
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ProcBSSLevFQPCH()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ProcBSSChFQPCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      quickPagingChannel
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSChFQPCH (ViSession instrSession,
                                               ViInt32 quickPagingChannel,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 441, &quickPagingChannel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[441].instrCommand
          , quickPagingChannel
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ProcBSSChFQPCH()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ProcBSSIbitsFQPCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      indicatorBits
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSIbitsFQPCH (ViSession instrSession,
                                                  ViInt32 IndicatorBits,
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 442, &IndicatorBits );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[442].instrCommand
          , indicatorBit.list[IndicatorBits]
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ProcBSSIbitsFQPCH()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ProcBSSDutPagingFQPCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      DUTPaging
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSDutPagingFQPCH (ViSession instrSession,
                                                      ViBoolean DUTPaging,
                                                      ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 443, &DUTPaging );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[443].instrCommand
          , enable.list[DUTPaging]
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ProcBSSDutPagingFQPCH()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfBSSProPNOffset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSProPNOffset (ViSession instrSession,
                                                   ViInt32 PNOffset,
                                                   ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 334, &PNOffset );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[334].instrCommand
          , PNOffset
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfBSSProPNOffset()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMD2K_ConfBSSProIDNumber
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

                             
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSProIDNumber (ViSession instrSession,
                                                   ViInt32 IDNumber,
                                                   ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 335, &IDNumber );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[335].instrCommand
          , IDNumber
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMD2K_ConfBSSProIDNumber()
 
/*****************************************************************************
 * Function: Power Step Size
 * Purpose:  This function selects the step size that the mobile station is to 
 *           use for closed loop power control.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSPCBSsize (ViSession instrSession,
                                                ViReal64 powerStepSize,
                                                ViChar errorMessage[])
{
    if ((powerStepSize != 0.25) &&
        (powerStepSize != 0.5) &&
        (powerStepSize != 1.0))
        RETMSG (VI_ERROR_PARAMETER2);
    
    RETMSG (RSCMU_setViReal64 (instrSession,
                               "CONF:BSS:PCB:SSIZ",
                               powerStepSize,
                               0.0,0.0,
                               0));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefBSSignal
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      BSSignalDefault
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefBSSignal (ViSession instrSession,
                                            ViBoolean BSSignalDefault,
                                            ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   

   sprintf( wrtBuf
          , CDMA[618].instrCommand
          , enable.list[BSSignalDefault]  
          );   
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );             
} //end of RSCMU_CDMA2K_DefBSSignal

/*****************************************************************************
 * Function: Leap Seconds
 * Purpose:  This function sets the number of leap seconds (in increments of
 *           1 seconds) used to calculate the CDMA local time of the AT. A
 *           leap second is an adjustment to UTC by skipping or adding an
 *           extra second on the last second of a UTC month. First preference
 *           is given to the end of December and June, and second preference
 *           is given to the end of March and September.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSProLsec (ViSession instrSession,
                                               ViInt32 leapSeconds,
                                               ViChar errorMessage[])
{
    RETMSG (RSCMU_setViInt32 (instrSession, 
                              "CONF:BSS:PROP:LSEC",
                              leapSeconds,
                              0, 255,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Local Time Offset
 * Purpose:  This function specifies the local time offset from CDMA system
 *           time as a constant value for the descriptor tag as specifed in
 *           standard EN 300 468.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSProLtof (ViSession instrSession,
                                               ViInt32 localTimeOffset,
                                               ViChar errorMessage[])
{
    RETMSG (RSCMU_setViInt32 (instrSession, 
                              "CONF:BSS:PROP:LTOF",
                              localTimeOffset,
                              0, 63,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Daylight Savings
 * Purpose:  This function sets the use of daylight saving time for CDMA
 *           system time calculations.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfBSSProDls (ViSession instrSession,
                                              ViBoolean daylightSavings,
                                              ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession, 
                           "CONF:BSS:PROP:DLS",
                           daylightSavings,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_NetIdenMCC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_NetIdenMCC (ViSession instrSession,
                                           ViChar MCC[], 
                                           ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[336].instrCommand
          , MCC
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_NetIdenMCC()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_NetIdenNID
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_NetIdenNID (ViSession instrSession,
                                           ViInt32 NID, 
                                           ViChar errorMessage[])           
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;


   checkRange( 337, &NID );    
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[337].instrCommand
          , NID
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_NetIdenNID()
 
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfMSSigID
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfMSSigID (ViSession instrSession,
                                            ViChar mobileID[],
                                            ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[338].instrCommand
          , mobileID
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ConfMSSigID()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfMSSigIDURData
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      mobileRegistrationDataMINIMSI
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfMSSigIDURData (ViSession instrSession,
                                                  ViInt32 mobileRegistrationDataMINIMSI,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   

   sprintf( wrtBuf
          , CDMA[621].instrCommand
          , modeEnable.list[mobileRegistrationDataMINIMSI]  
          );   
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );         
}//end of RSCMU_CDMA2K_ConfMSSigIDURData

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetMSSigMCC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetMSSigMCC (ViSession instrSession,
                                                ViChar MCC[],
                                                ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[339].instrCommand
          , MCC
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfNetMSSigMCC()

/*****************************************************************************
 * Function: Mobile Capabilities Report
 * Purpose:  This function qualifies whether the mobile capabilities report is 
 *           requested during registration and displayed. When set to OFF most 
 *           of the parameters in the [SENSe:]MSSinfo... subsystem returns 
 *           invalid results.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetMSSigMCR(
    ViSession   instrSession,
    ViBoolean   mobileCapabilitiesReport,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:MSS:MCR",
                           mobileCapabilitiesReport,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Caller ID
 * Purpose:  This function defines the caller ID to be sent to the mobile.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetCindCid(
    ViSession   instrSession,
    ViBoolean   enableTransferofCallerID,
    ViString    callerID,
 ViChar errorMessage[]
)
{
    ViChar  command[50];
    
    if (enableTransferofCallerID)
    {
        if (callerID)
            sprintf (command, "CONF:NETW:CIND:CID '%s'", callerID);
        else
            strcpy (command, "CONF:NETW:CIND:CID ON");
    }
    else
        strcpy (command, "CONF:NETW:CIND:CID OFF");
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Caller ID Presentation Ind
 * Purpose:  This function specifies how the mobile under test will display 
 *           the Caller ID (CPN) (CONFigure:NETWork:CINDicator:CID) received 
 *           from the CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetCindPind(
    ViSession   instrSession,
    ViInt32 callerIDPresentationInd,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:NETW:CIND:PIND",
                           callerIDPresentationInd,
                           pindArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Call Waiting Indicator
 * Purpose:  If set to ON during an established call, this command initiates 
 *           the transfer of the Caller ID to the mobile.
 *           The call waiting indicator is automatically set to Off when the 
 *           connection is released.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetCindCwin(
    ViSession   instrSession,
    ViBoolean   callWaitingIndicator,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:NETW:CIND:CWIN",
                           callWaitingIndicator,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetSysSID
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysSID (ViSession instrSession,
                                              ViInt32 systemID,
                                              ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 396, &systemID );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[396].instrCommand
          , systemID
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
       
    
} // end of RSCMU_CDMA2K_ConfNetSysSID()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetSysBSID
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysBSID (ViSession instrSession,
                                               ViInt32 stationID,
                                               ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 340, &stationID );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[340].instrCommand
          , stationID
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
       
    
} // end of RSCMU_CDMA2K_ConfNetSysBSID()

/*****************************************************************************
 * Function: Activate vs Candidate Window
 * Purpose:  This function sets the size of the search window for each pilot 
 *           in the Active Set or Candidate Set.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysSWA(
    ViSession   instrSession,
    ViInt32 windowSize,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:NETW:SYST:SWA",
                              windowSize,
                              0, 15,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Neighbor Window
 * Purpose:  This function sets the size of the search window for each pilot 
 *           in the Neighbor Set.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysSWN(
    ViSession   instrSession,
    ViInt32 windowSize,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:NETW:SYST:SWN",
                              windowSize,
                              0, 15,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Remaining Window
 * Purpose:  This function sets the size of the search window for each pilot 
 *           in the Remaining Set.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysSWR(
    ViSession   instrSession,
    ViInt32 windowSize,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:NETW:SYST:SWR",
                              windowSize,
                              0, 15,
                              RSCMU_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetSysPRevision
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysPRevision (ViSession instrSession,
                                                    ViInt32 protocolRevision,
                                                    ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 341, &protocolRevision );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[341].instrCommand
          , protocolRevision
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfNetSysPRevision()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetSysMinPrev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysMinPrev (ViSession instrSession,
                                                  ViInt32 minimumProtocolRevision,
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 342, &minimumProtocolRevision );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[342].instrCommand
          , minimumProtocolRevision
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfNetSysMinPrev()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetSysIMSIEtwelve
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysIMSIEtwelve (ViSession instrSession,
                                                      ViChar IMSI11_12[],
                                                      ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[343].instrCommand
          , IMSI11_12
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ConfNetSysIMSIEtwelve()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetSysUWCard
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysUWCard (ViSession instrSession,
                                                 ViBoolean stateUseWildcard,
                                                 ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 344, &stateUseWildcard );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[344].instrCommand
          , enable.list[stateUseWildcard]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfNetSysUWCard()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetSysAuthentication
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      authenticatinState
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysAuthentication (ViSession instrSession,
                                                         ViBoolean authenticationState,
                                                         ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 345, &authenticationState );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[345].instrCommand
          , enable.list[authenticationState]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfNetSysAuthentication()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetSysAuthChallenge
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      authenticationChallenge
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetSysAuthChallenge (ViSession instrSession,
                                                         ViChar authenticationChallenge[],
                                                         ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[356].instrCommand
          , authenticationChallenge
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfNetSysAuthChallenge()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetRegTBReg
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetRegTBReg (ViSession   instrSession,
                                                ViReal64    timerBaseRegistration,
                                                ViChar      errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 346, &timerBaseRegistration );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[346].instrCommand
          , timerBaseRegistration
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
       
    
} // end of RSCMU_CDMA2K_ConfNetRegTBReg()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetRegHome
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetRegHome (ViSession instrSession,
                                               ViBoolean homeMode,
                                               ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 347, &homeMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[347].instrCommand
          , enable.list[homeMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfNetRegHome()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetRegFSID
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetRegFSID (ViSession instrSession,
                                               ViBoolean foreignSID,
                                               ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 348, &foreignSID );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[348].instrCommand
          , enable.list[foreignSID]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfNetRegFSID()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetRegFNID
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetRegFNID (ViSession instrSession,
                                               ViBoolean foreignNID,
                                               ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 349, &foreignNID );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[349].instrCommand
          , enable.list[foreignNID]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfNetRegFNID()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CofNetRegPowUp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_CofNetRegPowUp (ViSession instrSession,
                                               ViBoolean powerUp,
                                               ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 350, &powerUp );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[350].instrCommand
          , enable.list[powerUp]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_CofNetRegPowUp()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetRegPowDown
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetRegPowDown (ViSession instrSession,
                                                  ViBoolean powerDown,
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 351, &powerDown );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[351].instrCommand
          , enable.list[powerDown]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfNetRegPowDown()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetRegParReg
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetRegParReg (ViSession instrSession,
                                                 ViBoolean parameterRegister,
                                                 ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 352, &parameterRegister );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[352].instrCommand
          , enable.list[parameterRegister]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfNetRegParReg()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetPCHRate
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetPCHRate (ViSession instrSession,
                                               ViInt32 pagingChannelRate,
                                               ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 353
             , &pagingChannelRate
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[353].instrCommand
          , pagingChanRate.list[pagingChannelRate]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfNetPCHRate()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetPCHSCIndex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetPCHSCIndex (ViSession instrSession,
                                                  ViInt32 slotCycleIndex,
                                                  ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 354, &slotCycleIndex );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[354].instrCommand
          , slotCycleIndex
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfNetPCHSCIndex()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetPCHMaxSCIndex
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetPCHMaxSCIndex (ViSession instrSession,
                                                     ViInt32 maxSlotCycleIndex,
                                                     ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 355, &maxSlotCycleIndex );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[355].instrCommand
          , maxSlotCycleIndex
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ConfNetPCHMaxSCIndex()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetAPRMode
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/



ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetAPRMode (ViSession instrSession,
                                               ViInt32 apMode,
                                               ViChar errorMessage[])
{  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 491, &accessProbeMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[491].instrCommand
          , accessProbeMode.list[apMode]
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfNetAPRMode()  

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetAPRNoffset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetAPRNoffset (ViSession instrSession,
                                                  ViReal64 nominalOffsetPower,
                                                  ViChar errorMessage[])
{  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 492, &nominalOffsetPower );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[492].instrCommand
          , nominalOffsetPower
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfNetAPRNoffset()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetAPRIoffset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetAPRIoffset (ViSession instrSession,
                                                  ViReal64 initialPowerOffset,
                                                  ViChar errorMessage[])
{  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 493, &initialPowerOffset );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[493].instrCommand
          , initialPowerOffset
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
    
} //end of RSCMU_CDMA2K_ConfNetAPRIoffset

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetAPRPIncrement
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetAPRPIncrement (ViSession instrSession,
                                                     ViReal64 powerIncrement,
                                                     ViChar errorMessage[])
{  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 494, &powerIncrement );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[494].instrCommand
          , powerIncrement
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfNetAPRPIncrement

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetAPRPPSequence
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

         
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetAPRPPSequence (ViSession instrSession,
                                                     ViInt32 probesPerSequence,
                                                     ViChar errorMessage[])
{ ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 495, &probesPerSequence );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[495].instrCommand
          , probesPerSequence
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
    
} //end of RSCMU_CDMA2K_ConfNetAPRPPSequence

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNetAPRSPAttempt
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNetAPRSPAttempt (ViSession instrSession,
                                                    ViInt32 number_ofAccessProbeSequence,
                                                    ViChar errorMessage[])
{ ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 496, &number_ofAccessProbeSequence );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[496].instrCommand
          , number_ofAccessProbeSequence
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfNetAPRSPAttempt      
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfMMONIPAddress
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      IPAddress1,IPAddress2,IPAddress3,IPAddress4  
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfMMONIPAddress (ViSession instrSession,
                                                  ViInt32 IPAddress1,
                                                  ViInt32 IPAddress2,
                                                  ViInt32 IPAddress3,
                                                  ViInt32 IPAddress4,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 624, &IPAddress1,&IPAddress2,&IPAddress3,&IPAddress4 );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[624].instrCommand
          ,IPAddress1
          ,IPAddress2
          ,IPAddress3
          ,IPAddress4
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );      
}//end of RSCMU_CDMA2K_ConfMMONIPAddress
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfMMONSmask
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      IPAddress1,IPAddress2,IPAddress3,IPAddress4  
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfMMONSmask (ViSession instrSession,
                                              ViInt32 IPAddress1,
                                              ViInt32 IPAddress2,
                                              ViInt32 IPAddress3,
                                              ViInt32 IPAddress4,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 625, &IPAddress1,&IPAddress2,&IPAddress3,&IPAddress4 );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[625].instrCommand
          ,IPAddress1
          ,IPAddress2
          ,IPAddress3
          ,IPAddress4
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );     
}//end of RSCMU_CDMA2K_ConfMMONSmask
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfMMONSgateway
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      IPAddress1,IPAddress2,IPAddress3,IPAddress4
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfMMONSgateway (ViSession instrSession,
                                                 ViInt32 IPAddress1,
                                                 ViInt32 IPAddress2,
                                                 ViInt32 IPAddress3,
                                                 ViInt32 IPAddress4,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 626, &IPAddress1,&IPAddress2,&IPAddress3,&IPAddress4 );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[626].instrCommand
          ,IPAddress1
          ,IPAddress2
          ,IPAddress3
          ,IPAddress4
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );     
} //end of RSCMU_CDMA2K_ConfMMONSgateway
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefMMON
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      defaultMessageMointorSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_DefMMON (ViSession instrSession,
                                        ViInt32 defaultMessageMointorSetting,
                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 623, &defaultMessageMointorSetting);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[623].instrCommand
          , enable.list[defaultMessageMointorSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );     
}//end of RSCMU_CDMA2K_DefMMON

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNPowCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNPowCont (ViSession instrSession,
                                             ViInt32 statistics,
                                             ViInt32 rep,
                                             ViInt32 stopCondition,
                                             ViInt32 step,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 59, &statistics, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   sprintf( wrtBuf
          , CDMA[59].instrCommand
          , statistics
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfNPowCont()      


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNPowContStats
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNPowContStats (ViSession instrSession,
                                                  ViInt32 statistics,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 60, &statistics );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[60].instrCommand
          , statistics
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfNPowContStats()      


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNPowContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNPowContRep (ViSession instrSession,
                                                ViInt32 rep,
                                                ViInt32 stopCondition,
                                                ViInt32 step,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 61, &rep, &stopCondition, &step);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   sprintf( wrtBuf
          , CDMA[61].instrCommand
          , repetition.list[rep]
          , stopCond3.list[stopCondition]
          , stepMode.list[step]
          );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfNPowContRep() 


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNPowEPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
 
/* JMG 020930 ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNPowEPow (ViSession instrSession,
                                             ViInt32 pow_Value,
                                             ViChar errorMessage[]) */

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNPowNCS (ViSession   instrSession,
                                            ViInt32     chipSamplePerStatistic,
                                            ViChar      errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 62, &chipSamplePerStatistic );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[62].instrCommand
          , chipSamplePerStatistic
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfNPowEPow()     



/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitNPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_InitNPow (ViSession instrSession,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[63].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_InitNPow()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortNPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_AbortNPow (ViSession instrSession,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[64].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_AbortNPow()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StopNPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_StopNPow (ViSession instrSession,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[65].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_StopNPow()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ContinueNPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueNPow (ViSession instrSession,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[66].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ContinueNPow()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchNPowStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchNPowStatus (ViSession instrSession,
                                                ViInt32 *measurementStatus,
                                                ViInt32 *CurrentStatCycleCount,
                                                ViInt32 *CurrentEvaluationPeriod,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[67].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

       // Get the counter for current statistics cycle
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", CurrentStatCycleCount );
       }
       else
       {
          *CurrentStatCycleCount = RSCMU_OFF;
       }
       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", CurrentEvaluationPeriod );
       }
       else
       {
          *CurrentEvaluationPeriod = RSCMU_OFF;
       }
   }

   return RSCMU_Status;
          
} //end of RSCMU_CDMA2K_FetchNPowStatus()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfNPowErrReporting
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfNPowErrReporting (ViSession instrSession,
                                                     ViInt32 reportMode,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 68, &reportMode );

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[68].instrCommand
          , eventReport.list[reportMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfNPowErrReporting() 


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadScalNPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalNPow (ViSession instrSession,
                                             ViReal64 *currAvePower_dBm,
                                             ViReal64 *currMinPower_dBm,
                                             ViReal64 *currMaxPower_dBm,
                                             ViReal64 *aveAvePower_dBm,
                                             ViReal64 *aveMinPower_dBm,
                                             ViReal64 *aveMaxPower_dBm,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage                                                  
             );
                
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[69].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                      
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", currAvePower_dBm );
   }
   else
   {
      *currAvePower_dBm = RSCMU_NAN;
   }

   // Get current minimum power
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", currMinPower_dBm );
   }
   else
   {
      *currMinPower_dBm = RSCMU_NAN;
   }

   // Get current maximum power
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", currMaxPower_dBm );
   }
   else
   {
      *currMaxPower_dBm = RSCMU_NAN;
   }

   // Get average average power
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", aveAvePower_dBm );
   }
   else
   {
      *aveAvePower_dBm = RSCMU_NAN;
   }
   
   // Get average minimum power
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", aveMinPower_dBm );
   }
   else
   {
      *aveMinPower_dBm = RSCMU_NAN;
   }
   
   // Get average maximum power
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", aveMaxPower_dBm );
   }
   else
   {
      *aveMaxPower_dBm = RSCMU_NAN;
   }
                          
   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ReadScalNPow() 


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchScalNPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalNPow (ViSession instrSession,
                                              ViReal64 *currAvePower_dBm,
                                              ViReal64 *currMinPower_dBm,
                                              ViReal64 *currMaxPower_dBm,
                                              ViReal64 *aveAvePower_dBm,
                                              ViReal64 *aveMinPower_dBm,
                                              ViReal64 *aveMaxPower_dBm,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[70].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", currAvePower_dBm );
   }
   else
   {
      *currAvePower_dBm = RSCMU_NAN;
   }

   // Get current minimum power
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", currMinPower_dBm );
   }
   else
   {
      *currMinPower_dBm = RSCMU_NAN;
   }

   // Get current maximum power
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", currMaxPower_dBm );
   }
   else
   {
      *currMaxPower_dBm = RSCMU_NAN;
   }

   // Get average average power
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", aveAvePower_dBm );
   }
   else
   {
      *aveAvePower_dBm = RSCMU_NAN;
   }
   
   // Get average minimum power
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", aveMinPower_dBm );
   }
   else
   {
      *aveMinPower_dBm = RSCMU_NAN;
   }
   
   // Get average maximum power
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", aveMaxPower_dBm );
   }
   else
   {
      *aveMaxPower_dBm = RSCMU_NAN;
   }

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_FetchScalNPow() 


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleScalNPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalNPow (ViSession instrSession,
                                               ViReal64 *currAvePower_dBm,
                                               ViReal64 *currMinPower_dBm,
                                               ViReal64 *currMaxPower_dBm,
                                               ViReal64 *aveAvePower_dBm,
                                               ViReal64 *aveMinPower_dBm,
                                               ViReal64 *aveMaxPower_dBm,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[71].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", currAvePower_dBm );
   }
   else
   {
      *currAvePower_dBm = RSCMU_NAN;
   }

   // Get current minimum power
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", currMinPower_dBm );
   }
   else
   {
      *currMinPower_dBm = RSCMU_NAN;
   }

   // Get current maximum power
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", currMaxPower_dBm );
   }
   else
   {
      *currMaxPower_dBm = RSCMU_NAN;
   }

   // Get average average power
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", aveAvePower_dBm );
   }
   else
   {
      *aveAvePower_dBm = RSCMU_NAN;
   }
   
   // Get average minimum power
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", aveMinPower_dBm );
   }
   else
   {
      *aveMinPower_dBm = RSCMU_NAN;
   }
   
   // Get average maximum power
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", aveMaxPower_dBm );
   }
   else
   {
      *aveMaxPower_dBm = RSCMU_NAN;
   }

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_SampleScalNPow() 

/*****************************************************************************
 * Function: Trigger Step Delay
 * Purpose:  This functions defines a delay time (number of frames) between 
 *           the trigger time and the start of the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSDEL (ViSession instrSession,
                                                     ViInt32 triggerStepDelay,
                                                     ViChar errorMessage[])
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:POW:XSL:CONT:SDEL",
                              triggerStepDelay,
                              0,
                              100,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Measurement Step Width
 * Purpose:  This function defines the number of frames skipped between two 
 *           consecutive measurements.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSWID (ViSession instrSession,
                                                     ViReal64 step_width_of_the_measurement,
                                                     ViChar errorMessage[])
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                              "CONF:POW:XSL:CONT:SWID",
                              step_width_of_the_measurement / 1000,
                              1.0e-3,
                              30.0e-3,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Measurement Slots
 * Purpose:  This function defines the number of frames measured in one 
 *           statistics cycle.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSCO (ViSession instrSession,
                                                    ViInt32 frameNumber_perStatCycle,
                                                    ViChar errorMessage[])
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:POW:XSL:CONT:SCO",
                              frameNumber_perStatCycle,
                              1,
                              100,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Measurement Width
 * Purpose:  This function defines the the measurement time for a single 
 *           measurement step.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContPMWd (ViSession instrSession,
                                                     ViReal64 powerMeasurementWidth,
                                                     ViChar errorMessage[])
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                           "CONF:POW:XSL:CONT:PMW",
                           powerMeasurementWidth / 1000.0,
                           0.5e-3, 10.0e-3,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Default Settings
 * Purpose:  This function sets all parameters of the subsystem to their 
 *           default values.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowXSlotCont (ViSession instrSession,
                                                ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession, "DEF:POW:XSL:CONT ON"));
}

/*****************************************************************************
 * Function: Repetition mode
 * Purpose:  This function determines the number of statistics cycles, the 
 *           stop condition and the stepping mode for the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContRep (ViSession instrSession,
                                                    ViInt32 repetition,
                                                    ViInt32 nbRepetition,
                                                    ViInt32 stopCondition,
                                                    ViInt32 stepMode,
                                                    ViChar errorMessage[])
{
    ViChar  command[256];
    
    CHECK_VI_INT32_RANGE (instrSession, repetition, 0, 2, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, nbRepetition, 1, 10000, VI_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, stopCondition, 0, 1, VI_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, stepMode, 0, 1, VI_ERROR_PARAMETER5, errorMessage);

    switch (repetition)
        {
        case RSCMU_MULTIPLE:
            sprintf (command, "CONF:POW:XSL:CONT:REP %ld,%s,%s",
                     nbRepetition,
                     stopConditionArr[stopCondition],
                     stepModeArr[stepMode]);
            break;
        default:
            sprintf (command, "CONF:POW:XSL:CONT:REP %s,%s,%s",
                     repetitionArr[repetition],
                     stopConditionArr[stopCondition],
                     stepModeArr[stepMode]);
            break;
        }

    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Complete Table
 * Purpose:  This function defines the RF Max. Level to be used for each of 
 *           the measured power steps and the first step in each step interval. 
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSintComp (ViSession instrSession,
                                                         ViBoolean enable[],
                                                         ViReal64 deviations[],
                                                         ViInt32 steps[],
                                                         ViChar errorMessage[])
{
    ViInt32 idx = 0;
    ViChar  command[512];
    ViChar  *p2str;
    
    CHKNULLP (enable, VI_ERROR_PARAMETER2);
    CHKNULLP (deviations, VI_ERROR_PARAMETER3);
    CHKNULLP (steps, VI_ERROR_PARAMETER4);

    p2str = command;
    p2str += sprintf (p2str, "CONF:POW:XSL:CONT:SINT ");

    /* The array has to have 5 elements */
    for (idx = 0; idx < 5; idx++)
        {
            p2str += (enable[idx] == VI_FALSE) ?
                sprintf (p2str, "OFF,") :
                sprintf (p2str, "%Lf,", deviations[idx]);
            p2str += (steps[idx] == VI_FALSE) ?
                sprintf (p2str, "OFF,") :
                sprintf (p2str, "%ld,", steps[idx]);
        }

    *--p2str = 0;

    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Complete Single Interval
 * Purpose:  This function defines the RF Max. Level to be used for specified 
 *           measured power steps and the.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSintSC (ViSession instrSession,
                                                       ViInt32 stepIntervalNumber,
                                                       ViBoolean enable,
                                                       ViReal64 deviation,
                                                       ViInt32 step,
                                                       ViChar errorMessage[])
{
    ViChar  command[256];
    ViChar  *p2str;
    
    CHECK_VI_INT32_RANGE (instrSession, stepIntervalNumber, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_BOOLEAN_RANGE (instrSession, enable, VI_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_REAL64_RANGE (instrSession, deviation, -70.0, 70.0, VI_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, step, 0, 99, VI_ERROR_PARAMETER5, errorMessage);

    p2str = command;
    p2str += sprintf (p2str, "CONF:POW:XSL:CONT:SINT:I%ld ", stepIntervalNumber);

    p2str += (enable == VI_FALSE) ?
        sprintf (p2str, "OFF,") :
        sprintf (p2str, "%Lf,", deviation);
    p2str += (step == VI_FALSE) ?
        sprintf (p2str, "OFF") :
        sprintf (p2str, "%ld", step);

    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Complete Deviation Table
 * Purpose:  This function defines the RF Max. Level to be used for each of 
 *           the measured power steps.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSintDC (ViSession instrSession,
                                                       ViBoolean enable[],
                                                       ViReal64 deviations[],
                                                       ViChar errorMessage[])
{
    ViInt32 idx = 0;
    ViChar  command[512];
    ViChar  *p2str;

    CHKNULLP (enable, VI_ERROR_PARAMETER2);
    CHKNULLP (deviations, VI_ERROR_PARAMETER3);

    p2str = command;
    p2str += sprintf (p2str, "CONF:POW:XSL:CONT:SINT:DEV ");
    
    /* The array has to have 5 elements */
    for (idx = 0; idx < 5; idx++)
        {
            p2str += (enable[idx] == VI_FALSE) ?
                sprintf (p2str, "OFF,") :
                sprintf (p2str, "%Lf,", deviations[idx]);
        }

    *--p2str = 0;

    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Complete Step Number Table
 * Purpose:  This function defines the first step in each step interval.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSintNC (ViSession instrSession,
                                                       ViInt32 steps[],
                                                       ViChar errorMessage[])
{
    ViInt32 idx = 0;
    ViChar  command[512];
    ViChar  *p2str;

    CHKNULLP (steps, VI_ERROR_PARAMETER2);
    
    p2str = command;
    p2str += sprintf (p2str, "CONF:POW:XSL:CONT:SINT:SNUM ");

    /* The array has to have 5 elements */
    for (idx = 0; idx < 5; idx++)
        {
            p2str += (steps[idx] == VI_FALSE) ?
                sprintf (p2str, "OFF,") :
                sprintf (p2str, "%ld,", steps[idx]);
        }

    *--p2str = 0;

    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Single Step Number
 * Purpose:  This function defines the first step in specified step interval.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSintIS (ViSession instrSession,
                                                       ViInt32 stepIntervalNumber,
                                                       ViInt32 step,
                                                       ViChar errorMessage[])
{
    ViChar  command[256];
    ViChar  *p2str;

    CHECK_VI_INT32_RANGE (instrSession, stepIntervalNumber, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, step, 0, 99, VI_ERROR_PARAMETER3, errorMessage);

    p2str = command;
    p2str += sprintf (p2str, "CONF:POW:XSL:CONT:SINT:SNUM:I%ld ", stepIntervalNumber);

    p2str += (step == VI_FALSE) ?
        sprintf (p2str, "OFF") :
        sprintf (p2str, "%ld", step);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Single Deviation
 * Purpose:  This function defines the RF Max. Level to be used for specified 
 *           measured power steps.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotContSintDS (ViSession instrSession,
                                                       ViInt32 stepIntervalNumber,
                                                       ViBoolean enable,
                                                       ViReal64 deviation,
                                                       ViChar errorMessage[])
{
    ViChar  command[256];
    ViChar  *p2str;

    CHECK_VI_INT32_RANGE (instrSession, stepIntervalNumber, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_BOOLEAN_RANGE (instrSession, enable, VI_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_REAL64_RANGE (instrSession, deviation, -70.0, 70.0, VI_ERROR_PARAMETER4, errorMessage);

    p2str = command;
    p2str += sprintf (p2str, "CONF:POW:XSL:CONT:SINT:DEV:I%ld ", stepIntervalNumber);

    p2str += (enable == VI_FALSE) ?
        sprintf (p2str, "OFF") :
        sprintf (p2str, "%Lf", deviation);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Init
 * Purpose:  This function starts a new measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitPowXSlot (ViSession instrSession,
                                             ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession, "INIT:POW:XSL"));
}

/*****************************************************************************
 * Function: Abort
 * Purpose:  This function aborts running measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_AborPowXSlot (ViSession instrSession,
                                             ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession, "ABOR:POW:XSL"));
}

/*****************************************************************************
 * Function: Stop
 * Purpose:  This function stops running measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_StopPowXSlot (ViSession instrSession,
                                             ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession, "STOP:POW:XSL"));
}

/*****************************************************************************
 * Function: Continue
 * Purpose:  This function continues stopped measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ContPowXSlot (ViSession instrSession,
                                             ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession, "CONT:POW:XSL"));
}

/*****************************************************************************
 * Function: Fetch Status
 * Purpose:  This function returns the status of the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcPowXSlotStat (ViSession instrSession,
                                                 ViInt32 *measurementStatus,
                                                 ViInt32 *counter_for_current_stat_cycle,
                                                 ViChar errorMessage[])
{
    ViChar  response [256];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar    tab[48][30];   

    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   "FETC:POW:XSL:STAT?",
                                   response,
                                   256,
                                   0));

    RSCMU_SeparateString( response, ",", tab );

    RSCMU_Status = RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

    if( strcmp( tab[1], "NONE" ) != 0 )
    {
        sscanf( tab[1], "%d", counter_for_current_stat_cycle );
    }
    else
    {
        *counter_for_current_stat_cycle = RSCMU_OFF;
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Set Event Reporting Mode
 * Purpose:  This function defines the events generated when the measurement 
 *           is terminated or stopped
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowXSlotErep (ViSession instrSession,
                                                 ViInt32 measurementEventReporting,
                                                 ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:POW:XSL:EREP",
                           measurementEventReporting,
                           erepArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Read
 * Purpose:  This function starts a single shot measurement and returns 
 *           results, depending on the statistics mode.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadPowXSlot (ViSession instrSession,
                                             ViReal64 framePowerValues[],
                                             ViChar errorMessage[])
{
    RETMSG(RSCMU_CDMA2K_MeasPowXSlot (instrSession, framePowerValues,
                                      0, errorMessage));
}

/*****************************************************************************
 * Function: Fetch
 * Purpose:  This function returns unsynchronized measurement results, 
 *           depending on the statistics mode.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcPowXSlot (ViSession instrSession,
                                             ViReal64 framePowerValues[],
                                             ViChar errorMessage[])
{
    RETMSG(RSCMU_CDMA2K_MeasPowXSlot (instrSession, framePowerValues,
                                      1, errorMessage));
}

/*****************************************************************************
 * Function: Sample
 * Purpose:  This function returns synchronized measurement results, depending 
 *           on the statistics mode.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SampPowXSlot (ViSession instrSession,
                                             ViReal64 framePowerValues[],
                                             ViChar errorMessage[])
{
    RETMSG(RSCMU_CDMA2K_MeasPowXSlot (instrSession, framePowerValues,
                                      2, errorMessage));
}

static ViStatus RSCMU_CDMA2K_MeasPowXSlot (ViSession instrSession,
                                        ViReal64 results[],
                                        ViInt32 cmdType,
                                        ViChar errorMessage[])
{
    ViChar  command[128];
    ViChar  *hugeBuf = VI_NULL;
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViString cmds[] = {"READ","FETC","SAMP"};
    
    CHECK_VI_INT32_RANGE (instrSession, cmdType, 0, 2, VI_ERROR_PARAMETER5, errorMessage);
    
    sprintf (command, "%s:POW:XSL:CURR?", cmds[cmdType]);
    
    CHECKRETMSG (RSCMU_viWrite(instrSession, command, strlen(command)));

    CHECKERR(RSCMU_ReadDataUnknownLength(instrSession, &hugeBuf, VI_NULL));
    
    if (RSCMU_Status < VI_SUCCESS)
        if (hugeBuf) free(hugeBuf);

    if (hugeBuf) 
    {
        RSCMU_atofArray (hugeBuf,results);
        free(hugeBuf);
    }

    RETMSG (RSCMU_Status);
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfIQAccessRXSWEnab
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
  ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfWPowContRep (ViSession instrSession,
                                                ViInt32 rep,
                                                ViInt32 stopCondition,
                                                ViInt32 step,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 539, &rep, &stopCondition, &step);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   sprintf( wrtBuf
          , CDMA[539].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
}//end of RSCMU_CDMA2K_ConfWPowContRep()        

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitWPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitWPow (ViSession instrSession,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[541].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
} //end of RSCMU_CDMA2K_InitWPow

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortWPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
  ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortWPow (ViSession instrSession,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[542].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}// end of RSCMU_CDMA2K_AbortWPow

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StopWPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_StopWPow (ViSession instrSession,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[543].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of RSCMU_CDMA2K_StopWPow

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ContinueWPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueWPow (ViSession instrSession,
                                             ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[544].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of RSCMU_CDMA2K_ContinueWPow

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchWPowStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchWPowStatus (ViSession instrSession,
                                                ViInt32 *measurementStatus,
                                                ViInt32 *currentStepCycleCount,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[545].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

       // Get the counter for current statistics cycle
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", currentStepCycleCount );
       }
       else
       {
          *currentStepCycleCount = RSCMU_OFF;
       }
   }

   return RSCMU_Status;    
}//end of RSCMU_CDMA2K_FetchWPowStatus

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfWPowErrReporting
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfWPowErrReporting (ViSession instrSession,
                                                     ViInt32 reportMode,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 540, &reportMode );

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[540].instrCommand
          , eventReport.list[reportMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of RSCMU_CDMA2K_ConfWPowErrReporting
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadScalWPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalWPow (ViSession instrSession,
                                             ViReal64 *widebandPower_dBm,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage                                                  
             );
                
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[546].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                      
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", widebandPower_dBm );
   }
   else
   {
      *widebandPower_dBm = RSCMU_NAN;
   }
 
   return( RSCMU_Status );    
}// end of RSCMU_CDMA2K_ReadScalWPow

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchScalWPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalWPow (ViSession instrSession,
                                              ViReal64 *widebandPower_dBm,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[547].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", widebandPower_dBm );
   }
   else
   {
      *widebandPower_dBm = RSCMU_NAN;
   }
 
   return( RSCMU_Status );    
}//end of RSCMU_CDMA2K_FetchScalWPow
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleScalWPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalWPow (ViSession instrSession,
                                               ViReal64 *widebandPower_dBm,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[548].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", widebandPower_dBm );
   }
   else
   {
      *widebandPower_dBm = RSCMU_NAN;
   }
 
   return( RSCMU_Status );    
}// end of RSCMU_CDMA2K_SampleScalWPow

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfIQAccessRXSWEnab
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
  ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIQAccessRXSWEnab (ViSession instrSession,
                                                     ViInt32 RXIQSwappingEnable,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 497, &RXIQSwappingEnable );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[497].instrCommand
          , modeEnable.list[RXIQSwappingEnable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfIQAccessRXSWEnab()     

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfIQAccessGMUL
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIQAccessGMUL (ViSession instrSession,
                                                 ViInt32 gainMultiplier,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 498, &gainMultiplier );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[498].instrCommand
          , gainMultiplier
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfIQAccessGMUL()    
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfIQAccessTCON
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIQAccessTCON (ViSession instrSession,
                                                 ViInt32 timingControl,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 499, &timingControl );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[499].instrCommand
          , timingControl
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfIQAccessTCON() 
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefIQACcessCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      IQAccessContrlol
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefIQACcessCont (ViSession instrSession,
                                                ViBoolean IQAccessContrlol,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 549, &IQAccessContrlol);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[549].instrCommand
          , enable.list[IQAccessContrlol]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );          
}// end of RSCMU_CDMA2K_DefIQACcessCont

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitIQAccess
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_InitIQAccess (ViSession instrSession,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[500].instrCommand
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_InitIQAccess() 
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortIQAccess
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortIQAccess (ViSession instrSession,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[501].instrCommand
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_AbortIQAccess() 
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchIQAccessStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchIQAccessStatus (ViSession instrSession,
                                                    ViInt32 *measurementStatus,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[502].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

   }

   return RSCMU_Status;
          
} //end of RSCMU_CDMA2K_FetchIQAccessStatus()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerFSSCConLevFschZ
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      SCH0Level
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCConLevFschZ (ViSession instrSession,
                                                         ViInt32 testSetupType,
                                                         ViReal64 SCH0Level,
                                                         ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
     
   checkRange( 559, &testSetupType, &SCH0Level);     

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[559].instrCommand
          , testSetupType
          , SCH0Level
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
        
    
}//end of CDMA2K_ConfRQFerFSSCConLevFschZ

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2k_RQFerFsscTsetEbntFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     calculatedEbNtFCH_dB
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2k_RQFerFsscTsetEbntFFCH (ViSession instrSession,
                                                      ViInt32 testSetupType,
                                                      ViReal64 *calculatedEbNtFFCH_dB,
                                                      ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
  
   checkRange( 560, &testSetupType); 
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             

   sprintf( wrtBuf
          , CDMA[560].instrCommand
          , testSetupType
          );
             

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", calculatedEbNtFFCH_dB );
   }
   else
   {
      *calculatedEbNtFFCH_dB = RSCMU_NAN;
   }

   return RSCMU_Status;
              
    
}// end of RSCMU_CDMA2k_RQFerFsscTsetEbntFFCH 

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2k_RQFerFsscTsetEbntFSCHZ
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     calculatedEbNtSCH0_dB
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2k_RQFerFsscTsetEbntFSCHZ (ViSession instrSession,   
                                                       ViInt32 testSetupType,
                                                       ViReal64 *calculatedEbNtSCH0_dB,
                                                       ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
  
   checkRange( 561, &testSetupType); 
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             

   sprintf( wrtBuf
          , CDMA[561].instrCommand
          , testSetupType
          );
             

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", calculatedEbNtSCH0_dB );
   }
   else
   {
      *calculatedEbNtSCH0_dB = RSCMU_NAN;
   }

   return RSCMU_Status;
    
}//end of RSCMU_CDMA2k_RQFerFsscTsetEbntFSCHZ 

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2k_RQFerFsscTsetEbntFSCHOne
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     calculatedEbNtSCH1_dB
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2k_RQFerFsscTsetEbntFSCHOne (ViSession instrSession,
                                                         ViInt32 testSetupType,
                                                         ViReal64 *calculatedEbNtSCH1_dB,
                                                         ViChar errorMessage[])
{


   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
  
   checkRange( 562, &testSetupType); 
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             

   sprintf( wrtBuf
          , CDMA[562].instrCommand
          , testSetupType
          );
             

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", calculatedEbNtSCH1_dB );
   }
   else
   {
      *calculatedEbNtSCH1_dB = RSCMU_NAN;
   }

   return RSCMU_Status;
    
}//end of RSCMU_CDMA2k_RQFerFsscTsetEbntFSCHOne

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefRQFerFSSCTset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      defaultFERCommonSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefRQFerFSSCTset (ViSession instrSession,
                                                 ViInt32 testSetupType, 
                                                 ViBoolean defaultFERCommonSetting,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
  
   checkRange( 558, &testSetupType, &defaultFERCommonSetting);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[558].instrCommand
          , testSetupType
          , enable.list[defaultFERCommonSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );              
}//end of RSCMU_CDMA2K_DefRQFerFSSCTset

/*****************************************************************************
 * Function: State
 * Purpose:  This function enables or disables the environment for an 
 *           individual test setup <nr> (<nr> = 1 to 5) Receiver Quality 
 *           measurement applications.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTsetEnvEnab (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViBoolean enable,
                                                         ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, testSetup, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:RXQ:FER:FSSC:TSET%ld:ENV:ENAB", testSetup);
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           enable,
                           stateArr,
                           VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: CDMA Output Power
 * Purpose:  This function determines the total CDMA output power (absolute 
 *           value, in dBm) of the CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTEnvPowCdma (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViReal64 CDMAPower,
                                                         ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, testSetup, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:RXQ:FER:FSSC:TSET%ld:ENV:POW:CDMA", testSetup);
    RETMSG (RSCMU_setViReal64 (instrSession,
                               command,
                               CDMAPower,
                               -120.0, 7.0,
                               VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Level
 * Purpose:  This function determines the level in the selected channel of the 
 *           CMU. The channel power is in units relative to the total CDMA 
 *           power.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTsetEnvLev (ViSession instrSession,
                                                        ViInt32 testSetup,
                                                        ViInt32 channel,
                                                        ViBoolean state,
                                                        ViReal64 level,
                                                        ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, testSetup, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, channel, 0, 3, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:RXQ:FER:FSSC:TSET%ld:ENV:LEV:%s", testSetup,
             channelArr [channel]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                state,
                                stateArr,
                                VI_ERROR_PARAMETER4));

    if (state)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    level,
                                    -20.0, -1.0,
                                    VI_ERROR_PARAMETER5));
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Calculated EbNt FFCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the forward FCH.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcRQFerFSSCEnvEbntFfch (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViReal64 *calculatedEbNtFFCH,
                                                         ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, testSetup, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CALC:RXQ:FER:FSSC:TSET%ld:ENV:EBNT:FFCH?", testSetup);
    RETMSG (RSCMU_getViReal64 (instrSession,
                               command,
                               calculatedEbNtFFCH,
                               VI_ERROR_PARAMETER4));
}

/*****************************************************************************
 * Function: Calculated EbNt FSCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the selected forward SCH channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcRQFerFSSCEnvEbntFsch (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViInt32 forwardSCH,
                                                         ViReal64 *calculatedEbNtFSCH,
                                                         ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, testSetup, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, forwardSCH, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    
    sprintf (command, "CALC:RXQ:FER:FSSC:TSET%ld:ENV:EBNT:FSCH:%s?",
             testSetup,
             schArr[forwardSCH]);
    RETMSG (RSCMU_getViReal64 (instrSession,
                               command,
                               calculatedEbNtFSCH,
                               VI_ERROR_PARAMETER4));
}

/*****************************************************************************
 * Function: Frame Rate
 * Purpose:  This function sets the frame rate for the variable rate traffic 
 *           channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCEnvFratFfch (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViInt32 frameRate,
                                                         ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, testSetup, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:RXQ:FER:FSSC:TSET%ld:ENV:FRAT:FFCH", testSetup);
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           frameRate,
                           frameArr,
                           VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Impairments
 * Purpose:  This function determines an Additional White Gaussian Noise 
 *           level, a frequency offset to impair the CMU output signal and 
 *           injected Tx FER.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSEnvImpairment (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViReal64 AWGN_level_dB,
                                                         ViBoolean AWGNEnable,
                                                         ViReal64 BSFreqOffset_kHz,
                                                         ViBoolean BSFreqEnable,
                                                         ViReal64 txFER,
                                                         ViBoolean txFEREnable,
                                                         ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, testSetup, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:RXQ:FER:FSSC:TSET%ld:ENV:IMP:LEVel:AWGN", testSetup);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                AWGNEnable,
                                stateArr,
                                VI_ERROR_PARAMETER4));

    if (AWGNEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    AWGN_level_dB,
                                    -20.0, 4.0,
                                    VI_ERROR_PARAMETER3));
    }

    sprintf (command, "CONF:RXQ:FER:FSSC:TSET%ld:ENV:IMP:FOFF", testSetup);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                BSFreqEnable,
                                stateArr,
                                VI_ERROR_PARAMETER6));

    if (BSFreqEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    BSFreqOffset_kHz,
                                    -5.0E+3, 5.0E+3,
                                    VI_ERROR_PARAMETER5));
    }

    sprintf (command, "CONF:RXQ:FER:FSSC:TSET%ld:ENV:IMP:ITF", testSetup);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                txFEREnable,
                                stateArr,
                                VI_ERROR_PARAMETER8));
    if (txFEREnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    txFER,
                                    0.0, 50.0,
                                    VI_ERROR_PARAMETER7));
    }
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Power Control Bits
 * Purpose:  This function queries the power control bit sequence that the CMU 
 *           sends to the mobile station to control its output power.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTsEnvPCBits (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViInt32 *powerControlBits,
                                                         ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, testSetup, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:RXQ:FER:FSSC:TSET%ld:ENV:PCB?", testSetup);
    RETMSG (RSCMU_getEnum (instrSession,
                           command,
                           powerControlBits,
                           PCBArr,
                           VI_ERROR_PARAMETER3));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerFCHContTsetFram
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFCHContTsetFram (ViSession instrSession,
                                                         ViInt32 testSetupType, 
                                                         ViInt32 frameCount,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 294, &testSetupType, &frameCount );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[294].instrCommand
          , testSetupType, frameCount
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfRQFerFCHContTsetFram()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerFCHContTsetRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFCHContTsetRep (ViSession instrSession,
                                                        ViInt32 testSetupType,
                                                        ViInt32 rep,
                                                        ViInt32 stopCondition,
                                                        ViInt32 step,
                                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   
   checkRange( 295, &testSetupType, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
 
   sprintf( wrtBuf
          , CDMA[295].instrCommand
          , testSetupType
          , repetition.list[rep]
          , stopCond2.list[stopCondition]
          , stepMode.list[step]
          );

  RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   
   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfRQFerFCHContTsetRep()      

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefRQFerFchContTset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      defaultFERFCHSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_DefRQFerFchContTset (ViSession instrSession,
                                                    ViInt32 testSetuptype,
                                                    ViBoolean defaultFERFCHSetting,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 563 ,&testSetuptype, &defaultFERFCHSetting);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[563].instrCommand
          , testSetuptype
          , enable.list[defaultFERFCHSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of RSCMU_CDMA2K_DefRQFerFchContTset

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerFCHLimTsetMFer
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFCHLimTsetMFer (ViSession instrSession,
                                                        ViInt32 testSetupType,   
                                                        ViReal64 maxFERLimit,
                                                        ViBoolean Enable,
                                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 296, &testSetupType, &maxFERLimit );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[296].instrCommand
          , testSetupType
          , maxFERLimit 
          , testSetupType
          , enable.list[Enable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfRQFerFCHLimTsetMFer()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerFCHLimTsetCLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFCHLimTsetCLev (ViSession instrSession,
                                                        ViInt32 testSetupType,
                                                        ViReal64 minConfidenceLevel,
                                                        ViBoolean Enable,
                                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 297, &testSetupType, &minConfidenceLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[297].instrCommand
          , testSetupType
          , minConfidenceLevel
          , testSetupType
          , enable.list[Enable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfRQFerFCHLimTsetCLev()

/*****************************************************************************
 * Function: Frequency Offset
 * Purpose:  This function determines one of four frequency offset values (1 
 *           to 4) which define the four adjacent channel pairs. Switching the 
 *           frequency offset off will disable the mesurement on the specified 
 *           frequency pair and INV will be returned as result.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSpecAcpContFOffsAcp (ViSession instrSession,
                                                        ViInt32 ACP,
                                                        ViReal64 frequencyOffset_Hz,
                                                        ViBoolean enable,
                                                        ViChar errorMessage[])
{
    ViChar  command [128];
    
    CHECK_VI_INT32_RANGE (instrSession, ACP, 1, 4, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_REAL64_RANGE (instrSession, frequencyOffset_Hz, 0.0, 2.0E+6, VI_ERROR_PARAMETER3, errorMessage);

    if (enable)
        sprintf (command, "CONF:SPEC:ACP:CONT:FOFF:ACP%ld %Le", ACP, frequencyOffset_Hz);
    else
        sprintf (command, "CONF:SPEC:ACP:CONT:FOFF:ACP%ld OFF", ACP);

    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Power Limit
 * Purpose:  This function defines the upper power limits for one of the 
 *           adjacent channel pairs. These limits apply to any of the statistic 
 *           evaluation modes (Current, Average and Maximum).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSpecAcpLimAcp (ViSession instrSession,
                                                  ViInt32 ACP,
                                                  ViReal64 powerLimit,
                                                  ViBoolean enable,
                                                  ViChar errorMessage[])
{
    ViChar  command [128];
    
    CHECK_VI_INT32_RANGE (instrSession, ACP, 1, 4, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_REAL64_RANGE (instrSession, powerLimit, -80.0, 10.0, VI_ERROR_PARAMETER3, errorMessage);

    if (enable)
        sprintf (command, "CONF:SPEC:ACP:LIM:ACP%ld %lf", ACP, powerLimit);
    else
        sprintf (command, "CONF:SPEC:ACP:LIM:ACP%ld OFF", ACP);

    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Statistics
 * Purpose:  This function defines the number of bursts forming a statistics 
 *           cycle. 
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSpecAcpStats (ViSession instrSession,
                                                 ViInt32 statistics,
                                                 ViChar errorMessage[])
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:SPEC:ACP:CONT:STAT",
                              statistics,
                              1, 1000,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Statistical results
 * Purpose:  This function qualifies whether the READ[:SCALar]:SPECtrum:ACP?, 
 *           FETCh...?, SAMPle...? Return the statistical results Out of 
 *           Tolerance and Current Statistics.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_XtndSpecAcpStat(
    ViSession   instrSession,
    ViBoolean   statisticalresults,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "XTND:SPEC:ACP:STAT",
                           statisticalresults,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Repetition
 * Purpose:  This function determines the number of statistics cycles, the 
 *           stop condition and the stepping mode for the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSpecAcpContRep (ViSession instrSession,
                                                   ViInt32 repetition,
                                                   ViInt32 nbRepetition,
                                                   ViInt32 stopCondition,
                                                   ViInt32 stepMode,
                                                   ViChar errorMessage[])
{
    ViChar  command[256];
    
    CHECK_VI_INT32_RANGE (instrSession, repetition, 0, 2, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, nbRepetition, 1, 10000, VI_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, stopCondition, 0, 1, VI_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, stepMode, 0, 1, VI_ERROR_PARAMETER5, errorMessage);

    switch (repetition)
        {
        case RSCMU_MULTIPLE:
            sprintf (command, "CONF:SPEC:ACP:CONT:REP %ld,%s,%s",
                     nbRepetition,
                     stopConditionArr[stopCondition],
                     stepModeArr[stepMode]);
            break;
        default:
            sprintf (command, "CONF:SPEC:ACP:CONT:REP %s,%s,%s",
                     repetitionArr[repetition],
                     stopConditionArr[stopCondition],
                     stepModeArr[stepMode]);
            break;
        }

    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Default
 * Purpose:  This function sets all parameters of the subsystem to default 
 *           values.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_DefSpecAcpCont (ViSession instrSession,
                                               ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession, "DEF:SPEC:ACP:CONT ON"));
}

/*****************************************************************************
 * Function: Init
 * Purpose:  This function starts the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitSpecAcp (ViSession instrSession,
                                            ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession, "INIT:SPEC:ACP"));
}

/*****************************************************************************
 * Function: Abort
 * Purpose:  This function aborts running of the measurement and switches it 
 *           off.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortSpecAcp (ViSession instrSession,
                                             ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession, "ABOR:SPEC:ACP"));
}

/*****************************************************************************
 * Function: Stop
 * Purpose:  This function stops the measurement after the current stat. 
 *           cycle.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_StopSpecAcp (ViSession instrSession,
                                            ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession, "STOP:SPEC:ACP"));
}

/*****************************************************************************
 * Function: Continue
 * Purpose:  This function runs the next measurement step (only stepping 
 *           mode).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueSpecAcp (ViSession instrSession,
                                                ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession, "CONT:SPEC:ACP"));
}

/*****************************************************************************
 * Function: Fetch Status
 * Purpose:  This function returns the status of the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchSpecAcpStatus (ViSession instrSession,
                                                   ViInt32 *measurementStatus,
                                                   ViInt32 *counter_forStatisticsCycle,
                                                   ViChar errorMessage[])
{
    ViChar  response [256];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar    tab[48][30];   

    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   "FETC:SPEC:ACP:STAT?",
                                   response,
                                   256,
                                   0));

    RSCMU_SeparateString( response, ",", tab );

    RSCMU_Status = RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

    if( strcmp( tab[1], "NONE" ) != 0 )
    {
        sscanf( tab[1], "%d", counter_forStatisticsCycle );
    }
    else
    {
        *counter_forStatisticsCycle = RSCMU_OFF;
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Set Event Reporting Mode
 * Purpose:  This function defines the events generated when the measurement 
 *           is terminated or stopped.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSpecAcpErep (ViSession instrSession,
                                                ViInt32 measurementEventReporting,
                                                ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:SPEC:ACP:EREP",
                           measurementEventReporting,
                           erepArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Read
 * Purpose:  This function starts a SPECtrum:ACP measurement and returns all 
 *           scalar measurement results.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadSpecAcp (ViSession instrSession,
                                            ViReal64 ACP_Current[],
                                            ViReal64 ACP_Average[],
                                            ViReal64 ACP_Maximum[],
                                            ViReal64 channelPower[],
                                            ViReal64 *outOfTolerance,
                                            ViInt32 *currentStatistics,
                                            ViChar errorMessage[])
{
    RETMSG (RSCMU_CDMA2K_MeasSpecAcp (instrSession,
                                      ACP_Current, ACP_Average,
                                      ACP_Maximum, channelPower,
                                      outOfTolerance, currentStatistics,
                                      0, errorMessage));
}

/*****************************************************************************
 * Function: Fetch
 * Purpose:  This function returns all scalar measurement results 
 *           (unsynchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcSpecAcp (ViSession instrSession,
                                            ViReal64 ACP_Current[],
                                            ViReal64 ACP_Average[],
                                            ViReal64 ACP_Maximum[],
                                            ViReal64 channelPower[],
                                            ViReal64 *outOfTolerance,
                                            ViInt32 *currentStatistics,
                                            ViChar errorMessage[])
{
    RETMSG (RSCMU_CDMA2K_MeasSpecAcp (instrSession,
                                      ACP_Current, ACP_Average,
                                      ACP_Maximum, channelPower,
                                      outOfTolerance, currentStatistics,
                                      1, errorMessage));
}

/*****************************************************************************
 * Function: Sample
 * Purpose:  This function returns all scalar measurement results 
 *           (synchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SampSpecAcp (ViSession instrSession,
                                            ViReal64 ACP_Current[],
                                            ViReal64 ACP_Average[],
                                            ViReal64 ACP_Maximum[],
                                            ViReal64 channelPower[],
                                            ViReal64 *outOfTolerance,
                                            ViInt32 *currentStatistics,
                                            ViChar errorMessage[])
{
    RETMSG (RSCMU_CDMA2K_MeasSpecAcp (instrSession,
                                      ACP_Current, ACP_Average,
                                      ACP_Maximum, channelPower,
                                      outOfTolerance, currentStatistics,
                                      2, errorMessage));
}

static ViStatus RSCMU_CDMA2K_MeasSpecAcp (ViSession instrSession,
                                            ViReal64 ACP_Current[],
                                            ViReal64 ACP_Average[],
                                            ViReal64 ACP_Maximum[],
                                            ViReal64 channelPower[],
                                            ViReal64 *outOfTolerance,
                                            ViInt32 *currentStatistics,
                                            ViInt32 cmdType,
                                            ViChar errorMessage[])
{
    ViChar      command[128];
    ViChar      response [2048];
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    cmds[] = {"READ","FETC","SAMP"};
    ViChar*     str;
    ViInt32     i;
    
    CHECK_VI_INT32_RANGE (instrSession, cmdType, 0, 2, RSCMU_ERROR_PARAMETER10, errorMessage);
    
    sprintf (command, "%s:SPEC:ACP?", cmds[cmdType]);
    
    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   command,
                                   response,
                                   2048,
                                   0));

    str = strtok (response, ",");
    ACP_Current[0] = RSCMU_atof (str);
    
    for (i = 1; i < 8; i++)
    {
        GET_VI_REAL64(ACP_Current[i],NULL);
    }

    for (i = 0; i < 8; i++)
    {
        GET_VI_REAL64(ACP_Average[i],NULL);
    }

    for (i = 0; i < 8; i++)
    {
        GET_VI_REAL64(ACP_Maximum[i],NULL);
    }
    
    for (i = 0; i < 3; i++)
    {
        GET_VI_REAL64(channelPower[i],NULL);
    }

    GET_VI_REAL64(*outOfTolerance,NULL);
    GET_VI_INT32(*currentStatistics,NULL,",");
    
    RETMSG (RSCMU_Status);
}
/*****************************************************************************
 * Function: Matching Limit
 * Purpose:  This function indicates whether and in which way the (fixed) 
 *           limit have been exceeded.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcSpecAcpMatcLimt (ViSession instrSession,
                                                    ViInt32 toleranceChannel_Current[],
                                                    ViInt32 toleranceChannel_Average[],
                                                    ViInt32 toleranceChannel_Maximum[],
                                                    ViChar errorMessage[])
{
    ViChar  response [2048];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar*     str;
    ViInt32 i;
    
    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   "CALC:SPEC:ACP:MATC:LIM?",
                                   response,
                                   2048,
                                   0));

    str = strtok (response, ",");
    for (i = 0; i < 8; i++)
    {
        if (toleranceChannel_Current)
        {
            CHECKRETMSG (RSCMU_getIndexFromString (instrSession, str, toleranceArr, toleranceChannel_Current + i));
        }
        strtok (NULL, ",");
    }

    for (i = 0; i < 8; i++)
    {
        if (toleranceChannel_Average)
        {
            CHECKRETMSG (RSCMU_getIndexFromString (instrSession, str, toleranceArr, toleranceChannel_Average + i));
        }
        strtok (NULL, ",");
    }

    if (toleranceChannel_Maximum)
    {
        for (i = 0; i < 8; i++)
        {
            CHECKRETMSG (RSCMU_getIndexFromString (instrSession, str, toleranceArr, toleranceChannel_Maximum + i));
            strtok (NULL, ",");
        }
    }
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Result Mode
 * Purpose:  This function specifies the type of measured values.  
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModIqanContRMode (ViSession instrSession,
                                                     ViInt32 mode,
                                                     ViInt32 signalType,
                                                     ViChar errorMessage[])
{
    ViChar  command[128];

    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER3, errorMessage);

    sprintf (command, "CONF:MOD:IQAN%s:CONT:RMOD", signalTypeArr [signalType]);

    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           mode,
                           resultModeArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Repetition
 * Purpose:  This function determines the number of statistics cycles, the 
 *           stop condition and the stepping mode for the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModIqanContRep (ViSession instrSession,
                                                   ViInt32 repetition,
                                                   ViInt32 nbRepetition,
                                                   ViInt32 stopCondition,
                                                   ViInt32 stepMode,
                                                   ViInt32 signalType,
                                                   ViChar errorMessage[])
{
    ViChar  command[256];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER6, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, repetition, 0, 2, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, nbRepetition, 1, 10000, VI_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, stopCondition, 0, 1, VI_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, stepMode, 0, 1, VI_ERROR_PARAMETER5, errorMessage);

    switch (repetition)
        {
        case RSCMU_MULTIPLE:
            sprintf (command, "CONF:MOD:IQAN%s:CONT:REP %ld,%s,%s",
                     signalTypeArr [signalType],
                     nbRepetition,
                     stopConditionArr[stopCondition],
                     stepModeArr[stepMode]);
            break;
        default:
            sprintf (command, "CONF:MOD:IQAN%s:CONT:REP %s,%s,%s",
                     signalTypeArr [signalType],
                     repetitionArr[repetition],
                     stopConditionArr[stopCondition],
                     stepModeArr[stepMode]);
            break;
        }

    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Default
 * Purpose:  This function sets all parameters of the subsystem to default 
 *           values.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_DefModIqanCont (ViSession instrSession,
                                               ViInt32 signalType,
                                               ViChar errorMessage[])
{
    ViChar  command[128];

    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);

    sprintf (command, "DEF:MOD:IQAN%s:CONT ON", signalTypeArr [signalType]);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Init
 * Purpose:  This function starts the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitModIqan (ViSession instrSession,
                                            ViInt32 signalType,
                                            ViChar errorMessage[])
{
    ViChar  command[128];

    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);

    sprintf (command, "INIT:MOD:IQAN%s", signalTypeArr [signalType]);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Abort
 * Purpose:  This function aborts running of the measurement and switches it 
 *           off.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortModIqan (ViSession instrSession,
                                             ViInt32 signalType,
                                             ViChar errorMessage[])
{
    ViChar  command[128];

    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);

    sprintf (command, "ABOR:MOD:IQAN%s", signalTypeArr [signalType]);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Stop
 * Purpose:  This function stops the measurement after the current stat. 
 *           cycle.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_StopModIqan (ViSession instrSession,
                                            ViInt32 signalType,
                                            ViChar errorMessage[])
{
    ViChar  command[128];

    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);

    sprintf (command, "STOP:MOD:IQAN%s", signalTypeArr [signalType]);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Continue
 * Purpose:  This function runs the next measurement step (only stepping 
 *           mode).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueModIqan (ViSession instrSession,
                                                ViInt32 signalType,
                                                ViChar errorMessage[])
{
    ViChar  command[128];

    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);

    sprintf (command, "CONT:MOD:IQAN%s", signalTypeArr [signalType]);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Fetch Status
 * Purpose:  This function returns the status of the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchModIqanStatus (ViSession instrSession,
                                                   ViInt32 *measurementStatus,
                                                   ViInt32 *counter_forStatisticsCycle,
                                                   ViInt32 signalType,
                                                   ViChar errorMessage[])
{
    ViChar  command[128];
    ViChar  response [256];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar    tab[48][30];   

    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER4, errorMessage);

    sprintf (command, "FETC:MOD:IQAN%s:STAT?",
             signalTypeArr [signalType]);
    
    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   command,
                                   response,
                                   256,
                                   0));

    RSCMU_SeparateString( response, ",", tab );

    RSCMU_Status = RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

    if( strcmp( tab[1], "NONE" ) != 0 )
    {
        sscanf( tab[1], "%d", counter_forStatisticsCycle );
    }
    else
    {
        *counter_forStatisticsCycle = RSCMU_OFF;
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Set Event Reporting Mode
 * Purpose:  This function defines the events generated when the measurement 
 *           is terminated or stopped.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModIqanErep (ViSession instrSession,
                                                ViInt32 measurementEventReporting,
                                                ViInt32 signalType,
                                                ViChar errorMessage[])
{
    ViChar  command[128];

    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:MOD:IQAN%s:EREP",signalTypeArr [signalType]); 

    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           measurementEventReporting,
                           erepArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Read
 * Purpose:  This function starts a MODulation:IQANalyzer measurement and 
 *           returns all scalar measurement results.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadModIqan (ViSession instrSession,
                                            ViReal64 *EVM_RMS,
                                            ViReal64 *magnitudeError_RMS,
                                            ViReal64 *phaseError_RMS,
                                            ViReal64 *waveformQuality,
                                            ViReal64 *iQImbalance,
                                            ViReal64 *carrierFeedthrough,
                                            ViReal64 *MSPower,
                                            ViInt32 signalType,
                                            ViChar errorMessage[])
{
    RETMSG (RSCMU_CDMA2K_MeasModIqan (instrSession, EVM_RMS, magnitudeError_RMS,
                                      phaseError_RMS, waveformQuality, iQImbalance,
                                      carrierFeedthrough, MSPower, signalType, 0, errorMessage));
}

/*****************************************************************************
 * Function: Fetch
 * Purpose:  This function returns all scalar measurement results 
 *           (unsynchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcModIqan (ViSession instrSession,
                                            ViReal64 *EVM_RMS,
                                            ViReal64 *magnitudeError_RMS,
                                            ViReal64 *phaseError_RMS,
                                            ViReal64 *waveformQuality,
                                            ViReal64 *iQImbalance,
                                            ViReal64 *carrierFeedthrough,
                                            ViReal64 *MSPower,
                                            ViInt32 signalType,
                                            ViChar errorMessage[])
{
    RETMSG (RSCMU_CDMA2K_MeasModIqan (instrSession, EVM_RMS, magnitudeError_RMS,
                                      phaseError_RMS, waveformQuality, iQImbalance,
                                      carrierFeedthrough, MSPower, signalType, 1, errorMessage));
}

/*****************************************************************************
 * Function: Sample
 * Purpose:  This function returns all scalar measurement results 
 *           (synchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SampModIqan (ViSession instrSession,
                                            ViReal64 *EVM_RMS,
                                            ViReal64 *magnitudeError_RMS,
                                            ViReal64 *phaseError_RMS,
                                            ViReal64 *waveformQuality,
                                            ViReal64 *iQImbalance,
                                            ViReal64 *carrierFeedthrough,
                                            ViReal64 *MSPower,
                                            ViInt32 signalType,
                                            ViChar errorMessage[])
{
    RETMSG (RSCMU_CDMA2K_MeasModIqan (instrSession, EVM_RMS, magnitudeError_RMS,
                                      phaseError_RMS, waveformQuality, iQImbalance,
                                      carrierFeedthrough, MSPower, signalType, 2, errorMessage));
}

static ViStatus RSCMU_CDMA2K_MeasModIqan (ViSession instrSession,
                                        ViReal64 *EVM_RMS,
                                        ViReal64 *magnitudeError_RMS,
                                        ViReal64 *phaseError_RMS,
                                        ViReal64 *waveformQuality,
                                        ViReal64 *iQImbalance,
                                        ViReal64 *carrierFeedthrough,
                                        ViReal64 *MSPower,
                                        ViInt32 signalType,
                                        ViInt32 cmdType,
                                        ViChar errorMessage[])
{
    ViChar  command[128];
    ViChar  response [2048];
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViString cmds[] = {"READ","FETC","SAMP"};
    ViChar*     str;
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, RSCMU_ERROR_PARAMETER9, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, cmdType, 0, 2, RSCMU_ERROR_PARAMETER10, errorMessage);
    
    sprintf (command, "%s:MOD:IQAN%s?", cmds[cmdType],
             signalTypeArr [signalType]);
    
    CHECKRETMSG (RSCMU_getViString(instrSession, 
                                   command,
                                   response,
                                   2048,
                                   0));

    GET_VI_REAL64(*EVM_RMS,response);
    GET_VI_REAL64(*magnitudeError_RMS,NULL);
    GET_VI_REAL64(*phaseError_RMS,NULL);
    GET_VI_REAL64(*waveformQuality,NULL);
    GET_VI_REAL64(*iQImbalance,NULL);
    GET_VI_REAL64(*carrierFeedthrough,NULL);
    GET_VI_REAL64(*MSPower,NULL);
    
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Read
 * Purpose:  This function starts a MODulation:IQANalyzer measurement and 
 *           returns all measurement results for selected phase.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrayModIqan (ViSession instrSession,
                                                 ViReal64 results[],
                                                 ViInt32 measurementType,
                                                 ViInt32 signalType,
                                                 ViChar errorMessage[])
{
    RETMSG (RSCMU_CDMA2K_MeasArrayModIqan (instrSession,
                                           results,
                                           measurementType,
                                           signalType,
                                           0,
                                           errorMessage));
}

/*****************************************************************************
 * Function: Fetch
 * Purpose:  This function returns all measurement results for selected phase 
 *           (unsynchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetcArrayModIqan (ViSession instrSession,
                                                 ViReal64 results[],
                                                 ViInt32 measurementType,
                                                 ViInt32 signalType,
                                                 ViChar errorMessage[])
{
    RETMSG (RSCMU_CDMA2K_MeasArrayModIqan (instrSession,
                                           results,
                                           measurementType,
                                           signalType,
                                           1,
                                           errorMessage));
}

/*****************************************************************************
 * Function: Sample
 * Purpose:  This function returns all measurement results for selected phase 
 *           (synchronized).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SampArrayModIqan (ViSession instrSession,
                                                 ViReal64 results[],
                                                 ViInt32 measurementType,
                                                 ViInt32 signalType,
                                                 ViChar errorMessage[])
{
    RETMSG (RSCMU_CDMA2K_MeasArrayModIqan (instrSession,
                                           results,
                                           measurementType,
                                           signalType,
                                           2,
                                           errorMessage));
}

static ViStatus RSCMU_CDMA2K_MeasArrayModIqan (ViSession instrSession,
                                        ViReal64 results[],
                                        ViInt32 measurementType,
                                        ViInt32 signalType,
                                        ViInt32 cmdType,
                                        ViChar errorMessage[])
{
    ViChar  command[128];
    ViChar  *hugeBuf = VI_NULL;
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViString cmds[] = {"READ","FETC","SAMP"};
    
    CHECK_VI_INT32_RANGE (instrSession, measurementType, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, cmdType, 0, 2, VI_ERROR_PARAMETER5, errorMessage);
    
    sprintf (command, "%s:ARR:MOD:IQAN%s:%s?", cmds[cmdType],
             signalTypeArr [signalType],
             phaseArr [measurementType]);
    
    CHECKRETMSG (RSCMU_viWrite(instrSession, command, strlen(command)));

    CHECKERR(RSCMU_ReadDataUnknownLength(instrSession, &hugeBuf, VI_NULL));
    
    if (RSCMU_Status < VI_SUCCESS)
        if (hugeBuf) free(hugeBuf);

    if (hugeBuf) 
    {
        RSCMU_atofArray (hugeBuf,results);
        free(hugeBuf);
    }

    RETMSG (RSCMU_Status);
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerFSSCTset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTset (ViSession instrSession,
                                                  ViInt32 TestSetup,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 298, &TestSetup );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[298].instrCommand
          , testSetup.list[TestSetup]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfRQFerFSSCTset()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerFSSCContTsetLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCContTsetLev (ViSession instrSession,
                                                         ViInt32 testSetupType, 
                                                         ViReal64 pilotLevel_dB,
                                                         ViReal64 FCHLevel_dB,
                                                         ViReal64 SCHSCCHLevel_dB,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 299, &testSetupType, &pilotLevel_dB, &FCHLevel_dB, &SCHSCCHLevel_dB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[299].instrCommand
          , testSetupType
          , pilotLevel_dB
          , FCHLevel_dB
          , SCHSCCHLevel_dB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfRQFerFSSCContTsetLev()  


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerFSSCTsetPowCDMA
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTsetPowCDMA (ViSession instrSession,
                                                         ViInt32 testSetupType,       
                                                         ViReal64 CDMAPower_dBm,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 300, &testSetupType, &CDMAPower_dBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[300].instrCommand
          , testSetupType, CDMAPower_dBm
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfRQFerFSSCTsetPowCDMA()  


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerFSSCTsetLevFPIC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTsetLevFPIC (ViSession instrSession,
                                                         ViInt32 testSetupType,
                                                         ViReal64 pilotLevel_dB,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 301, &testSetupType,&pilotLevel_dB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[301].instrCommand
          , testSetupType
          , pilotLevel_dB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfRQFerFSSCTsetLevFPIC()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerFSSCTsetLevFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTsetLevFFCH (ViSession instrSession,
                                                         ViInt32 testSetupType,   
                                                         ViReal64 FCHLevel_dB,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 302, &testSetupType, &FCHLevel_dB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[302].instrCommand
          , testSetupType   
          , FCHLevel_dB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfRQFerFSSCTsetLevFFCH()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerFSSCContTsetImp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCContTsetImp (ViSession instrSession,
                                                         ViInt32 testSetupType,     
                                                         ViReal64 AWGNLevel_dB,
                                                         ViBoolean AWGNEnable, 
                                                         ViReal64 BSFrequencyOffset_KHz,
                                                         ViBoolean BSFreqOffsetEnable,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 303, &testSetupType, &AWGNLevel_dB, &BSFrequencyOffset_KHz);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[303].instrCommand
          , testSetupType
          , AWGNLevel_dB
          , BSFrequencyOffset_KHz  
          , testSetupType
          , enable.list[AWGNEnable]
          , enable.list[BSFreqOffsetEnable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfRQFerFSSCContTsetImp()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitRQFerFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *                                              
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFSSCTsetFraFFCH (ViSession instrSession,
                                                         ViInt32 testSetupType,    
                                                         ViInt32 frameRate,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 304, &testSetupType, &frameRate );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

  sprintf( wrtBuf
          , CDMA[304].instrCommand
          , testSetupType
          , frameRateType.list[frameRate]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                               
   return( RSCMU_Status );

} // end of RSCMU_CDMA_ConfRxqFERTSetupFRate()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefRQFerFchLimTset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *                                              
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_DefRQFerFchLimTset (ViSession instrSession,
                                                   ViInt32 testSetuptype,
                                                   ViBoolean defaultFERFCHLimits,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 564, &testSetuptype, &defaultFERFCHLimits);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[564].instrCommand
          , testSetuptype
          , enable.list[defaultFERFCHLimits]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );        
}//end of RSCMU_CDMA2K_DefRQFerFchLimTset

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitRQFerFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_InitRQFerFCH (ViSession instrSession,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[305].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_InitRQFerFCH()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortRQFerFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortRQFerFCH (ViSession instrSession,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[306].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_AbortRQFerFCH()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StopRQFerFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_StopRQFerFCH (ViSession instrSession,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[307].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_StopRQFerFCH()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ContRQFerFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ContRQFerFCH (ViSession instrSession,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[308].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ContRQFerFCH()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchRQFerFCHStats
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchRQFerFCHStats (ViSession instrSession,
                                                   ViInt32 *measurementStatus,
                                                   ViInt32 *CurrentStatCycleCount,
                                                   ViInt32 *counter_forEvaluationPeriod,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   
   
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[309].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

       // Get the counter for current statistics cycle
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", CurrentStatCycleCount );
       }
       else
       {
          *CurrentStatCycleCount = RSCMU_OFF;
       }
       
       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", counter_forEvaluationPeriod );
       }
       else
       {
          *counter_forEvaluationPeriod = RSCMU_OFF;
       }
   }

   return RSCMU_Status;
          
} //end of RSCMU_CDMA2K_FetchRQFerFCHStats()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerFCHERep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerFCHERep (ViSession instrSession,
                                                 ViInt32 reportMode,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 310, &reportMode );

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[310].instrCommand
          , eventReport.list[reportMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfRQFerFCHERep() 


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadRQFerFCH
 *
 * DESCRIPTI    ON: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadRQFerFCH (ViSession instrSession,
                                             ViReal64 *FER, ViInt32 *frameErrors,
                                             ViInt32 *elapsedFrames,
                                             ViReal64 *confidenceLev,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 


   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[311].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get total mean output
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", FER );
   }
   else
   {
      *FER = RSCMU_NAN;
   }
   
   // Get measurement out of tolerance
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%d", frameErrors );
   }
   else
   {
      *frameErrors = RSCMU_NAN;
   }
   
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%d", elapsedFrames );
   }
   else
   {
      *elapsedFrames = RSCMU_NAN;
   }
   
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", confidenceLev );
   }
   else
   {
      *confidenceLev = RSCMU_NAN;
   }
   
   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ReadRQFerFCH()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchRQFerFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchRQFerFCH (ViSession instrSession,
                                              ViReal64 *FER,
                                              ViInt32 *frameErrors,
                                              ViInt32 *elapsedFrames,
                                              ViReal64 *confidenceLev,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViInt32   numMeasValues;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar    TempBuf[669][20];
   

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[312].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   numMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_Status  = RSCMU_ReturnFERResponse( numMeasValues
                                          , TempBuf
                                          , FER 
                                          , frameErrors 
                                          , elapsedFrames 
                                          , confidenceLev 
                                          );
   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_FetchRQFerFCH()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleRQFerFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleRQFerFCH (ViSession instrSession,
                                               ViReal64 *FER,
                                               ViInt32 *frameErrors,
                                               ViInt32 *elapsedFrames,
                                               ViReal64 *confidenceLev,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViInt32   numMeasValues;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar    TempBuf[669][20];


  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[313].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   numMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_Status  = RSCMU_ReturnFERResponse( numMeasValues
                                          , TempBuf
                                          , FER 
                                          , frameErrors 
                                          , elapsedFrames 
                                          , confidenceLev 
                                          );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_SampleRQFerFCH()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalcRQFerFCHMatcLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalcRQFerFCHMatcLim (ViSession instrSession,
                                                    ViInt32 *maxFER,
                                                    ViInt32 *ConfLev,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[314].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   RSCMU_Status = RSCMU_GetMeasureMatching( maxFER,  tab, 0 );
   RSCMU_Status = RSCMU_GetMeasureMatching( ConfLev, tab, 1 );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_CalcRQFerFCHMatcLim()

/*****************************************************************************
 * Function: Minimum SCH Confidence Level
 * Purpose:  This function defines the tolerances for the minimum confidence 
 *           level on the SCHs.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerSCHSLimTsetSCLv (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViInt32 SCH,
                                                         ViReal64 minConfidenceLevel,
                                                         ViBoolean enable,
                                                         ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, testSetup, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, SCH, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:RXQ:FER:SCHS:LIM:TSET%ld:SCH:%s:CLEV", testSetup,
             schArr [SCH]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                enable,
                                stateArr,
                                VI_ERROR_PARAMETER5));

    if (enable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    minConfidenceLevel,
                                    85.0, 99.9,
                                    VI_ERROR_PARAMETER4));
    }

    RETMSG (RSCMU_Status);
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefRQFerSchsLimTset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefRQFerSchsLimTset (ViSession instrSession,
                                                    ViInt32 testSetupType,
                                                    ViBoolean defaultFERSCHLimits,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 566, &testSetupType, &defaultFERSCHLimits);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[566].instrCommand
          ,testSetupType
          , enable.list[defaultFERSCHLimits]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );      
}//end of RSCMU_CDMA2K_DefRQFerSchsLimTset

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitRQFerSCHS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_InitRQFerSCHS (ViSession instrSession,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[516].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_InitRQFerSCHS()   

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortRQFerSCHS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortRQFerSCHS (ViSession instrSession,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[517].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_AbortRQFerSCHS()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StopRQFerSCHS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_StopRQFerSCHS (ViSession instrSession,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[518].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_StopRQFerSCHS()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ContRQFerSCHS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ContRQFerSCHS (ViSession instrSession,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[519].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ContRQFerSCHS()     

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchRQFerSCHSStats
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchRQFerSCHSStats (ViSession instrSession,
                                                   ViInt32 *measurementStatus,
                                                   ViInt32 *CurrentStatCycleCount,
                                                   ViInt32 *counter_forEvaluationPeriod,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   
   
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[520].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

       // Get the counter for current statistics cycle
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", CurrentStatCycleCount );
       }
       else
       {
          *CurrentStatCycleCount = RSCMU_OFF;
       }
       
       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", counter_forEvaluationPeriod );
       }
       else
       {
          *counter_forEvaluationPeriod = RSCMU_OFF;
       }
   }

   return RSCMU_Status;
          
} //end of RSCMU_CDMA2K_FetchRQFerSCHSStats()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerSCHSERep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerSCHSERep (ViSession instrSession,
                                                 ViInt32 reportMode,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 511, &reportMode );

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[511].instrCommand
          , eventReport.list[reportMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfRQFerSCHSERep() 

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerSCHSContTsetFr
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerSCHSContTsetFr (ViSession instrSession,
                                                         ViInt32 testSetupType, 
                                                         ViInt32 frameCount,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 512, &testSetupType, &frameCount );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[512].instrCommand
          , testSetupType, frameCount
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfRQFerSCHSContTsetFr()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerSCHSContTsetRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerSCHSContTsetRep (ViSession instrSession,
                                                         ViInt32 testSetupType,
                                                         ViInt32 rep,
                                                         ViInt32 stopCondition,
                                                         ViInt32 step,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   
   checkRange( 513, &testSetupType, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
 
   sprintf( wrtBuf
          , CDMA[513].instrCommand
          , testSetupType
          , repetition.list[rep]
          , stopCond2.list[stopCondition]
          , stepMode.list[step]
          );

  RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   
   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfRQFerSCHSContTsetRep()      

/*****************************************************************************
 * Function: SCH1 Extension Mode
 * Purpose:  This function extends the output arrays of the READ, FETCh,
 *           SAMPle[:SCALar]:RXQuality:FER:SCHScch? commands and the
 *           CALCulate[:SCALar]:RXQuality:FER:SCHScch:MATChing:LIMit? command 
 *           to include the results for the SCH1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_XtndRxqFerSchsSchOne (ViSession instrSession,
                                                     ViBoolean enable,
                                                     ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                                "XTND:RXQ:FER:SCHS:SCH:ONE",
                                enable,
                                stateArr,
                                VI_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefRQFerSchsContTset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      defaultFERSCHSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_DefRQFerSchsContTset (ViSession instrSession,
                                                     ViInt32 testSetuptype,
                                                     ViBoolean defaultFERSCHSetting,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 565, &testSetuptype, &defaultFERSCHSetting);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[565].instrCommand
          , testSetuptype
          , enable.list[defaultFERSCHSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );     
}//end of RSCMU_CDMA2K_DefRQFerSchsContTset

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerSCHSLimTsetMFer
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerSCHSLimTsetMFer (ViSession instrSession,
                                                         ViInt32 testSetupType,
                                                         ViReal64 maxFERLimit,
                                                         ViBoolean Enable,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 514, &testSetupType, &maxFERLimit );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[514].instrCommand
          , testSetupType
          , maxFERLimit 
          , testSetupType
          , enable.list[Enable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfRQFerSCHSLimTsetMFer()

/*****************************************************************************
 * Function: Maximum FER, SCH Limit
 * Purpose:  This function defines the tolerances for the FER on the SCHs for 
 *           test setup <nr> (1 to 5).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerSCHSLimTsetSMFr (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViInt32 SCH,
                                                         ViReal64 maxFER,
                                                         ViBoolean enable,
                                                         ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, testSetup, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, SCH, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:RXQ:FER:SCHS:LIM:TSET%ld:SCH:%s:MFER", testSetup,
             schArr [SCH]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                enable,
                                stateArr,
                                VI_ERROR_PARAMETER5));

    if (enable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    maxFER,
                                    0.1, 50.0,
                                    VI_ERROR_PARAMETER4));
    }

    RETMSG (RSCMU_Status);
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFerSCHSLimTsetCLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFerSCHSLimTsetCLev (ViSession instrSession,
                                                         ViInt32 testSetupType,
                                                         ViReal64 minConfidenceLevel,
                                                         ViBoolean Enable,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 515, &testSetupType, &minConfidenceLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[515].instrCommand
          , testSetupType
          , minConfidenceLevel
          , testSetupType
          , enable.list[Enable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ConfRQFerSCHSLimTsetCLev()   

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadRQFerSCHS
 *
 * DESCRIPTI    ON: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadRQFerSCHS (ViSession instrSession,
                                              ViReal64 *FER,
                                              ViInt32 *frameErrors,
                                              ViInt32 *elapsedFrames,
                                              ViReal64 *confidenceLev,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 


   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[521].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get total mean output
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", FER );
   }
   else
   {
      *FER = RSCMU_NAN;
   }
   
   // Get measurement out of tolerance
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%d", frameErrors );
   }
   else
   {
      *frameErrors = RSCMU_NAN;
   }
   
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%d", elapsedFrames );
   }
   else
   {
      *elapsedFrames = RSCMU_NAN;
   }
   
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", confidenceLev );
   }
   else
   {
      *confidenceLev = RSCMU_NAN;
   }
   
   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ReadRQFerSCHS()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      statistics,repetition,stopCondition,stepMode
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcCont (ViSession instrSession,
                                              ViInt32 statistics,
                                              ViInt32 rep,
                                              ViInt32 stopCondition,
                                              ViInt32 step,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 569, &statistics, &rep, &stopCondition, &step );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   sprintf( wrtBuf
          , CDMA[569].instrCommand
          , statistics
          , repetition.list[rep]
          , stopCond2.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status );
    
}//end of RSCMU_CDMA2K_ConfRQFpcCont
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      repetition, stopCondition,stepMode
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContRep (ViSession instrSession,
                                                 ViInt32 rep,
                                                 ViInt32 stopCondition,
                                                 ViInt32 step,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 571
             , &rep
             , &stopCondition 
             , &step
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[571].instrCommand
          , repetition.list[rep]
          , stopCond2.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
               
}//end of RSCMU_CDMA2K_ConfRQFpcContRep
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContStats
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      statistics
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContStats (ViSession instrSession,
                                                   ViInt32 statistics,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 570, &statistics );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[570].instrCommand
          , statistics
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
        
}//end of RSCMU_CDMA2K_ConfRQFpcContStats
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContFPCMode
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      FPCMode
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContFPCMode (ViSession instrSession,
                                                     ViInt32 FPCMode,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 572, &FPCMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[572].instrCommand
          , FPCMode
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
            
}//end of RSCMU_CDMA2K_ConfRQFpcContFPCMode
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContRDelay
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      reportDelay
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContRDelay (ViSession instrSession,
                                                    ViInt32 reportDelay,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 573, &reportDelay );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[573].instrCommand
          , reportDelay
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of RSCMU_CDMA2K_ConfRQFpcContRDelay
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContRFrames
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      reportFrames
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContRFrames (ViSession instrSession,
                                                     ViInt32 reportFrames,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 574, &reportFrames );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[574].instrCommand
          , reportFrames
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of RSCMU_CDMA2K_ConfRQFpcContRFrames
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_RXFpcContCPRimary
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      CPrimiary
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_RXFpcContCPRimary (ViSession instrSession,
                                                  ViInt32 CPrimiary,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   //checkRange( 575, &CPrimiary );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[575].instrCommand
          , CPrimiary
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );        
}//end of RSCMU_CDMA2K_RXFpcContCPRimary
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_RXFpcContCSECondary
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      CSecondary
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_RXFpcContCSECondary (ViSession instrSession,
                                                    ViInt32 CSecondary,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   // checkRange( 576, &CSecondary );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[576].instrCommand
          , CSecondary
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );        
}//end of RSCMU_CDMA2K_RXFpcContCSECondary
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContPowCDMA
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      CDMAPower_dBm
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContPowCDMA (ViSession instrSession,
                                                     ViReal64 CDMAPower_dBm,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 587, &CDMAPower_dBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[587].instrCommand
          , CDMAPower_dBm
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );      
}//end of RSCMU_CDMA2K_ConfRQFpcContPowCDMA
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContLevFPIC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      pilotLevel_dB
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContLevFPIC (ViSession instrSession,
                                                     ViReal64 pilotLevel_dB,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 588, &pilotLevel_dB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[588].instrCommand
          , pilotLevel_dB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );       
}//end of RSCMU_CDMA2K_ConfRQFpcContLevFPIC
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContLevFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      FCHLevel_dB
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContLevFFCH (ViSession instrSession,
                                                     ViReal64 FCHLevel_dB,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 589, &FCHLevel_dB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[589].instrCommand
          , FCHLevel_dB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );           
}//end of RSCMU_CDMA2K_ConfRQFpcContLevFFCH
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContLevFSCH0
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      SCH0Level_dB
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContLevFSCH0 (ViSession instrSession,
                                                      ViReal64 SCH0Level_dB,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 590, &SCH0Level_dB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[590].instrCommand
          , SCH0Level_dB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );        
}//end of RSCMU_CDMA2K_ConfRQFpcContLevFSCH0

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContImp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      AWGNLevel_dB,AWGNEnable,BSFrequencyOffset_KHz,BSFreqOffsetEnable
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContImp (ViSession instrSession,
                                                 ViReal64 AWGNLevel_dB,
                                                 ViInt32 AWGNEnable,
                                                 ViReal64 BSFrequencyOffset_KHz,
                                                 ViInt32 BSFreqOffsetEnable,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 591, &AWGNLevel_dB, &BSFrequencyOffset_KHz );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[591].instrCommand
          , AWGNLevel_dB
          , BSFrequencyOffset_KHz
          , modeEnable.list[AWGNEnable]
          , modeEnable.list[BSFreqOffsetEnable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );        
}//end of RSCMU_CDMA2K_ConfRQFpcContImp
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContFraFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      frameRate
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContFraFFCH (ViSession instrSession,
                                                     ViInt32 frameRate,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 592, &frameRate );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[592].instrCommand
          , frameRateType.list[frameRate] 
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );      
}//end of RSCMU_CDMA2K_ConfRQFpcContFraFFCH

/*****************************************************************************
 * Function: State
 * Purpose:  This function enables or disables the environment for an 
 *           individual test setup <nr> (<nr> = 1 to 5) Receiver Quality 
 *           measurement applications.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcEnvEnab (ViSession instrSession,
                                                 ViBoolean enable,
                                                 ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:RXQ:FPC:ENV:ENAB",
                           enable,
                           stateArr,
                           VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: CDMA Output Power
 * Purpose:  This function determines the total CDMA output power (absolute 
 *           value, in dBm) of the CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcEnvPowCdma (ViSession instrSession,
                                                    ViReal64 CDMAPower,
                                                    ViChar errorMessage[])
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                               "CONF:RXQ:FPC:ENV:POW:CDMA",
                               CDMAPower,
                               -120.0, 7.0,
                               VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Level
 * Purpose:  This function determines the level in the selected channel of the 
 *           CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcEnvLev (ViSession instrSession,
                                                ViInt32 channel, ViBoolean state,
                                                ViReal64 level,
                                                ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, channel, 0, 3, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:RXQ:FPC:ENV:LEV:%s",
             channelArr [channel]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                state,
                                stateArr,
                                VI_ERROR_PARAMETER3));

    if (state)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    level,
                                    -20.0, -7.0,
                                    VI_ERROR_PARAMETER4));
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Frame Rate
 * Purpose:  This function sets the frame rate for the variable rate traffic 
 *           channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcEnvFratFfch (ViSession instrSession,
                                                     ViInt32 frameRate,
                                                     ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:RXQ:FPC:ENV:FRAT:FFCH",
                           frameRate,
                           frameArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Impairments
 * Purpose:  This function determines an Additional White Gaussian Noise 
 *           level, a frequency offset to impair the CMU output signal and 
 *           injected Tx FER.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcEnvImpairment (ViSession instrSession,
                                                       ViReal64 AWGN_level_dB,
                                                       ViBoolean AWGNEnable,
                                                       ViReal64 BSFreqOffset_kHz,
                                                       ViBoolean BSFreqEnable,
                                                       ViReal64 txFER,
                                                       ViBoolean txFEREnable,
                                                       ViChar errorMessage[])
{
    ViStatus RSCMU_Status;
    
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:RXQ:FPC:ENV:IMP:LEV:AWGN",
                                AWGNEnable,
                                stateArr,
                                VI_ERROR_PARAMETER4));

    if (AWGNEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:RXQ:FPC:ENV:IMP:LEV:AWGN",
                                    AWGN_level_dB,
                                    -20.0, 4.0,
                                    VI_ERROR_PARAMETER3));
    }

    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:RXQ:FPC:ENV:IMP:FOFF",
                                BSFreqEnable,
                                stateArr,
                                VI_ERROR_PARAMETER6));

    if (BSFreqEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:RXQ:FPC:ENV:IMP:FOFF",
                                    BSFreqOffset_kHz,
                                    -5.0E+3, 5.0E+3,
                                    VI_ERROR_PARAMETER5));
    }

    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:RXQ:FPC:ENV:IMP:ITF",
                                txFEREnable,
                                stateArr,
                                VI_ERROR_PARAMETER8));
    if (txFEREnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:RXQ:FPC:ENV:IMP:ITF",
                                    txFER,
                                    0.0, 50.0,
                                    VI_ERROR_PARAMETER7));
    }
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Power Control Bits
 * Purpose:  This function queries the power control bit sequence that the CMU 
 *           sends to the mobile station to control its output power.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcEnvPCBits (ViSession instrSession,
                                                   ViInt32 *powerControlBits,
                                                   ViChar errorMessage[])
{
    RETMSG (RSCMU_getEnum (instrSession,
                           "CONF:RXQ:FPC:ENV:PCB?",
                           powerControlBits,
                           PCBArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Initial EbNt Setpoint
 * Purpose:  This function sets the initial outer loop Eb/Nt setpoint.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContLspInit(
    ViSession   instrSession,
    ViInt32 channel,
    ViReal64    initialEbNtSetpoint,
 ViChar errorMessage[]
)
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, channel, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:RXQ:FPC:CONT:%s:LSP:INIT",
             rqfChannelArr [channel]);

    RETMSG (RSCMU_setViReal64 (instrSession,
                               command,
                               initialEbNtSetpoint,
                               0.0, 31.75,
                               RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: EbNt Setpoint Threshold
 * Purpose:  This function sets the Eb/Nt setpoint report threshold above 
 *           which the mobile station will send the outer loop report message.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContLspThr(
    ViSession   instrSession,
    ViInt32     channel,
    ViInt32     enable,
    ViReal64    ebntSetpointThreshold,
 ViChar errorMessage[]
)
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, channel, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:RXQ:FPC:CONT:%s:LSP:THR",
             rqfChannelArr [channel]);

    switch (enable)
    {
        case RSCMU_NEW:
        {
            RETMSG (RSCMU_setViReal64 (instrSession,
                                   command,
                                   ebntSetpointThreshold,
                                   0.0, 31.75,
                                   RSCMU_ERROR_PARAMETER3));
        }
        default:
        {
            RETMSG (RSCMU_setEnum (instrSession,
                                   command,
                                   enable,
                                   stateArr,
                                   RSCMU_ERROR_PARAMETER2));
        }
    }
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContFchTFer
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      targetFERFCH
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContFchTFer (ViSession instrSession,
                                                     ViReal64 targetFERFCH,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 577, &targetFERFCH );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[577].instrCommand
          , targetFERFCH
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );            
}//end of RSCMU_CDMA2K_ConfRQFpcContFchTFer
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContFchLSL
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      lowerStaticLevel
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContFchLSL (ViSession instrSession,
                                                    ViReal64 lowerStaticLevel,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 578, &lowerStaticLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[578].instrCommand
          , lowerStaticLevel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of RSCMU_CDMA2K_ConfRQFpcContFchLSL
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContFchLSU
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      upperStaticLevel
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContFchLSU (ViSession instrSession,
                                                    ViReal64 upperStaticLevel,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 580, &upperStaticLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[580].instrCommand
          , upperStaticLevel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );            
}//end of RSCMU_CDMA2K_ConfRQFpcContFchLSU
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_RQFpcContFchLDL
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      lowerDynamicLevelSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_RQFpcContFchLDL (ViSession instrSession,
                                                ViInt32 lowerDynamicLevelSetting,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 579, &lowerDynamicLevelSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[579].instrCommand
          , modeEnable.list[lowerDynamicLevelSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );       
}//end of RSCMU_CDMA2K_RQFpcContFchLDL
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_RQFpcContFchLDU
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      upperDynamicLevelSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_RQFpcContFchLDU (ViSession instrSession,
                                                ViInt32 upperDynamicLevelSetting,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 581, &upperDynamicLevelSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[581].instrCommand
          , modeEnable.list[upperDynamicLevelSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );     
}//end of RSCMU_CDMA2K_RQFpcContFchLDU
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContSchZTFer
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      targetFERFCH
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE                    
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchZTFer (ViSession instrSession,
                                                      ViReal64 targetFERFCH,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 582, &targetFERFCH );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[582].instrCommand
          , targetFERFCH
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );            
}//end of RSCMU_CDMA2K_ConfRQFpcContSchZTFer
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContSchZLSL
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      lowerStaticLevel
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchZLSL (ViSession instrSession,
                                                     ViReal64 lowerStaticLevel,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 583, &lowerStaticLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[583].instrCommand
          , lowerStaticLevel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );      
}//end of RSCMU_CDMA2K_ConfRQFpcContSchZLSL
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcContSchZLSU
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      upperStaticLevel
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchZLSU (ViSession instrSession,
                                                     ViReal64 upperStaticLevel,
                                                     ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 585, &upperStaticLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[585].instrCommand
          , upperStaticLevel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );          
}//end of RSCMU_CDMA2K_ConfRQFpcContSchZLSU
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_RQFpcContSchZLDL
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      lowerDynamicLevelSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_RQFpcContSchZLDL (ViSession instrSession,
                                                 ViInt32 lowerDynamicLevelSetting,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 584, &lowerDynamicLevelSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[584].instrCommand
          , modeEnable.list[lowerDynamicLevelSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );       
}//end of RSCMU_CDMA2K_RQFpcContSchZLDL
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_RQFpcContSchZLDU
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      upperDynamicLevelSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_RQFpcContSchZLDU (ViSession instrSession,
                                                 ViInt32 upperDynamicLevelSetting,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 586, &upperDynamicLevelSetting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[586].instrCommand
          , modeEnable.list[upperDynamicLevelSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );      
}//end of RSCMU_CDMA2K_RQFpcContSchZLDU

/*****************************************************************************
 * Function: Target FER SCH1
 * Purpose:  This function sets a Frame Error Rate target (percentage of 
 *           error) for the mobile station to achieve on the forward 
 *           supplemental traffic channels 0 or 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchOTFer (ViSession instrSession,
                                                      ViReal64 targetFERSCH1,
                                                      ViChar errorMessage[])
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                           "CONF:RXQ:FPC:CONT:SCH:ONE:TFER",
                           targetFERSCH1,
                           0.2, 30.0,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Lower Static Level Setup
 * Purpose:  This function sets the minimum level that the mobile station is 
 *           allowed to move the Eb/Nt setpoint to for forward power control of 
 *           the forward supplemental traffic channels 0 or 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchOLSL (ViSession instrSession,
                                                     ViReal64 lowerStaticLevel,
                                                     ViChar errorMessage[])
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                           "CONF:RXQ:FPC:CONT:SCH:ONE:LSP:STT:LOW",
                           lowerStaticLevel,
                           0,31.75,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Upper Static Level Setup
 * Purpose:  This function sets the maximum level that the mobile station is 
 *           allowed to move the Eb/Nt setpoint to for forward power control of 
 *           the supplemental traffic channels 0 or 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchOLSU (ViSession instrSession,
                                                     ViReal64 upperStaticLevel,
                                                     ViChar errorMessage[])
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                           "CONF:RXQ:FPC:CONT:SCH:ONE:LSP:STT:UPP",
                           upperStaticLevel,
                           0, 31.75,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Lower Dynamic Level Setup
 * Purpose:  This function enables or disables the use of the dynamic 
 *           (minimum) setpoint setting for forward power control of the 
 *           forward supplemental traffic channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchOLDL (ViSession instrSession,
                                                 ViInt32 lowerDynamicLevelSetting,
                                                 ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:RXQ:FPC:CONT:SCH:ONE:LSP:DYN:LOW",
                           lowerDynamicLevelSetting,
                           stateDefArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Upper Dynamic Level Setup
 * Purpose:  This function enables or disables the use of the dynamic 
 *           (maximum) setpoint setting for forward power control of the 
 *           forward supplemental traffic channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcContSchOLDU (ViSession instrSession,
                                                 ViInt32 upperDynamicLevelSetting,
                                                 ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:RXQ:FPC:CONT:SCH:ONE:LSPoint:DYN:UPP",
                           upperDynamicLevelSetting,
                           stateDefArr,
                           VI_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefRQFpcCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      defaultFPCControl
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_DefRQFpcCont (ViSession instrSession,
                                             ViBoolean defaultFPCControl,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 568, &defaultFPCControl);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[568].instrCommand
          , enable.list[defaultFPCControl]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitRQFpc
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitRQFpc (ViSession instrSession,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[593].instrCommand
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );     

}//end of RSCMU_CDMA2K_InitRQFpc
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortRQFpc
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortRQFpc (ViSession instrSession,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 


   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[594].instrCommand
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );         
}//end of RSCMU_CDMA2K_AbortRQFpc
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StopRQFpc
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      reportMode
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_StopRQFpc (ViSession instrSession,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[595].instrCommand
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );         
}//end of RSCMU_CDMA2K_StopRQFpc
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ContRQFPControl
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ContRQFPControl (ViSession instrSession,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[596].instrCommand
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );         
}//end of RSCMU_CDMA2K_ContRQFPControl
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchRQFpcStats
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     measurementStatus,counter_forStatisticsCycle,elapsedFrames
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchRQFpcStats (ViSession instrSession,
                                                ViInt32 *measurementStatus,
                                                ViInt32 *counter_forStatisticsCycle,
                                                ViInt32 *elapsedFrames,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the measurement status:
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[597].instrCommand   
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );
          
       if( strcmp( tab[1], "NAN" ) != 0 )
       {
          sscanf( tab[1], "%d", counter_forStatisticsCycle );
       }
       else
       {
          *counter_forStatisticsCycle = RSCMU_NAN;
       }
       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NAN" ) != 0 )
       {
          sscanf( tab[2], "%d", elapsedFrames );
       }
       else
       {
          *elapsedFrames = RSCMU_NAN;
       }
    }


   return RSCMU_Status;    
}//end of RSCMU_CDMA2K_FetchRQFpcStats

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfRQFpcERep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      reportMode
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRQFpcERep (ViSession instrSession,
                                              ViInt32 reportMode,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
  
   checkRange( 567, &reportMode );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[567].instrCommand
          , eventReport.list[reportMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
            
}//end of RSCMU_CDMA2K_ConfRQFpcERep

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadRQFpc
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     actualOutputPower,FCHResult,DCCHResult,SCH0Result,SCH1Result 
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadRQFpc (ViSession instrSession,
                                           tFPC     *FPC,
                                          ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ViInt32  i;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
  
  getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

  RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[598].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get actual output power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", &FPC->actualOutputPower);
   }
   else
   {
      FPC->actualOutputPower = RSCMU_NAN;
   }

   for(i =0;i<25; i+=8 )   
   {
       
     switch (i)
     {
     case 0:  // FCH
      
       
       //Get FER measurement
       if( strcmp( tab[1+i], "NAN" ) != 0 )
       {
          sscanf( tab[1+i], "%lf", &FPC->FCH.FER );
       }
       else
       {
          FPC->FCH.FER = RSCMU_NAN;
       }
       //Get FrameError measurement
       if( strcmp( tab[2+i], "NAN" ) != 0 )
       {
          sscanf( tab[2+i], "%d", &FPC->FCH.FrameError );
       }
       else
       {
          FPC->FCH.FrameError = RSCMU_NAN_VI_INT32;
       }  
       //Get Transmit Frame measurement
       if( strcmp( tab[3+i], "NAN" ) != 0 )
       {
          sscanf( tab[3+i], "%d", &FPC->FCH.TransmitFrame );
       }
       else
       {
          FPC->FCH.TransmitFrame = RSCMU_NAN_VI_INT32;
       }
       //Get Confidence Level measurement
       if( strcmp( tab[4+i], "NAN" ) != 0 )
       {
          sscanf( tab[4+i], "%lf", &FPC->FCH.ConfidenceLevel );
       }
       else
       {
          FPC->FCH.ConfidenceLevel = RSCMU_NAN;
       }    
       //Get Adjusted Level measurement
       if( strcmp( tab[5+i], "NAN" ) != 0 )
       {
          sscanf( tab[5+i], "%lf", &FPC->FCH.AdjustLevel );
       }
       else
       {
          FPC->FCH.AdjustLevel= RSCMU_NAN;
       }
       //Get Forward Channel Level measurement
       if( strcmp( tab[6+i], "NAN" ) != 0 )
       {
          sscanf( tab[6+i], "%lf", &FPC->FCH.FwdChLevel );
       }
       else
       {
          FPC->FCH.FwdChLevel= RSCMU_NAN;
       }  
       //Get Current Set Point value
       if( strcmp( tab[7+i], "NAN" ) != 0 )
       {
          sscanf( tab[7+i], "%lf", &FPC->FCH.CurrentSetPoint );
       }
       else
       {
          FPC->FCH.CurrentSetPoint = RSCMU_NAN;
       }
       //Get BS Calculate Eb/Nt measurement
       if( strcmp( tab[8+i], "NAN" ) != 0 )
       {                                                                
          sscanf( tab[8+i], "%lf", &FPC->FCH.BSCalEbNt );
       }
       else                                                                 
       {
         FPC->FCH.BSCalEbNt  = RSCMU_NAN;
       }
       
     break;
     
     case 8: // DCCH
     
       //Get FER measurement
       if( strcmp( tab[1+i], "NAN" ) != 0 )
       {
          sscanf( tab[1+i], "%lf", &FPC->DCCH.FER );
       }
       else
       {
          FPC->DCCH.FER = RSCMU_NAN;
       }
       //Get FrameError measurement
       if( strcmp( tab[2+i], "NAN" ) != 0 )
       {
          sscanf( tab[2+i], "%d", &FPC->DCCH.FrameError );
       }
       else
       {
          FPC->DCCH.FrameError = RSCMU_NAN_VI_INT32;
       }  
       //Get Transmit Frame measurement
       if( strcmp( tab[3+i], "NAN" ) != 0 )
       {
          sscanf( tab[3+i], "%d", &FPC->DCCH.TransmitFrame );
       }
       else
       {
          FPC->DCCH.TransmitFrame = RSCMU_NAN_VI_INT32;
       }
       //Get Confidence Level measurement
       if( strcmp( tab[4+i], "NAN" ) != 0 )
       {
          sscanf( tab[4+i], "%lf", &FPC->DCCH.ConfidenceLevel );
       }
       else
       {
          FPC->DCCH.ConfidenceLevel = RSCMU_NAN;
       }    
       //Get Adjusted Level measurement
       if( strcmp( tab[5+i], "NAN" ) != 0 )
       {
          sscanf( tab[5+i], "%lf", &FPC->DCCH.AdjustLevel );
       }
       else
       {
          FPC->DCCH.AdjustLevel= RSCMU_NAN;
       }
       //Get Forward Channel Level measurement
       if( strcmp( tab[6+i], "NAN" ) != 0 )
       {
          sscanf( tab[6+i], "%lf", &FPC->DCCH.FwdChLevel );
       }
       else
       {
          FPC->DCCH.FwdChLevel= RSCMU_NAN;
       }  
       //Get Current Set Point value
       if( strcmp( tab[7+i], "NAN" ) != 0 )
       {
          sscanf( tab[7+i], "%lf", &FPC->DCCH.CurrentSetPoint );
       }
       else
       {
          FPC->DCCH.CurrentSetPoint = RSCMU_NAN;
       }
       //Get BS Calculate Eb/Nt measurement
       if( strcmp( tab[8+i], "NAN" ) != 0 )
       {                                                                
          sscanf( tab[8+i], "%lf", &FPC->DCCH.BSCalEbNt );
       }
       else                                                                 
       {
         FPC->DCCH.BSCalEbNt  = RSCMU_NAN;
       }
     
     break;
     
     case 16: // SCH0
     
       //Get FER measurement
       if( strcmp( tab[1+i], "NAN" ) != 0 )
       {
          sscanf( tab[1+i], "%lf", &FPC->SCH0.FER );
       }
       else
       {
          FPC->SCH0.FER = RSCMU_NAN;
       }
       //Get FrameError measurement
       if( strcmp( tab[2+i], "NAN" ) != 0 )
       {
          sscanf( tab[2+i], "%d", &FPC->SCH0.FrameError );
       }
       else
       {
          FPC->SCH0.FrameError = RSCMU_NAN_VI_INT32;
       }  
       //Get Transmit Frame measurement
       if( strcmp( tab[3+i], "NAN" ) != 0 )
       {
          sscanf( tab[3+i], "%d", &FPC->SCH0.TransmitFrame );
       }
       else
       {
          FPC->SCH0.TransmitFrame = RSCMU_NAN_VI_INT32;
       }
       //Get Confidence Level measurement
       if( strcmp( tab[4+i], "NAN" ) != 0 )
       {
          sscanf( tab[4+i], "%lf", &FPC->SCH0.ConfidenceLevel );
       }
       else
       {
          FPC->SCH0.ConfidenceLevel = RSCMU_NAN;
       }    
       //Get Adjusted Level measurement
       if( strcmp( tab[5+i], "NAN" ) != 0 )
       {
          sscanf( tab[5+i], "%lf", &FPC->SCH0.AdjustLevel );
       }
       else
       {
          FPC->SCH0.AdjustLevel= RSCMU_NAN;
       }
       //Get Forward Channel Level measurement
       if( strcmp( tab[6+i], "NAN" ) != 0 )
       {
          sscanf( tab[6+i], "%lf", &FPC->SCH0.FwdChLevel );
       }
       else
       {
          FPC->SCH0.FwdChLevel= RSCMU_NAN;
       }  
       //Get Current Set Point value
       if( strcmp( tab[7+i], "NAN" ) != 0 )
       {
          sscanf( tab[7+i], "%lf", &FPC->SCH0.CurrentSetPoint );
       }
       else
       {
          FPC->SCH0.CurrentSetPoint = RSCMU_NAN;
       }
       //Get BS Calculate Eb/Nt measurement
       if( strcmp( tab[8+i], "NAN" ) != 0 )
       {                                                                
          sscanf( tab[8+i], "%lf", &FPC->SCH0.BSCalEbNt );
       }
       else                                                                 
       {
         FPC->SCH0.BSCalEbNt  = RSCMU_NAN;
       }
     
     break;
     
     case 24: // SCH1
     
       //Get FER measurement
       if( strcmp( tab[1+i], "NAN" ) != 0 )
       {
          sscanf( tab[1+i], "%lf", &FPC->SCH1.FER );
       }
       else
       {
          FPC->SCH1.FER = RSCMU_NAN;
       }
       //Get FrameError measurement
       if( strcmp( tab[2+i], "NAN" ) != 0 )
       {
          sscanf( tab[2+i], "%d", &FPC->SCH1.FrameError );
       }
       else
       {
          FPC->SCH1.FrameError = RSCMU_NAN_VI_INT32;
       }  
       //Get Transmit Frame measurement
       if( strcmp( tab[3+i], "NAN" ) != 0 )
       {
          sscanf( tab[3+i], "%d", &FPC->SCH1.TransmitFrame );
       }
       else
       {
          FPC->SCH1.TransmitFrame = RSCMU_NAN_VI_INT32;
       }
       //Get Confidence Level measurement
       if( strcmp( tab[4+i], "NAN" ) != 0 )
       {
          sscanf( tab[4+i], "%lf", &FPC->SCH1.ConfidenceLevel );
       }
       else
       {
          FPC->SCH1.ConfidenceLevel = RSCMU_NAN;
       }    
       //Get Adjusted Level measurement
       if( strcmp( tab[5+i], "NAN" ) != 0 )
       {
          sscanf( tab[5+i], "%lf", &FPC->SCH1.AdjustLevel );
       }
       else
       {
          FPC->SCH1.AdjustLevel= RSCMU_NAN;
       }
       //Get Forward Channel Level measurement
       if( strcmp( tab[6+i], "NAN" ) != 0 )
       {
          sscanf( tab[6+i], "%lf", &FPC->SCH1.FwdChLevel );
       }
       else
       {
          FPC->SCH1.FwdChLevel= RSCMU_NAN;
       }  
       //Get Current Set Point value
       if( strcmp( tab[7+i], "NAN" ) != 0 )
       {
          sscanf( tab[7+i], "%lf", &FPC->SCH1.CurrentSetPoint );
       }
       else
       {
          FPC->SCH1.CurrentSetPoint = RSCMU_NAN;
       }
       //Get BS Calculate Eb/Nt measurement
       if( strcmp( tab[8+i], "NAN" ) != 0 )
       {                                                                
          sscanf( tab[8+i], "%lf", &FPC->SCH1.BSCalEbNt );
       }
       else                                                                 
       {
         FPC->SCH1.BSCalEbNt  = RSCMU_NAN;
       }
     
     break;
     
     }
 
  }  
  
   return( RSCMU_Status );        
}//end of RSCMU_CDMA2K_ReadRQFpc

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchRQFerSCHS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchRQFerSCHS (ViSession instrSession,
                                               ViReal64 *FER,
                                               ViInt32 *frameErrors,
                                               ViInt32 *elapsedFrames,
                                               ViReal64 *confidenceLev,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViInt32   numMeasValues;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar    TempBuf[669][20];
   

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[522].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   numMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_Status  = RSCMU_ReturnFERResponse( numMeasValues
                                          , TempBuf
                                          , FER 
                                          , frameErrors 
                                          , elapsedFrames 
                                          , confidenceLev 
                                          );
   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_FetchRQFerSCHS()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleRQFerSCHS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleRQFerSCHS (ViSession instrSession,
                                                ViReal64 *FER,
                                                ViInt32 *frameErrors,
                                                ViInt32 *elapsedFrames,
                                                ViReal64 *confidenceLev,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViInt32   numMeasValues;
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar    TempBuf[669][20];


  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[523].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   numMeasValues = RSCMU_scanStringBurst( rdBuf, TempBuf );
   RSCMU_Status  = RSCMU_ReturnFERResponse( numMeasValues
                                          , TempBuf
                                          , FER 
                                          , frameErrors 
                                          , elapsedFrames 
                                          , confidenceLev 
                                          );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_SampleRQFerSCHS()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalcRQFerSHCSMatcLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalcRQFerSCHSMatcLim (ViSession instrSession,
                                                     ViInt32 *maxFER,
                                                     ViInt32 *ConfLev,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[524].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   RSCMU_Status = RSCMU_GetMeasureMatching( maxFER,  tab, 0 );
   RSCMU_Status = RSCMU_GetMeasureMatching( ConfLev, tab, 1 );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_CalcRQFerSHCSMatcLim() 
    
  
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitSAPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitSAPow (ViSession instrSession,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;             

  // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;    
   
   // test CMU FW release   
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[399].instrCommand
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
}//end of RSCMU_CDMA2K_InitSAPow

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortSAPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortSAPow (ViSession instrSession,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
      struct RSCMU_CDMA_Globals  *p_globalvarCDMA;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;    
   
   // test CMU FW release   
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[400].instrCommand
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_AbortSAPow

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StopSAPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_StopSAPow (ViSession instrSession,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
         struct RSCMU_CDMA_Globals  *p_globalvarCDMA;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;    
   
   // test CMU FW release   
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[401].instrCommand
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
    
} //end of RSCMU_CDMA2K_StopSAPow

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ContinueSAPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueSAPow (ViSession instrSession,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
            struct RSCMU_CDMA_Globals  *p_globalvarCDMA;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;    
   
   // test CMU FW release   
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[402].instrCommand
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} // end of RSCMU_CDMA2K_ContinueSAPow

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchSAPowStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *measurementStatus
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchSAPowStatus (ViSession instrSession,
                                                ViInt32 *measurementStatus,
                                                ViInt32 *statisticCount,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;         

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;    
   
   // test CMU FW release   
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 
  
   getBuffers( instrSession         
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[403].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

       // Get the counter for current statistics cycle
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", statisticCount );
       }
       else
       {
          *statisticCount = RSCMU_OFF;
       }
   }

   return RSCMU_Status;
          
    
}//end of RSCMU_CDMA2K_FetchSAPowStatus

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfSAPowErrReporting
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSAPowErrReporting (ViSession instrSession,
                                                     ViInt32 reportMode,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
      struct RSCMU_CDMA_Globals  *p_globalvarCDMA;         

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;    
   
   // test CMU FW release   
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 
   
   
   checkRange( 398, &reportMode );

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[398].instrCommand
          , eventReport.list[reportMode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfSAPowErrReporting

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadScalSAPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *currAveSAPower_dBm, *currMinSAPower_dBm, *currMaxSAPower_dBm,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalSAPow (ViSession instrSession,
                                             ViReal64 *standby_Power,
                                             ViReal64 *access_Probe_Power,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   struct    RSCMU_CDMA_Globals  *p_globalvarCDMA;  

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;    
   
   // test CMU FW release   
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 
    
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage                                                  
             );
                
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[404].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                      
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", standby_Power );
   }
   else
   {
      *standby_Power = RSCMU_NAN;
   }

   // Get access probe power
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", access_Probe_Power );
   }
   else
   {
      *access_Probe_Power = RSCMU_NAN;
   }

  
   return( RSCMU_Status );
    
}// end of RSCMU_CDMA2K_ReadScalSAPow

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchScalSAPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *currAveSAPower_dBm, *currMinSAPower_dBm, *currMaxSAPower_dBm,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalSAPow (ViSession instrSession,
                                             ViReal64 *standby_Power,
                                             ViReal64 *access_Probe_Power,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   struct    RSCMU_CDMA_Globals  *p_globalvarCDMA;    

   // Get the global structure
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;    
   
   // test CMU FW release   
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 
   

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage                                                  
             );
                
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[405].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                      
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", standby_Power );
   }
   else
   {
      *standby_Power = RSCMU_NAN;
   }

   // Get access probe power
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", access_Probe_Power );
   }
   else
   {
      *access_Probe_Power = RSCMU_NAN;
   }
   

   return( RSCMU_Status );
    
    
}//end of RSCMU_CDMA2K_FetchScalSAPow

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleScalSAPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *currAveSAPower_dBm, *currMinSAPower_dBm, *currMaxSAPower_dBm,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalSAPow (ViSession instrSession,
                                                ViReal64 *standby_Power,
                                                ViReal64 *access_Probe_Power,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   struct    RSCMU_CDMA_Globals  *p_globalvarCDMA;  

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;    
   
   // test CMU FW release   
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_07)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_07, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage                                                  
             );
                
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[406].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                      
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", standby_Power );
   }
   else
   {
      *standby_Power = RSCMU_NAN;
   }

   // Get access probe power
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", access_Probe_Power );
   }
   else
   {
      *access_Probe_Power = RSCMU_NAN;
   }

   return( RSCMU_Status );
    
    
}//end of RSCMU_CDMA2K_SampleScalSAPow
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowOLTRespIBSPow
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTRespIBSPow( ViSession instrSession
                                  , ViReal64  initialBSPowerdBm
                                  , ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 417, &initialBSPowerdBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[417].instrCommand
          , initialBSPowerdBm
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ConfPowOLTRespIBSPow()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowOLTRespPowStep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTRespPowStep( ViSession instrSession
                                   , ViReal64  BSPowerStepdBm
                                   , ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 418, &BSPowerStepdBm );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[418].instrCommand
          , BSPowerStepdBm
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
        
} // end of RSCMU_CDMA2K_ConfPowOLTRespPowStep()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowOLTRespPStepDir
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTRespPStepDir( ViSession instrSession
                                    , ViInt32   BSPowerStepDirection
                                    , ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 419, &BSPowerStepDirection );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[419].instrCommand
          , powerDir.list[BSPowerStepDirection]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
            
} // end of RSCMU_CDMA2K_ConfPowOLTRespPStepDir()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowOLTRespLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTRespLev( ViSession instrSession
                               , ViReal64  trafficLeveldB
                               , ViReal64  pilotLeveldB
                               , ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 414, &trafficLeveldB, &pilotLeveldB );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[414].instrCommand
          , trafficLeveldB
          , pilotLeveldB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
     
} // end of RSCMU_CDMA2K_ConfPowOLTRespLev()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowOLTRContFratFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      frameRate
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTRContFratFFCH (ViSession instrSession,
                                                        ViInt32 frameRate,
                                                        ViChar errorMessage[])
{
 ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);      
  
   checkRange( 646, &frameRate );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[646].instrCommand
          , frameRateType.list[frameRate] 
          );
/*
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
*/
   
        RSCMU_Status    = RSCMU_CDMA_errorMessage( instrSession, RSCMU_WARNING_GPIB_FEATURE, errorMessage );
        return( RSCMU_Status);

   
}//end of RSCMU_CDMA2K_ConfPowOLTRContFratFFCH

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalPowOLTREbntFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     calculatedEbNtFCH
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalPowOLTREbntFFCH (ViSession instrSession,
                                                   ViReal64 *calculatedEbNtFFCH,
                                                   ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];   
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *) CDMA[645].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", calculatedEbNtFFCH );
   }
   else
   {
      *calculatedEbNtFFCH = RSCMU_NAN;
   }

   return RSCMU_Status;      
}//end of RSCMU_CDMA2K_CalPowOLTREbntFFCH

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefPowOLTResp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowOLTResp( ViSession instrSession
                           , ViBoolean state
                           , ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 415, &state );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[415].instrCommand
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
         
} // end of RSCMU_CDMA2K_DefPowOLTResp()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowOLTRContImpair
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      AWGNleveldB, BSFreqOffsetkHz,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTRContImpair (ViSession instrSession,
                                                      ViReal64 AWGNleveldB,
                                                      ViBoolean AWGNEnable, 
                                                      ViReal64 BSFreqOffsetkHz,
                                                      ViBoolean BSFreqOffsetEnable,    
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 416, &AWGNleveldB, &BSFreqOffsetkHz);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[416].instrCommand
          , AWGNleveldB  
          , BSFreqOffsetkHz   
          , enable.list[AWGNEnable]
          , enable.list[BSFreqOffsetEnable]        
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ConfPowMinOutContImpair 


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchPowOLTimeRespStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchPowOLTimeRespStatus ( ViSession  instrSession
                                       , ViInt32   *measurementStatus
                                       , ViInt32   *counterforStatCycle
                                       , ViInt32   *counterforEvalPeriod
                                       , ViChar     errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the measurement status:
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[412].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );

       // Get the counter for current statistics cycle
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", counterforStatCycle );
       }
       else
       {
          *counterforStatCycle = RSCMU_NONE;
       }

       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", counterforEvalPeriod );
       }
       else
       {
          *counterforEvalPeriod = RSCMU_NONE;
       }
   }

   return RSCMU_Status;
          
} // end of RSCMU_CDMA2K_FetchPowOLTimeRespStatus()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowOLTimeRespEReport
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTimeRespEReport ( ViSession instrSession
                                       , ViInt32   measurementEventReporting
                                       , ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 413, &measurementEventReporting );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[413].instrCommand
          , eventReport.list[measurementEventReporting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
        
} // end of RSCMU_CDMA2K_ConfPowOLTimeRespEReport() 

/*****************************************************************************
 * Function: State
 * Purpose:  This function enables or disables the environment for the Open 
 *           Loop Time Response measurement application.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTEnvEnab (ViSession instrSession,
                                                  ViBoolean enable,
                                                  ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:POW:OLTR:ENV:ENAB",
                           enable,
                           stateArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: CDMA Output Power
 * Purpose:  This function determines the total CDMA output power (absolute 
 *           value, in dBm) of the CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTEnvPowCdma (ViSession instrSession,
                                                     ViReal64 CDMAPower,
                                                     ViChar errorMessage[])
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                               "CONF:POW:OLTR:ENV:POW:CDMA",
                               CDMAPower,
                               -120.0, 7.0,
                               VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Level
 * Purpose:  This function determines the level in the selected channel of the 
 *           CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTEnvLev (ViSession instrSession,
                                                 ViInt32 channel,
                                                 ViBoolean state, ViReal64 level,
                                                 ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, channel, 0, 3, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:POW:OLTR:ENV:LEV:%s",
             channelArr [channel]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                state,
                                stateArr,
                                VI_ERROR_PARAMETER3));

    if (state)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    level,
                                    -20.0, -7.0,
                                    VI_ERROR_PARAMETER4));
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Calculated EbNt FFCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the forward FCH. This quantity is undefined unless the AWGN 
 *           generator is turned on.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowOLTEnvEbntFfch (ViSession instrSession,
                                                      ViReal64 *calculatedEbNtFFCH,
                                                      ViChar errorMessage[])
{
    RETMSG (RSCMU_getViReal64 (instrSession,
                               "CALC:POW:OLTR:ENV:EBNT:FFCH?",
                               calculatedEbNtFFCH,
                               VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Calculated EbNt FSCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the selected forward SCH channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowOLTEnvEbntFsch (ViSession instrSession,
                                                      ViInt32 forwardSCH,
                                                      ViReal64 *calculatedEbNtFSCH,
                                                      ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, forwardSCH, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CALC:POW:OLTR:ENV:EBNT:FSCH:%s?",
             schArr[forwardSCH]);
    RETMSG (RSCMU_getViReal64 (instrSession,
                               command,
                               calculatedEbNtFSCH,
                               VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Impairments
 * Purpose:  This function determines an Additional White Gaussian Noise 
 *           level, a frequency offset to impair the CMU output signal and 
 *           injected Tx FER.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTEnvImpairment (ViSession instrSession,
                                                        ViReal64 AWGN_level_dB,
                                                        ViBoolean AWGNEnable,
                                                        ViReal64 BSFreqOffset_kHz,
                                                        ViBoolean BSFreqEnable,
                                                        ViReal64 txFER,
                                                        ViBoolean txFEREnable,
                                                        ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:POW:OLTR:ENV:IMP:LEVel:AWGN",
                                AWGNEnable,
                                stateArr,
                                VI_ERROR_PARAMETER3));

    if (AWGNEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:POW:OLTR:ENV:IMP:LEVel:AWGN",
                                    AWGN_level_dB,
                                    -20.0, 4.0,
                                    VI_ERROR_PARAMETER2));
    }

    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:POW:OLTR:ENV:IMP:FOFF",
                                BSFreqEnable,
                                stateArr,
                                VI_ERROR_PARAMETER5));

    if (BSFreqEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:POW:OLTR:ENV:IMP:FOFF",
                                    BSFreqOffset_kHz,
                                    -5.0E+3, 5.0E+3,
                                    VI_ERROR_PARAMETER4));
    }

    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:POW:OLTR:ENV:IMP:ITF",
                                txFEREnable,
                                stateArr,
                                VI_ERROR_PARAMETER7));
    if (txFEREnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:POW:OLTR:ENV:IMP:ITF",
                                    txFER,
                                    0.0, 50.0,
                                    VI_ERROR_PARAMETER6));
    }
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Power Control Bits
 * Purpose:  This function queries the power control bit sequence that the CMU 
 *           sends to the mobile station to control its output power.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowOLTEnvPCBits (ViSession instrSession,
                                                    ViInt32 *powerControlBits,
                                                    ViChar errorMessage[])
{
    RETMSG (RSCMU_getEnum (instrSession,
                           "CONF:POW:OLTR:ENV:PCB?",
                           powerControlBits,
                           PCBArr,
                           VI_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitPowOLTimeResponse
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_InitPowOLTimeResponse( ViSession instrSession
                                   , ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[408].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_InitPowOLTimeResponse()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortPowOLTimeResponse
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_AbortPowOLTimeResponse( ViSession instrSession
                                    , ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[409].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

       
} // end of RSCMU_CDMA2K_AbortPowOLTimeResponse()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StopPowOLTimeResponse
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_StopPowOLTimeResponse( ViSession instrSession
                                   , ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[410].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
       
} // end of RSCMU_CDMA2K_StopPowOLTimeResponse()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ContPowOLTimeResponse
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ContPowOLTimeResponse( ViSession instrSession
                                   , ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[411].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
        
} // end of RSCMU_CDMA2K_ContPowOLTimeResponse()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchScalPowOLResp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalPowOLResp( ViSession  instrSession
                                , ViReal64  *initialMSPowerdBm
                                , ViReal64  *initialBSPowerdBm
                                , ViReal64  *currentBSPowerdBm
                                , ViInt32   *limitLinesMatching
                                , ViChar     errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[421].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get initial mobile station power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", initialMSPowerdBm );
   }
   else
   {
      *initialMSPowerdBm = RSCMU_NAN;
   }

   // Get initial base station power
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", initialBSPowerdBm );
   }
   else
   {
      *initialBSPowerdBm = RSCMU_NAN;
   }

   // Get current base station power
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", currentBSPowerdBm );
   }
   else
   {
      *currentBSPowerdBm = RSCMU_NAN;
   }

   // Get limit lines matching state
   if( strcmp( tab[3], "NMAL" ) == 0 )
   {
      *limitLinesMatching = RSCMU_NMAL;
   }
   else if( strcmp( tab[3], "NMAU" ) == 0 )
   {
      *limitLinesMatching = RSCMU_NMAU;
   }
   else if( strcmp( tab[3], "MATC" ) == 0 )
   {
      *limitLinesMatching = RSCMU_OK;
   } 
   else 
   {
      *limitLinesMatching = RSCMU_INV;
   }

   return( RSCMU_Status );
      
} // end of RSCMU_CDMA2K_FetchScalPowOLResp()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleScalPowOLResp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalPowOLResp( ViSession  instrSession
                                 , ViReal64  *initialMSPowerdBm
                                 , ViReal64  *initialBSPowerdBm
                                 , ViReal64  *currentBSPowerdBm
                                 , ViInt32   *limitLinesMatching
                                 , ViChar     errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[422].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get initial mobile station power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", initialMSPowerdBm );
   }
   else
   {
      *initialMSPowerdBm = RSCMU_NAN;
   }

   // Get initial base station power
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", initialBSPowerdBm );
   }
   else
   {
      *initialBSPowerdBm = RSCMU_NAN;
   }

   // Get current base station power
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", currentBSPowerdBm );
   }
   else
   {
      *currentBSPowerdBm = RSCMU_NAN;
   }

   // Get limit lines matching state
   if( strcmp( tab[3], "NMAL" ) == 0 )
   {
      *limitLinesMatching = RSCMU_NMAL;
   }
   else if( strcmp( tab[3], "NMAU" ) == 0 )
   {
      *limitLinesMatching = RSCMU_NMAU;
   }
   else if( strcmp( tab[3], "MATC" ) == 0 )
   {
      *limitLinesMatching = RSCMU_OK;
   } 
   else 
   {
      *limitLinesMatching = RSCMU_INV;
   }

   return( RSCMU_Status );
      
} // end of RSCMU_CDMA2K_SampleScalPowOLResp()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadScalPowOLResp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalPowOLResp( ViSession  instrSession
                               , ViReal64  *initialMSPowerdBm
                               , ViReal64  *initialBSPowerdBm
                               , ViReal64  *currentBSPowerdBm
                               , ViInt32   *limitLinesMatching
                               , ViChar     errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[420].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get initial mobile station power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", initialMSPowerdBm );
   }
   else
   {
      *initialMSPowerdBm = RSCMU_NAN;
   }

   // Get initial base station power
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", initialBSPowerdBm );
   }
   else
   {
      *initialBSPowerdBm = RSCMU_NAN;
   }

   // Get current base station power
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", currentBSPowerdBm );
   }
   else
   {
      *currentBSPowerdBm = RSCMU_NAN;
   }

   // Get limit lines matching state
   if( strcmp( tab[3], "NMAL" ) == 0 )
   {
      *limitLinesMatching = RSCMU_NMAL;
   }
   else if( strcmp( tab[3], "NMAU" ) == 0 )
   {
      *limitLinesMatching = RSCMU_NMAU;
   }
   else if( strcmp( tab[3], "OK" ) == 0 )
   {
      *limitLinesMatching = RSCMU_OK;
   } 
   else if( strcmp( tab[3], "MATC" ) == 0 )
   {
      *limitLinesMatching = RSCMU_OK;
   } 
   else 
   {
      *limitLinesMatching = RSCMU_INV;
   }

   return( RSCMU_Status );
    
} // end of RSCMU_CDMA_ReadScalPowOLResp()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadArrayPowOLResp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

// JMG 020930
ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrayPowOLResp( ViSession instrSession
                                , ViReal64  burstPower[]
                                , ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   // JMG 020923
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA; 

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[423].instrCommand
          );

   
    RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     );

    RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , burstPower
                             );


/*   
   
   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , wrtBuf
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , burstPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/
   return( RSCMU_Status );
    
} // end of RSCMU_CDMA2K_ReadArrayPowOLResp()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchArrayPowOLResp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchArrayPowOLResp( ViSession instrSession
                                 , ViReal64  burstPower[]
                                 , ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   // JMG 020923
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA; 

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );


   
   sprintf( wrtBuf
          , CDMA[424].instrCommand
          );

   
    RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     );

    RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , burstPower
                             );


/*   
   
   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , wrtBuf
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , burstPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/
   return( RSCMU_Status );
        
} // end of RSCMU_CDMA2K_FetchArrayPowOLResp()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleArrayPowOLResp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SampleArrayPowOLResp( ViSession instrSession
                                  , ViReal64  burstPower[]
                                  , ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   // JMG 020923
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA; 

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

  
   
   sprintf( wrtBuf
          , CDMA[425].instrCommand
          );

   
    RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     );

    RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , burstPower
                             );


/*   
   
   // Allocate a much larger memory block than the default.
   rdBuf = malloc( RD_BUFFER_SIZE_ARRAY );
   if( rdBuf != NULL )
   {
#if 0
      if( (RSCMU_Status = RSCMU_Query( instrSession
                                     , wrtBuf
                                     , rdBuf
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     )) < 0 )
      {
         free( rdBuf );
         return( RSCMU_Status );
      }
#else
      // Write data to the CMU
      if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }

      // Read the resulting output
      if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
      {
         free( rdBuf );
         return RSCMU_Base_errorMessage( instrSession, RSCMU_Status, errorMessage );
      }
#endif

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( rdBuf
                             , burstPower
                             );

      // Free the temporary buffer allocation.
      free( rdBuf );
   }
   else
   {
      RSCMU_Status = RSCMU_ERROR_MEMORY_ALLOCATION;
   }
*/
   return( RSCMU_Status );
        
} // end of RSCMU_CDMA2K_SampleArrayPowOLResp()



/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMinOutCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      statistics, repetition, stopCond, stepMode, signalType,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutCont (ViSession instrSession,
                                            ViInt32 statistics,
                                            ViInt32 rep, ViInt32 step,
                                            ViInt32 stopCondition,
                                            ViInt32 signaltype,
                                            ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 72, &statistics, &rep, &step, &stopCondition, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   sprintf( wrtBuf
          , CDMA[72].instrCommand
          , signalType.list[signaltype]
          , statistics
          , repetition.list[rep]
          , stopCond3.list[stopCondition]
          , stepMode.list[step] 
          );
   
    RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   

   return( RSCMU_Status );
    
}//end of RSCMU_CDMA2K_ConfPowMinOutCont ()


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMinOutContStats
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      statistics, signalType
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutContStats (ViSession instrSession,
                                                 ViInt32 statistics,
                                                 ViInt32 signaltype,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 73, &statistics, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[73].instrCommand
          , signalType.list[signaltype]
          , statistics
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfPowMinOutContStats

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMinOutContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      rep_On, repetition, stopCondition, stepMode, signalType,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutContRep (ViSession instrSession,
                                               ViInt32 rep,
                                               ViInt32 stopCondition,
                                               ViInt32 step,
                                               ViInt32 signaltype,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 74, &rep, &step, &stopCondition, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[74].instrCommand   
          , signalType.list[signaltype]
          , repetition.list[rep]
          , stopCond3.list[stopCondition]
          , stepMode.list[step]
          );
   
   

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
}//end of RSCMU_CDMA2K_ConfPowMinOutContRep


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMinOutLev 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      CDMAPowerdBm, FCHLeveldB, pilotLeveldB, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutLev (ViSession instrSession,
                                           ViReal64 CDMAPowerdBm,
                                           ViReal64 FCHLeveldB,
                                           ViReal64 pilotLeveldB,
                                           ViInt32 signaltype,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 75
             , &CDMAPowerdBm
             , &FCHLeveldB
             , &pilotLeveldB
             , &signalType
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[75].instrCommand
          , signalType.list[signaltype]
          , CDMAPowerdBm
          , FCHLeveldB
          , pilotLeveldB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ConfPowMinOutLev

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMinOutContPowCDMA
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      CDMA_On, CDMA, stopCondition, stepMode, signalType,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutContPowCDMA (ViSession instrSession,
                                                   ViReal64 CDMAPower,
                                                   ViInt32 signaltype,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 76, &CDMAPower, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

  
    sprintf( wrtBuf
          , CDMA[76].instrCommand
          , signalType.list[signaltype]
          , CDMAPower
          );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
}//end of RSCMU_CDMA2K_ConfPowMinOutContPowCDMA

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMinOutContLev 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      FCHLevel, pilotLevel, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutContLev (ViSession instrSession,
                                               ViReal64 FCHLeveldB,
                                               ViReal64 pilotLeveldB,
                                               ViInt32 signaltype,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 77
             , &FCHLeveldB
             , &pilotLeveldB
             , &signalType
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[77].instrCommand
          , signalType.list[signaltype]
          , FCHLeveldB
          , pilotLeveldB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ConfPowMinOutContLev

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMinOutContImpair
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      AWGNleveldB, BSFreqOffsetkHz,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutContImpair (ViSession instrSession,
                                                      ViReal64 AWGNleveldB,
                                                      ViBoolean AWGNEnable, 
                                                      ViReal64 BSFreqOffsetkHz,
                                                      ViBoolean BSFreqOffsetEnable,    
                                                      ViInt32 signaltype,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 78
             , &AWGNleveldB
             , &BSFreqOffsetkHz
             , &signalType
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[78].instrCommand
          , signalType.list[signaltype]
          , AWGNleveldB  
          , BSFreqOffsetkHz   
          , signalType.list[signaltype] 
          , enable.list[AWGNEnable]
          , enable.list[BSFreqOffsetEnable]

          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ConfPowMinOutContImpair 
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMinContFratFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signalType, frameRate 
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinContFratFFCH (ViSession instrSession,
                                                       ViInt32 signaltype,
                                                       ViInt32 frameRate,
                                                       ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);      
  
   checkRange( 631, &signaltype,&frameRate );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[631].instrCommand
          , signalType.list[signaltype]
          , frameRateType.list[frameRate] 
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );            
}//end of RSCMU_CDMA2K_ConfPowMinContFratFFCH
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalPowMinEbntFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      defaultSetting, signalType 
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalPowMinEbntFFCH (ViSession instrSession,
                                                  ViInt32 signaltype,
                                                  ViReal64 *calculatedEbNtFFCH,
                                                  ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];   
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   checkRange( 630, &signalType);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[630].instrCommand
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", calculatedEbNtFFCH );
   }
   else
   {
      *calculatedEbNtFFCH = RSCMU_NAN;
   }

   return RSCMU_Status;          
}//end of RSCMU_CDMA2K_CalPowMinEbntFFCH

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefPowMinOutCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      defaultSetting, signalType 
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowMinOutCont (ViSession instrSession,  
                                           ViInt32 defaultSetting,          
                                           ViInt32 signaltype,          
                                           ViChar errorMessage[])       
{  
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 79, &defaultSetting, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[79].instrCommand
          , signalType.list[signaltype]
          , modeEnable.list[defaultSetting]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
                                                                        
} //end of RSCMU_CDMA2K_DefPowMinOutCont                                                                      

/*****************************************************************************
 * Function: State
 * Purpose:  This function enables or disables the environment for the Min. 
 *           Power measurement applications.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinEnvEnab (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViBoolean enable,
                                                  ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:POW:MIO%s:ENV:ENAB",
             signalTypeArr[signalType]);
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           enable,
                           stateArr,
                           VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: CDMA Output Power
 * Purpose:  This function determines the total CDMA output power (absolute 
 *           value, in dBm) of the CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinEnvPowCdma (ViSession instrSession,
                                                     ViInt32 signalType,
                                                     ViReal64 CDMAPower,
                                                     ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:POW:MIO%s:ENV:POW:CDMA",
             signalTypeArr[signalType]);
    RETMSG (RSCMU_setViReal64 (instrSession,
                               command,
                               CDMAPower,
                               -120.0, 7.0,
                               VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Level
 * Purpose:  This function determines the level in the selected channel of the 
 *           CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinEnvLev (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViInt32 channel,
                                                 ViBoolean state, ViReal64 level,
                                                 ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, channel, 0, 3, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:POW:MIO%s:ENV:LEV:%s", signalTypeArr [signalType],
             channelArr [channel]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                state,
                                stateArr,
                                VI_ERROR_PARAMETER4));

    if (state)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    level,
                                    -20.0, -7.0,
                                    VI_ERROR_PARAMETER5));
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Calculated EbNt FFCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the forward FCH.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowMinEnvEbntFfch (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViReal64 *calculatedEbNtFFCH,
                                                      ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CALC:POW:MIO%s:ENV:EBNT:FFCH?",
             signalTypeArr[signalType]);
    RETMSG (RSCMU_getViReal64 (instrSession,
                               command,
                               calculatedEbNtFFCH,
                               VI_ERROR_PARAMETER4));
}

/*****************************************************************************
 * Function: Calculated EbNt FSCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the selected forward SCH channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowMinEnvEbntFsch (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViInt32 forwardSCH,
                                                      ViReal64 *calculatedEbNtFSCH,
                                                      ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, forwardSCH, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    
    sprintf (command, "CALC:POW:MIO%s:ENV:EBNT:FSCH:%s?",
             signalTypeArr[signalType],
             schArr[forwardSCH]);
    RETMSG (RSCMU_getViReal64 (instrSession,
                               command,
                               calculatedEbNtFSCH,
                               VI_ERROR_PARAMETER4));
}

/*****************************************************************************
 * Function: Frame Rate
 * Purpose:  This function sets the frame rate for the variable rate traffic 
 *           channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinEnvFratFfch (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViInt32 frameRate,
                                                      ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:POW:MIO%s:ENV:FRAT:FFCH", signalTypeArr [signalType]);
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           frameRate,
                           frameArr,
                           VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Impairments
 * Purpose:  This function determines an Additional White Gaussian Noise 
 *           level, a frequency offset to impair the CMU output signal and 
 *           injected Tx FER.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinEnvImpairment (ViSession instrSession,
                                                        ViInt32 signalType,
                                                        ViReal64 AWGN_level_dB,
                                                        ViBoolean AWGNEnable,
                                                        ViReal64 BSFreqOffset_kHz,
                                                        ViBoolean BSFreqEnable,
                                                        ViReal64 txFER,
                                                        ViBoolean txFEREnable,
                                                        ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:POW:MIO%s:ENV:IMP:LEVel:AWGN", signalTypeArr [signalType]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                AWGNEnable,
                                stateArr,
                                VI_ERROR_PARAMETER4));

    if (AWGNEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    AWGN_level_dB,
                                    -20.0, 4.0,
                                    VI_ERROR_PARAMETER3));
    }

    sprintf (command, "CONF:POW:MIO%s:ENV:IMP:FOFF", signalTypeArr [signalType]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                BSFreqEnable,
                                stateArr,
                                VI_ERROR_PARAMETER6));

    if (BSFreqEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    BSFreqOffset_kHz,
                                    -5.0E+3, 5.0E+3,
                                    VI_ERROR_PARAMETER5));
    }

    sprintf (command, "CONF:POW:MIO%s:ENV:IMP:ITF", signalTypeArr [signalType]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                txFEREnable,
                                stateArr,
                                VI_ERROR_PARAMETER8));
    if (txFEREnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    txFER,
                                    0.0, 50.0,
                                    VI_ERROR_PARAMETER7));
    }
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Power Control Bits
 * Purpose:  This function queries the power control bit sequence that the CMU 
 *           sends to the mobile station to control its output power.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinEnvPCBits (ViSession instrSession,
                                                    ViInt32 signalType,
                                                    ViInt32 *powerControlBits,
                                                    ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:POW:MIO%s:ENV:PCB?", signalTypeArr [signalType]);
    RETMSG (RSCMU_getEnum (instrSession,
                           command,
                           powerControlBits,
                           PCBArr,
                           VI_ERROR_PARAMETER3));
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMinOutLimAsymVal
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      absolutMinPower, waveFormQuality, signalType 
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutLimAsymVal (ViSession instrSession,
                                                  ViReal64 absolutMinPower,
                                                  ViReal64 waveFormQuality,
                                                  ViInt32 signaltype,
                                                  ViChar errorMessage[])
{   
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 80, &absolutMinPower, &waveFormQuality, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[80].instrCommand
          , signalType.list[signaltype]
          , absolutMinPower
          , waveFormQuality
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
}//end of RSCMU_CDMA2K_ConfPowMinOutLimAsymVal

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefPowMinOutLimits
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      defaultSetting, signalType,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowMinOutLimits (ViSession instrSession,
                                             ViInt32 defaultSetting,
                                             ViInt32 signaltype,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 81, &defaultSetting, &signalType );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[81].instrCommand
          , signalType.list[signaltype]
          , modeEnable.list[defaultSetting]  
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
} //end of RSCMU_CDMA2K_DefPowMinOutLimits

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_InitPowMinOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signalType,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_InitPowMinOut (ViSession instrSession,
                                        ViInt32 signaltype,
                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 82, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[82].instrCommand
          , signalType.list[signaltype]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_InitPowMinOut

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_AbortPowMinOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signalType,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_AbortPowMinOut (ViSession instrSession,
                                         ViInt32 signaltype,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 83, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[83].instrCommand
          , signalType.list[signaltype]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
    
}//end of RSCMU_CDMA2K_AbortPowMinOut


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StopPowMinOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signalType,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_StopPowMinOut (ViSession instrSession,
                                        ViInt32 signaltype,
                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 84, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[84].instrCommand
          , signalType.list[signaltype]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_StopPowMinOut


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ContinuePowMinOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signalType,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ContinuePowMinOut (ViSession instrSession,
                                            ViInt32 signaltype,
                                            ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 85, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[85].instrCommand
          , signalType.list[signaltype]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ContinuePowMinOut

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchPowMinOutStatus 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      measStatus, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchPowMinOutStatus (ViSession instrSession,
                                               ViInt32 *measurementStatus,
                                               ViInt32 *CurrentStatCycleCount,
                                               ViInt32 *CurrentEvaluationPeriod,
                                               ViInt32 signaltype,   
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   checkRange( 86, &signaltype ); 
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[86].instrCommand
          , signalType.list[signaltype]
          );
  
   
   
   // Fetch the measurement status:
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             /*, (ViChar *)CDMA[256].instrCommand   */
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );
          
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", CurrentStatCycleCount );
       }
       else
       {
          *CurrentStatCycleCount = RSCMU_OFF;
       }
       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", CurrentEvaluationPeriod );
       }
       else
       {
          *CurrentEvaluationPeriod = RSCMU_OFF;
       }
      
   }


   return RSCMU_Status;
          
}//end of RSCMU_CDMA2K_FetchPowMinOutStatus


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMinOutErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      measurementEventReporting, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMinOutErep (ViSession instrSession,
                                            ViInt32 measurementEventReporting,
                                            ViInt32 signaltype,
                                            ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 87, &measurementEventReporting, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[87].instrCommand
          , signalType.list[signaltype]
          , eventReport.list[measurementEventReporting]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
} //end of RSCMU_CDMA2K_ConfPowMinOutErep



/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ReadScalPowMinOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      *totalPowerCurr_dBm, *totalPowerAve_dBm, *totalPowerMin_dBm,
                *totalPowerMax_dBm,  *waveformQualCurr,  *waveformQualAve,
                *waveformQualMin,    *waveformQualMax,   *measurement_out_ofTolerance,
                signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalPowMinOut (ViSession instrSession,
                                            ViReal64 *totalPowerCurr,
                                            ViReal64 *totalPowerAve,
                                            ViReal64 *totalPowerMin,
                                            ViReal64 *totalPowerMax,
                                            ViReal64 *waveformQualCurr,
                                            ViReal64 *waveformQualAve,
                                            ViReal64 *waveformQualMin,
                                            ViReal64 *waveformQualMax,
                                            ViReal64 *measurementTol,
                                            ViInt32 signaltype,
                                            ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   sprintf( wrtBuf
          , CDMA[88].instrCommand
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );    
                       
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get total power current
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", totalPowerCurr );
   }
   else
   {
      *totalPowerCurr = RSCMU_NAN;
   }

   // Get total power average
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", totalPowerAve );
   }
   else
   {
      *totalPowerAve = RSCMU_NAN;
   }

   // Get total power minimum
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", totalPowerMin );
   }
   else
   {
      *totalPowerMin = RSCMU_NAN;
   }

   // Get total power maximum
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", totalPowerMax );
   }
   else
   {
      *totalPowerMax = RSCMU_NAN;
   }
   
   // Get waveform quality current
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", waveformQualCurr );
   }
   else
   {
      *waveformQualCurr = RSCMU_NAN;
   }
   
   // Get waveform quality average
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", waveformQualAve );
   }
   else
   {
      *waveformQualAve = RSCMU_NAN;
   }

   // Get waveform quality minimum
   if( strcmp( tab[6], "NAN" ) != 0 )
   {
      sscanf( tab[6], "%lf", waveformQualMin );
   }
   else
   {
      *waveformQualMin = RSCMU_NAN;
   }
   
   // Get waveform quality maximum
   if( strcmp( tab[7], "NAN" ) != 0 )
   {
      sscanf( tab[7], "%lf", waveformQualMax );
   }
   else
   {
      *waveformQualMax = RSCMU_NAN;
   }
   
   // Get measurement out of tolerance
   if( strcmp( tab[8], "NAN" ) != 0 )
   {
      sscanf( tab[8], "%lf", measurementTol );
   }
   else
   {
      *measurementTol = RSCMU_NAN;
   }

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ReadScalPowMinOut


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_FetchScalPowMinOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      *totalPowerCurr_dBm, *totalPowerAve_dBm, *totalPowerMin_dBm,
                *totalPowerMax_dBm,  *waveformQualCurr,  *waveformQualAve,
                *waveformQualMin,    *waveformQualMax,   *measurement_out_ofTolerance,
                signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalPowMinOut (ViSession instrSession,
                                             ViReal64 *totalPowerCurr,
                                             ViReal64 *totalPowerAve,
                                             ViReal64 *totalPowerMin,
                                             ViReal64 *totalPowerMax,
                                             ViReal64 *waveformQualCurr,
                                             ViReal64 *waveformQualAve,
                                             ViReal64 *waveformQualMin,
                                             ViReal64 *waveformQualMax,
                                             ViReal64 *measurementTol,
                                             ViInt32 signaltype,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];             

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   sprintf( wrtBuf
          , CDMA[89].instrCommand
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             /*, (ViChar *)CDMA[94].instrCommand */
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get total power current
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", totalPowerCurr );
   }
   else
   {
      *totalPowerCurr = RSCMU_NAN;
   }

   // Get total power average
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", totalPowerAve );
   }
   else
   {
      *totalPowerAve = RSCMU_NAN;
   }

   // Get total power minimum
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", totalPowerMin );
   }
   else
   {
      *totalPowerMin = RSCMU_NAN;
   }

   // Get total power maximum
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", totalPowerMax );
   }
   else
   {
      *totalPowerMax = RSCMU_NAN;
   }
   
   // Get waveform quality current
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", waveformQualCurr );
   }
   else
   {
      *waveformQualCurr = RSCMU_NAN;
   }
   
   // Get waveform quality average
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", waveformQualAve );
   }
   else
   {
      *waveformQualAve = RSCMU_NAN;
   }

   // Get waveform quality minimum
   if( strcmp( tab[6], "NAN" ) != 0 )
   {
      sscanf( tab[6], "%lf", waveformQualMin );
   }
   else
   {
      *waveformQualMin = RSCMU_NAN;
   }
   
   // Get waveform quality maximum
   if( strcmp( tab[7], "NAN" ) != 0 )
   {
      sscanf( tab[7], "%lf", waveformQualMax );
   }
   else
   {
      *waveformQualMax = RSCMU_NAN;
   }
   
   // Get measurement out of tolerance
   if( strcmp( tab[8], "NAN" ) != 0 )
   {
      sscanf( tab[8], "%lf", measurementTol );
   }
   else
   {
      *measurementTol = RSCMU_NAN;
   }

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_FetchScalPowMinOut


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SampleScalPowMinOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      *totalPowerCurr_dBm, *totalPowerAve_dBm, *totalPowerMin_dBm,
                *totalPowerMax_dBm,  *waveformQualCurr,  *waveformQualAve,
                *waveformQualMin,    *waveformQualMax,   *measurement_out_ofTolerance,
                signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalPowMinOut (ViSession instrSession,
                                             ViReal64 *totalPowerCurr,
                                             ViReal64 *totalPowerAve,
                                             ViReal64 *totalPowerMin,
                                             ViReal64 *totalPowerMax,
                                             ViReal64 *waveformQualCurr,
                                             ViReal64 *waveformQualAve,
                                             ViReal64 *waveformQualMin,
                                             ViReal64 *waveformQualMax,
                                             ViReal64 *measurementTol,
                                             ViInt32 signaltype,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];             

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   sprintf( wrtBuf
          , CDMA[90].instrCommand
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             /*, (ViChar *)CDMA[94].instrCommand */
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get total power current
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", totalPowerCurr );
   }
   else
   {
      *totalPowerCurr = RSCMU_NAN;
   }

   // Get total power average
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", totalPowerAve );
   }
   else
   {
      *totalPowerAve = RSCMU_NAN;
   }

   // Get total power minimum
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", totalPowerMin );
   }
   else
   {
      *totalPowerMin = RSCMU_NAN;
   }

   // Get total power maximum
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", totalPowerMax );
   }
   else
   {
      *totalPowerMax = RSCMU_NAN;
   }
   
   // Get waveform quality current
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", waveformQualCurr );
   }
   else
   {
      *waveformQualCurr = RSCMU_NAN;
   }
   
   // Get waveform quality average
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", waveformQualAve );
   }
   else
   {
      *waveformQualAve = RSCMU_NAN;
   }

   // Get waveform quality minimum
   if( strcmp( tab[6], "NAN" ) != 0 )
   {
      sscanf( tab[6], "%lf", waveformQualMin );
   }
   else
   {
      *waveformQualMin = RSCMU_NAN;
   }
   
   // Get waveform quality maximum
   if( strcmp( tab[7], "NAN" ) != 0 )
   {
      sscanf( tab[7], "%lf", waveformQualMax );
   }
   else
   {
      *waveformQualMax = RSCMU_NAN;
   }
   
   // Get measurement out of tolerance
   if( strcmp( tab[8], "NAN" ) != 0 )
   {
      sscanf( tab[8], "%lf", measurementTol );
   }
   else
   {
      *measurementTol = RSCMU_NAN;
   }

   return( RSCMU_Status );  
}// end of RSCMU_CDMA2K_SampleScalPowMinOut

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalcScalPowMinOutMAtcLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signaltype
 *
 * OUTPUTS:     *totalPowerCurr_dBm, *totalPowerAve_dBm, *totalPowerMin_dBm,
 *
 *              *totalPowerMax_dBm,  *waveformQualCurr,  *waveformQualAve,
 *              *waveformQualMin,    *waveformQualMax,   
 *              
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalPowMinOutMAtcLim (ViSession instrSession,
                                                   ViInt32 *totalPowerCurr,
                                                   ViInt32 *totalPowerAve,
                                                   ViInt32 *totalPowerMin,
                                                   ViInt32 *totalPowerMax,
                                                   ViInt32 *waveformQualCurr,
                                                   ViInt32 *waveformQualAve,
                                                   ViInt32 *waveformQualMin,
                                                   ViInt32 *waveformQualMax,
                                                   ViInt32 signaltype,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];             

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   sprintf( wrtBuf
          , CDMA[91].instrCommand
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // totalPowerCurrent
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[0]
                                       , totalPowerCurr
                                       );
   // totalPowerAverage
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[1]
                                       , totalPowerAve
                                       );
   //totalPowerMax
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[2]
                                       , totalPowerMin
                                       );   
   //totalPowerMin
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[3]
                                       , totalPowerMax
                                       );   
      // waveformQualCurr
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[4]
                                       , waveformQualCurr
                                       );
   // waveformQualAve
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[5]
                                       , waveformQualAve
                                       );
   //waveformQualMin
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[6]
                                       , waveformQualMin
                                       );   
   //waveformQualMax
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[7]
                                       , waveformQualMax
                                       ); 
   return( RSCMU_Status );  
}//end of CalcScalPowMinOutMAtcLim 

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMaxOutCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      statistics, rep, stopCondition, step, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutCont (ViSession instrSession,
                                            ViInt32 statistics,
                                            ViInt32 rep,
                                            ViInt32 stopCondition,
                                            ViInt32 step, ViInt32 signaltype,
                                            ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 92, &statistics, &rep, &step, &stopCondition, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   sprintf( wrtBuf
          , CDMA[92].instrCommand 
          , signalType.list[signaltype]
          , statistics
          , repetition.list[rep]
          , stopCond3.list[stopCondition]
          , stepMode.list[step]
          );
   
    RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ConfPowMaxOutCont

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMaxOutContStats
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      statistics, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutContStats (ViSession instrSession,
                                                 ViInt32 statistics,
                                                 ViInt32 signaltype,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 93, &statistics, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[93].instrCommand
          , signalType.list[signaltype]
          , statistics
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
} //end of RSCMU_CDMA2K_ConfPowMaxOutContStats


/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMaxOutContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      rep, stopCondition, step, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutContRep (ViSession instrSession,
                                               ViInt32 rep,
                                               ViInt32 stopCondition,
                                               ViInt32 step,
                                               ViInt32 signaltype,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 94, &rep, &step, &stopCondition, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[94].instrCommand   
          , signalType.list[signaltype]
          , repetition.list[rep]
          , stopCond3.list[stopCondition]
          , stepMode.list[step]
          );
          
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
} //end of RSCMU_CDMA2K_ConfPowMaxOutContRep

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMaxOutLev 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      CDMAPowerdBm, FCHLeveldB, pilotLeveldB, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutLev (ViSession instrSession,
                                           ViReal64 CDMAPowerdBm,
                                           ViReal64 FCHLeveldB,
                                           ViReal64 pilotLeveldB,
                                           ViInt32 signaltype,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 95
             , &CDMAPowerdBm
             , &FCHLeveldB
             , &pilotLeveldB
             , &signalType
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[95].instrCommand
          , signalType.list[signaltype]
          , CDMAPowerdBm
          , FCHLeveldB
          , pilotLeveldB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ConfPowMaxOutLev

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMaxOutContPowCDMA
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      CDMAPower, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutContPowCDMA (ViSession instrSession,
                                                   ViReal64 CDMAPower,
                                                   ViInt32 signaltype,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 96, &CDMAPower, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

  
    sprintf( wrtBuf
          , CDMA[96].instrCommand
          , signalType.list[signaltype]
          , CDMAPower
          );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
}//end of RSCMU_CDMA2K_ConfPowMaxOutContPowCDMA

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMaxOutContLev 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      CDMAPower, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutContLev (ViSession instrSession,
                                               ViReal64 FCHLeveldB,
                                               ViReal64 pilotLeveldB,
                                               ViInt32 signaltype,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 97
             , &FCHLeveldB
             , &pilotLeveldB
             , &signalType
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[97].instrCommand
          , signalType.list[signaltype]
          , FCHLeveldB
          , pilotLeveldB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
} //end of RSCMU_CDMA2K_ConfPowMaxOutContLev

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMaxOutContImpair
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      AWGN_level_dB, BSFreqOffset_kHz, signalType,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutContImpair (ViSession instrSession,
                                                      ViReal64 AWGNleveldB,
                                                      ViBoolean AWGNEnable, 
                                                      ViReal64 BSFreqOffsetkHz,
                                                      ViBoolean BSFreqOffsetEnable, 
                                                      ViInt32 signaltype,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 98
             , &AWGNleveldB
             , &BSFreqOffsetkHz
             , &signalType
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[98].instrCommand
          , signalType.list[signaltype]
          , AWGNleveldB  
          , BSFreqOffsetkHz  
          , signalType.list[signaltype]    
          , enable.list[AWGNEnable]
          , enable.list[BSFreqOffsetEnable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ConfPowMaxOutContImpair
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ConfPowMaxContFratFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signalType, frameRate, 
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxContFratFFCH (ViSession instrSession,
                                                       ViInt32 signaltype,
                                                       ViInt32 frameRate,
                                                       ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);      
  
   checkRange( 633, &signaltype,&frameRate );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[633].instrCommand
          , signalType.list[signaltype]
          , frameRateType.list[frameRate] 
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );        
} //end of RSCMU_CDMA2K_ConfPowMaxContFratFFCH
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_CalPowMaxEbntFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signalType
 *
 * OUTPUTS:     calculatedEbNtFCH
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalPowMaxEbntFFCH (ViSession instrSession,
                                                  ViInt32 signaltype,
                                                  ViReal64 *calculatedEbNtFFCH,
                                                  ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];   
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   checkRange( 632, &signaltype);
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[632].instrCommand
          , signalType.list[signaltype]
         );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", calculatedEbNtFFCH );
   }
   else
   {
      *calculatedEbNtFFCH = RSCMU_NAN;
   }

   return RSCMU_Status;      
}//end of RSCMU_CDMA2K_CalPowMaxEbntFFCH

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_DefPowMaxOutCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      defaultSetting, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowMaxOutCont (ViSession instrSession,
                                           ViInt32 defaultSetting,
                                           ViInt32 signaltype,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 99, &defaultSetting, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[99].instrCommand
          , signalType.list[signaltype]
          , modeEnable.list[defaultSetting]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
} //end of RSCMU_CDMA2K_DefPowMaxOutCont

/*****************************************************************************
 * Function: State
 * Purpose:  This function enables or disables the environment for the Max. 
 *           Power measurement applications.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxEnvEnab (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViBoolean enable,
                                                  ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:POW:MAO%s:ENV:ENAB",
             signalTypeArr[signalType]);
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           enable,
                           stateArr,
                           VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: CDMA Output Power
 * Purpose:  This function determines the total CDMA output power (absolute 
 *           value, in dBm) of the CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxEnvPowCdma (ViSession instrSession,
                                                     ViInt32 signalType,
                                                     ViReal64 CDMAPower,
                                                     ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:POW:MAO%s:ENV:POW:CDMA",
             signalTypeArr[signalType]);
    RETMSG (RSCMU_setViReal64 (instrSession,
                               command,
                               CDMAPower,
                               -120.0, 7.0,
                               VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Level
 * Purpose:  This function determines the level in the selected channel of the 
 *           CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxEnvLev (ViSession instrSession,
                                                 ViInt32 signalType,
                                                 ViInt32 channel,
                                                 ViBoolean state, ViReal64 level,
                                                 ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, channel, 0, 3, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:POW:MAO%s:ENV:LEV:%s", signalTypeArr [signalType],
             channelArr [channel]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                state,
                                stateArr,
                                VI_ERROR_PARAMETER4));

    if (state)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    level,
                                    -20.0, -7.0,
                                    VI_ERROR_PARAMETER5));
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Calculated EbNt FFCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the forward FCH.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowMaxEnvEbntFfch (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViReal64 *calculatedEbNtFFCH,
                                                      ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CALC:POW:MAO%s:ENV:EBNT:FFCH?",
             signalTypeArr[signalType]);
    RETMSG (RSCMU_getViReal64 (instrSession,
                               command,
                               calculatedEbNtFFCH,
                               VI_ERROR_PARAMETER4));
}

/*****************************************************************************
 * Function: Calculated EbNt FSCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the selected forward SCH channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowMaxEnvEbntFsch (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViInt32 forwardSCH,
                                                      ViReal64 *calculatedEbNtFSCH,
                                                      ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, forwardSCH, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    
    sprintf (command, "CALC:POW:MAO%s:ENV:EBNT:FSCH:%s?",
             signalTypeArr[signalType],
             schArr[forwardSCH]);
    RETMSG (RSCMU_getViReal64 (instrSession,
                               command,
                               calculatedEbNtFSCH,
                               VI_ERROR_PARAMETER4));
}

/*****************************************************************************
 * Function: Frame Rate
 * Purpose:  This function sets the frame rate for the variable rate traffic 
 *           channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxEnvFratFfch (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViInt32 frameRate,
                                                      ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:POW:MAO%s:ENV:FRAT:FFCH", signalTypeArr [signalType]);
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           frameRate,
                           frameArr,
                           VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Impairments
 * Purpose:  This function determines an Additional White Gaussian Noise 
 *           level, a frequency offset to impair the CMU output signal and 
 *           injected Tx FER.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxEnvImpairment (ViSession instrSession,
                                                        ViInt32 signalType,
                                                        ViReal64 AWGN_level_dB,
                                                        ViBoolean AWGNEnable,
                                                        ViReal64 BSFreqOffset_kHz,
                                                        ViBoolean BSFreqEnable,
                                                        ViReal64 txFER,
                                                        ViBoolean txFEREnable,
                                                        ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:POW:MAO%s:ENV:IMP:LEV:AWGN", signalTypeArr [signalType]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                AWGNEnable,
                                stateArr,
                                VI_ERROR_PARAMETER4));

    if (AWGNEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    AWGN_level_dB,
                                    -20.0, 4.0,
                                    VI_ERROR_PARAMETER3));
    }

    sprintf (command, "CONF:POW:MAO%s:ENV:IMP:FOFF", signalTypeArr [signalType]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                BSFreqEnable,
                                stateArr,
                                VI_ERROR_PARAMETER6));

    if (BSFreqEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    BSFreqOffset_kHz,
                                    -5.0E+3, 5.0E+3,
                                    VI_ERROR_PARAMETER5));
    }

    sprintf (command, "CONF:POW:MAO%s:ENV:IMP:ITF", signalTypeArr [signalType]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                txFEREnable,
                                stateArr,
                                VI_ERROR_PARAMETER8));
    if (txFEREnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    txFER,
                                    0.0, 50.0,
                                    VI_ERROR_PARAMETER7));
    }
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: State
 * Purpose:  This function enables or disables the environment for all Code 
 *           Domain Power measurement applications.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCEnvEnab (ViSession instrSession,
                                                     ViBoolean enable,
                                                     ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:CDP:CPCC:ENV:ENAB",
                           enable,
                           stateArr,
                           VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: CDMA Output Power
 * Purpose:  This function determines the total CDMA output power (absolute 
 *           value, in dBm) of the CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCEnvPowCdma (ViSession instrSession,
                                                        ViReal64 CDMAPower,
                                                        ViChar errorMessage[])
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                               "CONF:CDP:CPCC:ENV:POW:CDMA",
                               CDMAPower,
                               -120.0, 7.0,
                               VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Level
 * Purpose:  This function determines the level in the selected channel of the 
 *           CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCEnvLev (ViSession instrSession,
                                                    ViInt32 channel,
                                                    ViBoolean state,
                                                    ViReal64 level,
                                                    ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, channel, 0, 3, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:CDP:CPCC:ENV:LEV:%s",
             channelArr [channel]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                state,
                                stateArr,
                                VI_ERROR_PARAMETER3));

    if (state)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    level,
                                    -20.0, -1.0,
                                    VI_ERROR_PARAMETER4));
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Calculated EbNt FFCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the forward FCH.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcCDPowCpcCEnvEbntFfch (ViSession instrSession,
                                                         ViReal64 *calculatedEbNtFFCH,
                                                         ViChar errorMessage[])
{
    RETMSG (RSCMU_getViReal64 (instrSession,
                               "CALC:CDP:CPCC:ENV:EBNT:FFCH?",
                               calculatedEbNtFFCH,
                               VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Calculated EbNt FSCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the selected forward SCH channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcCDPowCpcCEnvEbntFsch (ViSession instrSession,
                                                         ViInt32 forwardSCH,
                                                         ViReal64 *calculatedEbNtFSCH,
                                                         ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, forwardSCH, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    
    sprintf (command, "CALC:CDP:CPCC:ENV:EBNT:FSCH:%s?",
             schArr[forwardSCH]);
    RETMSG (RSCMU_getViReal64 (instrSession,
                               command,
                               calculatedEbNtFSCH,
                               VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Frame Rate
 * Purpose:  This function sets the frame rate for the variable rate traffic 
 *           channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCEnvFratFfch (ViSession instrSession,
                                                         ViInt32 frameRate,
                                                         ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:CDP:CPCC:ENV:FRAT:FFCH",
                           frameRate,
                           frameArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Impairments
 * Purpose:  This function determines an Additional White Gaussian Noise 
 *           level, a frequency offset to impair the CMU output signal and 
 *           injected Tx FER.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfCDPowCpcCEnvImp (ViSession instrSession,
                                                    ViReal64 AWGN_level_dB,
                                                    ViBoolean AWGNEnable,
                                                    ViReal64 BSFreqOffset_kHz,
                                                    ViBoolean BSFreqEnable,
                                                    ViReal64 txFER,
                                                    ViBoolean txFEREnable,
                                                    ViChar errorMessage[])
{
    ViStatus RSCMU_Status;
    
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:CDP:CPCC:ENV:IMP:LEV:AWGN",
                                AWGNEnable,
                                stateArr,
                                VI_ERROR_PARAMETER4));

    if (AWGNEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:CDP:CPCC:ENV:IMP:LEV:AWGN",
                                    AWGN_level_dB,
                                    -20.0, 4.0,
                                    VI_ERROR_PARAMETER3));
    }

    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:CDP:CPCC:ENV:IMP:FOFF",
                                BSFreqEnable,
                                stateArr,
                                VI_ERROR_PARAMETER6));

    if (BSFreqEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:CDP:CPCC:ENV:IMP:FOFF",
                                    BSFreqOffset_kHz,
                                    -5.0E+3, 5.0E+3,
                                    VI_ERROR_PARAMETER5));
    }

    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:CDP:CPCC:ENV:IMP:ITF",
                                txFEREnable,
                                stateArr,
                                VI_ERROR_PARAMETER8));
    if (txFEREnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:CDP:CPCC:ENV:IMP:ITF",
                                    txFER,
                                    0.0, 50.0,
                                    VI_ERROR_PARAMETER7));
    }
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Power Control Bits
 * Purpose:  This function queries the power control bit sequence that the CMU 
 *           sends to the mobile station to control its output power.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxEnvPCBits (ViSession instrSession,
                                                    ViInt32 signalType,
                                                    ViInt32 *powerControlBits,
                                                    ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:POW:MAO%s:ENV:PCB?", signalTypeArr [signalType]);
    RETMSG (RSCMU_getEnum (instrSession,
                           command,
                           powerControlBits,
                           PCBArr,
                           VI_ERROR_PARAMETER3));
}

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowMaxOutLimAsymVal
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      absolutMaxPower, waveFormQuality, signaltype, upperLimit, lowerLimit,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutLimAsymVal (ViSession instrSession,
                                                  ViReal64 absolutMaxPower,
                                                  ViReal64 waveFormQuality,
                                                  ViInt32 signaltype,
                                                  ViReal64 upperLimit,
                                                  ViReal64 lowerLimit,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 100, &absolutMaxPower, &waveFormQuality, &signalType, &upperLimit, &lowerLimit );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[100].instrCommand
          , signalType.list[signaltype]
          , absolutMaxPower
          , upperLimit
          , lowerLimit
          , waveFormQuality
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
}//end of RSCMU_CDMA2K_ConfPowMaxOutLimAsymVal

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_DefPowMaxOutLimits
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      defaultSetting, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowMaxOutLimits (ViSession instrSession,
                                             ViInt32 defaultSetting,
                                             ViInt32 signaltype,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 101, &defaultSetting, &signalType );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[101].instrCommand
          , signalType.list[signaltype]
          , modeEnable.list[defaultSetting]  
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_DefPowMaxOutLimits

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_InitPowMaxOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_InitPowMaxOut (ViSession instrSession,
                                        ViInt32 signaltype,
                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 102, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[102].instrCommand
          , signalType.list[signaltype]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_InitPowMaxOut

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_AbortPowMaxOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_AbortPowMaxOut (ViSession instrSession,
                                         ViInt32 signaltype,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 103, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[103].instrCommand
          , signalType.list[signaltype]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_AbortPowMaxOut

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_StopPowMaxOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_StopPowMaxOut (ViSession instrSession,
                                        ViInt32 signaltype,
                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 104, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[104].instrCommand
          , signalType.list[signaltype]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
} //end of RSCMU_CDMA2K_StopPowMaxOut

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ContinuePowMaxOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ContinuePowMaxOut (ViSession instrSession,
                                            ViInt32 signaltype,
                                            ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 105, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[105].instrCommand
          , signalType.list[signaltype]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
} //end of RSCMU_CDMA2K_ContinuePowMaxOut

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_FetchPowMaxOutStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      *measurementStatus, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchPowMaxOutStatus (ViSession instrSession,
                                               ViInt32 *measurementStatus,
                                               ViInt32 *CurrentStatCycleCount,
                                               ViInt32 *CurrentEvaluationPeriod,                                               
                                               ViInt32 signaltype,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   checkRange( 106, &signaltype ); 
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[106].instrCommand
          , signalType.list[signaltype]
          );
  
   
   
   // Fetch the measurement status:
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             /*, (ViChar *)CDMA[256].instrCommand   */
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );
          
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", CurrentStatCycleCount );
       }
       else
       {
          *CurrentStatCycleCount = RSCMU_OFF;
       }
       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", CurrentEvaluationPeriod );
       }
       else
       {
          *CurrentEvaluationPeriod = RSCMU_OFF;
       }
      
   }


   return RSCMU_Status; 
}//end of RSCMU_CDMA2K_FetchPowMaxOutStatus

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowMaxOutErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      measurementEventReporting,signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowMaxOutErep (ViSession instrSession,
                                            ViInt32 measurementEventReporting,
                                            ViInt32 signaltype,
                                            ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 107, &measurementEventReporting, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[107].instrCommand
          , signalType.list[signaltype]
          , eventReport.list[measurementEventReporting]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of RSCMU_CDMA2K_ConfPowMaxOutErep


/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ReadScalPowMaxOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      *totalPowerCurr, *totalPowerAve, *totalPowerMin,
                *totalPowerMax,  *waveformQualCurr,  *waveformQualAve,
                *waveformQualMin,*waveformQualMax,   *measurementTol,
                signalype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalPowMaxOut (ViSession instrSession,
                                            ViReal64 *totalPowerCurr,
                                            ViReal64 *totalPowerAve,
                                            ViReal64 *totalPowerMin,
                                            ViReal64 *totalPowerMax,
                                            ViReal64 *waveformQualCurr,
                                            ViReal64 *waveformQualAve,
                                            ViReal64 *waveformQualMin,
                                            ViReal64 *waveformQualMax,
                                            ViReal64 *measurementTol,
                                            ViInt32 signaltype,
                                            ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   sprintf( wrtBuf
          , CDMA[108].instrCommand
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
     
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get total power current
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", totalPowerCurr );
   }
   else
   {
      *totalPowerCurr = RSCMU_NAN;
   }

   // Get total power average
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", totalPowerAve );
   }
   else
   {
      *totalPowerAve = RSCMU_NAN;
   }

   // Get total power minimum
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", totalPowerMin );
   }
   else
   {
      *totalPowerMin = RSCMU_NAN;
   }

   // Get total power maximum
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", totalPowerMax );
   }
   else
   {
      *totalPowerMax = RSCMU_NAN;
   }
   
   // Get waveform quality current
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", waveformQualCurr );
   }
   else
   {
      *waveformQualCurr = RSCMU_NAN;
   }
   
   // Get waveform quality average
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", waveformQualAve );
   }
   else
   {
      *waveformQualAve = RSCMU_NAN;
   }

   // Get waveform quality minimum
   if( strcmp( tab[6], "NAN" ) != 0 )
   {
      sscanf( tab[6], "%lf", waveformQualMin );
   }
   else
   {
      *waveformQualMin = RSCMU_NAN;
   }
   
   // Get waveform quality maximum
   if( strcmp( tab[7], "NAN" ) != 0 )
   {
      sscanf( tab[7], "%lf", waveformQualMax );
   }
   else
   {
      *waveformQualMax = RSCMU_NAN;
   }
   
   // Get measurement out of tolerance
   if( strcmp( tab[8], "NAN" ) != 0 )
   {
      sscanf( tab[8], "%lf", measurementTol );
   }
   else
   {
      *measurementTol = RSCMU_NAN;
   }
     
   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ReadScalPowMaxOut

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_FetchScalPowMaxOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      *totalPowerCurr, *totalPowerAve, *totalPowerMin,
                *totalPowerMax,  *waveformQualCurr,  *waveformQualAve,
                *waveformQualMin,*waveformQualMax,   *measurementTol,
                signalype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalPowMaxOut (ViSession instrSession,
                                             ViReal64 *totalPowerCurr,
                                             ViReal64 *totalPowerAve,
                                             ViReal64 *totalPowerMin,
                                             ViReal64 *totalPowerMax,
                                             ViReal64 *waveformQualCurr,
                                             ViReal64 *waveformQualAve,
                                             ViReal64 *waveformQualMin,
                                             ViReal64 *waveformQualMax,
                                             ViReal64 *measurementTol,
                                             ViInt32 signaltype,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];             

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   sprintf( wrtBuf
          , CDMA[109].instrCommand
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get total power current
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", totalPowerCurr );
   }
   else
   {
      *totalPowerCurr = RSCMU_NAN;
   }

   // Get total power average
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", totalPowerAve );
   }
   else
   {
      *totalPowerAve = RSCMU_NAN;
   }

   // Get total power minimum
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", totalPowerMin );
   }
   else
   {
      *totalPowerMin = RSCMU_NAN;
   }

   // Get total power maximum
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", totalPowerMax );
   }
   else
   {
      *totalPowerMax = RSCMU_NAN;
   }
   
   // Get waveform quality current
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", waveformQualCurr );
   }
   else
   {
      *waveformQualCurr = RSCMU_NAN;
   }
   
   // Get waveform quality average
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", waveformQualAve );
   }
   else
   {
      *waveformQualAve = RSCMU_NAN;
   }

   // Get waveform quality minimum
   if( strcmp( tab[6], "NAN" ) != 0 )
   {
      sscanf( tab[6], "%lf", waveformQualMin );
   }
   else
   {
      *waveformQualMin = RSCMU_NAN;
   }
   
   // Get waveform quality maximum
   if( strcmp( tab[7], "NAN" ) != 0 )
   {
      sscanf( tab[7], "%lf", waveformQualMax );
   }
   else
   {
      *waveformQualMax = RSCMU_NAN;
   }
   
   // Get measurement out of tolerance
   if( strcmp( tab[8], "NAN" ) != 0 )
   {
      sscanf( tab[8], "%lf", measurementTol );
   }
   else
   {
      *measurementTol = RSCMU_NAN;
   }

   return( RSCMU_Status );   
} //end of RSCMU_CDMA2K_FetchScalPowMaxOut


/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_SampleScalPowMaxOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      *totalPowerCurr, *totalPowerAve, *totalPowerMin,
                *totalPowerMax,  *waveformQualCurr,  *waveformQualAve,
                *waveformQualMin,*waveformQualMax,   *measurementTol,
                signalype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalPowMaxOut (ViSession instrSession,
                                              ViReal64 *totalPowerCurr,
                                              ViReal64 *totalPowerAve,
                                              ViReal64 *totalPowerMin,
                                              ViReal64 *totalPowerMax,
                                              ViReal64 *waveformQualCurr,
                                              ViReal64 *waveformQualAve,
                                              ViReal64 *waveformQualMin,
                                              ViReal64 *waveformQualMax,
                                              ViReal64 *measurementTol,
                                              ViInt32 signaltype,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];             

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   sprintf( wrtBuf
          , CDMA[110].instrCommand
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get total power current
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", totalPowerCurr );
   }
   else
   {
      *totalPowerCurr = RSCMU_NAN;
   }

   // Get total power average
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", totalPowerAve );
   }
   else
   {
      *totalPowerAve = RSCMU_NAN;
   }

   // Get total power minimum
   if( strcmp( tab[2], "NAN" ) != 0 )
   {
      sscanf( tab[2], "%lf", totalPowerMin );
   }
   else
   {
      *totalPowerMin = RSCMU_NAN;
   }

   // Get total power maximum
   if( strcmp( tab[3], "NAN" ) != 0 )
   {
      sscanf( tab[3], "%lf", totalPowerMax );
   }
   else
   {
      *totalPowerMax = RSCMU_NAN;
   }
   
   // Get waveform quality current
   if( strcmp( tab[4], "NAN" ) != 0 )
   {
      sscanf( tab[4], "%lf", waveformQualCurr );
   }
   else
   {
      *waveformQualCurr = RSCMU_NAN;
   }
   
   // Get waveform quality average
   if( strcmp( tab[5], "NAN" ) != 0 )
   {
      sscanf( tab[5], "%lf", waveformQualAve );
   }
   else
   {
      *waveformQualAve = RSCMU_NAN;
   }

   // Get waveform quality minimum
   if( strcmp( tab[6], "NAN" ) != 0 )
   {
      sscanf( tab[6], "%lf", waveformQualMin );
   }
   else
   {
      *waveformQualMin = RSCMU_NAN;
   }
   
   // Get waveform quality maximum
   if( strcmp( tab[7], "NAN" ) != 0 )
   {
      sscanf( tab[7], "%lf", waveformQualMax );
   }
   else
   {
      *waveformQualMax = RSCMU_NAN;
   }
   
   // Get measurement out of tolerance
   if( strcmp( tab[8], "NAN" ) != 0 )
   {
      sscanf( tab[8], "%lf", measurementTol );
   }
   else
   {
      *measurementTol = RSCMU_NAN;
   }

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_SampleScalPowMaxOut


/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_CalcScalPowMaxOutMatcLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      *totalPowerCurr, *totalPowerAve, *totalPowerMin,
                *totalPowerMax,  *waveformQualCurr,  *waveformQualAve,
                *waveformQualMin,*waveformQualMax,   *measurementTol,
                signalype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalPowMaxOutMatcLim (ViSession instrSession,
                                                   ViInt32 *totalPowerCurr,
                                                   ViInt32 *totalPowerAve,
                                                   ViInt32 *totalPowerMin,
                                                   ViInt32 *totalPowerMax,
                                                   ViInt32 *waveformQualCurr,
                                                   ViInt32 *waveformQualAve,
                                                   ViInt32 *waveformQualMin,
                                                   ViInt32 *waveformQualMax,
                                                   ViInt32 signaltype,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];             

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   sprintf( wrtBuf
          , CDMA[111].instrCommand
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // totalPowerCurrent
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[0]
                                       , totalPowerCurr
                                       );
   // totalPowerAverage
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[1]
                                       , totalPowerAve
                                       );
   //totalPowerMax
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[2]
                                       , totalPowerMin
                                       );   
   //totalPowerMin
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[3]
                                       , totalPowerMax
                                       );   
      // waveformQualCurr
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[4]
                                       , waveformQualCurr
                                       );
   // waveformQualAve
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[5]
                                       , waveformQualAve
                                       );
   //waveformQualMin
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[6]
                                       , waveformQualMin
                                       );   
   //waveformQualMax
   RSCMU_Status = RSCMU_MatchOneLimits( &tab[7]
                                       , waveformQualMax
                                       ); 

   return( RSCMU_Status );   
} //end of RSCMU_CDMA2K_CalcScalPowMaxOutMatcLim 


/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGatedOutCont 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      mode, statistics, rep, stopCondition, step,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutCont (ViSession instrSession,
                                              ViInt32 mode, ViInt32 statistics,
                                              ViInt32 rep,
                                              ViInt32 stopCondition,
                                              ViInt32 step,    
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 112, &mode, &statistics, &rep, &stopCondition, &step);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[112].instrCommand
          , resultMode.list[mode]
          , statistics
          , repetition.list[rep]
          , stopCond3.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ConfPowGatedOutCont

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGatedOutRmode 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      mode
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutRmode (ViSession instrSession,
                                               ViInt32 mode,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 113, &mode);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[113].instrCommand
          , resultMode.list[mode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ConfPowGatedOutRmode

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGatedOutContStats 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      statistics
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutContStats (ViSession instrSession,
                                                   ViInt32 statistics,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 114, &statistics);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[114].instrCommand
          , statistics
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ConfPowGatedOutContStats

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGatedOutContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      rep, stopCondition, step,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutContRep (ViSession instrSession,
                                                 ViInt32 rep,
                                                 ViInt32 stopCondition,
                                                 ViInt32 step,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 115, &rep, &stopCondition, &step);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[115].instrCommand
          , repetition.list[rep]
          , stopCond.list[stopCondition]
          , stepMode.list[step]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ConfPowGatedOutContRep

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfSubArrPowGateOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      mode, start, samples,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSubArrPowGateOut (ViSession instrSession,
                                               ViInt32 mode, ViReal64 start,
                                               ViInt32 samples,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 116, &mode, &start, &samples);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[116].instrCommand
          , gateMode.list[mode]
          , start * 1E-6
          , samples
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ConfSubArrPowGateOut 


/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGatedOutLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      CDMAPowerdBm, FCHLeveldB, pilotLeveldB,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutLev (ViSession instrSession,
                                             ViReal64 CDMAPowerdBm,
                                             ViReal64 FCHLeveldB,
                                             ViReal64 pilotLeveldB,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 117, &CDMAPowerdBm, &FCHLeveldB, &pilotLeveldB);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[117].instrCommand
          , CDMAPowerdBm
          , FCHLeveldB
          , pilotLeveldB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ConfPowGatedOutLev

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGatOutContPowCDMA
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      CDMAPower
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutContPowCDMA (ViSession instrSession,
                                                     ViReal64 CDMAPower,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 118, &CDMAPower);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[118].instrCommand
          , CDMAPower
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ConfPowGatOutContPowCDMA


/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGatedOutContLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     FCHLeveldB, pilotLeveldB,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutContLev (ViSession instrSession,
                                                 ViReal64 FCHLeveldB,
                                                 ViReal64 pilotLeveldB,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 119, &FCHLeveldB,&pilotLeveldB);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[119].instrCommand
          , FCHLeveldB
          , pilotLeveldB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ConfPowGatedOutContLev


/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGatOutContImpair
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     AWGNleveldB, BSFreqOffsetkHz,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutContImpair (ViSession instrSession,
                                                        ViReal64 AWGNleveldB,
                                                        ViBoolean AWGNEnable,
                                                        ViReal64 BSFreqOffsetkHz,
                                                        ViBoolean BSFreqOffsetEnable,  
                                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 120, &AWGNleveldB,&BSFreqOffsetkHz);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[120].instrCommand
          , AWGNleveldB
          , BSFreqOffsetkHz
          , enable.list[AWGNEnable]
          , enable.list[BSFreqOffsetEnable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ConfPowGatOutContImpair

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGatedOutContPCG
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     PCG
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutContPCG (ViSession instrSession,
                                                       ViInt32 PCG,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 121, &PCG);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[121].instrCommand
          , PCG
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ConfPowGatedOutContPCG
/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGoutContFratFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     defaultSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutContFratFFCH (ViSession instrSession,
                                                        ViInt32 frameRate,
                                                        ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);      
  
   checkRange( 635, &frameRate );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   if (frameRate == RSCMU_CDMA_FULL) 
   {
        RSCMU_Status = VI_INSTR_WARNING_OFFSET + 0x302L;
        strcpy(errorMessage, "test can't be performed at FULL RATE. Change RATE.");
        return( RSCMU_Status );
        
   }
   
   sprintf( wrtBuf
          , CDMA[635].instrCommand
          , frameRateType.list[frameRate] 
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of RSCMU_CDMA2K_ConfPowGoutContFratFFCH
/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_CalPowGoutEbntFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     defaultSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalPowGoutEbntFFCH (ViSession instrSession,
                                                   ViReal64 *calculatedEbNtFFCH,
                                                   ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];   
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *) CDMA[634].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get current average power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", calculatedEbNtFFCH );
   }
   else
   {
      *calculatedEbNtFFCH = RSCMU_NAN;
   }

   return RSCMU_Status;  
}//end of RSCMU_CDMA2K_CalPowGoutEbntFFCH

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_DefPowGatedOutCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     defaultSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowGatedOutCont (ViSession instrSession,
                                             ViInt32 defaultSetting,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 122, &defaultSetting);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[122].instrCommand
          , modeEnable.list[defaultSetting]      
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_DefPowGatedOutCont

/*****************************************************************************
 * Function: State
 * Purpose:  This function enables or disables the environment for the Gated 
 *           Output measurement applications.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutEnvEnab (ViSession instrSession,
                                                     ViBoolean enable,
                                                     ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:POW:GOUT:ENV:ENAB",
                           enable,
                           stateArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: CDMA Output Power
 * Purpose:  This function determines the total CDMA output power (absolute 
 *           value, in dBm) of the CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutEnvPowCdma (ViSession instrSession,
                                                        ViReal64 CDMAPower,
                                                        ViChar errorMessage[])
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                               "CONF:POW:GOUT:ENV:POW:CDMA",
                               CDMAPower,
                               -120.0, 7.0,
                               VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Level
 * Purpose:  This function determines the level in the selected channel of the 
 *           CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutEnvLev (ViSession instrSession,
                                                    ViInt32 channel,
                                                    ViBoolean state,
                                                    ViReal64 level,
                                                    ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, channel, 0, 3, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:POW:GOUT:ENV:LEV:%s",
             channelArr [channel]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                state,
                                stateArr,
                                VI_ERROR_PARAMETER3));

    if (state)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    level,
                                    -20.0, -7.0,
                                    VI_ERROR_PARAMETER4));
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Calculated EbNt FFCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the forward FCH.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowGatOutEnvEbntFfch (ViSession instrSession,
                                                         ViReal64 *calculatedEbNtFFCH,
                                                         ViChar errorMessage[])
{
    RETMSG (RSCMU_getViReal64 (instrSession,
                               "CALC:POW:GOUT:ENV:EBNT:FFCH?",
                               calculatedEbNtFFCH,
                               VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Calculated EbNt FSCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the selected forward SCH channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcPowGatOutEnvEbntFsch (ViSession instrSession,
                                                         ViInt32 forwardSCH,
                                                         ViReal64 *calculatedEbNtFSCH,
                                                         ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, forwardSCH, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    
    sprintf (command, "CALC:POW:GOUT:ENV:EBNT:FSCH:%s?",
             schArr[forwardSCH]);
    RETMSG (RSCMU_getViReal64 (instrSession,
                               command,
                               calculatedEbNtFSCH,
                               VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Frame Rate
 * Purpose:  This function sets the frame rate for the variable rate traffic 
 *           channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutEnvFratFfch (ViSession instrSession,
                                                         ViInt32 frameRate,
                                                         ViChar errorMessage[])
{
    if (frameRate == 3)
        RETMSG (VI_ERROR_PARAMETER2);
        
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:POW:GOUT:ENV:FRAT:FFCH",
                           frameRate,
                           frameArr,
                           VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Impairments
 * Purpose:  This function determines an Additional White Gaussian Noise 
 *           level, a frequency offset to impair the CMU output signal and 
 *           injected Tx FER.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutEnvImp (ViSession instrSession,
                                                    ViReal64 AWGN_level_dB,
                                                    ViBoolean AWGNEnable,
                                                    ViReal64 BSFreqOffset_kHz,
                                                    ViBoolean BSFreqEnable,
                                                    ViReal64 txFER,
                                                    ViBoolean txFEREnable,
                                                    ViChar errorMessage[])
{
    ViStatus RSCMU_Status;
    
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:POW:GOUT:ENV:IMP:LEV:AWGN",
                                AWGNEnable,
                                stateArr,
                                VI_ERROR_PARAMETER3));

    if (AWGNEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:POW:GOUT:ENV:IMP:LEV:AWGN",
                                    AWGN_level_dB,
                                    -20.0, 4.0,
                                    VI_ERROR_PARAMETER2));
    }

    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:POW:GOUT:ENV:IMP:FOFF",
                                BSFreqEnable,
                                stateArr,
                                VI_ERROR_PARAMETER5));

    if (BSFreqEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:POW:GOUT:ENV:IMP:FOFF",
                                    BSFreqOffset_kHz,
                                    -5.0E+3, 5.0E+3,
                                    VI_ERROR_PARAMETER4));
    }

    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                "CONF:POW:GOUT:ENV:IMP:ITF",
                                txFEREnable,
                                stateArr,
                                VI_ERROR_PARAMETER7));
    if (txFEREnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    "CONF:POW:GOUT:ENV:IMP:ITF",
                                    txFER,
                                    0.0, 50.0,
                                    VI_ERROR_PARAMETER6));
    }
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Power Control Bits
 * Purpose:  This function selects the power control bit sequence that the CMU 
 *           sends to the mobile station to control its output power.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatOutEnvPCBits (ViSession instrSession,
                                                       ViInt32 *powerControlBits,
                                                       ViChar errorMessage[])
{
    RETMSG (RSCMU_getEnum (instrSession,
                           "CONF:POW:GOUT:ENV:PCB?",
                           powerControlBits,
                           PCBArr,
                           VI_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGatedOutLimits
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     defaultSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutLimits( ViSession instrSession
                                   , ViReal64  ALimRiseTime
                                   , ViReal64  BLimFallTime
                                   , ViReal64  CLim
                                   , ViReal64  DLimRel
                                   , ViReal64  DLimAbs
                                   , ViReal64  ELimBurstLen
                                   , ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 407, &ALimRiseTime, &BLimFallTime, &CLim, &DLimRel, &DLimAbs, &ELimBurstLen);
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[407].instrCommand
          , ALimRiseTime  * 1E-6
          , BLimFallTime  * 1E-6    
          , CLim       
          , DLimRel
          , DLimAbs
          , ELimBurstLen  * 1E-6
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ConfPowGatedOutLimits

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGoutCAMMLimA
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     limitA_us
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimA (ViSession instrSession,
                                                    ViReal64 limitA_us,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   checkRange( 636, &limitA_us);
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[636].instrCommand
          , limitA_us  * 1E-6
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
      
}//end of RSCMU_CDMA2K_ConfPowGoutCAMMLimA
/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGoutCAMMLimBref
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     refence_forBLimit_us
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimBref (ViSession instrSession,
                                                       ViReal64 refence_forBLimit_us,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    

   checkRange( 637, &refence_forBLimit_us);
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[637].instrCommand
          , refence_forBLimit_us * 1E-6
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
      
}//end of RSCMU_CDMA2K_ConfPowGoutCAMMLimBref
/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGoutCAMMLimB
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     limitB_us
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimB (ViSession instrSession,
                                                    ViReal64 limitB_us,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    

   checkRange( 638, &limitB_us);
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[638].instrCommand
          , limitB_us * 1E-6
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
      
}//end of RSCMU_CDMA2K_ConfPowGoutCAMMLimB
/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGoutCAMMLimC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     limitC_us
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimC (ViSession instrSession,
                                                    ViReal64 limitC_us,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);  
  
   checkRange( 639, &limitC_us);
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[639].instrCommand
          , limitC_us
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
        
      
}//end of RSCMU_CDMA2K_ConfPowGoutCAMMLimC
/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGoutCAMMLimDRel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     limitDRelative_dB
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimDRel (ViSession instrSession,
                                                       ViReal64 limitDRelative_dB,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);   

   checkRange( 640, &limitDRelative_dB);
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[640].instrCommand
          , limitDRelative_dB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
      
}//end of RSCMU_CDMA2K_ConfPowGoutCAMMLimDRel
/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGoutCAMMLimDAbs
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     limitDAbsolute_dBm
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimDAbs (ViSession instrSession,
                                                       ViReal64 limitDAbsolute_dBm,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);   
  
   checkRange( 641, &limitDAbsolute_dBm);
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[641].instrCommand
          , limitDAbsolute_dBm
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );     
      
}//end of RSCMU_CDMA2K_ConfPowGoutCAMMLimDAbs
/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGoutCAMMLimEref
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     reference_forELimit_us
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimEref (ViSession instrSession,
                                                       ViReal64 reference_forELimit_us,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 642, &reference_forELimit_us);
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[642].instrCommand
          , reference_forELimit_us  * 1E-6
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
      
}//end of RSCMU_CDMA2K_ConfPowGoutCAMMLimEref
/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGoutCAMMLimE
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     ELimit_us
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimE (ViSession instrSession,
                                                    ViReal64 ELimit_us,
                                                    ViChar errorMessage[])
{
    ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    

   checkRange( 643, &ELimit_us);
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[643].instrCommand
          , ELimit_us * 1E-6
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}
//end of RSCMU_CDMA2K_ConfPowGoutCAMMLimE
/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ConfPowGoutCAMMLimVal
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     limitA_us,refence_forBLimit_us,limitB_us,limitC_us,limitDRelative_dB,
 *             limitDAbsolute_dBm,reference_forELimit_us,ELimit_us
 *                                     
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGoutCAMMLimVal (ViSession instrSession,
                                                      ViReal64 limitA_us,
                                                      ViReal64 refence_forBLimit_us,
                                                      ViReal64 limitB_us,
                                                      ViReal64 limitC_us,
                                                      ViReal64 limitDRelative_dB,
                                                      ViReal64 limitDAbsolute_dBm,
                                                      ViReal64 reference_forELimit_us,
                                                      ViReal64 ELimit_us,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);  
  
   checkRange( 644, &limitA_us, &refence_forBLimit_us,
                    &limitB_us, &limitC_us,
                    &limitDRelative_dB,&limitDAbsolute_dBm,
                    &reference_forELimit_us,&ELimit_us);
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[644].instrCommand
          , limitA_us * 1E-6
          , refence_forBLimit_us * 1E-6
          , limitB_us * 1E-6
          , limitC_us 
          , limitDRelative_dB
          , limitDAbsolute_dBm           
          , reference_forELimit_us * 1E-6
          , ELimit_us * 1E-6
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
      
}//end of RSCMU_CDMA2K_ConfPowGoutCAMMLimVal

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_DefPowGatedOutLimits
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     defaultSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefPowGatedOutLimits (ViSession instrSession,
                                             ViInt32 defaultSetting,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 397, &defaultSetting);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[397].instrCommand
          , modeEnable.list[defaultSetting]      
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_DefPowGatedOutLimits

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_InitPowGatedOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_InitPowGatedOut (ViSession instrSession,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[123].instrCommand
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_InitPowGatedOut


/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_AbortPowGatedOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_AbortPowGatedOut (ViSession instrSession,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[124].instrCommand
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of RSCMU_CDMA2K_AbortPowGatedOut

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_StopPowGatedOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_StopPowGatedOut (ViSession instrSession,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[125].instrCommand
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
} //end of RSCMU_CDMA2K_StopPowGatedOut

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ContinuePowGatedOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ContinuePowGatedOut (ViSession instrSession,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[126].instrCommand
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
} //end of RSCMU_CDMA2K_ContinuePowGatedOut 

/**************************************************************************
 *
 * NAME:       RSCMU_CDMA2K_ContinuePowGatedOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchPowGatedOutStatus (ViSession instrSession,
                                                 ViInt32 *measurementStatus,
                                                 ViInt32 *CurrentStatCycleCount,
                                                 ViInt32 *CurrentEvaluationPeriod,                                                 
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   // Fetch the measurement status:
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[127].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );
       
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", CurrentStatCycleCount );
       }
       else
       {
          *CurrentStatCycleCount = RSCMU_OFF;
       }
       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", CurrentEvaluationPeriod );
       }
       else
       {
          *CurrentEvaluationPeriod = RSCMU_OFF;
       }
      
   }


   return RSCMU_Status;  
}//end of RSCMU_CDMA2K_FetchPowGatedOutStatus


/**************************************************************************
 *
 * NAME:      RSCMU_CDMA2K_ConfPowGatedOutErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      measurementEventReporting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfPowGatedOutErep (ViSession instrSession,
                                              ViInt32 measurementEventReporting,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 128, &measurementEventReporting);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[128].instrCommand
          , eventReport.list[measurementEventReporting]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
} //end of RSCMU_CDMA2K_ConfPowGatedOutErep


/**************************************************************************
 *
 * NAME:      RSCMU_CDMA2K_ReadScalGatedMaxOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      measurementEventReporting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalPowGatedOut (ViSession instrSession,
                                              ViReal64 *meanOutput,
                                              ViInt32 *limitLinesMatching,
                                              ViReal64 *measurementTol,
                                              ViChar errorMessage[]
                                              )
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[129].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );           
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get total mean output
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", meanOutput );
   }
   else
   {
      *meanOutput = RSCMU_NAN;
   }
   
   // Get measurement out of tolerance
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", measurementTol );
   }
   else
   {
      *measurementTol = RSCMU_NAN;
   }
   
   // Get limit lines matching state
   if( strcmp( tab[2], "OK" ) == 0 )
   {
      *limitLinesMatching = RSCMU_OK;
   }
   else if( strcmp( tab[2], "INV" ) == 0 )
   {
      *limitLinesMatching = RSCMU_INV;
   }
   else if( strcmp( tab[2], "NMAU" ) == 0 )
   {
      *limitLinesMatching = RSCMU_NMAU;
   } 
   else 
   {
      *limitLinesMatching = RSCMU_NMAL;
   }
     
   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ReadScalGatedMaxOut

/**************************************************************************
 *
 * NAME:      RSCMU_CDMA2K_ReadScalGatedMaxOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *meanOutput, *limitLinesMatching, *measurementTol,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalPowGatedOut (ViSession instrSession,
                                               ViReal64 *meanOutput,
                                               ViInt32 *limitLinesMatching,
                                               ViReal64 *measurementTol,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[130].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get total mean output
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", meanOutput );
   }
   else
   {
      *meanOutput = RSCMU_NAN;
   }
   
   // Get measurement out of tolerance
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", measurementTol );
   }
   else
   {
      *measurementTol = RSCMU_NAN;
   }
   
   // Get limit lines matching state
   if( strcmp( tab[2], "OK" ) == 0 )
   {
      *limitLinesMatching = RSCMU_OK;
   }
   else if( strcmp( tab[2], "INV" ) == 0 )
   {
      *limitLinesMatching = RSCMU_INV;
   }
   else if( strcmp( tab[2], "NMAU" ) == 0 )
   {
      *limitLinesMatching = RSCMU_NMAU;
   } 
   else 
   {
      *limitLinesMatching = RSCMU_NMAL;
   }

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_FetchScalPowGatedOut


/**************************************************************************
 *
 * NAME:     RSCMU_CDMA2K_SampleScalPowGatedOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *meanOutput, *limitLinesMatching, *measurementTol,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalPowGatedOut (ViSession instrSession,
                                                ViReal64 *meanOutput,
                                                ViInt32 *limitLinesMatching,
                                                ViReal64 *measurementTol,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[131].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get total mean output
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", meanOutput );
   }
   else
   {
      *meanOutput = RSCMU_NAN;
   }
   
   // Get measurement out of tolerance
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", measurementTol );
   }
   else
   {
      *measurementTol = RSCMU_NAN;
   }
   
   // Get limit lines matching state
   if( strcmp( tab[2], "OK" ) == 0 )
   {
      *limitLinesMatching = RSCMU_OK;
   }
   else if( strcmp( tab[2], "INV" ) == 0 )
   {
      *limitLinesMatching = RSCMU_INV;
   }
   else if( strcmp( tab[2], "NMAU" ) == 0 )
   {
      *limitLinesMatching = RSCMU_NMAU;
   } 
   else 
   {
      *limitLinesMatching = RSCMU_NMAL;
   }

   return( RSCMU_Status ); 
}
//end of RSCMU_CDMA2K_SampleScalPowGatedOut

/**************************************************************************
 *
 * NAME:     RSCMU_CDMA2K_CalScalPowGatOutMatcRamp
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *totalrampStatus
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalScalPowGatOutMatcRamp (ViSession instrSession,
                                                     ViInt32 *totalrampStatus,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[132].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get limit lines matching state
   if( strcmp( tab[0], "OK" ) == 0 )
   {
      *totalrampStatus = RSCMU_OK;
   }
   else if( strcmp( tab[0], "INV" ) == 0 )
   {
      *totalrampStatus = RSCMU_INV;
   }
   else if( strcmp( tab[0], "NMAU" ) == 0 )
   {
      *totalrampStatus = RSCMU_NMAU;
   } 
   else 
   {
      *totalrampStatus = RSCMU_NMAL;
   }

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_CalScalPowGatOutMatcRamp

/**************************************************************************
 *
 * NAME:     RSCMU_CDMA2K_ReadArrPowGatedOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *totalrampStatus
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrPowGatedOut (ViSession instrSession,
                                             ViInt32 measurementSetting,
                                             ViReal64 burstPower[],
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;  
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        
   
   checkRange( 133, &measurementSetting); 
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[133].instrCommand
          , measMode.list[measurementSetting]
          );

   RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     ); 


      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , burstPower
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ReadArrPowGatedOut

/**************************************************************************
 *
 * NAME:    RSCMU_CDMA2K_FetchArrPowGatedOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     measurementSetting
 *
 * OUTPUTS:     burstPower
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchArrPowGatedOut (ViSession instrSession,
                                              ViInt32 measurementSetting,
                                              ViReal64 burstPower[],
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;                               
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        
   
   checkRange( 134, &measurementSetting); 
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );


   sprintf( wrtBuf
          , CDMA[134].instrCommand
          , measMode.list[measurementSetting]
          );

   RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     ); 
    

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , burstPower
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_FetchArrPowGatedOut

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_SampleArrPowGatedOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      measurementSetting
 *
 * OUTPUTS:     burstPower
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleArrPowGatedOut (ViSession instrSession,
                                               ViInt32 measurementSetting,
                                               ViReal64 burstPower[],
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;                               
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        
   
   checkRange( 135, &measurementSetting); 
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   
   sprintf( wrtBuf
          , CDMA[135].instrCommand
          , measMode.list[measurementSetting]
          );

   RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     ); 


      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , burstPower
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_SampleArrPowGatedOut


/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_CalArrPowGatOutMatcLimit
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *bitFieldUpperLimits, *bitFieldLowerLimits,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalArrPowGatOutMatcLimit (ViSession instrSession,
                                                     ViReal64 *bitFieldUpperLimits,
                                                     ViReal64 *bitFieldLowerLimits,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[136].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   // Get bitFieldUpperLimits
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", bitFieldUpperLimits );
   }
   else
   {
      *bitFieldUpperLimits = RSCMU_NAN;
   }
   
   // Get bitFieldLowerLimits
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", bitFieldLowerLimits );
   }
   else
   {
      *bitFieldLowerLimits = RSCMU_NAN;
   }
   
   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_CalArrPowGatOutMatcLimit


/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ReadSubArrPowGatedOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      measurementSetting
 *
 * OUTPUTS:     burstPower
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadSubArrPowGatedOut (ViSession instrSession,
                                                ViInt32 measurementSetting,
                                                ViReal64 burstPower[],
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;  
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        
   
   checkRange( 137, &measurementSetting); 
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );


   sprintf( wrtBuf
          , CDMA[137].instrCommand
          , measMode.list[measurementSetting]
          );

   RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     ); 
    

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , burstPower
                             );

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_ReadSubArrPowGatedOut

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_FetchSubArrPowGatedOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      measurementSetting
 *
 * OUTPUTS:     burstPower
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchSubArrPowGatedOut (ViSession instrSession,
                                                 ViInt32 measurementSetting,
                                                 ViReal64 burstPower[],
                                                 ViChar errorMessage[])
{
    ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;                               
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        
   
   checkRange( 138, &measurementSetting); 
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[138].instrCommand
          , measMode.list[measurementSetting]
          );

   RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     ); 
    

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , burstPower
                             );



   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_FetchSubArrPowGatedOut

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_SampleSubArrPowGatedOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      measurementSetting
 *
 * OUTPUTS:     burstPower
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleSubArrPowGatedOut (ViSession instrSession,
                                                  ViInt32 measurementSetting,
                                                  ViReal64 burstPower[],
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;                               
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        
   
   checkRange( 139, &measurementSetting); 
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[139].instrCommand
          , measMode.list[measurementSetting]
          );

   RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     ); 
    

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , burstPower
                             );



   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_SampleSubArrPowGatedOut
                             

////////////////////////////Test Object Modulation////////////////////////
/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModMQualPCBits
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      powerControlBits
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualPCBits (ViSession instrSession,
                                             ViInt32 powerControlBits,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 246, &powerControlBits);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[246].instrCommand
          , powerCtlBits.list[powerControlBits]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf 
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );     
}//end of RSCMU_CDMA2K_ConfModMQualPCBits

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_SampleSubArrPowGatedOut
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      controlDefaultAllSettings
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefModMQualCont (ViSession instrSession,
                                          ViInt32 limitDeafultAllSetting,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
  // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;


   checkRange( 247, &limitDeafultAllSetting);       
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[247].instrCommand
          , enable.list[limitDeafultAllSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             ); 
   if (limitDeafultAllSetting == RSCMU_MODE_ON) p_globalvarCDMA->RSCMU_XtndMOD  = VI_FALSE;      
   
   return( RSCMU_Status );  
}
//end of RSCMU_CDMA2K_DefModMQualCont


/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_DefModMQualAllLim 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      limitsDefaultAllSettings
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefModMQualAllLim (ViSession instrSession,
                                                  ViInt32 limitDeafultAllSetting,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 248, &limitDeafultAllSetting);       
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   sprintf( wrtBuf
          , CDMA[248].instrCommand
          , enable.list[limitDeafultAllSetting]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             ); 

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_DefModMQualAllLim


/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModMQualCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      statistics, repetitionCount, rep,
                stopCondition, step, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualCont (ViSession instrSession,
                                                 ViInt32 statistics,
                                                 ViInt32 rep,
                                                 ViInt32 stopCondition,
                                                 ViInt32 step,
                                                 ViInt32 signaltype,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 249, &statistics, &rep, &stopCondition, &step, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   sprintf( wrtBuf
          , CDMA[249].instrCommand   
          , signalType2.list[signaltype]
          , statistics
          , repetition.list[rep]
          , stopCond3.list[stopCondition]
          , stepMode.list[step]
          );
          
   
      RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ConfModMQualCont

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModMQualContRep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:     repetitionCount, repetition, stepMode, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualContRep (ViSession instrSession,
                                                    ViInt32 rep,
                                                    ViInt32 stopCondition,
                                                    ViInt32 step,
                                                    ViInt32 signaltype,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 250, &rep, &stopCondition, &step, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   sprintf( wrtBuf
          , CDMA[250].instrCommand   
          , signalType2.list[signaltype]
          , repetition.list[rep]
          , stopCond3.list[stopCondition]
          , stepMode.list[step]
          );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   
   
   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ConfModMQualContRep

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModMQualCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      statistics,signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualContStats (ViSession instrSession,
                                                ViInt32 statistics,
                                                ViInt32 signaltype,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 251, &statistics, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[251].instrCommand
          , signalType2.list[signaltype]
          , statistics
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
} //end of RSCMU_CDMA2K_ConfModMQualContStats

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModMQualContSBdFOffs 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:       sideBandOffset, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualContSBdFOffs (ViSession instrSession,
                                                         ViReal64 sideBandOffset,
                                                         ViInt32 signaltype,
                                                         ViBoolean Enable, 
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 252, &sideBandOffset, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[252].instrCommand
          , signalType2.list[signaltype]
          , enable.list[Enable], signalType2.list[signaltype], sideBandOffset
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ConfModMQualContSBdFOffs

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_XtndModMQualSBS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      controlDefaultAllSettings, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_XtndModMQualSBS (ViSession instrSession,
                                                ViInt32 signalType,
                                                ViInt32 SBSuppressionExtensionMode,
                                                ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10)
     return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);
     
   checkRange(551, &signalType, &SBSuppressionExtensionMode );
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[551].instrCommand
          , signalType2.list[signalType]
          , modeEnable.list[SBSuppressionExtensionMode]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
   if (SBSuppressionExtensionMode == RSCMU_MODE_ON)
    p_globalvarCDMA->RSCMU_XtndMOD = VI_TRUE;
   else
    p_globalvarCDMA->RSCMU_XtndMOD = VI_FALSE;
   
   return( RSCMU_Status );        
}//end of RSCMU_CDMA2K_XtndModMQualSBS
/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModMQualExtFOffSBS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      controlDefaultAllSettings, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualExtFOffSBS (ViSession instrSession,
                                                       ViInt32 signalType,
                                                       ViInt32 ACPFreqOffset1,
                                                       ViBoolean enable1,
                                                       ViInt32 ACPFreqOffset2,
                                                       ViBoolean enable2,
                                                       ViInt32 ACPFreqOffset3,
                                                       ViBoolean enable3,
                                                       ViInt32 ACPFreqOffset4,
                                                       ViBoolean enable4,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10)
     return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
   
   checkRange( 552
             , &signalType
             , &ACPFreqOffset1
             );
             
   checkRange( 552
             , &signalType
             , &ACPFreqOffset2
             );
   checkRange( 552
             , &signalType
             , &ACPFreqOffset3
             );
   checkRange( 552
             , &signalType
             , &ACPFreqOffset4
             );
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[552].instrCommand
          , signalType2.list[signalType]
          , signalType2.list[signalType]
          , ACPFreqOffset1
          , enable.list[enable1]
          , ACPFreqOffset2
          , enable.list[enable2]
          , ACPFreqOffset3
          , enable.list[enable3]
          , ACPFreqOffset4
          , enable.list[enable4]
         );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   if (RSCMU_Status == VI_SUCCESS) 
    p_globalvarCDMA->RSCMU_XtndMOD = VI_TRUE;
   else
    p_globalvarCDMA->RSCMU_XtndMOD = VI_FALSE;
   
   return( RSCMU_Status );
   
}//end of RSCMU_CDMA2K_ConfModMQualExtFOffSBS 

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_DefModMQualControl
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      controlDefaultAllSettings, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefModMQualControl (ViSession instrSession,
                                             ViInt32 limitDefaultAllSetting,
                                             ViInt32 signaltype,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   
  // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;

   checkRange( 253, &limitDefaultAllSetting, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[253].instrCommand
          , signalType2.list[signaltype]
          , enable.list[limitDefaultAllSetting]
          );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    if (limitDefaultAllSetting == RSCMU_MODE_ON) p_globalvarCDMA->RSCMU_XtndMOD     = VI_FALSE;      
    
   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_DefModMQualControl


/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModMQualLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      limitWaveFormQuality, carrierFreqLimit, transmitTimeErrorLimit_us,
                limitCarrierFeedThrough, sidebandSupprLimit, limitSetting, signalType,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualLim (ViSession instrSession,
                                                ViReal64 limitWaveFormQuality,
                                                ViBoolean WFEnable,
                                                ViInt32 carrierFreqLimit,
                                                ViBoolean CFEnable,
                                                ViReal64 transmitTimeErrorLimit_us,
                                                ViBoolean TTEnable,
                                                ViInt32 limitCarrierFeedThrough,
                                                ViBoolean CFTEnable,
                                                ViInt32 reserved,
                                                ViInt32 sidebandSupprLimit,
                                                ViBoolean SSEnable,
                                                ViInt32 signaltype,
                                                ViInt32 limitSetting,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 254, &limitWaveFormQuality,&carrierFreqLimit,&transmitTimeErrorLimit_us,
                    &limitCarrierFeedThrough, &sidebandSupprLimit, &signaltype, &limitSetting);
                    
   transmitTimeErrorLimit_us = transmitTimeErrorLimit_us * 0.000001;
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[254].instrCommand
          , signalType2.list[signaltype]
          , measMode2.list[limitSetting]
          , enable.list[WFEnable]
          , enable.list[CFEnable]
          , enable.list[TTEnable]
          , enable.list[CFTEnable]
          , reserved 
          , enable.list[SSEnable]        
          , signalType2.list[signaltype]
          , measMode2.list[limitSetting]
          , limitWaveFormQuality
          , carrierFreqLimit
          , transmitTimeErrorLimit_us
          , limitCarrierFeedThrough
          , reserved
          , sidebandSupprLimit
          );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  

}
//end of RSCMU_CDMA2K_ConfModMQualLim

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModMQualLimLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      limitWaveFormQuality, carrierFreqLimit, transmitTimeErrorLimit_us,
                limitCarrierFeedThrough, sidebandSupprLimit, SBSACP2Limit,
                SBSACP3Limit,SBSACP4Limit,limitSetting, signalType,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualLimLev (ViSession instrSession,
                                                   ViReal64 limitWaveFormQuality,
                                                   ViReal64 carrierFreqLimit,
                                                   ViReal64 transmitTimeErrorLimit_us,
                                                   ViReal64 limitCarrierFeedThrough,
                                                   ViInt32 reverse,
                                                   ViReal64 sidebandSupprLimit,
                                                   ViReal64 SBSACP2Limit,
                                                   ViReal64 SBSACP3Limit,
                                                   ViReal64 SBSACP4Limit,
                                                   ViInt32 signalType,
                                                   ViInt32 limit_setting,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA; 
   
   //Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;         

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10)
     return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);

   checkRange( 553
             , &signalType
             , &limit_setting
             , &limitWaveFormQuality
             , &carrierFreqLimit
             , &transmitTimeErrorLimit_us
             , &limitCarrierFeedThrough
             , &sidebandSupprLimit
             , &SBSACP2Limit
             , &SBSACP3Limit
             , &SBSACP4Limit
             );

   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   sprintf( wrtBuf
          , CDMA[553].instrCommand
          , signalType2.list[signalType] 
          , measMode2.list[limit_setting]   
          , limitWaveFormQuality
          , (ViInt32)carrierFreqLimit
          , transmitTimeErrorLimit_us * 1E-6
          , limitCarrierFeedThrough
          , reverse
          , sidebandSupprLimit
          , SBSACP2Limit
          , SBSACP3Limit
          , SBSACP4Limit
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );     
}//end of RSCMU_CDMA2K_ConfModMQualLimLev

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModMQualLimEnable
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      waveFormEnable, carrierFrequencyEnable, transmitTimeErrorEnable,
                carrierFeedthroughEnable, reverseEnable, SBSEnable,
                SBSACP2Enable,SBSACP3Enable,SBSACP4Enable, signalType,limit_setting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualLimEnable (ViSession instrSession,
                                                      ViBoolean waveFormEnable,
                                                      ViBoolean carrierFrequencyEnable,
                                                      ViBoolean transmitTimeErrorEnable,
                                                      ViBoolean carrierFeedthroughEnable,
                                                      ViBoolean reverseEnable,
                                                      ViBoolean SBSEnable,
                                                      ViBoolean SBSACP2Enable,
                                                      ViBoolean SBSACP3Enable,
                                                      ViBoolean SBSACP4Enable,
                                                      ViInt32 signalType,
                                                      ViInt32 limit_setting,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 554
            , &signalType
            , &limit_setting
            , &waveFormEnable
            , &carrierFrequencyEnable
            , &transmitTimeErrorEnable
            , &carrierFeedthroughEnable
            , &reverseEnable
            , &SBSEnable
            , &SBSACP2Enable
            , &SBSACP3Enable
            , &SBSACP4Enable
            );
            
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[554].instrCommand
          , signalType2.list[signalType]
          , measMode2.list[limit_setting]
          , enable.list[waveFormEnable]
          , enable.list[carrierFrequencyEnable]  
          , enable.list[transmitTimeErrorEnable]  
          , enable.list[carrierFeedthroughEnable]  
          , enable.list[reverseEnable]
          , enable.list[SBSEnable]  
          , enable.list[SBSACP2Enable]  
          , enable.list[SBSACP3Enable]   
          , enable.list[SBSACP4Enable]             
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
    
} //end of RSCMU_CDMA2K_ConfModMQualLimEnable

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_DefModMQualLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      limitDefaultAllSettings, signalType, limitSetting
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefModMQualLim (ViSession instrSession,
                                         ViInt32 limitDefaultSetting,
                                         ViInt32 signaltype,
                                         ViInt32 limitSetting,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 255, &limitDefaultSetting, &signaltype, &limitSetting);
                    
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[255].instrCommand
          , signalType2.list[signaltype]
          , measMode2.list[limitSetting]
          , enable.list[limitDefaultSetting] 
          );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
} //end of RSCMU_CDMA2K_DefModMQualLim 

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_InitModMQuality
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_InitModMQuality (ViSession instrSession,
                                          ViInt32 signaltype,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 256, &signaltype);
                    
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[256].instrCommand
          , signalType2.list[signaltype]
          );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
} //end of RSCMU_CDMA2K_InitModMQuality

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_AbortModMQuality
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_AbortModMQuality (ViSession instrSession,
                                           ViInt32 signaltype,
                                           ViChar errorMessage[])
{
ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 257, &signaltype);
                    
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[257].instrCommand
          , signalType2.list[signaltype]
          );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
    
}
//end of RSCMU_CDMA2K_AbortModMQuality

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_StopModMQuality
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_StopModMQuality (ViSession instrSession,
                                          ViInt32 signaltype,
                                          ViChar errorMessage[])
{
ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 258, &signaltype);
                    
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[258].instrCommand
          , signalType2.list[signaltype]
          );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
    
}
//end of RSCMU_CDMA2K_StopModMQuality

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ContinueModMQuality
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueModMQuality (ViSession instrSession,
                                              ViInt32 signaltype,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 259, &signaltype);
                    
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[259].instrCommand
          , signalType2.list[signaltype]
          );
  
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
    
}
//end of RSCMU_CDMA2K_ContinueModMQuality

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_FetchModMQualStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      measurementStatus, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_FetchModMQualStatus (ViSession instrSession,
                                              ViInt32 *measurementStatus,
                                              ViInt32 *CurrentStatCycleCount,
                                              ViInt32 *CurrentEvaluationPeriod,                                              
                                              ViInt32 signaltype,
                                              ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   checkRange( 260, &signaltype ); 
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[260].instrCommand
          , signalType2.list[signaltype]
          );
  
   
   
   // Fetch the measurement status:
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );
          
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", CurrentStatCycleCount );
       }
       else
       {
          *CurrentStatCycleCount = RSCMU_OFF;
       }
       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", CurrentEvaluationPeriod );
       }
       else
       {
          *CurrentEvaluationPeriod = RSCMU_OFF;
       }   
      
   }


   return RSCMU_Status; 

    
} //end of RSCMU_CDMA2K_FetchModMQualStatus

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModMQualErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      measurementEventReporting, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModMQualErep (ViSession instrSession,
                                           ViInt32 measurementEventReporting,
                                           ViInt32 signaltype,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
                                                                 
   checkRange( 261, &measurementEventReporting,&signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[261].instrCommand
          , signalType2.list[signaltype] 
          , eventReport.list[measurementEventReporting]
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );     
}
//end of RSCMU_CDMA2K_ConfModMQualErep

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ReadModMQuallity
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signaltype,
 *
 * OUTPUTS:     *modulationValue, signalType,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadModMQuality (ViSession   instrSession,
                                                ModQualOver *modulationValue,
                                                ViInt32     signaltype,
                                                ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ViInt32  index;       
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                
     
   checkRange( 262, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[262].instrCommand
          , signalType2.list[signaltype]
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                          
   // Separate the CMU response:

   //index = strcspn (p_globalvarCDMA->rdABuf, "\n");
   //p_globalvarCDMA->rdABuf[index] = '\0';
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                      , &modulationValue->msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &modulationValue->WaveFormQuality
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &modulationValue->CarrierFrequencyError
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &modulationValue->TransmitTimeError
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &modulationValue->CarrierFeedThrough
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &modulationValue->SideBandSuppresLower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &modulationValue->SideBandSuppresUpper
                                       );                                       

   index = 21;
   
   //ACP2
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndMOD == VI_TRUE))
     index= index + 3;
   else
     index = index -3;
     
    // retreive 2nd the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionLowerACP2
                                       );
    index = index + 3; 
    // retreive 2nd the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                           , &modulationValue->sidebandSuppressionUpperACP2
                                       );
    
   //ACP3                                      
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndMOD == VI_TRUE))
     index= index + 3;
   else
     index = index -3;                                     
    
    // retreive 3rd the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionLowerACP3
                                     );
    index = index + 3; 
    
    // retreive 3rd the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionUpperACP3
                                       );

    // ACP 4
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndMOD == VI_TRUE))
     index= index + 3;
   else
     index = index -3;  

    // retreive 4th the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionLowerACP4
                                       );
    index = index + 3; 

    // retreive 4th the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionUpperACP4
                                       );



    //Bursts Out of tolerance
    index = index + 3; 

//    RSCMU_Status = RSCMU_ReturnLimits( &tab[index],
      RSCMU_ReturnArrayValues(tab[index], &modulationValue->MeasOutOfTolerance);         

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ReadModMQuallity

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_FetchModMQuality
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signaltype,
 *
 * OUTPUTS:     *modulationValue, signalType,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchModMQuality (ViSession instrSession,
                                                 ModQualOver *modulationValue,
                                                 ViInt32 signaltype,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ViInt32  index;       
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   checkRange( 263, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[263].instrCommand
          , signalType2.list[signaltype]
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                      , &modulationValue->msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &modulationValue->WaveFormQuality
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &modulationValue->CarrierFrequencyError
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &modulationValue->TransmitTimeError
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &modulationValue->CarrierFeedThrough
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &modulationValue->SideBandSuppresLower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &modulationValue->SideBandSuppresUpper
                                       );                                       

   index = 21;
   
   //ACP2
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndMOD == VI_TRUE))
     index= index + 3;
   else
     index = index -3;
     
    // retreive 2nd the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionLowerACP2
                                       );
    index = index + 3; 
    // retreive 2nd the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                           , &modulationValue->sidebandSuppressionUpperACP2
                                       );
    
   //ACP3                                      
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndMOD == VI_TRUE))
     index= index + 3;
   else
     index = index -3;                                     
    
    // retreive 3rd the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionLowerACP3
                                     );
    index = index + 3; 
    
    // retreive 3rd the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionUpperACP3
                                       );

    // ACP 4
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndMOD == VI_TRUE))
     index= index + 3;
   else
     index = index -3;  

    // retreive 4th the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionLowerACP4
                                       );
    index = index + 3; 

    // retreive 4th the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionUpperACP4
                                       );



    //Bursts Out of tolerance
    index = index + 3; 

    //RSCMU_Status = RSCMU_ReturnLimits( &tab[index],
      RSCMU_ReturnArrayValues(tab[index], &modulationValue->MeasOutOfTolerance);         
      

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_FetchModMQuallity

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_SampleModMQuality
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signaltype,
 *
 * OUTPUTS:     *modulationValue, signalType,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleModMQuality (ViSession instrSession,
                                                  ModQualOver *modulationValue,
                                                  ViInt32 signaltype,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ViInt32  index;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   checkRange( 264, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[264].instrCommand
          , signalType2.list[signaltype]
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:

   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                      , &modulationValue->msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &modulationValue->WaveFormQuality
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &modulationValue->CarrierFrequencyError
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &modulationValue->TransmitTimeError
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &modulationValue->CarrierFeedThrough
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &modulationValue->SideBandSuppresLower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &modulationValue->SideBandSuppresUpper
                                       );                                       

   index = 21;
   
   //ACP2
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndMOD == VI_TRUE))
     index= index + 3;
   else
     index = index -3;
     
    // retreive 2nd the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionLowerACP2
                                       );
    index = index + 3; 
    // retreive 2nd the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                           , &modulationValue->sidebandSuppressionUpperACP2
                                       );
    
   //ACP3                                      
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndMOD == VI_TRUE))
     index= index + 3;
   else
     index = index -3;                                     
    
    // retreive 3rd the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionLowerACP3
                                     );
    index = index + 3; 
    
    // retreive 3rd the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionUpperACP3
                                       );

    // ACP 4
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndMOD == VI_TRUE))
     index= index + 3;
   else
     index = index -3;  

    // retreive 4th the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionLowerACP4
                                       );
    index = index + 3; 

    // retreive 4th the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionUpperACP4
                                       );



    //Bursts Out of tolerance
    index = index + 3; 

    //RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &modulationValue->MeasOutOfTolerance);    
      RSCMU_ReturnArrayValues(tab[index], &modulationValue->MeasOutOfTolerance);         

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_SampleModMQuality


/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_CalcModMQualMatcLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      signaltype,
 *
 * OUTPUTS:     *modulationValue, signalType,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalcModMQualMatcLim (ViSession instrSession,
                                                    ModQualOver *modulationValue,
                                                    ViInt32 signaltype,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ViInt32  index;       
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;   

   //Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;    
  
   checkRange( 265, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[265].instrCommand
          , signalType2.list[signaltype]  
          );
  

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

  // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   RSCMU_Status = RSCMU_MatchLimits( &tab[0]
                                       , &modulationValue->WaveFormQuality
                                       );
   RSCMU_Status = RSCMU_MatchLimits( &tab[3]
                                       , &modulationValue->CarrierFrequencyError
                                       );
   RSCMU_Status = RSCMU_MatchLimits( &tab[6]
                                       , &modulationValue->TransmitTimeError
                                       );
   RSCMU_Status = RSCMU_MatchLimits( &tab[9]
                                       , &modulationValue->CarrierFeedThrough
                                       );
   RSCMU_Status = RSCMU_MatchLimits( &tab[15]
                                       , &modulationValue->SideBandSuppresLower
                                       );
   RSCMU_Status = RSCMU_MatchLimits( &tab[18]
                                       , &modulationValue->SideBandSuppresUpper
                                       );                                       
   index = 18;
   
   //ACP2
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndMOD == VI_TRUE))
     index= index + 3;
   else
     index = index -3;
     
    // retreive 2nd the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionLowerACP2
                                       );
    index = index + 3; 
    // retreive 2nd the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                           , &modulationValue->sidebandSuppressionUpperACP2
                                       );
    
   //ACP3                                      
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndMOD == VI_TRUE))
     index= index + 3;
   else
     index = index -3;                                     
    
    // retreive 3rd the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionLowerACP3
                                     );
    index = index + 3; 
    
    // retreive 3rd the right sideband suppression    
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionUpperACP3
                                       );

    // ACP 4
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndMOD == VI_TRUE))
     index= index + 3;
   else
     index = index -3;  

    // retreive 4th the low sideband suppression 
    RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                       , &modulationValue->sidebandSuppressionLowerACP4
                                       );    
   return( RSCMU_Status );   
}
 //end of RSCMU_CDMA2K_CalcModMQualMatcLim

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_CalcModMQualMatcLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      CDMAPower, trafficLevel, pilotLevel,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempLev (ViSession instrSession,
                                         ViReal64 CDMAPowerdBm,
                                         ViReal64 trafficLeveldB,
                                         ViReal64 pilotLeveldB,
                                         ViInt32 signaltype,
                                         ViChar errorMessage[])
{

   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 266
             , &CDMAPowerdBm
             , &trafficLeveldB
             , &pilotLeveldB
             , &signaltype
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[266].instrCommand
          , signalType.list[signaltype]
          , CDMAPowerdBm
          , trafficLeveldB
          , pilotLeveldB
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
}
 //end of RSCMU_CDMA2K_ConfModOempLev

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModOempContPowCDMA
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      CDMAPower, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempContPowCDMA (ViSession instrSession,
                                                 ViReal64 CDMAPowerdBm,
                                                 ViInt32 signaltype,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 267
             , &CDMAPowerdBm
             , &signaltype
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[267].instrCommand
          , signalType2.list[signaltype]
          , CDMAPowerdBm
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
}  //end of RSCMU_CDMA2K_ConfModOempContPowCDMA

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModOempContLev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      trafficLeveldB, pilotLeveldB, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempContLev (ViSession instrSession,
                                             ViReal64 trafficLeveldB,
                                             ViBoolean FCHEnable,
                                             ViReal64 pilotLeveldB,
                                             ViBoolean PICHEnable,
                                             ViInt32 signaltype,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 268
             , &trafficLeveldB
             , &pilotLeveldB
             , &signaltype
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[268].instrCommand
          , signalType2.list[signaltype]
          , trafficLeveldB
          , pilotLeveldB
          , signalType2.list[signaltype]   
          , enable.list[FCHEnable]
          , enable.list[PICHEnable] 
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
} //end of RSCMU_CDMA2K_ConfModOempContLev


/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModOempImpairments
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      AWGNLeveldB, BSFreqOffset, signaltype,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempImpairments (ViSession instrSession,
                                                 ViReal64 AWGNLeveldB,
                                                 ViBoolean AWGNEnable,
                                                 ViReal64 BSFreqOffset,
                                                 ViBoolean BSFreqOffsetEnable,
                                                 ViInt32 signaltype,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 269
             , &AWGNLeveldB
             , &BSFreqOffset
             , &signaltype
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[269].instrCommand
          , signalType.list[signaltype]
          , AWGNLeveldB
          , BSFreqOffset
          , signalType.list[signaltype]  
          , enable.list[AWGNEnable]
          , enable.list[BSFreqOffsetEnable]

          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
}//end of RSCMU_CDMA2K_ConfModOempImpairments

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModOempPCBits 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS: SignalType,  powerControlBits
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

// JMG 021002 
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempPCBits (ViSession instrSession,
                                                  ViInt32   SignalType,
                                                  ViInt32   PowerControlBits,
                                                  ViChar    errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 531
             , &PowerControlBits
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[531].instrCommand
          , signalType.list[SignalType]  
          , powerCtlBits.list[PowerControlBits]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
           
} // end of RSCMU_CDMA2K_ConfModOempPCBits()

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModOempPCBits 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS: SignalType,  powerControlBits
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempContFrFFCH (ViSession instrSession,
                                                      ViInt32 SignalType,
                                                      ViInt32 frameRate,
                                                      ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 628
             , &signalType 
             , &frameRate
             );
             
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[628].instrCommand
          , signalType.list[SignalType]  
          , frameRateType.list[frameRate]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
}//end of RSCMU_CDMA2K_ConfModOempContFrFFCH
/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_CalOverOempEbntFFCH 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS: SignalType,  powerControlBits
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalOverOempEbntFFCH (ViSession instrSession,
                                                    ViInt32 signaltype,
                                                    ViReal64 *calculatedEbNtFFCH,
                                                    ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];     

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[627].instrCommand
          , signalType.list[signaltype]  
          );             

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
  
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if (strcmp(tab[0], "NAN") != 0)
      sscanf( tab[0], "%lf", calculatedEbNtFFCH );  
   else
      *calculatedEbNtFFCH = RSCMU_NAN;  
   

   return( RSCMU_Status );          
}//end of RSCMU_CDMA2K_CalOverOempEbntFFCH

/*****************************************************************************
 * Function: State
 * Purpose:  This function enables or disables the environment for the 
 *           Modulation measurement applications.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempEnvEnab (ViSession instrSession,
                                                   ViInt32 signalType,
                                                   ViBoolean enable,
                                                   ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:MOD:OEMP%s:ENV:ENAB",
             signalTypeArr[signalType]);
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           enable,
                           stateArr,
                           VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: CDMA Output Power
 * Purpose:  This function determines the total CDMA output power (absolute 
 *           value, in dBm) of the CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempEnvPowCdma (ViSession instrSession,
                                                      ViInt32 signalType,
                                                      ViReal64 CDMAPower,
                                                      ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:MOD:OEMP%s:ENV:POW:CDMA",
             signalTypeArr[signalType]);
    RETMSG (RSCMU_setViReal64 (instrSession,
                               command,
                               CDMAPower,
                               -120.0, 7.0,
                               VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Level
 * Purpose:  This function determines the level in the selected channel of the 
 *           CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempEnvLev (ViSession instrSession,
                                                  ViInt32 signalType,
                                                  ViInt32 channel,
                                                  ViBoolean state,
                                                  ViReal64 level,
                                                  ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, channel, 0, 3, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:MOD:OEMP%s:ENV:LEV:%s", signalTypeArr [signalType],
             channelArr [channel]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                state,
                                stateArr,
                                VI_ERROR_PARAMETER4));

    if (state)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    level,
                                    -20.0, -1.0,
                                    VI_ERROR_PARAMETER5));
    }

    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Calculated EbNt FFCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the forward FCH.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcModOempEnvEbntFfch (ViSession instrSession,
                                                       ViInt32 signalType,
                                                       ViReal64 *calculatedEbNtFFCH,
                                                       ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CALC:MOD:OEMP%s:ENV:EBNT:FFCH?",
             signalTypeArr[signalType]);
    RETMSG (RSCMU_getViReal64 (instrSession,
                               command,
                               calculatedEbNtFFCH,
                               VI_ERROR_PARAMETER4));
}

/*****************************************************************************
 * Function: Calculated EbNt FSCH
 * Purpose:  This function returns the calculated signal to noise ratio for 
 *           the selected forward SCH channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_CalcModOempEnvEbntFsch (ViSession instrSession,
                                                       ViInt32 signalType,
                                                       ViInt32 forwardSCH,
                                                       ViReal64 *calculatedEbNtFSCH,
                                                       ViChar errorMessage[])
{
    ViChar command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, forwardSCH, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    
    sprintf (command, "CALC:MOD:OEMP%s:ENV:EBNT:FSCH:%s?",
             signalTypeArr[signalType],
             schArr[forwardSCH]);
    RETMSG (RSCMU_getViReal64 (instrSession,
                               command,
                               calculatedEbNtFSCH,
                               VI_ERROR_PARAMETER4));
}

/*****************************************************************************
 * Function: Frame Rate
 * Purpose:  This function sets the frame rate for the variable rate traffic 
 *           channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempEnvFratFfch (ViSession instrSession,
                                                       ViInt32 signalType,
                                                       ViInt32 frameRate,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:MOD:OEMP%s:ENV:FRAT:FFCH", signalTypeArr [signalType]);
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           frameRate,
                           frameArr,
                           VI_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Impairments
 * Purpose:  This function determines an Additional White Gaussian Noise 
 *           level, a frequency offset to impair the CMU output signal and 
 *           injected Tx FER.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempEnvImpairment (ViSession instrSession,
                                                         ViInt32 signalType,
                                                         ViReal64 AWGN_level_dB,
                                                         ViBoolean AWGNEnable,
                                                         ViReal64 BSFreqOffset_kHz,
                                                         ViBoolean BSFreqEnable,
                                                         ViReal64 txFER,
                                                         ViBoolean txFEREnable,
                                                         ViChar errorMessage[])
{
    ViChar  command[128];
    ViStatus RSCMU_Status;
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:MOD:OEMP%s:ENV:IMP:LEV:AWGN", signalTypeArr [signalType]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                AWGNEnable,
                                stateArr,
                                VI_ERROR_PARAMETER4));

    if (AWGNEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    AWGN_level_dB,
                                    -20.0, 4.0,
                                    VI_ERROR_PARAMETER3));
    }

    sprintf (command, "CONF:MOD:OEMP%s:ENV:IMP:FOFF", signalTypeArr [signalType]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                BSFreqEnable,
                                stateArr,
                                VI_ERROR_PARAMETER6));

    if (BSFreqEnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    BSFreqOffset_kHz,
                                    -5.0E+3, 5.0E+3,
                                    VI_ERROR_PARAMETER5));
    }

    sprintf (command, "CONF:MOD:OEMP%s:ENV:IMP:ITF", signalTypeArr [signalType]);
    CHECKRETMSG (RSCMU_setEnum (instrSession,
                                command,
                                txFEREnable,
                                stateArr,
                                VI_ERROR_PARAMETER8));
    if (txFEREnable)
    {
        CHECKRETMSG (RSCMU_setViReal64 (instrSession,
                                    command,
                                    txFER,
                                    0.0, 50.0,
                                    VI_ERROR_PARAMETER7));
    }
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Power Control Bits
 * Purpose:  This function selects the power control bit sequence that the CMU 
 *           sends to the mobile station to control its output power.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempEnvPCBits (ViSession instrSession,
                                                     ViInt32 signalType,
                                                     ViInt32 powerControlBits,
                                                     ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, signalType, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    sprintf (command, "CONF:MOD:OEMP%s:ENV:PCB", signalTypeArr [signalType]);
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           powerControlBits,
                           PCBArr,
                           VI_ERROR_PARAMETER3));
}

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModOempLimSymVal
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      EVMErrorPeak, EVMErrorRMS, magErrorPeak, magErrorRMS,
                phaseErrorPeak, phaseErrorRMS, carrierFeedthrough, IQImbalance_dB,
                carrierFreqErr, transmitTimeErr_Us, waveformQuality, measurementMode,
                signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempLimSymVal (ViSession instrSession,
                                               ViReal64 EVMErrorPeak,
                                               ViReal64 EVMErrorRMS,
                                               ViReal64 magErrorPeak,
                                               ViReal64 magErrorRMS,
                                               ViReal64 phaseErrorPeak,
                                               ViReal64 phaseErrorRMS,
                                               ViReal64 carrierFeedthrough,
                                               ViReal64 IQImbalancedB,
                                               ViReal64 carrierFreqErr,
                                               ViReal64 transmitTimeErrs,
                                               ViReal64 waveformQuality,
                                               ViInt32 mode,
                                               ViInt32 signaltype,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;


   transmitTimeErrs = transmitTimeErrs/1000000.00;

   checkRange( 270
             , &EVMErrorPeak
             , &EVMErrorRMS
             , &magErrorPeak
             , &magErrorRMS
             , &phaseErrorPeak
             , &phaseErrorRMS
             , &carrierFeedthrough
             , &IQImbalancedB
             , &carrierFreqErr
             , &transmitTimeErrs
             , &waveformQuality
             , &mode
             , &signaltype
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[270].instrCommand
          , signalType.list[signaltype] 
          , measMode2.list[mode]   
          , EVMErrorPeak
          , EVMErrorRMS
          , magErrorPeak
          , magErrorRMS
          , phaseErrorPeak
          , phaseErrorRMS
          , carrierFeedthrough
          , IQImbalancedB
          , carrierFreqErr
          , transmitTimeErrs
          , waveformQuality
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ConfModOempLimSymVal

/**************************************************************************
 *
 * NAME:   ConfModOempLimSymEnable
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      EVMErrorPeak, EVMErrorRMS, magErrorPeak, magErrorRMS,
                phaseErrorPeak, phaseErrorRMS, carrierFeedthrough, IQImbalance_dB,
                carrierFreqErr, transmitTimeErr_Us, waveformQuality, measurementMode,
                signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModOempLimSymEnable (ViSession instrSession,
                                                  ViInt32 EVMErrorPeak,
                                                  ViInt32 EVMErrorRMS,
                                                  ViInt32 magErrorPeak,
                                                  ViInt32 magErrorRMS,
                                                  ViInt32 phaseErrorPeak,
                                                  ViInt32 phaseErrorRMS,
                                                  ViInt32 carrierFeedthrough,
                                                  ViInt32 IQImbalance,
                                                  ViInt32 carrierFreqErr,
                                                  ViInt32 transmitTimeError,
                                                  ViInt32 waveformQuality,
                                                  ViInt32 mode,
                                                  ViInt32 signaltype,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 271 
             , &EVMErrorPeak
             , &EVMErrorRMS
             , &magErrorPeak
             , &magErrorRMS
             , &phaseErrorPeak
             , &phaseErrorRMS
             , &carrierFeedthrough
             , &IQImbalance
             , &carrierFreqErr
             , &transmitTimeError
             , &waveformQuality
             , &mode   
             , &signaltype    
             );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[271].instrCommand
          , signalType.list[signaltype] 
          , measMode2.list[mode]  
          , enable.list[EVMErrorPeak]
          , enable.list[EVMErrorRMS]
          , enable.list[magErrorPeak]
          , enable.list[magErrorRMS]
          , enable.list[phaseErrorPeak]
          , enable.list[phaseErrorRMS]
          , enable.list[carrierFeedthrough]
          , enable.list[IQImbalance]
          , enable.list[carrierFreqErr]
          , enable.list[transmitTimeError]
          , enable.list[waveformQuality]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ConfModOempLimSymEnable

/**************************************************************************
 *
 * NAME:   ConfModOempLimSymEnable
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      enable, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefModOempLim (ViSession instrSession,
                                        ViBoolean state, ViInt32 signaltype,
                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 272, &state,&signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[272].instrCommand
          , signalType.list[signaltype]   
          , enable.list[state]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_DefModOempLim

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModCont
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      enable, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModCont (ViSession instrSession,
                                      ViInt32 rMode,
                                      ViInt32 statistics, 
                                      ViInt32 rep, 
                                      ViInt32 stopCondition,
                                      ViInt32 step, 
                                      ViInt32 type,
                                      ViInt32 signaltype, 
                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
  
   checkRange( 273, &resultMode, &statistics, &rep, &stopCondition, &step, &type, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   
   if ((type == 1) || (type ==2) || (type ==3))
   {  
   sprintf( wrtBuf
          , CDMA[273].instrCommand   
          , measType.list[type]
          , signalType.list[signaltype]
          , resultMode.list[rMode]
          , statistics
          , repetition.list[rep]
          , stopCond3.list[stopCondition]
          , stepMode.list[step]
          );
   }
   else
   {
   
   sprintf( wrtBuf
          , CDMA[273].instrCommand   
          , measType.list[type]
          , signalType.list[signaltype]
          , ""
          , statistics
          , repetition.list[rep]
          , stopCond3.list[stopCondition]
          , stepMode.list[step]
          );
   }
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
  
   return( RSCMU_Status ); 
}
 //end of RSCMU_CDMA2K_ConfModCont 

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModContRMode
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      enable, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModContRMode (ViSession instrSession,
                                           ViInt32 mode, 
                                           ViInt32 type,
                                           ViInt32 signaltype,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 274, &mode, &type, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[274].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          , resultMode.list[mode]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ConfModContRMode 


/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModContStats
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      enable, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModContStats (ViSession instrSession,
                                           ViInt32 statistics, 
                                           ViInt32 type,
                                           ViInt32 signaltype,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 275, &statistics, &type, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[275].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          , statistics
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ConfModContStats 

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModContStats
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      repetitionCount, repetition, stopCondition, stepMode,
                type, signalType
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModContRep (ViSession instrSession,
                                               ViInt32 rep,
                                               ViInt32 stopCondition, 
                                               ViInt32 step,
                                               ViInt32 type, 
                                               ViInt32 signaltype,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
  
   checkRange( 276, &rep, &stopCondition, &step,  &type, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   sprintf( wrtBuf
          , CDMA[276].instrCommand 
          , measType.list[type]
          , signalType.list[signaltype]
          , repetition.list[rep]   
          , stopCond3.list[stopCondition]
          , stepMode.list[step]
          );
          
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   return( RSCMU_Status ); 
}  //end of RSCMU_CDMA2K_ConfModContRep

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfSubArrayMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      repetitionCount, repetition, stopCondition, stepMode,
                type, signalType
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSubArrayMod (ViSession instrSession,
                                          ViInt32 valueMode,
                                          ViInt32 startTime, 
                                          ViInt32 samples,
                                          ViInt32 type, 
                                          ViInt32 signaltype,
                                          ViChar errorMessage[])
{
    
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 277, &valueMode, &startTime, &samples, &type, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[277].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          , gateMode.list[valueMode]
          , startTime  * 1E-6
          , samples
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}
//end of RSCMU_CDMA2K_ConfSubArrayMod
/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_DefModCont 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      type, signaltype, defaultSet
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_DefModCont (ViSession instrSession,
                                           ViInt32 type, ViInt32 signaltype,
                                           ViBoolean defaultSet,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   checkRange( 629,&type, &signaltype, &defaultSet );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[629].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]          
          , enable.list[defaultSet]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );      
}//end of RSCMU_CDMA2K_DefModCont 

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_InitMod 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_InitMod (ViSession instrSession, ViInt32 type,
                                  ViInt32 signaltype, ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 278, &type, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[278].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_InitMod

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_AbortMod 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_AbortMod (ViSession instrSession, ViInt32 type,
                                   ViInt32 signaltype, ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 279, &type, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[279].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_AbortMod

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_StopMod 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_StopMod (ViSession instrSession, ViInt32 type,
                                  ViInt32 signaltype, ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 280, &type, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[280].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_StopMod


/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ContinueMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ContinueMod (ViSession instrSession, ViInt32 type,
                                      ViInt32 signaltype, ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 281, &type, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[281].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
} //end of RSCMU_CDMA2K_ContinueMod

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_FetchModStatus
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchModStatus (ViSession instrSession,
                                               ViInt32 *measurementStatus,
                                               ViInt32 *CurrentStatCycleCount,
                                               ViInt32 *CurrentEvaluationPeriod,                                               
                                               ViInt32 type, 
                                               ViInt32 signaltype,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];   

   checkRange( 282, &type, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[282].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
       // Separate the CMU response:
       RSCMU_SeparateString( rdBuf, ",", tab );

       // Get the measurement status
       RSCMU_Status = 
          RSCMU_GetMeasurementStatus( measurementStatus, tab, 0 );
          
       if( strcmp( tab[1], "NONE" ) != 0 )
       {
          sscanf( tab[1], "%d", CurrentStatCycleCount );
       }
       else
       {
          *CurrentStatCycleCount = RSCMU_OFF;
       }
       // Get the counter for current evaluation period within a cycle
       if( strcmp( tab[2], "NONE" ) != 0 )
       {
          sscanf( tab[2], "%d", CurrentEvaluationPeriod );
       }
       else
       {
          *CurrentEvaluationPeriod = RSCMU_OFF;
       }
      
   }
 

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_FetchModStatus


/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ConfModErep
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfModErep (ViSession instrSession,
                                      ViInt32 measurementEventReporting,
                                      ViInt32 type, 
                                      ViInt32 signaltype,
                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 283, &measurementEventReporting, &type, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[283].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          , eventReport.list[measurementEventReporting]    
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_ConfModErep

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_ReadMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ReadMod (ViSession instrSession,
                                  ERROR_MOD *Modulation,
                                  OVERVIEW *Overview, 
                                  ViInt32 type,
                                  ViInt32 signaltype, 
                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   checkRange( 284, &type, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[284].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   
   if( type == RSCMU_OVERVIEW )
   {
      
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Overview->EVMPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Overview->EVMRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Overview->MErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Overview->MErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Overview->PErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Overview->PErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Overview->CarrierFeedthrough
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Overview->IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[24]
                                       , &Overview->FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[27]
                                       , &Overview->TransmitTimeError
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[30]
                                       , &Overview->WaveformQuality
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[33]
                                       , &Overview->MSPower
                                       );                                       
      if( strcmp( tab[36], "NAN" ) != 0 )
      {
         sscanf( tab[36], "%d", &Overview->MeasCount );
      }
      else
      {
         Overview->MeasCount = RSCMU_NAN;
      } 
      
      if( strcmp( tab[37], "NAN" ) != 0 )
      {
         sscanf( tab[37], "%lf", &Overview->MeasOutOfTolerance );
      }
      else
      {
         Overview->MeasOutOfTolerance = RSCMU_NAN;
      }     
   }
   else
   {
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Modulation->Peak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Modulation->RMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Modulation->CarrierFeedthrough
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Modulation->IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Modulation->FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Modulation->TransmitTimeError
                                       );                                      
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Modulation->WaveformQuality
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Modulation->MSPower
                                       );                                       
      if( strcmp( tab[24], "NAN" ) != 0 )
      {
         sscanf( tab[24], "%d", &Modulation->MeasCount );
      }
      else
      {
         Modulation->MeasCount = RSCMU_NAN;
      } 
      
      if( strcmp( tab[25], "NAN" ) != 0 )
      {
         sscanf( tab[25], "%lf", &Modulation->MeasOutOfTolerance );
      }
      else
      {
         Modulation->MeasOutOfTolerance = RSCMU_NAN;
      }     
   }

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ReadMod

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_FetchMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchMod (ViSession instrSession,
                                   ERROR_MOD *Modulation,
                                   OVERVIEW *Overview, ViInt32 type,
                                   ViInt32 signaltype, ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   checkRange( 285, &type, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[285].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   
   if( type == RSCMU_OVERVIEW )
   {
      
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Overview->EVMPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Overview->EVMRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Overview->MErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Overview->MErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Overview->PErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Overview->PErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Overview->CarrierFeedthrough
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Overview->IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[24]
                                       , &Overview->FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[27]
                                       , &Overview->TransmitTimeError
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[30]
                                       , &Overview->WaveformQuality
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[33]
                                       , &Overview->MSPower
                                       );                                       
      if( strcmp( tab[36], "NAN" ) != 0 )
      {
         sscanf( tab[36], "%d", &Overview->MeasCount );
      }
      else
      {
         Overview->MeasCount = RSCMU_NAN;
      } 
      
      if( strcmp( tab[37], "NAN" ) != 0 )
      {
         sscanf( tab[37], "%lf", &Overview->MeasOutOfTolerance );
      }
      else
      {
         Overview->MeasOutOfTolerance = RSCMU_NAN;
      }     
   }
   else
   {
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Modulation->Peak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Modulation->RMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Modulation->CarrierFeedthrough
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Modulation->IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Modulation->FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Overview->TransmitTimeError
                                       );                                      
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Modulation->WaveformQuality
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Modulation->MSPower
                                       );                                       
      if( strcmp( tab[24], "NAN" ) != 0 )
      {
         sscanf( tab[24], "%d", &Modulation->MeasCount );
      }
      else
      {
         Modulation->MeasCount = RSCMU_NAN;
      } 
      
      if( strcmp( tab[25], "NAN" ) != 0 )
      {
         sscanf( tab[25], "%lf", &Modulation->MeasOutOfTolerance );
      }
      else
      {
         Modulation->MeasOutOfTolerance = RSCMU_NAN;
      }     
   }

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_FetchMod  

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_SampleMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleMod (ViSession instrSession,
                                    ERROR_MOD *Modulation,   
                                    OVERVIEW *Overview, ViInt32 type,
                                    ViInt32 signaltype, ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   checkRange( 286, &type, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[286].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   
   if( type == RSCMU_OVERVIEW )
   {
      
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Overview->EVMPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Overview->EVMRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Overview->MErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Overview->MErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Overview->PErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Overview->PErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Overview->CarrierFeedthrough
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Overview->IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[24]
                                       , &Overview->FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[27]
                                       , &Overview->TransmitTimeError
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[30]
                                       , &Overview->WaveformQuality
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[33]
                                       , &Overview->MSPower
                                       );                                       
      if( strcmp( tab[36], "NAN" ) != 0 )
      {
         sscanf( tab[36], "%d", &Overview->MeasCount );
      }
      else
      {
         Overview->MeasCount = RSCMU_NAN;
      } 
      
      if( strcmp( tab[37], "NAN" ) != 0 )
      {
         sscanf( tab[37], "%lf", &Overview->MeasOutOfTolerance );
      }
      else
      {
         Overview->MeasOutOfTolerance = RSCMU_NAN;
      }     
   }
   else
   {
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Modulation->Peak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Modulation->RMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Modulation->CarrierFeedthrough
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Modulation->IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Modulation->FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Overview->TransmitTimeError
                                       );                                      
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Modulation->WaveformQuality
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Modulation->MSPower
                                       );                                       
      if( strcmp( tab[24], "NAN" ) != 0 )
      {
         sscanf( tab[24], "%d", &Modulation->MeasCount );
      }
      else
      {
         Modulation->MeasCount = RSCMU_NAN;
      } 
      
      if( strcmp( tab[25], "NAN" ) != 0 )
      {
         sscanf( tab[25], "%lf", &Modulation->MeasOutOfTolerance );
      }
      else
      {
         Modulation->MeasOutOfTolerance = RSCMU_NAN;
      }     
   }

   return( RSCMU_Status );   
} //end of RSCMU_CDMA2K_SampleMod

/**************************************************************************
 *
 * NAME:   RSCMU_CDMA2K_CalcModMatcLim
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_CalcModMatcLim (ViSession instrSession,
                                         ERROR_MOD *Modulation,
                                         OVERVIEW *Overview, ViInt32 type,
                                         ViInt32 signaltype,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   checkRange( 287, &type, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[287].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if ( type == RSCMU_OVERVIEW )
   {
      RSCMU_Status = RSCMU_MatchLimits( &tab[0]
                                      , &Overview->EVMPeak
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[3]
                                      , &Overview->EVMRMS
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[6]
                                      , &Overview->MErrPeak
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[9]
                                      , &Overview->MErrRMS
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[12]
                                      , &Overview->PErrPeak
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[15]
                                      , &Overview->PErrRMS
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[18]
                                      , &Overview->CarrierFeedthrough
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[21]
                                      , &Overview->IQImbalance
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[24]
                                      , &Overview->FreqErr
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[27]
                                      , &Overview->TransmitTimeError
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[30]
                                      , &Overview->WaveformQuality
                                      );    
      RSCMU_Status = RSCMU_MatchLimits( &tab[30]
                                      , &Overview->MSPower
                                      );                                   
   }
   else
   {
      RSCMU_Status = RSCMU_MatchLimits( &tab[0]
                                      , &Modulation->Peak
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[3]
                                      , &Modulation->RMS
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[6]
                                      , &Modulation->CarrierFeedthrough
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[9]
                                      , &Modulation->IQImbalance
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[12]
                                      , &Modulation->FreqErr
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[15]
                                      , &Modulation->TransmitTimeError
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[18]
                                      , &Modulation->WaveformQuality
                                      );   
      RSCMU_Status = RSCMU_MatchLimits( &tab[21]
                                      , &Modulation->MSPower
                                      );
   }

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_CalcModMatcLim

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ReadArrayMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      BurstPower[], measurementSetting, type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadArrayMod (ViSession instrSession,
                                       ViReal64 BurstPower[],
                                       ViInt32 measurementSetting,
                                       ViInt32 type,
                                       ViInt32 signaltype, 
                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   checkRange( 288, &measurementSetting, &type, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );


   sprintf( wrtBuf
          , CDMA[288].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          , measMode3.list[measurementSetting]
          );

 
   RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     ); 

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , BurstPower
                             );
   
   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ReadArrayMod


/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_FetchArrayMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      BurstPower[], measurementSetting, type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchArrayMod (ViSession instrSession,
                                        ViReal64 BurstPower[],
                                        ViInt32 measurementSetting,
                                        ViInt32 type,
                                        ViInt32 signaltype,
                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   checkRange( 289, &measurementSetting, &type, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[289].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          , measMode3.list[measurementSetting]
          );

 
   RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     ); 

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , BurstPower
                             );
   
   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_FetchArrayMod



/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_SampleArrayMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      BurstPower[], measurementSetting, type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleArrayMod (ViSession instrSession,
                                         ViReal64 BurstPower[],
                                         ViInt32 measurementSetting,
                                         ViInt32 type,
                                         ViInt32 signaltype,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   checkRange( 290, &measurementSetting, &type, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );


   sprintf( wrtBuf
          , CDMA[290].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          , measMode3.list[measurementSetting]
          );

 
   RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     ); 

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , BurstPower
                             );
   
   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_SampleArrayMod

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ReadSubArrayMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      bursts[], measurementSetting, type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadSubArrayMod (ViSession instrSession,
                                          ViReal64 bursts[],
                                          ViInt32 measurementSetting,
                                          ViInt32 type,
                                          ViInt32 signaltype,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   checkRange( 291, &measurementSetting, &type, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );


   sprintf( wrtBuf
          , CDMA[291].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          , measMode3.list[measurementSetting]
          );

 
   RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     ); 

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , bursts
                             );
   
   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ReadSubArrayMod

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_FetchSubArrayMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      bursts[], measurementSetting, type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchSubArrayMod (ViSession instrSession,
                                           ViReal64 bursts[],
                                           ViInt32 measurementSetting,
                                           ViInt32 type,
                                           ViInt32 signaltype,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   checkRange( 292, &measurementSetting, &type, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );


   sprintf( wrtBuf
          , CDMA[292].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          , measMode3.list[measurementSetting]
          );

 
   RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     ); 

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , bursts
                             );
   
   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_FetchSubArrayMod

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_SampleSubArrayMod
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      bursts[], measurementSetting, type, signaltype
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleSubArrayMod (ViSession instrSession,
                                            ViReal64 bursts[],
                                            ViInt32 measurementSetting,
                                            ViInt32 type,
                                            ViInt32 signaltype,
                                            ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   checkRange( 293, &measurementSetting, &type, &signaltype );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[293].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          , measMode3.list[measurementSetting]
          );

 
   RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     ); 

      // Find all burst power values by breaking the read buffer:
      RSCMU_ReturnArrayValues( p_globalvarCDMA->rdABuf
                             , bursts
                             );
   
   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_SampleSubArrayMod


//////////////////////////// Signalling /////////////////////

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_Origination
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      timeout
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_Origination (ViSession instrSession,
                                      ViInt32 timeout, 
                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViBoolean TimerExpired = RSCMU_FALSE;
   ViInt32   state        = 0;
   clock_t   StartTime;
   clock_t   DeltaTime;

   // Check timeout is between 1 and 60 seconds.
   if( timeout < 1 )
   {
      timeout = 1;
   }
   else if( timeout > 60 )
   {
      timeout = 60;
   }

   if( RSCMU_Status == VI_SUCCESS )
   {
      // Wait for a call from MS
      StartTime = clock() / CLOCKS_PER_SEC;
      while( (state != RSCMU_CDMA_STATE_CEST) && (state != RSCMU_CDMA_STATE_VCES) && (RSCMU_Status == VI_SUCCESS) && !TimerExpired )
      {                                      
         RSCMU_Delay(0.150);   
         RSCMU_Status = RSCMU_CDMA2K_ProcSigState( instrSession
                                               , &state
                                               , errorMessage
                                               );
         DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
         if( DeltaTime >= timeout )
         {
            TimerExpired = RSCMU_TRUE;
         }
      }

      if( TimerExpired )
      {
         RSCMU_Status = RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_TIMEOUT, errorMessage );
      }
      else if( RSCMU_Status != VI_SUCCESS )
      {
         RSCMU_Status = RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_CALL_FROM_MS_FAILED, errorMessage );
      }
   }
   
   return( RSCMU_Status );
}//end of RSCMU_CDMA2K_Origination


/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_PagingCallToMS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      timeout
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_PagingCallToMS (ViSession instrSession,
                                         ViInt32 timeout, ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViStatus  status;
   ViBoolean TimerExpired = RSCMU_FALSE;
   ViInt32   state        = 0;
   ViInt32   attrTO;
   clock_t   StartTime;
   clock_t   DeltaTime;

   // Check timeout is between 1 and 60 seconds.
   if( timeout < 5 )
   {
      timeout = 5;
   }
   else if( timeout > 60 )
   {
      timeout = 60;
   }

   RSCMU_Status = viGetAttribute( instrSession, VI_ATTR_TMO_VALUE, &attrTO );

   if( attrTO < (timeout * 1000) )
   {
      RSCMU_Status = viSetAttribute( instrSession
                                   , VI_ATTR_TMO_VALUE
                                   , timeout * 1000
                                   );
   }
   
   // Paging (call to MS).
   RSCMU_Status = RSCMU_CDMA2K_ProcSigAction( instrSession
                                          , RSCMU_SIG_ACT_CTM
                                          , errorMessage
                                          );
   
   // Wait for call released from MS
   StartTime = clock() / CLOCKS_PER_SEC;
   RSCMU_Status = RSCMU_CDMA2K_ProcSigState( instrSession
                                         , &state
                                         , errorMessage
                                         );
   while( (state != RSCMU_CDMA_STATE_CEST) && (state != RSCMU_CDMA_STATE_VCES) && (RSCMU_Status == VI_SUCCESS) && !TimerExpired )
   {
      // Wait 150 ms
      RSCMU_Delay(0.150);
      
      
      RSCMU_Status = RSCMU_CDMA2K_ProcSigState( instrSession
                                            , &state
                                            , errorMessage
                                            );
      DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
      if( DeltaTime >= timeout )
      {
         TimerExpired = RSCMU_TRUE;
      }
   }

   // Determine if the test passed.
   if (!(( state == RSCMU_CDMA_STATE_CEST ) || ( state == RSCMU_CDMA_STATE_VCES )))
   {
      RSCMU_Status = RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_CALL_TO_MS_FAILED, errorMessage );
   }
   else if( TimerExpired )
   {
      RSCMU_Status = RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_TIMEOUT, errorMessage );
   }
   
   // DO NOT use RSCMU_Status since we want to return the status of
   // the paging function!!
   status = viSetAttribute( instrSession , VI_ATTR_TMO_VALUE, attrTO );

   return( RSCMU_Status );
} //end of RSCMU_CDMA2K_PagingCallToMS

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ReleaseCallFromMS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      timeout
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ReleaseCallFromMS (ViSession instrSession,
                                            ViInt32 timeout,
                                            ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;
   ViBoolean TimerExpired = RSCMU_FALSE;
   ViInt32   state        = 0;
   clock_t   StartTime;
   clock_t   DeltaTime;

   // Verify CMU is in CEST or VCES
   RSCMU_Status = RSCMU_CDMA2K_ProcSigState( instrSession, &state, errorMessage );
   if (!(( state == RSCMU_CDMA_STATE_CEST ) || ( state == RSCMU_CDMA_STATE_VCES )))
   {
      return RSCMU_CDMA_errorMessage( instrSession
                               , RSCMU_ERROR_INVALID_SIGN_STAT
                               , errorMessage
                               );
   }
   
   // Check timeout is between 1 and 60 seconds.
   if( timeout < 1 )
   {
      timeout = 1;
   }
   else if( timeout > 60 )
   {
      timeout = 60;
   }

   // Wait for call released from MS
   StartTime = clock() / CLOCKS_PER_SEC;
   while( ((state == RSCMU_CDMA_STATE_CEST) || (state == RSCMU_CDMA_STATE_VCES)) && (RSCMU_Status == VI_SUCCESS) && !TimerExpired )
   {
      RSCMU_Delay(0.150);   
      RSCMU_Status = RSCMU_CDMA2K_ProcSigState( instrSession
                                            , &state
                                            , errorMessage
                                            );
      DeltaTime = (clock() / CLOCKS_PER_SEC) - StartTime;
      if( DeltaTime >= timeout )
      {
         TimerExpired = RSCMU_TRUE;
      }
   }

   if( TimerExpired )
   {
      RSCMU_Status = RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_TIMEOUT, errorMessage );
   }
   else if( RSCMU_Status != VI_SUCCESS )
   {
      RSCMU_Status = RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_RELEASE_TO_MS_FAILED, errorMessage );
   }
   
   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ReleaseCallFromMS

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ReleaseCallfromBTS
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      timeout
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ReleaseCallfromBTS (ViSession instrSession,
                                             ViInt32 timeout,
                                             ViChar errorMessage[])
{
   ViStatus     RSCMU_Status = VI_SUCCESS;
   ViInt32      state        = 0;


   // Release the call.
   RSCMU_Status = RSCMU_CDMA2K_ProcSigAction( instrSession
                                          , RSCMU_CREL
                                          , errorMessage
                                          );
                                          
   // Wait until MS Ready
   RSCMU_Delay (timeout);

   if( RSCMU_Status == VI_SUCCESS )
   {
      RSCMU_Status = RSCMU_CDMA2K_ProcSigState( instrSession
                                            , &state
                                            , errorMessage
                                            );
      if (( state == RSCMU_CDMA_STATE_CEST )  || ( state == RSCMU_CDMA_STATE_VCES ))
      {
         RSCMU_Status = RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_RELEASE_TO_MS_FAILED, errorMessage );
      }
   }
   
   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ReleaseCallfromBTS

/*****************************************************************************
 * Function: Radio Configuration
 * Purpose:  This function selects the forward and reverse radio configuration 
 *           for the active service option.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconCurrRc (ViSession instrSession,
                                               ViInt32 f_RC, ViInt32 r_RC,
                                               ViChar errorMessage[])
{
    ViChar      command [1024];
    
    CHECK_VI_INT32_RANGE (instrSession, f_RC, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, r_RC, 1, 5, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:SCON:CURR:RC %ld,%ld",
             f_RC, r_RC);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ConfSConfSclService
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      service
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclService (ViSession instrSession,
                                              ViInt32 Service,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 360, &Service );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[360].instrCommand
          , service.list[Service]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
} //end of RSCMU_CDMA2K_ConfSConfSclService 

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ConfSConfSclLoopSOption
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      SerOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclLoopSOption (ViSession instrSession,
                                                  ViInt32 SerOption,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 361, &SerOption );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[361].instrCommand
          , serviceOption2.list[SerOption]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ConfSConfSclLoopSOption

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ConfSConfSclLoopFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      SerOption
 *
 * OUTPUTS:     *F_RC, *F_MO, *R_RC, *R_MO,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclLoopFCH (ViSession instrSession,
                                                    ViInt32 *F_RC, 
                                                    ViInt32 *F_MO,
                                                    ViInt32 *R_RC, 
                                                    ViInt32 *R_MO,
                                                    ViInt32 SerOption,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   checkRange( 362, &SerOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[362].instrCommand
          , serviceOption2.list[SerOption]  
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", F_RC );
     }
   else
     {
        *F_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[1], "NAN" ) != 0 )
     {
       sscanf( tab[1], "%d", F_MO );
     }
   else
     {
        *F_MO = RSCMU_NAN;
     } 
     
   if( strcmp( tab[2], "NAN" ) != 0 )
     {
       sscanf( tab[2], "%d", R_RC );
     }
   else
     {
        *R_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[3], "NAN" ) != 0 )
     {
       sscanf( tab[3], "%d", R_MO );
     }
   else
     {
        *R_MO = RSCMU_NAN;
     }  

   return( RSCMU_Status ); 
    
}//end of RSCMU_CDMA2K_ConfSConfSclLoopFCH

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ConfSConfSclLoopFCHRC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      F_RC, R_RC,SerOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclLoopFCHRC (ViSession instrSession,
                                                ViInt32 F_RC, ViInt32 R_RC,
                                                ViInt32 SerOption,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar   temp[512] = "\0";
   
   checkRange( 363, &F_RC, &R_RC, &SerOption);
   
   if (SerOption == RSCMU_SERV_OPT2_S02D)
   {
      if (F_RC > 4)
          F_RC = 4;
      if (R_RC > 3)
          R_RC = 3;
   }
   
   if (SerOption == RSCMU_SERV_OPT2_S09D)
   {
      if (F_RC < 2)
          F_RC = 2;
      if (R_RC < 2)
          R_RC = 2;
   }
   

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

          
   sprintf( temp
          , CDMA[363].instrCommand
          , serviceOption2.list[SerOption]
          , F_RC, R_RC
          );

   if (SerOption == RSCMU_SERV_OPT2_S55D)
   {

    if (((F_RC == 1) || (F_RC == 3) || (F_RC == 4))     &&  ((R_RC == 1) || (R_RC == 3))) strcpy(wrtBuf,"CONF:SCON:SCL:LOOP:S55D:FCH:FORW:MO 1\0");
    if (((F_RC == 2) || (F_RC == 5))                    &&  ((R_RC == 2) || (R_RC == 4))) strcpy(wrtBuf,"CONF:SCON:SCL:LOOP:S55D:FCH:FORW:MO 2\0");
    
    strcat(wrtBuf,";:\0"); 
    strcat(wrtBuf, temp);
    strcat(wrtBuf,"\0");
    
   } 
   else
    strcpy(wrtBuf, temp);

   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_ConfSConfSclLoopFCHRC


/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclLoopFCHFr
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      frameRate, SerOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclLoopFCHFr (ViSession instrSession,
                                                      ViInt32 frameRate,
                                                      ViInt32 SerOption,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 364, &frameRate, &SerOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[364].instrCommand
          , serviceOption2.list[SerOption]
          , frameRateType.list[frameRate]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ConfSConfSclLoopFCHFr

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclLoopPattern
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      pattern, SerOption,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclLoopPattern (ViSession   instrSession,
                                                        ViChar      pattern[],
                                                        ViInt32     SerOption,
                                                        ViChar      errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 365, &SerOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[365].instrCommand
          , serviceOption2.list[SerOption]
          , pattern
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of RSCMU_CDMA2K_ConfSConfSclLoopPattern

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclLoopPattGen
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      patternGeneration,serviceOption,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclLoopPattGen (ViSession instrSession,
                                                     ViInt32 patternGeneration,
                                                     ViInt32 SerOption,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 366, &patternGeneration, &SerOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[366].instrCommand
          , serviceOption2.list[SerOption]
          , patternGen.list[patternGeneration]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ConfSConfSclLoopPattGen

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclSpeechSOpt
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      SerOption,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclSpeechSOpt (ViSession instrSession,
                                                    ViInt32 SerOption,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 367, &SerOption );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[367].instrCommand
          , serviceOption.list[SerOption]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ConfSConfSclSpeechSOpt


/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclSpeechFCH 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      SerOption,
 *
 * OUTPUTS:      *f_RC, *f_MO, *r_RC, *r_MO,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclSpeechFCH (ViSession instrSession,
                                                ViInt32 *F_RC, ViInt32 *F_MO,
                                                ViInt32 *R_RC, ViInt32 *R_MO,
                                                ViInt32 SerOption,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   checkRange( 368, &SerOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[368].instrCommand
          , serviceOption.list[SerOption]  
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", F_RC );
     }
   else
     {
        *F_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[1], "NAN" ) != 0 )
     {
       sscanf( tab[1], "%d", F_MO );
     }
   else
     {
        *F_MO = RSCMU_NAN;
     } 
     
   if( strcmp( tab[2], "NAN" ) != 0 )
     {
       sscanf( tab[2], "%d", R_RC );
     }
   else
     {
        *R_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[3], "NAN" ) != 0 )
     {
       sscanf( tab[3], "%d", R_MO );
     }
   else
     {
        *R_MO = RSCMU_NAN;
     }  

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_ConfSConfSclSpeechFCH 

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclSpeechFCH 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      F_RC, R_RC, SerOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclSpeechFCHRC (ViSession instrSession,
                                                  ViInt32 F_RC, ViInt32 R_RC,
                                                  ViInt32 SerOption,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 369, &F_RC, &R_RC, &SerOption);
   
   if ((SerOption == RSCMU_SERV_OPT_S01D) || (SerOption == RSCMU_SERV_OPT_S03D))
   {
      if (F_RC > 4)
          F_RC = 4;
      if (R_RC > 3)
          R_RC = 3;
   }
   
   if ((SerOption == RSCMU_SERV_OPT_S17D) || (SerOption ==RSCMU_SERV_OPT_SX8T) || (SerOption == RSCMU_SERV_OPT_S68D))
   {
      if (F_RC < 2)
          F_RC = 2;
      if (R_RC < 2)
          R_RC = 2;
   }
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[369].instrCommand
          , serviceOption.list[SerOption]
          , F_RC, R_RC
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ConfSConfSclSpeechFCHRC

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConSclSpeechVcoder
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      F_RC, R_RC, SerOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/    

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConSclSpeechVcoder (ViSession instrSession,
                                                        ViInt32 SerOption,
                                                        ViInt32 VCoder,
                                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;             


   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;    
   
   // test CMU FW release   
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_08)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_08, errorMessage); 

   // Init variable 
   strcpy(errorMessage,"\0");
 
   if(((VCoder == RSCMU_VOCODER_SET_V8) && (SerOption != RSCMU_SERV_OPT_S01D))||
      ((VCoder == RSCMU_VOCODER_SET_V8E)&&(SerOption !=RSCMU_SERV_OPT_S03D)) ||   
      ((VCoder == RSCMU_VOCODER_SET_V13)&&(SerOption != RSCMU_SERV_OPT_S17D))||
      ((VCoder == RSCMU_VOCODER_SET_V8L)&&(SerOption != RSCMU_SERV_OPT_S01D))||
      ((VCoder == RSCMU_VOCODER_SET_V8EL)&&(SerOption != RSCMU_SERV_OPT_S03D))||
      ((VCoder == RSCMU_VOCODER_SET_V13L)&&(SerOption != RSCMU_SERV_OPT_S17D))||
      (((VCoder != RSCMU_VOCODER_SET_ECHO)||(VCoder != RSCMU_VOCODER_SET_DEF))&&(SerOption == RSCMU_SERV_OPT_S56D)||
      (((VCoder != RSCMU_VOCODER_SET_ECHO)||(VCoder != RSCMU_VOCODER_SET_DEF))&&(SerOption == RSCMU_SERV_OPT_SX8T))) ||
      ((VCoder == RSCMU_VOCODER_SET_ON) && (SerOption != RSCMU_SERV_OPT_S68D)) ||
      ((VCoder == RSCMU_VOCODER_SET_OLOW) && (SerOption != RSCMU_SERV_OPT_S68D)))
      
   {
    RSCMU_Status = -1;
    sprintf(errorMessage, "Service Option %s and Vocoder Selection %s can't match together\0", serviceOption.list[SerOption], voiceCoder.list[VCoder]);
   }
   else
   {
    checkRange( 359, &SerOption, &VCoder);
    getBuffers( instrSession
              , &wrtBuf
              , &rdBuf
              , errorMessage
              );

    sprintf( wrtBuf
           , CDMA[359].instrCommand
           , serviceOption.list[SerOption]
           , voiceCoder.list[VCoder]
           );

    RSCMU_Status = RSCMU_Query( instrSession
                              , wrtBuf
                              , rdBuf
                              , RSCMU_STB_ON
                              , errorMessage
                              );

   }
   return( RSCMU_Status );     
}//end of RSCMU_CDMA2K_ConfSConSclSpeechVcoder
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSconSclSpeechEDelay
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      serviceOption, echoDelay
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclSpeechEDelay (ViSession instrSession,
                                                        ViInt32 ServiceOption,
                                                        ViReal64 echoDelay,
                                                        ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   checkRange( 611, &serviceOption, &echoDelay );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[611].instrCommand
          , serviceOption.list[ServiceOption]
          , echoDelay
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );     
}//end of RSCMU_CDMA2K_ConfSconSclSpeechEDelay

/*****************************************************************************
 * Function: Init Voice Coder
 * Purpose:  This function initiates the voice coder of service option 68.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitSconSclSpeechVCoder (ViSession instrSession,
                                                        ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession, "INIT:SCON:SCL:SPE:S68D:VOC"));   
}

/*****************************************************************************
 * Function: Average Encoding Rate
 * Purpose:  This function selects the average encoding rate.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclSpeechEncRate (ViSession instrSession,
                                                         ViInt32 encodingRate,
                                                         ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:SCON:SCL:SPE:S68D:ENC:ARAT",
                           encodingRate,
                           encodingRateArr,
                           RSCMU_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATSOption
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATSOption (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 444, &currentServiceOption );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[444].instrCommand
          , serviceOption2.list[currentServiceOption]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ConfSConfSclTDATSOption
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATFch 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      currentSerOption,
 *
 * OUTPUTS:      *f_RC, *f_MO, *r_RC, *r_MO,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATFch (ViSession instrSession,
                                                    ViInt32 *f_RC, ViInt32 *f_MO,
                                                    ViInt32 *r_RC, ViInt32 *r_MO,
                                                    ViInt32 currentServiceOption,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   checkRange( 446, &currentServiceOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[446].instrCommand
          , serviceOption2.list[currentServiceOption]  
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", f_RC );
     }
   else
     {
        *f_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[1], "NAN" ) != 0 )
     {
       sscanf( tab[1], "%d", f_MO );
     }
   else
     {
        *f_MO = RSCMU_NAN;
     } 
     
   if( strcmp( tab[2], "NAN" ) != 0 )
     {
       sscanf( tab[2], "%d", r_RC );
     }
   else
     {
        *r_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[3], "NAN" ) != 0 )
     {
       sscanf( tab[3], "%d", r_MO );
     }
   else
     {
        *r_MO = RSCMU_NAN;
     }  

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_ConfSConfSclTDATFch 

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATComFchRc 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      F_RC, R_RC, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATComFchRc (ViSession instrSession,
                                                         ViInt32 f_RC,
                                                         ViInt32 r_RC,
                                                         ViInt32 currentServiceOption,
                                                         ViChar errorMessage[])
{                                                        
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 445, &currentServiceOption,&f_RC, &r_RC);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[445].instrCommand
          , serviceOption2.list[currentServiceOption]
          , f_RC, r_RC
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_ConfSConfSclTDATComFchRc

/*****************************************************************************
 * Function: Supplementary Channel Setting
 * Purpose:  This function disables or enables the forward supplemental 
 *           channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATOSchOn (ViSession instrSession,
                                                       ViBoolean SCH1Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "PROC:SCON:SCL1:PDAT:S33D:SCH:ONE:%s:ENAB",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           SCH1Enable,
                           stateArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: MuxPDUs Per Physical Layer
 * Purpose:  This function sets the MuxPDUs per physical layer SDU which is 
 *           used to determine Multiplex Option and Data Rate of the forward 
 *           supplemental channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATOMppl (ViSession instrSession,
                                                      ViInt32 MPPL,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    if ((MPPL != 1) &&
        (MPPL != 2) &&
        (MPPL != 4) &&
        (MPPL != 8))
        RETMSG (VI_ERROR_PARAMETER2);
        
    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:SCH:ONE:%s:MPPL",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setViInt32 (instrSession,
                              command,
                              MPPL,
                              1, 8,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Frame Type
 * Purpose:  This function sets the frame type used for the forward 
 *           supplemental channel 1 to determine the Multiplex Option and Data 
 *           Rate.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOFType (ViSession instrSession,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViInt32 frameType,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER2, errorMessage);

    sprintf (command, "CONF:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:FRTY",
             directionArr[trafficChannelDirection]);
    RETMSG (RSCMU_setViInt32 (instrSession,
                              command,
                              frameType,
                              0, 1,
                              VI_ERROR_PARAMETER4));
}

/*****************************************************************************
 * Function: Setting
 * Purpose:  This function disables or enables the forward supplemental 
 *           channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATOSchOn (ViSession instrSession,
                                                       ViBoolean SCH1Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "PROC:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:ENAB",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           SCH1Enable,
                           stateArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Pattern Generation
 * Purpose:  This function sets the pattern generation for service option 32 
 *           to either a random or fixed pattern for the forward fundamental 
 *           channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOPattGn (ViSession instrSession,
                                                        ViInt32 patternGeneration,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:PGEN",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           patternGeneration,
                           patternArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Pattern
 * Purpose:  This function defines the pattern used by the pattern generator 
 *           for service option 32.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOPat (ViSession instrSession,
                                                     ViChar pattern[],
                                                     ViInt32 trafficChannelDirection,
                                                     ViInt32 currentServiceOption,
                                                     ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:PATT \"%s\"",
             directionArr[trafficChannelDirection],
             pattern);
    
    RETMSG (RSCMU_sendCmd (instrSession,
                              command));
}

/*****************************************************************************
 * Function: Pattern Generation
 * Purpose:  This function sets the pattern generation for service option 32 
 *           to either a random or fixed pattern for the forward fundamental 
 *           channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATOPattGn (ViSession instrSession,
                                                        ViInt32 patternGeneration,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "PROC:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:PGEN",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           patternGeneration,
                           patternArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Pattern
 * Purpose:  This function defines the pattern used by the pattern generator 
 *           for service option 32.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATOPat (ViSession instrSession,
                                                     ViChar pattern[],
                                                     ViInt32 trafficChannelDirection,
                                                     ViInt32 currentServiceOption,
                                                     ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "PROC:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:PATT \"%s\"",
             directionArr[trafficChannelDirection],
             pattern);
    
    RETMSG (RSCMU_sendCmd (instrSession,
                           command));
}

/*****************************************************************************
 * Function: Circular Buffer Frames
 * Purpose:  This function sets the number of frames to use in the circular 
 *           buffer of the forward secondary channel 1 when the random pattern 
 *           is selected.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOCBFrm (ViSession instrSession,
                                                       ViInt32 circularBufferFrames,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:CBFR",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setViInt32 (instrSession,
                              command,
                              circularBufferFrames,
                              1, 255,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Tx On Period
 * Purpose:  This function sets the transmission on period in frames of the 
 *           forward supplemental channel 1 when the frame activity is 
 *           deterministic.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOTxon (ViSession instrSession,
                                                      ViInt32 transmitOnPeriod,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:TXON",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setViInt32 (instrSession,
                              command,
                              transmitOnPeriod,
                              0, 255,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Circular Buffer Frames
 * Purpose:  This function sets the number of frames to use in the circular 
 *           buffer of the forward secondary channel 1 when the random pattern 
 *           is selected.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATOCBFrm (ViSession instrSession,
                                                       ViInt32 circularBufferFrames,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "PROC:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:CBFR",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setViInt32 (instrSession,
                              command,
                              circularBufferFrames,
                              1, 255,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Tx On Period
 * Purpose:  This function sets the transmission on period in frames of the 
 *           forward supplemental channel 1 when the frame activity is 
 *           deterministic.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATOTxon (ViSession instrSession,
                                                      ViInt32 transmitOnPeriod,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "PROC:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:TXON",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setViInt32 (instrSession,
                              command,
                              transmitOnPeriod,
                              0, 255,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Tx Off Period
 * Purpose:  This function sets the transmission off period in frames of the 
 *           forward supplemental channel 1 when the frame activity is 
 *           deterministic.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOTxoff (ViSession instrSession,
                                                       ViInt32 transmitOffPeriod,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:TXOF",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setViInt32 (instrSession,
                              command,
                              transmitOffPeriod,
                              0, 255,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Coding Method
 * Purpose:  This function returns the coding method of the forward 
 *           supplemental channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOCoding (ViSession instrSession,
                                                        ViInt32 coding,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);

    sprintf (command, "CONF:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:COD",
             directionArr[trafficChannelDirection]);
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           coding,
                           codingArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Tx Off Period
 * Purpose:  This function sets the transmission off period in frames of the 
 *           forward supplemental channel 1 when the frame activity is 
 *           deterministic.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATOTxoff (ViSession instrSession,
                                                       ViInt32 transmitOffPeriod,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "PROC:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:TXOF",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setViInt32 (instrSession,
                              command,
                              transmitOffPeriod,
                              0, 255,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Query Data Rate
 * Purpose:  This function returns the data rate of the forward supplemental 
 *           channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATODataR (ViSession instrSession,
                                                       ViReal64 *dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    sprintf (command, "CONF:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:DRAT?",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_getViReal64 (instrSession,
                              command,
                              dataRate,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Query Data Rate
 * Purpose:  This function returns the data rate of the forward supplemental 
 *           channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATODataR (ViSession instrSession,
                                                       ViReal64 *dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    sprintf (command, "PROC:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:DRAT?",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_getViReal64 (instrSession,
                              command,
                              dataRate,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Query Radio & Mux Config
 * Purpose:  This function returns the radio configuration and multiplex 
 *           option of the forward and reverse suplemental traffic channel 1 
 *           for service option 32D.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOSch (ViSession instrSession,
                                                     ViInt32 *f_RC,
                                                     ViInt32 *f_MO,
                                                     ViInt32 *r_RC,
                                                     ViInt32 *r_MO,
                                                     ViInt32 currentServiceOption,
                                                     ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      response [1024];
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "PROC:SCON:SCL1:TDAT:S32D:SCH:ONE?",
                                    response, 1024,
                                    -1));
    sscanf (response, "%ld,%ld,%ld,%ld", f_RC, f_MO, r_RC, r_MO);
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: MIP Stand Alone Mode
 * Purpose:  This function selects the MIP mode that the CMU is configured 
 *           for.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipSam(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViBoolean   mipStandAloneMode,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:SCON:SCL1:PDAT:S33D:MIP:SAM",
                           mipStandAloneMode,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Secret
 * Purpose:  This function defines the secret used by the R&S CMU to do Mobile 
 *           IP MD5 authentication in MIP stand alone mode.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipHas(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViString    secret,
 ViChar errorMessage[]
)
{
    ViChar  command[40];
    
    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:MIP:HAS '%s'", secret);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Mobile Node Home IP Address
 * Purpose:  This function defines the IP address of the mobile in its home 
 *           network.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipMhip(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViInt32 ipAddresspart1,
    ViInt32 ipAddresspart2,
    ViInt32 ipAddresspart3,
    ViInt32 ipAddresspart4,
 ViChar errorMessage[]
)
{
    ViChar  command[WR_BUFFER_SIZE];
    
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart1, 0, 255, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart2, 0, 255, RSCMU_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart3, 0, 255, RSCMU_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart4, 0, 255, RSCMU_ERROR_PARAMETER5, errorMessage);
    
    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:MIP:MHIP %ld,%ld,%ld,%ld", ipAddresspart1,
                                                                           ipAddresspart2,
                                                                           ipAddresspart3,
                                                                           ipAddresspart4);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Foreign Agent Home IP Address
 * Purpose:  This function defines the IP address of the of the Foreign Agent. 
 *           The command is only available in MIP gateway mode 
 *           (CONFigure:SCONfig:SCLass1:PDAT :S33D:MIP:SAMode OFF).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipFaip(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViInt32 ipAddresspart1,
    ViInt32 ipAddresspart2,
    ViInt32 ipAddresspart3,
    ViInt32 ipAddresspart4,
 ViChar errorMessage[]
)
{
    ViChar  command[WR_BUFFER_SIZE];
    
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart1, 0, 255, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart2, 0, 255, RSCMU_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart3, 0, 255, RSCMU_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart4, 0, 255, RSCMU_ERROR_PARAMETER5, errorMessage);
    
    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:MIP:FAIP %ld,%ld,%ld,%ld", ipAddresspart1,
                                                                           ipAddresspart2,
                                                                           ipAddresspart3,
                                                                           ipAddresspart4);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: MS Node Home Agent IP Address
 * Purpose:  This function queries the IP address of the Home Agent. This 
 *           address is programmed in the mobile and used for registration and 
 *           tunneling purposes. It is captured and displayed when a mobile IP 
 *           call is made.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipHaip(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViInt32*    ipAddresspart1,
    ViInt32*    ipAddresspart2,
    ViInt32*    ipAddresspart3,
    ViInt32*    ipAddresspart4,
 ViChar errorMessage[]
)
{
    ViStatus    RSCMU_Status;
    ViChar      buffer[RD_BUFFER_SIZE];
    ViChar      *str;
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "CONF:SCON:SCL1:PDAT:S33D:MIP:HAIP?",
                                    buffer,
                                    RD_BUFFER_SIZE,
                                    0));
    
    GET_VI_INT32 (*ipAddresspart1, buffer, ",");
    GET_VI_INT32 (*ipAddresspart2, VI_NULL, ",");
    GET_VI_INT32 (*ipAddresspart3, VI_NULL, ",");
    GET_VI_INT32 (*ipAddresspart4, VI_NULL, ",");
    
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Care of Address
 * Purpose:  This function queries the IP address that the Foreign Agent uses 
 *           to decapsulate packets which have been tunneled by the home agent 
 *           and to deliver them to the mobile node. The address is captured 
 *           and displayed when a mobile IP call is made.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipCoad(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViInt32*    ipAddresspart1,
    ViInt32*    ipAddresspart2,
    ViInt32*    ipAddresspart3,
    ViInt32*    ipAddresspart4,
 ViChar errorMessage[]
)
{
    ViStatus    RSCMU_Status;
    ViChar      buffer[RD_BUFFER_SIZE];
    ViChar      *str;
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "CONF:SCON:SCL1:PDAT:S33D:MIP:COAD?",
                                    buffer,
                                    RD_BUFFER_SIZE,
                                    0));
    
    GET_VI_INT32 (*ipAddresspart1, buffer, ",");
    GET_VI_INT32 (*ipAddresspart2, VI_NULL, ",");
    GET_VI_INT32 (*ipAddresspart3, VI_NULL, ",");
    GET_VI_INT32 (*ipAddresspart4, VI_NULL, ",");
    
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: MIP Agent Advertisements
 * Purpose:  This function enables or disables the R&S CMU to broadcast MIP 
 *           Agent Advertisements to advertise its presence on the network. The 
 *           function is only available in MIP stand alone mode 
 *           (CONFigure:SCONfig:SCLass1:PDAT :S33D:MIP:SAMode OFF).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipAadv(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViBoolean   mipAgentAdvertisements,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:SCON:SCL1:PDAT:S33D:MIP:AADV",
                           mipAgentAdvertisements,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Registration Reply Code
 * Purpose:  This function defines a code number sent to the mobile in the 
 *           CAUSE_CODE field of the Registration Reply message. The function 
 *           is only available in MIP stand alone mode 
 *           (CONFigure:SCONfig:SCLass1:PDAT:S33D:MIP:SAMode OFF).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipRrc(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViInt32 codeNo,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:SCON:SCL1:PDAT:S33D:MIP:RRC",
                              codeNo,
                              0, 136,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Registration Reply Lifetime
 * Purpose:  This function defines the number of seconds remaining before the 
 *           registration is considered expired. The function is only available 
 *           in MIP stand alone mode 
 *           CONFigure:SCONfig:SCLass1:PDAT:S33D:MIP:SAMode OFF).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipRrlt(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViReal64    time,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                              "CONF:SCON:SCL1:PDAT:S33D:MIP:RRLT",
                              time,
                              0, 65535,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Authentication Type
 * Purpose:  This function defines the MIP authentication type used.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATMipAuth (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViInt32 authenticationType,
                                                        ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:SCON:SCL1:PDAT:S33D:MIP:AUTH:TYPE",
                           authenticationType,
                           mipAuthTypeArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Packet Data Service Current Set
 * Purpose:  This function determines the service option to use when
 *           establishing a call in the packet data mode, particularly for
 *           the high data rates using the supplemental channels (SCH).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATSOption (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession,
                          "CONF:SCON:SCL1:PDAT:SOPT S33D"));
}

/*****************************************************************************
 * Function: Fundamental Channel
 * Purpose:  This function returns the radio configuration and multiplex 
 *           option of the forward and reverse fundamental traffic channel for 
 *           service option 33D.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATFch (ViSession instrSession,
                                                    ViInt32 *f_RC, ViInt32 *f_MO,
                                                    ViInt32 *r_RC, ViInt32 *r_MO,
                                                    ViInt32 currentServiceOption,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      response [1024];
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "CONF:SCON:SCL1:PDAT:S33D:FCH?",
                                    response, 1024,
                                    -1));
    sscanf (response, "%ld,%ld,%ld,%ld", f_RC, f_MO, r_RC, r_MO);
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Common Radio Configuration
 * Purpose:  This function sets a common radio configuration of the 
 *           fundamental and supplementalforward and reverse traffic channel 
 *           for service option 33D.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATComFchRc (ViSession instrSession,
                                                         ViInt32 f_RC,
                                                         ViInt32 r_RC,
                                                         ViInt32 currentServiceOption,
                                                         ViChar errorMessage[])
{
    ViChar      command [1024];
    
    CHECK_VI_INT32_RANGE (instrSession, f_RC, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, r_RC, 1, 5, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:FSC:RC %ld,%ld",
             f_RC, r_RC);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATFchRc 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      f_RC, r_RC, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATFchRc (ViSession instrSession,
                                                      ViInt32 *f_RC, 
                                                      ViInt32 *r_RC,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[])
{                                                      
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
    struct RSCMU_CDMA_Globals  *p_globalvarCDMA;  

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version <= RSCMU200_V3_10)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

//   checkRange( 447, &currentServiceOption , &f_RC, &r_RC);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[447].instrCommand
          , serviceOption2.list[currentServiceOption]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", r_RC );
     }
   else
     {
        *r_RC = RSCMU_NAN;
     } 
                             
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", r_RC );
     }
   else
     {
        *r_RC = RSCMU_NAN;
     } 

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ConfSConfSclTDATFchRc

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ConfSConfSclTDATPattern
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      pattern, trafficChannelDirection,currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATPattern (ViSession instrSession,
                                                        ViChar pattern[],
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 449, &currentServiceOption, &trafficChannelDirection);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[449].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , pattern
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ConfSConfSclTDATPattern

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ConfSConfSclTDATPattGen
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      patternGeneration, trafficChannelDirection,currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATPattGen (ViSession instrSession,
                                                        ViInt32 patternGeneration,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 448, &currentServiceOption, &trafficChannelDirection, &patternGeneration);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[448].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , patternGen.list[patternGeneration]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ConfSConfSclTDATPattGen
                                     
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATCBFrame 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      circularBufferFrames, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATCBFrame (ViSession instrSession,
                                                        ViInt32 circularBufferFrames,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 450, &currentServiceOption, &trafficChannelDirection, &circularBufferFrames);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[450].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , circularBufferFrames
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ConfSConfSclTDATCBFrame
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATTxon 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      transmitOnPeriod, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATTxon (ViSession instrSession,
                                                     ViInt32 transmitOnPeriod,
                                                     ViInt32 trafficChannelDirection,
                                                     ViInt32 currentServiceOption,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 451, &currentServiceOption, &trafficChannelDirection, &transmitOnPeriod);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[451].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , transmitOnPeriod
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ConfSConfSclTDATTxon    

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATTxoff 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      transmitOffPeriod, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATTxoff (ViSession instrSession,
                                                      ViInt32 transmitOffPeriod,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 452, &currentServiceOption, &trafficChannelDirection, &transmitOffPeriod);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[452].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , transmitOffPeriod
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ConfSConfSclTDATTxoff   

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATSchZEn 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      SCH0Enable, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATSchZEn (ViSession instrSession,
                                                       ViBoolean SCH0Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 453, &currentServiceOption, &trafficChannelDirection, &SCH0Enable);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[453].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , enable.list[SCH0Enable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ConfSConfSclTDATSchZEn

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ConfSConfSclTDATSchZero
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      currentServiceOption
 *
 * OUTPUTS:     *F_RC, *F_MO, *R_RC, *R_MO,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATSchZero (ViSession instrSession,
                                                        ViInt32 *f_RC,
                                                        ViInt32 *f_MO,
                                                        ViInt32 *r_RC,
                                                        ViInt32 *r_MO,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   checkRange( 454, &currentServiceOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[454].instrCommand
          , serviceOption2.list[currentServiceOption]  
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", f_RC );
     }
   else
     {
        *f_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[1], "NAN" ) != 0 )
     {
       sscanf( tab[1], "%d", f_MO );
     }
   else
     {
        *f_MO = RSCMU_NAN;
     } 
     
   if( strcmp( tab[2], "NAN" ) != 0 )
     {
       sscanf( tab[2], "%d", r_RC );
     }
   else
     {
        *r_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[3], "NAN" ) != 0 )
     {
       sscanf( tab[3], "%d", r_MO );
     }
   else
     {
        *r_MO = RSCMU_NAN;
     }  

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_ConfSConfSclTDATSchZero

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATZeroRc 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      currentServiceOption, f_RC, r_RC
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZeroRc (ViSession instrSession,
                                                   ViInt32 *f_RC, 
                                                   ViInt32 *r_RC,
                                                   ViInt32 currentServiceOption,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;  

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version <= RSCMU200_V3_10)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
   
   //checkRange( 455, &currentServiceOption, &f_RC, r_RC );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[455].instrCommand
          , serviceOption2.list[currentServiceOption]  
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", f_RC );
     }
   else
     {
        *f_RC = RSCMU_NAN;
     } 

   if( strcmp( tab[1], "NAN" ) != 0 )
     {
       sscanf( tab[1], "%d", r_RC );
     }
   else
     {
        *r_RC = RSCMU_NAN;
     } 
   
   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ConfSConfSclTDATZeroRc

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATZPattern 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      pattern, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZPattern (ViSession instrSession,
                                                        ViChar pattern[],
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 457, &currentServiceOption, &trafficChannelDirection);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[457].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , pattern
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ConfSConfSclTDATZPattern

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATZPattGen 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      patternGeneration, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZPattGen (ViSession instrSession,
                                                         ViInt32 patternGeneration,
                                                         ViInt32 trafficChannelDirection,
                                                         ViInt32 currentServiceOption,
                                                         ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 456, &currentServiceOption, &trafficChannelDirection, &patternGeneration);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[456].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , patternGen.list[patternGeneration]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ConfSConfSclTDATZPattGen
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATZCBFr 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      circularBufferFrames, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZCBFrame (ViSession instrSession,
                                                      ViInt32 circularBufferFrames,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 458, &currentServiceOption, &trafficChannelDirection, &circularBufferFrames);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[458].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , circularBufferFrames
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ConfSConfSclTDATZCBFrame

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATZTxon 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      transmitOnPeriod, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZTxon (ViSession instrSession,
                                                      ViInt32 transmitOnPeriod, 
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[])
                                                      
{  
    ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 459, &currentServiceOption, &trafficChannelDirection, &transmitOnPeriod);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[459].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , transmitOnPeriod
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ConfSConfSclTDATZTxon

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATZTxoff 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      transmitOffPeriod, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZTxoff (ViSession instrSession,
                                                       ViInt32 transmitOffPeriod,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 460, &currentServiceOption, &trafficChannelDirection, &transmitOffPeriod);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[460].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , transmitOffPeriod
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ConfSConfSclTDATZTxoff
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATZFsize 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     frameSize
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZFsize (ViSession instrSession,
                                                       ViInt32 *frameSize,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];      
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;  

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version <= RSCMU200_V3_10)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
   
   checkRange( 461, &currentServiceOption, &trafficChannelDirection);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[461].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
      // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", frameSize );
     }
   else
     {
        *frameSize = RSCMU_NAN;
     } 
  
   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ConfSConfSclTDATZFsize
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATZFType 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     frameType
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
// JMG 020926
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZFType (ViSession instrSession,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViInt32 frameType,
                                                       ViChar errorMessage[])
/*ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZFType (ViSession instrSession,
                                                       ViInt32 *frameType,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
*/                                                       
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   
   checkRange( 463, &currentServiceOption, &trafficChannelDirection);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[463].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , frameType
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
/*                             
      // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", frameType );
     }
   else
     {
        *frameType = RSCMU_NAN;
     } 
*/  
   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ConfSConfSclTDATZFType

/*****************************************************************************
 * Function: IP Address
 * Purpose:  This function defines the IP address of the MS (Reverse) and the 
 *           BS/CMU (Forward).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATSchIpad (ViSession instrSession,
                                                        ViInt32 IPAddress_part1,
                                                        ViInt32 IPAddress_part2,
                                                        ViInt32 IPAddress_part3,
                                                        ViInt32 IPAddress_part4,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, IPAddress_part1, 0, 255, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, IPAddress_part2, 0, 255, VI_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, IPAddress_part3, 0, 255, VI_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, IPAddress_part4, 0, 255, VI_ERROR_PARAMETER5, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER6, errorMessage);
    
    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:%s:IPAD %ld,%ld,%ld,%ld",
             directionArr[trafficChannelDirection],
             IPAddress_part1, IPAddress_part2, IPAddress_part3, IPAddress_part4);
    
    RETMSG (RSCMU_sendCmd (instrSession,
                           command));
}

/*****************************************************************************
 * Function: Dynamic IP Address
 * Purpose:  This function queries the dynamically allocated PPP IP addresses 
 *           of the MS (:REVerse) and the BS/CMU (:FORWard). The addresses are 
 *           available if the CMU is configured for dynamic IP addressing using 
 *           DHCP (CONFigure:IPADdress:MODE DYNamic).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATDynIpad(
    ViSession   instrSession,
    ViInt32 trafficChannelDirection,
    ViInt32 currentServiceOption,
    ViInt32*    ipAddresspart1,
    ViInt32*    ipAddresspart2,
    ViInt32*    ipAddresspart3,
    ViInt32*    ipAddresspart4,
 ViChar errorMessage[]
)
{
    ViStatus    RSCMU_Status;
    ViChar      buffer[RD_BUFFER_SIZE];
    ViChar      command[50];
    ViChar      *str;
    
    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:%s:DYN:IPAD?", directionArr[trafficChannelDirection]);
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    command,
                                    buffer,
                                    RD_BUFFER_SIZE,
                                    0));
    
    GET_VI_INT32 (*ipAddresspart1, buffer, ",");
    GET_VI_INT32 (*ipAddresspart2, VI_NULL, ",");
    GET_VI_INT32 (*ipAddresspart3, VI_NULL, ",");
    GET_VI_INT32 (*ipAddresspart4, VI_NULL, ",");
    
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: PPP Authentication Type
 * Purpose:  This function selects the authentication protocol for Simple IP 
 *           connections. Authentication must be disabled for Mobile IP 
 *           connections.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATAuthType(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViInt32 type,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:SCON:SCL1:PDAT:S33D:AUTH:TYPE",
                           type,
                           authTypeArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Username
 * Purpose:  This function selects the username for CHAP or PAP authentication 
 *           (CONFigure:SCONfig:SCLass1:PDAT:S33D:AUTHentic:TYPE).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATAuthUnam(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViString    username,
 ViChar errorMessage[]
)
{
    ViChar      command[50];
    
    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:AUTH:UNAM '%s'", username);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Password
 * Purpose:  This function selects the password for CHAP or PAP authentication 
 *           (CONFigure:SCONfig:SCLass1:PDAT:S33D:AUTHentic:TYPE).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATAuthPwor(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViString    password,
 ViChar errorMessage[]
)
{
    ViChar      command[50];
    
    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:AUTH:PWOR '%s'", password);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: CHAP Interval
 * Purpose:  This function defines the time interval for CHAP authentication 
 *           (CONFigure:SCONfig:SCLass1:PDAT:S33D:AUTHentic:TYPE). The interval 
 *           defines how often the mobile is deauthenticated with the system.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATAuthCint(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViReal64    chapInterval,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                               "CONF:SCON:SCL1:PDAT:S33D:AUTH:CINT",
                               chapInterval,
                               30.0, 600.0,
                               RSCMU_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Network PPP Inactivity Timer
 * Purpose:  This function defines the time interval after which the CMU will 
 *           transition the MS from PPP Connected to PPP Dormant state if there 
 *           is no data being sent to the MS.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATIacNiat(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViBoolean   state,
    ViReal64    networkInactivityTimer,
 ViChar errorMessage[]
)
{
    if (state)
    {
        RETMSG (RSCMU_setViReal64 (instrSession,
                                   "CONF:SCON:SCL1:PDAT:S33D:IAC:NIAT",
                                   networkInactivityTimer,
                                   5.0, 60.0,
                                   RSCMU_ERROR_PARAMETER4));
    }
    else
    {
        RETMSG (RSCMU_sendCmd (instrSession, "CONF:SCON:SCL1:PDAT:S33D:IAC:NIAT OFF"));
    }
}

/*****************************************************************************
 * Function: MS Dormant Control
 * Purpose:  This function enables or disables packet data dormant timer 
 *           control of the MS. The setting takes effect only after a Service 
 *           Option Control Message is transferred to the MS 
 *           (CONFigure:SCONfig:SCLass<nr>:PDAT:S33D:IAControl:SOCMessage).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATIacMsdc(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViBoolean   msDormantControl,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:SCON:SCL1:PDAT:S33D:IAC:MSDC",
                           msDormantControl,
                           stateArr,
                           RSCMU_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: MS Dormant Timer
 * Purpose:  This function defines the time that the MS, after receiving data 
 *           in the PPP Dormant state, will wait before returning to PPP 
 *           Connected. The time is not used if MS dormant control is disabled 
 *           (CONFigure:SCONfig:SCLass1:PDAT:S33D:IAControl:MSDControl OFF). 
 *           Moreover the setting takes effect only after a Service Option 
 *           Control Message is transferred to the MS 
 *           (CONFigure:SCONfig:SCLass<nr>:PDAT:S33D:IAControl :SOCMessage).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATIacMsdt(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViReal64    msDormantTimer,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                               "CONF:SCON:SCL1:PDAT:S33D:IAC:MSDT",
                               msDormantTimer,
                               0.0, 25.5,
                               RSCMU_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Service Option Ctrl Message
 * Purpose:  This function sends a Service Option Control Message to the MS in 
 *           order to configure its MS Dormant Timer and MS Dormant Control 
 *           parameters 
 *           (CONFigure:SCONfig:SCLass1:PDAT:S33D:IAControl:MSDTimer, 
 *           CONFigure:SCONfig:SCLass1:PDAT:S33D:IAControl:MSDControl).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitSConfSclPDATIacSocm(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "INIT:SCON:SCL1:PDAT:S33D:IAC:SOCM"));
}

/*****************************************************************************
 * Function: SO Ctrl Message State
 * Purpose:  This function returns the status of the Service Option Control 
 *           Message transfer from the CMU to the MS 
 *           (CONFigure:SCONfig:SCLass<nr>:PDAT:S33D:IAControl:SOCMessage).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SensSConfSclPDATIacSOS(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViInt32*    soCtrlMessageState,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_getViInt32 (instrSession,
                              ":SCON:SCL1:PDAT:S33D:IAC:SOCM:STAT?",
                              soCtrlMessageState,
                              RSCMU_ERROR_PARAMETER3));
}
/*****************************************************************************
 * Function: Target PDSN
 * Purpose:  This function qualifies whether the Packet Data Service Node 
 *           (PDSN) is changed along with the Packet Zone ID, or whether it 
 *           remains unchanged.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATPzonTpds(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViInt32 targetPDSN,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:SCON:SCL1:PDAT:S33D:PZON:TPDS",
                           targetPDSN,
                           pdsnArr,
                           RSCMU_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Packet Zone Connect Control
 * Purpose:  This function defines the value of the PKT_CON_CNTL parameter 
 *           defined in the standard.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATPzonCctr(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViInt32 packetZoneConnectControl,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:SCON:SCL1:PDAT:S33D:PZON:CCTR",
                              packetZoneConnectControl,
                              0, 3,
                              RSCMU_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Packet Zone List Length
 * Purpose:  This function defines the value of the PKT_ZONE_LIST_LEN 
 *           parameter defined in the standard.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATPzonLlen(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViInt32 packetZoneListLength,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:SCON:SCL1:PDAT:S33D:PZON:LLEN",
                              packetZoneListLength,
                              1, 15,
                              RSCMU_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Service Option Ctrl Message
 * Purpose:  This function sends a Service Option Control Message to the MS in 
 *           order to configure its Packet Zone Connect. Control and Packet 
 *           Zone List Length parameters 
 *           (CONFigure:SCONfig:SCLass1:PDAT:S33D:PZONe:CCTRl, 
 *           CONFigure:SCONfig:SCLass1:PDAT:S33D:PZONe:LLENgth).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitSConfSclPDATPzonSocm(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "INIT:SCON:SCL1:PDAT:S33D:PZON:SOCM"));
}

/*****************************************************************************
 * Function: SO Ctrl Message State
 * Purpose:  This function returns the status of the Service Option Control 
 *           Message transfer from the CMU to the MS 
 *           (CONFigure:SCONfig:SCLass<nr>:PDAT:S33D:PZONe:SOCMessage).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SensSConfSclPDATPzonSOS(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViInt32*    soCtrlMessageState,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_getViInt32 (instrSession,
                              ":SCON:SCL1:PDAT:S33D:PZON:SOCM:STAT?",
                              soCtrlMessageState,
                              RSCMU_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Supplementary Channel Setting
 * Purpose:  This function disables or enables the reverse supplemental 
 *           channel 0.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATSchZEn (ViSession instrSession,
                                                       ViBoolean SCH0Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:SCH:ZERO:%s:ENAB",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           SCH0Enable,
                           stateArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: MuxPDUs Per Physical Layer
 * Purpose:  This function sets the MuxPDUs per physical layer SDU which is 
 *           used to determine Multiplex Option and Data Rate of the forward 
 *           supplemental channel 0.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZMppl (ViSession instrSession,
                                                      ViInt32 MPPL,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[]) 
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   
   checkRange( 462, &currentServiceOption, &trafficChannelDirection);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[462].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , MPPL
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
/*                             
      // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", MPPL );
     }
   else
     {
        *MPPL = RSCMU_NAN;
     } 
*/  
   return( RSCMU_Status );   
   
}//end of RSCMU_CDMA2K_ConfSConfSclTDATZMppl

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATZCoding 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     coding
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZCoding (ViSession instrSession,
                                                        ViChar coding[],
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];  
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;  

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
       return RSCMU_Status;                                        

   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version <= RSCMU200_V3_10)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 
   
   checkRange( 464, &currentServiceOption, &trafficChannelDirection);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[464].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
      // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%s", coding );
     }
   else
     {
        *coding = RSCMU_NAN;
     } 
 
   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ConfSConfSclTDATZCoding
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSConfSclTDATZDataR 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     dataRate
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATZDataR (ViSession instrSession,
                                                       ViInt32 *dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];      
   
   checkRange( 465, &currentServiceOption, &trafficChannelDirection);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[465].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
      // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", dataRate );
     }
   else
     {
        *dataRate = RSCMU_NAN;
     } 
 
   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ConfSConfSclTDATZDataR


/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATSOption
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATSOption (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 466, &currentServiceOption );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[466].instrCommand
          , serviceOption2.list[currentServiceOption]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ProcSConfSclTDATSOption
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATFch 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      currentSerOption,
 *
 * OUTPUTS:      *f_RC, *f_MO, *r_RC, *r_MO,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATFch (ViSession instrSession,
                                                    ViInt32 *f_RC, ViInt32 *f_MO,
                                                    ViInt32 *r_RC, ViInt32 *r_MO,
                                                    ViInt32 currentServiceOption,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   checkRange( 468, &currentServiceOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[468].instrCommand
          , serviceOption2.list[currentServiceOption]  
          );
   
   // 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", f_RC );
     }
   else
     {
        *f_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[1], "NAN" ) != 0 )
     {
       sscanf( tab[1], "%d", f_MO );
     }
   else
     {
        *f_MO = RSCMU_NAN;
     } 
     
   if( strcmp( tab[2], "NAN" ) != 0 )
     {
       sscanf( tab[2], "%d", r_RC );
     }
   else
     {
        *r_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[3], "NAN" ) != 0 )
     {
       sscanf( tab[3], "%d", r_MO );
     }
   else
     {
        *r_MO = RSCMU_NAN;
     }  

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_ProcSConfSclTDATFch 

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATComFchRc 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      F_RC, R_RC, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATComFchRc (ViSession instrSession,
                                                         ViInt32 f_RC,
                                                         ViInt32 r_RC,
                                                         ViInt32 currentServiceOption,
                                                         ViChar errorMessage[])
{                                                        
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 467, &currentServiceOption,&f_RC, &r_RC);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[467].instrCommand
          , serviceOption2.list[currentServiceOption]
          , f_RC, r_RC
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_ProcSConfSclTDATComFchRc

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATFchRc 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      f_RC, r_RC, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
/*ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATFchRc (ViSession instrSession,
                                                      ViInt32 f_RC, ViInt32 r_RC,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[])
{                                                      
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 469, &currentServiceOption, &f_RC, &r_RC);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[469].instrCommand
          , serviceOption2.list[currentServiceOption]
          , f_RC, r_RC
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ProcSConfSclTDATFchRc
*/
/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ProcSConfSclTDATPattern
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      pattern, trafficChannelDirection,currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATPattern (ViSession instrSession,
                                                        ViChar pattern[],
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 471, &currentServiceOption, &trafficChannelDirection);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[471].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , pattern
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ProcSConfSclTDATPattern

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ProcSConfSclTDATPattGen
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      patternGeneration, trafficChannelDirection,currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATPattGen (ViSession instrSession,
                                                        ViInt32 patternGeneration,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 470, &currentServiceOption, &trafficChannelDirection, &patternGeneration);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[470].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , patternGen.list[patternGeneration]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ProcSConfSclTDATPattGen
                                     
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATCBFrame 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      circularBufferFrames, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATCBFrame (ViSession instrSession,
                                                        ViInt32 circularBufferFrames,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 472, &currentServiceOption, &trafficChannelDirection, &circularBufferFrames);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[472].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , circularBufferFrames
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ProcSConfSclTDATCBFrame
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATTxon 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      transmitOnPeriod, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATTxon (ViSession instrSession,
                                                     ViInt32 transmitOnPeriod,
                                                     ViInt32 trafficChannelDirection,
                                                     ViInt32 currentServiceOption,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 473, &currentServiceOption, &trafficChannelDirection, &transmitOnPeriod);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[473].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , transmitOnPeriod
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ProcSConfSclTDATTxon    

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATTxoff 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      transmitOffPeriod, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATTxoff (ViSession instrSession,
                                                      ViInt32 transmitOffPeriod,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 474, &currentServiceOption, &trafficChannelDirection, &transmitOffPeriod);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[474].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , transmitOffPeriod
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ProcSConfSclTDATTxoff   

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATSchZEn 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      SCH0Enable, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATSchZEn (ViSession instrSession,
                                                       ViBoolean SCH0Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 475, &currentServiceOption, &trafficChannelDirection, &SCH0Enable);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[475].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , enable.list[SCH0Enable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ProcSConfSclTDATSchZEn

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ProcSConfSclTDATSchZero
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      currentServiceOption
 *
 * OUTPUTS:     *F_RC, *F_MO, *R_RC, *R_MO,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATSchZero (ViSession instrSession,
                                                        ViInt32 *f_RC,
                                                        ViInt32 *f_MO,
                                                        ViInt32 *r_RC,
                                                        ViInt32 *r_MO,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   checkRange( 476, &currentServiceOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[476].instrCommand
          , serviceOption2.list[currentServiceOption]  
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", f_RC );
     }
   else
     {
        *f_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[1], "NAN" ) != 0 )
     {
       sscanf( tab[1], "%d", f_MO );
     }
   else
     {
        *f_MO = RSCMU_NAN;
     } 
     
   if( strcmp( tab[2], "NAN" ) != 0 )
     {
       sscanf( tab[2], "%d", r_RC );
     }
   else
     {
        *r_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[3], "NAN" ) != 0 )
     {
       sscanf( tab[3], "%d", r_MO );
     }
   else
     {
        *r_MO = RSCMU_NAN;
     }  

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_ProcSConfSclTDATSchZero

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATZeroRc 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      currentServiceOption, f_RC, r_RC
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

/*ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZeroRc (ViSession instrSession,
                                                   ViInt32 f_RC, ViInt32 r_RC,
                                                   ViInt32 currentServiceOption,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 477, &currentServiceOption, &f_RC, r_RC );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[477].instrCommand
          , serviceOption2.list[currentServiceOption]           
          , f_RC, r_RC
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} *///end of RSCMU_CDMA2K_ProcSConfSclTDATZeroRc

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATZPattern 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      pattern, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZPattern (ViSession instrSession,
                                                        ViChar pattern[],
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 479, &currentServiceOption, &trafficChannelDirection);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[479].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , pattern
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ProcSConfSclTDATZPattern
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATZPattGen 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      patternGeneration, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZPattGen (ViSession instrSession,
                                                         ViInt32 patternGeneration,
                                                         ViInt32 trafficChannelDirection,
                                                         ViInt32 currentServiceOption,
                                                         ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 478, &currentServiceOption, &trafficChannelDirection, &patternGeneration);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[478].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , patternGen.list[patternGeneration]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ProcSConfSclTDATZPattGen
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATZCBFr 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      circularBufferFrames, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZCBFrame (ViSession instrSession,
                                                      ViInt32 circularBufferFrames,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 480, &currentServiceOption, &trafficChannelDirection, &circularBufferFrames);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[480].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , circularBufferFrames
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ProcSConfSclTDATZCBFrame

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATZTxon 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      transmitOnPeriod, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZTxon (ViSession instrSession,
                                                      ViInt32 transmitOnPeriod, 
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[])
                                                      
{  
    ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 481, &currentServiceOption, &trafficChannelDirection, &transmitOnPeriod);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[481].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , transmitOnPeriod
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of vRSCMU_CDMA2K_ProcSConfSclTDATZTxon
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATZTxoff 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      transmitOffPeriod, trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZTxoff (ViSession instrSession,
                                                       ViInt32 transmitOffPeriod,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 482, &currentServiceOption, &trafficChannelDirection, &transmitOffPeriod);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[482].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          , transmitOffPeriod
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ProcSConfSclTDATZTxoff
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATZFsize 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     frameSize
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
/*ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZFsize (ViSession instrSession,
                                                       ViInt32 *frameSize,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];      
   
   checkRange( 483, &currentServiceOption, &trafficChannelDirection);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[483].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
      // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", frameSize );
     }
   else
     {
        *frameSize = RSCMU_NAN;
     } 
  
   return( RSCMU_Status );  
} *///end of RSCMU_CDMA2K_ProcSConfSclTDATZFsize
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATZFType 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     frameType
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
/*ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZFType (ViSession instrSession,
                                                       ViInt32 *frameType,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];  
   
   checkRange( 485, &currentServiceOption, &trafficChannelDirection);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[485].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
      // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", frameType );
     }
   else
     {
        *frameType = RSCMU_NAN;
     } 
  
   return( RSCMU_Status );   
}*///end of RSCMU_CDMA2K_ProcSConfSclTDATZFType
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATZMppl 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     MPPL
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
/*ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZMppl (ViSession instrSession,
                                                      ViInt32 *MPPL,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];           
   
   checkRange( 484, &currentServiceOption, &trafficChannelDirection);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[484].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
      // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", MPPL );
     }
   else
     {
        *MPPL = RSCMU_NAN;
     } 
  
   return( RSCMU_Status );     
} *///end of RSCMU_CDMA2K_ProcSConfSclTDATZMppl
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATZCoding 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     coding
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
/*ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZCoding (ViSession instrSession,
                                                        ViChar coding[],
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];  
   
   checkRange( 486, &currentServiceOption, &trafficChannelDirection);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[486].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
      // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%s", coding );
     }
   else
     {
        *coding = RSCMU_NAN;
     } 
 
   return( RSCMU_Status ); 
} */  //end of RSCMU_CDMA2K_ProcSConfSclTDATZCoding
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclTDATZDataR 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      trafficChannelDirection, currentServiceOption
 *
 * OUTPUTS:     dataRate
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATZDataR (ViSession instrSession,
                                                       ViInt32 *dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];      
   
   checkRange( 487, &currentServiceOption, &trafficChannelDirection);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[487].instrCommand
          , serviceOption2.list[currentServiceOption]
          , direction.list[trafficChannelDirection]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
      // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", dataRate );
     }
   else
     {
        *dataRate = RSCMU_NAN;
     } 
 
   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ProcSConfSclTDATZDataR

/*****************************************************************************
 * Function: Frame Type
 * Purpose:  This function sets the MuxPDUs per physical layer SDU which is
 *           used to determine Multiplex Option and Data Rate of the forward
 *           supplemental channel 0.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATZMppl (ViSession instrSession,
                                                      ViInt32 MPPL,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    if ((MPPL != 1) &&
        (MPPL != 2) &&
        (MPPL != 4) &&
        (MPPL != 8))
        RETMSG (VI_ERROR_PARAMETER2);
        
    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:SCH:ZERO:%s:MPPL",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setViInt32 (instrSession,
                              command,
                              MPPL,
                              1, 8,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Frame Type
 * Purpose:  This function sets the frame type used for the forward 
 *           supplemental channel 0 to determine the Multiplex Option and Data 
 *           Rate.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATZFType (ViSession instrSession,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViInt32 frameType,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER2, errorMessage);

    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:SCH:ZERO:%s:FRTY",
             directionArr[trafficChannelDirection]);
    RETMSG (RSCMU_setViInt32 (instrSession,
                              command,
                              frameType,
                              0, 1,
                              VI_ERROR_PARAMETER4));
}

/*****************************************************************************
 * Function: Coding Method
 * Purpose:  This function returns the coding method of the supplemental 
 *           channel 0.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATZCoding (ViSession instrSession,
                                                        ViInt32 coding,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);

    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:SCH:ZERO:%s:COD",
             directionArr[trafficChannelDirection]);
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           coding,
                           codingArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Query Radio & Mux Config
 * Purpose:  This function returns the radio configuration and multiplex
*            option of the forward and reverse suplemental traffic channel 1
 *           for service option 32D.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclTDATOSch (ViSession instrSession,
                                                     ViInt32 *f_RC,
                                                     ViInt32 *f_MO,
                                                     ViInt32 *r_RC,
                                                     ViInt32 *r_MO,
                                                     ViInt32 currentServiceOption,
                                                     ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      response [1024];
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "PROC:SCON:SCL1:TDAT:S32D:SCH:ONE?",
                                    response, 1024,
                                    -1));
    sscanf (response, "%ld,%ld,%ld,%ld", f_RC, f_MO, r_RC, r_MO);
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Packet Data Service Current Set
 * Purpose:  This function determines the service option to use when
 *           establishing a call in the packet data mode, particularly for
 *           the high data rates using the supplemental channels (SCH).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATSOption (ViSession instrSession,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession,
                          "PROC:SCON:SCL1:PDAT:SOPT S33D"));
}

/*****************************************************************************
 * Function: Fundamental Channel
 * Purpose:  This function returns the radio configuration and multiplex 
 *           option of the forward and reverse fundamental traffic channel for 
 *           service option 33D.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATFch (ViSession instrSession,
                                                    ViInt32 *f_RC, ViInt32 *f_MO,
                                                    ViInt32 *r_RC, ViInt32 *r_MO,
                                                    ViInt32 currentServiceOption,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      response [1024];
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "PROC:SCON:SCL1:PDAT:S33D:FCH?",
                                    response, 1024,
                                    -1));
    sscanf (response, "%ld,%ld,%ld,%ld", f_RC, f_MO, r_RC, r_MO);
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Common Radio Configuration
 * Purpose:  This function sets a common radio configuration of the 
 *           fundamental and supplementalforward and reverse traffic channel 
 *           for service option 33D.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATComFchRc (ViSession instrSession,
                                                         ViInt32 f_RC,
                                                         ViInt32 r_RC,
                                                         ViInt32 currentServiceOption,
                                                         ViChar errorMessage[])
{
    ViChar      command [1024];
    
    CHECK_VI_INT32_RANGE (instrSession, f_RC, 1, 5, VI_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, r_RC, 1, 5, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "PROC:SCON:SCL1:PDAT:S33D:FSC:RC %ld,%ld",
             f_RC, r_RC);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Setting
 * Purpose:  This function disables or enables the reverse supplemental 
 *           channel 0.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATSchZEn (ViSession instrSession,
                                                       ViBoolean SCH0Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "PROC:SCON:SCL1:PDAT:S33D:SCH:ZERO:%s:ENAB",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           SCH0Enable,
                           stateArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Return Radio Config
 * Purpose:  This function returns the radio configuration and multiplex 
 *           option of the forward and reverse supplemental traffic channel 0 
 *           for service option 33.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATSchZero (ViSession instrSession,
                                                        ViInt32 *f_RC,
                                                        ViInt32 *f_MO,
                                                        ViInt32 *r_RC,
                                                        ViInt32 *r_MO,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      response [1024];
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "PROC:SCON:SCL1:PDAT:S33D:SCH:ZERO?",
                                    response, 1024,
                                    -1));
    sscanf (response, "%ld,%ld,%ld,%ld", f_RC, f_MO, r_RC, r_MO);
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Query Data Rate
 * Purpose:  This function returns the data rate of the forward or reverse 
 *           supplemental channel 0.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATZDataR (ViSession instrSession,
                                                       ViReal64 *dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    sprintf (command, "PROC:SCON:SCL1:PDAT:S33D:SCH:ZERO:%s:DRATe?",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_getViReal64 (instrSession,
                              command,
                              dataRate,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Query Data Rate
 * Purpose:  This function returns the data rate of the forward or reverse 
 *           supplemental channel 0.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATZDataR (ViSession instrSession,
                                                       ViReal64 *dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:SCH:ZERO:%s:DRAT?",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_getViReal64 (instrSession,
                              command,
                              dataRate,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Query Radio & Mux Config
 * Purpose:  This function returns the radio configuration and multiplex 
 *           option of the forward and reverse supplemental traffic channel 0 
 *           for service option 33.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATSchZero (ViSession instrSession,
                                                        ViInt32 *f_RC,
                                                        ViInt32 *f_MO,
                                                        ViInt32 *r_RC,
                                                        ViInt32 *r_MO,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      response [1024];
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "CONF:SCON:SCL1:PDAT:S33D:SCH:ZERO?",
                                    response, 1024,
                                    -1));
    sscanf (response, "%ld,%ld,%ld,%ld", f_RC, f_MO, r_RC, r_MO);
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Supplementary Channel Setting
 * Purpose:  This function disables or enables the reverse supplemental 
 *           channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATSchOEn (ViSession instrSession,
                                                       ViBoolean SCH1Enable,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:SCON:SCL1:PDAT:S33D:SCH:ONE:FORW:ENAB",
                           SCH1Enable,
                           stateArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Supplementary Channel Setting
 * Purpose:  This function disables or enables the reverse supplemental 
 *           channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOSchOn (ViSession instrSession,
                                                       ViBoolean SCH1Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "CONF:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:ENAB",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           SCH1Enable,
                           stateArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: MuxPDUs Per Physical Layer
 * Purpose:  This function sets the MuxPDUs per physical layer SDU which is 
 *           used to determine Multiplex Option and Data Rate of the forward 
 *           supplemental channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclTDATOMppl (ViSession instrSession,
                                                      ViInt32 MPPL,
                                                      ViInt32 trafficChannelDirection,
                                                      ViInt32 currentServiceOption,
                                                      ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    if ((MPPL != 1) &&
        (MPPL != 2) &&
        (MPPL != 4) &&
        (MPPL != 8))
        RETMSG (VI_ERROR_PARAMETER2);
        
    sprintf (command, "CONF:SCON:SCL1:TDAT:S32D:SCH:ONE:%s:MPPL",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setViInt32 (instrSession,
                              command,
                              MPPL,
                              1, 8,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Frame Type
 * Purpose:  This function sets the frame type used for the forward 
 *           supplemental channel 1 to determine the Multiplex Option and Data 
 *           Rate.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATOFType (ViSession instrSession,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViInt32 frameType,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER2, errorMessage);

    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:SCH:ONE:%s:FRTY",
             directionArr[trafficChannelDirection]);
    RETMSG (RSCMU_setViInt32 (instrSession,
                              command,
                              frameType,
                              0, 1,
                              VI_ERROR_PARAMETER4));
}

/*****************************************************************************
 * Function: Coding Method
 * Purpose:  This function returns the coding method of the supplemental 
 *           channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATOCoding (ViSession instrSession,
                                                        ViInt32 coding,
                                                        ViInt32 trafficChannelDirection,
                                                        ViInt32 currentServiceOption,
                                                        ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);

    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:SCH:ONE:%s:COD",
             directionArr[trafficChannelDirection]);
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           coding,
                           codingArr,
                           VI_ERROR_PARAMETER2));
} 

/*****************************************************************************
 * Function: Setting
 * Purpose:  This function disables or enables the reverse supplemental 
 *           channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATSchOEn (ViSession instrSession,
                                                       ViBoolean SCH1Enable,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    
    sprintf (command, "PROC:SCON:SCL1:PDAT:S33D:SCH:ONE:%s:ENAB",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_setEnum (instrSession,
                           command,
                           SCH1Enable,
                           stateArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Return Radio Config
 * Purpose:  This function returns the radio configuration and multiplex 
 *           option of the forward and reverse supplemental traffic channel 1 
 *           for service option 33. The function is valid in the Call 
 *           Established state.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATSchOne (ViSession instrSession,
                                                       ViInt32 *f_RC,
                                                       ViInt32 *f_MO,
                                                       ViInt32 *r_RC,
                                                       ViInt32 *r_MO,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      response [1024];
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "PROC:SCON:SCL1:PDAT:S33D:SCH:ONE?",
                                    response, 1024,
                                    -1));
    sscanf (response, "%ld,%ld,%ld,%ld", f_RC, f_MO, r_RC, r_MO);
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Query Data Rate
 * Purpose:  This function returns the data rate of the forward or reverse 
 *           supplemental channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclPDATODataR (ViSession instrSession,
                                                       ViReal64 *dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    sprintf (command, "PROC:SCON:SCL1:PDAT:S33D:SCH:ONE:%s:DRATe?",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_getViReal64 (instrSession,
                              command,
                              dataRate,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Query Data Rate
 * Purpose:  This function returns the data rate of the forward or reverse 
 *           supplemental channel 1.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATODataR (ViSession instrSession,
                                                       ViReal64 *dataRate,
                                                       ViInt32 trafficChannelDirection,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViChar  command[128];
    
    CHECK_VI_INT32_RANGE (instrSession, trafficChannelDirection, 0, 1, VI_ERROR_PARAMETER3, errorMessage);
    sprintf (command, "CONF:SCON:SCL1:PDAT:S33D:SCH:ONE:%s:DRAT?",
             directionArr[trafficChannelDirection]);
    
    RETMSG (RSCMU_getViReal64 (instrSession,
                              command,
                              dataRate,
                              VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Query Radio & Mux Config
 * Purpose:  This function returns the radio configuration and multiplex 
 *           option of the forward and reverse supplemental traffic channel 1 
 *           for service option 33.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATSchOne (ViSession instrSession,
                                                       ViInt32 *f_RC,
                                                       ViInt32 *f_MO,
                                                       ViInt32 *r_RC,
                                                       ViInt32 *r_MO,
                                                       ViInt32 currentServiceOption,
                                                       ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      response [1024];
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "CONF:SCON:SCL1:PDAT:S33D:SCH:ONE?",
                                    response, 1024,
                                    -1));
    sscanf (response, "%ld,%ld,%ld,%ld", f_RC, f_MO, r_RC, r_MO);
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Service Option
 * Purpose:  This function selects the service option for the Messaging 
 *           Teleservice.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSOpt (ViSession instrSession,
                                                   ViInt32 WMTServiceOption,
                                                   ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:SCON:SCL1:WMT:SOPT",
                           WMTServiceOption,
                           wmtServiceAllArr,
                           VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: WMT Current Set
 * Purpose:  This function returns the service option for the Messaging 
 *           Teleservice. If used in CONN state, it returns that it is possible 
 *           to send an SMS.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSOption (ViSession instrSession,
                                                      ViInt32 *WMTCurrentSet,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];      
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *) CDMA[612].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
      // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "S06D" ) == 0 )
       *WMTCurrentSet = RSCMU_WMT_S06D;
       else   if( strcmp( tab[0], "CCON" ) == 0 )    
          *WMTCurrentSet = RSCMU_WMT_CCON;
          else
              *WMTCurrentSet = RSCMU_NAN;       

   return( RSCMU_Status );       
}//end of RSCMU_CDMA2K_ConfSconSclWMTSOption

/*****************************************************************************
 * Function: Packet Zone ID
 * Purpose:  This function selects a packet data services zone identifier to 
 *           be transferred to the MS.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclPDATPzonId(
    ViSession   instrSession,
    ViInt32 currentServiceOption,
    ViInt32 packetZoneID,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:SCON:SCL1:PDAT:S33D:PZON:ID",
                              packetZoneID,
                              0, 255,
                              RSCMU_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Outgoing Message File
 * Purpose:  Sets an index of the file containing the outgoing SMS content.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSMSFile (ViSession instrSession,
                                                      ViInt32 file,
                                                      ViChar errorMessage[])
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:SCON:SCL1:WMT:SMS:FILE",
                              file,
                              1, 3,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Outgoing File SMS State
 * Purpose:  This function verifies whether or not the specified file has
 *           been loaded succesfully.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsFilStat (ViSession instrSession,
                                                         ViInt32 *state,
                                                         ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      buffer [RD_BUFFER_SIZE];
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "SENS:SCON:SCL1:WMT:SMS:FILE:STAT?",
                                    buffer,
                                    RD_BUFFER_SIZE,
                                    0));
    *state = (strncmp (buffer, "OK", 2) == 0);
    return RSCMU_Status;
}

/*****************************************************************************
 * Function: Outgoing File SMS Length
 * Purpose:  This function returns the length of the SMS message to be sent.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsFilLen (ViSession instrSession,
                                                        ViInt32 *outgoingLength,
                                                        ViChar errorMessage[])
{
    RETMSG (RSCMU_getViInt32 (instrSession,
                              "CONF:SCON:SCL1:WMT:SMS:FILE:LENG?",
                              outgoingLength,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Max Outgoing SMS Length
 * Purpose:  This function restricts the maximum length of the SMS message to 
 *           be sent (including the optional time stamp which is of the form 
 *           [CMU200 00:00:00]) and truncates the Outgoing SMS 
 *           (CONFigure:SCONfig:SCLass1:WMT:SMS:TEXT) to the selected number of 
 *           characters.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsLeng(
    ViSession   instrSession,
    ViInt32 maxOutgoingSMSLength,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setViInt32 (instrSession,
                              "CONF:SCON:SCL1:WMT:SMS:LENG",
                              maxOutgoingSMSLength,
                              18, 152,
                              RSCMU_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSconSclWMTSmsText 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      messageText
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsText (ViSession instrSession,
                                                      ViChar messageText[],
                                                      ViChar errorMessage[])
{ 
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[613].instrCommand
          , messageText
          );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );      
}//end of RSCMU_CDMA2K_ConfSconSclWMTSmsText
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSconSclWMTSmsAckEnab 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      acknowledgeFromMobile
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsAckEnab (ViSession instrSession,
                                                         ViInt32 acknowledgeFromMobile,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    

   checkRange( 614, &acknowledgeFromMobile);


   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[614].instrCommand
          , modeEnable.list[acknowledgeFromMobile]
          );
   
   // 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );          
}//end of RSCMU_CDMA2K_ConfSconSclWMTSmsAckEnab

/*****************************************************************************
 * Function: Outgoing Message Handle
 * Purpose:  This function qualifies whether the outgoing SMS message content
 *           is entered manually (using RC
 *           CONFigure:SCONfig:SCLass1:WMT:SMS[:INTernal]:TEXT[?]) or is
 *           taken from an existing file, which is specified using
 *           CONFigure:SCONfig:SCLass$1$:WMT:SMS:FILE[?].
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSMSHand (ViSession instrSession,
                                                      ViInt32 handle,
                                                      ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:SCON:SCL1:WMT:SMS:HAND",
                           handle,
                           wmtHandleArr,
                           RSCMU_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSconSclWMTSmsTSTEnab 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      timeStampOnOutgoingMessage
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsTSTEnab (ViSession instrSession,
                                                         ViInt32 timeStampOnOutgoingMessage,
                                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    

   checkRange( 615, &timeStampOnOutgoingMessage);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[615].instrCommand
          , modeEnable.list[timeStampOnOutgoingMessage]
          );
   
   // 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );      
}//end of RSCMU_CDMA2K_ConfSconSclWMTSmsTSTEnab
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSconSclWMTSOption 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     f_RC, f_MO, r_RC, r_MO
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSConfSclWMTFCH (ViSession instrSession,
                                                   ViInt32 serviceOption,
                                                   ViInt32 *f_RC, ViInt32 *f_MO,
                                                   ViInt32 *r_RC, ViInt32 *r_MO,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   checkRange( 616, &serviceOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[616].instrCommand
          , serviceOption3.list[serviceOption]  
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", f_RC );
     }
   else
     {
        *f_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[1], "NAN" ) != 0 )
     {
       sscanf( tab[1], "%d", f_MO );
     }
   else
     {
        *f_MO = RSCMU_NAN;
     } 
     
   if( strcmp( tab[2], "NAN" ) != 0 )
     {
       sscanf( tab[2], "%d", r_RC );
     }
   else
     {
        *r_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[3], "NAN" ) != 0 )
     {
       sscanf( tab[3], "%d", r_MO );
     }
   else
     {
        *r_MO = RSCMU_NAN;
     }  

   return( RSCMU_Status );      
} //end of RSCMU_CDMA2K_ConfSConfSclWMTFCH
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConfSconSclWMTFCHRC 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      f_RC, r_RC
 *
 * OUTPUTS:     dataRate
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTFCHRC (ViSession instrSession,
                                                    ViInt32 serviceOption,
                                                    ViInt32 f_RC, ViInt32 r_RC,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   checkRange( 617, &serviceOption, &f_RC, &r_RC);

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[617].instrCommand
          , serviceOption3.list[serviceOption]
          , f_RC, r_RC
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );      
}//end of RSCMU_CDMA2K_ConfSconSclWMTFCHRC

/*****************************************************************************
 * Function: SMS Radio Configuration
 * Purpose:  This function sets a common radio configuration of the 
 *           fundamental forward and reverse traffic channel for selected 
 *           service option.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSMSFCHRC (ViSession instrSession,
                                                       ViInt32 serviceOption,
                                                       ViInt32 f_RC,
                                                       ViInt32 r_RC,
                                                       ViChar errorMessage[])
{
    ViChar      command [1024];
    
    CHECK_VI_INT32_RANGE (instrSession, serviceOption, 0, 1, VI_ERROR_PARAMETER2, errorMessage);
    
    if (serviceOption)
    {
        if ((f_RC != 2) && (f_RC != 5))
            return VI_ERROR_PARAMETER3;
        if ((r_RC != 2) && (r_RC != 4))
            return VI_ERROR_PARAMETER4;
    }
    else
    {
        if ((f_RC != 1) && (f_RC != 3) && (f_RC != 4))
            return VI_ERROR_PARAMETER3;
        if ((r_RC != 1) && (r_RC != 3))
            return VI_ERROR_PARAMETER4;
    }
    
    sprintf (command, "CONFigure:SCONfig:SCLass1:WMT:SMS:%s:FCH:RC %ld,%ld",
             wmtServiceArr [serviceOption], f_RC, r_RC);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcBSSRfChannel 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      channel
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSRfChannel (ViSession instrSession,
                                           ViInt32 channel,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 370, &channel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[370].instrCommand
          , channel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );                
}

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcBSSRfFrequency
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      frequency,units,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSRfFrequency (ViSession instrSession,
                                             ViReal64 frequency,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   // checkRange routine is not used due to bug in how unions are
   // handled when initializing float types.
   if( frequency < 0.2 )  frequency = 0.2;
   if( frequency > 2700 ) frequency = 2700;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[371].instrCommand
          , frequency
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );
}

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcBSSRfPowCDMA
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      power
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSRfPowCDMA (ViSession instrSession,
                                           ViReal64 power, 
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[372].instrCommand
          , power
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}// end of RSCMU_CDMA2K_ProcBSSRfPowCDMA

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcBSSFFCHLevel 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      power
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFFCHLevel (ViSession instrSession,
                                           ViReal64 FFCHLevel, 
                                           ViBoolean Enable, 
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 373, &FFCHLevel);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[373].instrCommand
          , FFCHLevel
          , enable.list[Enable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
} //end of RSCMU_CDMA2K_ProcBSSFFCHLevel


/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcBSSFFCHChannel 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      FFCHChannel
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFFCHChannel (ViSession instrSession,
                                             ViInt32 FFCHChannel,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 374, &FFCHChannel);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[374].instrCommand
          , FFCHChannel
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ProcBSSFFCHChannel

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcBSSFFCHFrameOffset 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      FFCHFrame
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFFCHFrameOffset (ViSession instrSession,
                                                 ViInt32 FfchFrameOffset,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 375, &FFCHFrameOffset);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[375].instrCommand
          , FfchFrameOffset
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ProcBSSFFCHFrameOffset
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ProcBSSQofFFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSQofFFCH (ViSession instrSession,
                                               ViInt32 QOF,
                                               ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 358, &QOF );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[358].instrCommand
          , QOF
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ProcBSSQofFFCH()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ProcBSSFSCHLevelZero
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFSCHLevelZero (ViSession instrSession,
                                                     ViReal64 FSCHLevel,
                                                     ViBoolean Enable,
                                                     ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 507, &FSCHLevel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
    sprintf( wrtBuf
          , CDMA[507].instrCommand
          , FSCHLevel
          , enable.list[Enable]
          );
 
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ProcBSSFSCHLevelZero()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ProcBSSFSCHChannelZero
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFSCHChannelZero (ViSession instrSession,
                                                       ViInt32 FSCHChannel,
                                                       ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 508, &FSCHChannel );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[508].instrCommand
          , FSCHChannel
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ProcBSSFSCHChannelZero()

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ProcBSSFSCHFrameOffZero
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFSCHFrameOffZero (ViSession instrSession,
                                                        ViInt32 FSCHFrameOffset,
                                                        ViChar errorMessage[])

{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 509, &FSCHFrameOffset );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[509].instrCommand
          , FSCHFrameOffset
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ProcBSSFSCHFrameOffZero()
/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_ProcBSSQofFSCHZero
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSQofFSCHZero (ViSession instrSession,
                                                   ViInt32 QOF,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 510, &QOF );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
             
   sprintf( wrtBuf
          , CDMA[510].instrCommand
          , QOF
          );
        
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );

} //end of RSCMU_CDMA2K_ProcBSSQofFSCHZero()

/*****************************************************************************
 * Function: FSCH Level
 * Purpose:  This function determines the signal level of the supplemental 
 *           traffic channel 1 in the forward CDMA channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFSCHLevelOne (ViSession instrSession,
                                                    ViReal64 FSCHLevel,
                                                    ViBoolean enable,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    
    RSCMU_Status = RSCMU_setViReal64 (instrSession,
                                 "PROCedure:BSSignal:LEVel:FSCH:ONE",
                                 FSCHLevel,
                                 -20.0, 7.0,
                                 VI_ERROR_PARAMETER2);
    CHECKERR(RSCMU_setEnum (instrSession,
                          "PROCedure:BSSignal:LEVel:FSCH:ONE",
                          enable,
                          stateArr,
                          VI_ERROR_PARAMETER3));
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: FSCH Channel
 * Purpose:  This function determines the forward supplemental traffic channel 
 *           number.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFSCHChannelOne (ViSession instrSession,
                                                      ViInt32 FSCHChannel,
                                                      ViChar errorMessage[])
{
    RETMSG(RSCMU_setViInt32 (instrSession,
                             "PROC:BSS:CHAN:FSCH:ONE",
                             FSCHChannel,
                             0, 63,
                             VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: FSCH Frame Offset
 * Purpose:  This function determines an offset for the traffic channel timing 
 *           in CDMA frames.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFSCHFrameOffOne (ViSession instrSession,
                                                       ViInt32 FSCHFrameOffset,
                                                       ViChar errorMessage[])
{
    RETMSG(RSCMU_setViInt32 (instrSession,
                             "PROC:BSS:FROF:FSCH:ONE",
                             FSCHFrameOffset,
                             0, 15,
                             VI_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: FSCH Quasi Orthogonal Function
 * Purpose:  This function sets the Qasi-Orthogonal Function that the 
 *           Supplemental Channels uses in the forward CDMA channel.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSQofFSCHOne (ViSession instrSession,
                                                  ViInt32 QOF,
                                                  ViChar errorMessage[])
{
    RETMSG(RSCMU_setViInt32 (instrSession,
                             "PROC:BSS:QOF:FSCH:ONE",
                             QOF,
                             0, 3,
                             VI_ERROR_PARAMETER2));
}

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcBSSFPCHLevel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      FPCHLevel
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFPCHLevel (ViSession instrSession,
                                           ViReal64 FPCHLevel,
                                           ViBoolean Enable,
                                           ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 376, &FPCHLevel, &Enable);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[376].instrCommand
          , FPCHLevel
          , enable.list[Enable]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}
 //end of RSCMU_CDMA2K_ProcBSSFPCHLevel

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcBSSFPCHChannel
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      channelMode, FPCHChannel
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSFPCHChannel (ViSession instrSession,
                                                   ViInt32 FPCHChannel,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 377, &FPCHChannel);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   sprintf( wrtBuf
          , CDMA[377].instrCommand
          , FPCHChannel
          );
          
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ProcBSSFPCHChannel


/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcBSSProPNOffset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      PNOffset
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcBSSProPNOffset (ViSession instrSession,
                                             ViInt32 PNOffset,
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 378, &PNOffset);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[378].instrCommand
          , PNOffset
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ProcBSSProPNOffset

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclService
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      PNOffset
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclService (ViSession instrSession,
                                              ViInt32 Service,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 379, &Service);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[379].instrCommand
          , service.list[Service] 
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ProcSConfSclService


/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ProcSConfSclLoopSOption
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      SerOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclLoopSOption (ViSession instrSession,
                                                  ViInt32 SerOption,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 380, &SerOption );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[380].instrCommand
          , serviceOption2.list[SerOption]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ProcSConfSclLoopSOption


/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ProcSConfSclLoopFCH
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      SerOption
 *
 * OUTPUTS:     *F_RC, *F_MO, *R_RC, *R_MO,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclLoopFCH (ViSession instrSession,
                                              ViInt32 *F_RC, ViInt32 *F_MO,
                                              ViInt32 *R_RC, ViInt32 *R_MO,
                                              ViInt32 SerOption,
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   checkRange( 381, &SerOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[381].instrCommand
          , serviceOption2.list[SerOption]  
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", F_RC );
     }
   else
     {
        *F_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[1], "NAN" ) != 0 )
     {
       sscanf( tab[1], "%d", F_MO );
     }
   else
     {
        *F_MO = RSCMU_NAN;
     } 
     
   if( strcmp( tab[2], "NAN" ) != 0 )
     {
       sscanf( tab[2], "%d", R_RC );
     }
   else
     {
        *R_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[3], "NAN" ) != 0 )
     {
       sscanf( tab[3], "%d", R_MO );
     }
   else
     {
        *R_MO = RSCMU_NAN;
     }  

   return( RSCMU_Status ); 
    
}//end of RSCMU_CDMA2K_ProcSConfSclLoopFCH

/**************************************************************************
 *
 * NAME:  RSCMU_CDMA2K_ProcSConfSclLoopFCHRC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      F_RC, R_RC,SerOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclLoopFCHRC (ViSession instrSession,
                                                ViInt32 F_RC, ViInt32 R_RC,
                                                ViInt32 SerOption,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar   temp[512] = "\0";
   
   checkRange( 382, &F_RC, &R_RC, &SerOption);
   
   if (SerOption == RSCMU_SERV_OPT2_S02D)
   {
      if (F_RC > 4)
          F_RC = 4;
      if (R_RC > 3)
          R_RC = 3;
   }
   
   if (SerOption == RSCMU_SERV_OPT2_S09D)
   {
      if (F_RC < 2)
          F_RC = 2;
      if (R_RC < 2)
          R_RC = 2;
   }

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( temp
          , CDMA[382].instrCommand
          , serviceOption2.list[SerOption]
          , F_RC, R_RC
          );

   if (SerOption == RSCMU_SERV_OPT2_S55D)
   {

    if (((F_RC == 1) || (F_RC == 3) || (F_RC == 4))     &&  ((R_RC == 1) || (R_RC == 3))) strcpy(wrtBuf,"PROC:SCON:SCL:LOOP:S55D:FCH:FORW:MO 1\0");
    if (((F_RC == 2) || (F_RC == 5))                    &&  ((R_RC == 2) || (R_RC == 4))) strcpy(wrtBuf,"PROC:SCON:SCL:LOOP:S55D:FCH:FORW:MO 2\0");
    
    strcat(wrtBuf,";:\0"); 
    strcat(wrtBuf, temp);
    strcat(wrtBuf,"\0");
    
   } 
   else
    strcpy(wrtBuf, temp);
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_ProcSConfSclLoopFCHRC


/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclLoopFCHFr
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      frameRate, SerOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclLoopFCHFr (ViSession instrSession,
                                                      ViInt32 frameRate,
                                                      ViInt32 SerOption,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 383, &frameRate, &SerOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[383].instrCommand
          , serviceOption2.list[SerOption]
          , frameRateType.list[frameRate]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ProcSConfSclLoopFCHFr

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclLoopPattern
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      pattern, SerOption,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclLoopPattern (ViSession instrSession,
                                                  ViChar pattern[], 
                                                  ViInt32 SerOption,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 384, &SerOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[384].instrCommand
          , serviceOption2.list[SerOption]
          , pattern
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );    
}//end of 3RSCMU_CDMA2K_ProcSConfSclLoopPattern

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclLoopPattGen
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      patternGeneration,serviceOption,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclLoopPattGen (ViSession instrSession,
                                                     ViInt32 patternGeneration,
                                                     ViInt32 SerOption,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 385, &patternGeneration, &SerOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[385].instrCommand
          , serviceOption2.list[SerOption]
          , patternGen.list[patternGeneration]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_ProcSConfSclLoopPattGen

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclSpeechSOpt
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      SerOption,
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclSpeechSOpt (ViSession instrSession,
                                                    ViInt32 SerOption,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 386, &SerOption );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[386].instrCommand
          , serviceOption.list[SerOption]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_ProcSConfSclSpeechSOpt


/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclSpeechFCH 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      SerOption,
 *
 * OUTPUTS:      *f_RC, *f_MO, *r_RC, *r_MO,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclSpeechFCH (ViSession instrSession,
                                                ViInt32 *F_RC, ViInt32 *F_MO,
                                                ViInt32 *R_RC, ViInt32 *R_MO,
                                                ViInt32 SerOption,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   checkRange( 387, &SerOption);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[387].instrCommand
          , serviceOption.list[SerOption]  
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
     {
       sscanf( tab[0], "%d", F_RC );
     }
   else
     {
        *F_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[1], "NAN" ) != 0 )
     {
       sscanf( tab[1], "%d", F_MO );
     }
   else
     {
        *F_MO = RSCMU_NAN;
     } 
     
   if( strcmp( tab[2], "NAN" ) != 0 )
     {
       sscanf( tab[2], "%d", R_RC );
     }
   else
     {
        *R_RC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[3], "NAN" ) != 0 )
     {
       sscanf( tab[3], "%d", R_MO );
     }
   else
     {
        *R_MO = RSCMU_NAN;
     }  

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_ProcSConfSclSpeechFCH 


/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ProcSConfSclSpeechFCHRC 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      F_RC, R_RC, SerOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ProcSConfSclSpeechFCHRC (ViSession instrSession,
                                                        ViInt32 F_RC, ViInt32 R_RC,
                                                        ViInt32 SerOption,
                                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;

   checkRange( 388, &F_RC, &R_RC, &SerOption);
   
   if ((SerOption == RSCMU_SERV_OPT_S01D) || (SerOption == RSCMU_SERV_OPT_S03D))
   {
      if (F_RC > 4)
          F_RC = 4;
      if (R_RC > 3)
          R_RC = 3;
   }
   
   if ((SerOption == RSCMU_SERV_OPT_S17D) || (SerOption == RSCMU_SERV_OPT_SX8T))
   {
      if (F_RC < 2)
          F_RC = 2;
      if (R_RC < 2)
          R_RC = 2;
   }
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[388].instrCommand
          , serviceOption.list[SerOption]
          , F_RC, R_RC
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ProcSConfSclSpeechFCHRC


/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_Handoff 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      F_RC, R_RC, SerOption
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_Handoff (ViSession instrSession,
                                        ViSession DestinationHandle,
                                        ViInt32 Target, ViInt32 Timeout, 
                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status   = VI_SUCCESS;
   ViBoolean Found          = RSCMU_FALSE;
   ViBoolean TimerExpired   = RSCMU_FALSE;
   ViChar    TargetName[30] = "";
   ViInt32   state          = 0;
   ViInt32   cnt            = 0;
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   clock_t   StartTime;
   clock_t   DeltaTime;
   ViInt16   i;
   ViChar    tab[48][30]; 
   ViInt32   measType,signalType;
      struct RSCMU_CDMA_Globals  *p_globalvarCDMA;             
      
   // JMG 020923
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   if( Timeout < 5 )
   {
      Timeout = 5;
   }
   else if( Timeout > 60 )
   {
      Timeout = 60;
   }
   
   if( DestinationHandle == (ViSession)NULL )
   {
      return RSCMU_CDMA_errorMessage( instrSession
                               , RSCMU_ERROR_INVALID_HANDOVER_TARGET
                               , errorMessage
                               );
   }

   if( instrSession == (ViSession)NULL )
   {
      return RSCMU_CDMA_errorMessage( instrSession
                               , RSCMU_ERROR_PARAMETER1
                               , errorMessage
                               );
   }

   // Get the 'HandOverSessionName' of the TargetSession
   strncpy( TargetName
          , HandoffTargets[Target]
          , strlen( HandoffTargets[Target] )
          );

   // Get po#s to buffers.
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   // Extract HandOver TargetList, compare TargetHandle with it.  
   if( (RSCMU_Status = RSCMU_Query( instrSession
                                  , "STATUS:HANDOFF:TARGET:LIST?"
                                  , rdBuf
                                  , RSCMU_STB_ON
                                  , errorMessage
                                  ) ) < 0 )
   {
      return( RSCMU_Status );
   }
 
   // Separate the CMU response:
   cnt = RSCMU_SeparateString( rdBuf, ",", tab );

   // Determine if the destination target was found in the list.
   for( i = 0; i < cnt; i++ )
   {
      if( strncmp( TargetName, tab[i], strlen(tab[i]) ) == 0 )
      {
         Found = RSCMU_TRUE;
      }
   }

   if( !Found )
   {
      return RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_INVALID_HANDOVER_TARGET, errorMessage ); 
   }

   // Be sured that RSCMU is in CEST.
   if( (RSCMU_Status = RSCMU_CDMA2K_ProcSigState( instrSession, &state, errorMessage )) != VI_SUCCESS )
   {
      return( RSCMU_Status );
   }

   if( state != RSCMU_CDMA_STATE_CEST )
   {
      return RSCMU_CDMA_errorMessage( instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage );
   }
   
   // Abort all measurements for the source session.
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version >= RSCMU200_V3_10)
   {
        RSCMU_Status = RSCMU_CDMA2K_AbortALL (instrSession, 0, errorMessage);
        
   }
   else
   { 
  
       // Signaltype
       for(signalType=0; signalType<2; signalType++) 
       {
             RSCMU_Status = RSCMU_CDMA2K_AbortOverview(instrSession,  signalType, errorMessage); 
       }  
   
       for(signalType=0; signalType<2; signalType++) 
       {
            RSCMU_Status = RSCMU_CDMA2K_AbortPowMinOut(instrSession, signalType, errorMessage);
       }

       for(signalType=0; signalType<2; signalType++) 
       {
            RSCMU_Status = RSCMU_CDMA2K_AbortPowMaxOut(instrSession, signalType, errorMessage);
       }
  

       // meastype Signaltype
       for (measType=0; measType<4; measType++) 
       {
        for(signalType=0; signalType<1; signalType++)
        {
                   RSCMU_Status = RSCMU_CDMA2K_AbortMod(instrSession, measType, signalType, errorMessage);   
        }
       }
        
        RSCMU_Status = RSCMU_CDMA2K_AbortOverCQuality(instrSession, errorMessage);

        RSCMU_Status = RSCMU_CDMA2K_AbortRQFerFCH(instrSession, errorMessage);   

        RSCMU_Status = RSCMU_CDMA2K_AbortNPow(instrSession, errorMessage);                   

        RSCMU_Status = RSCMU_CDMA2K_AbortPowGatedOut(instrSession, errorMessage);   
    
        RSCMU_Status = RSCMU_CDMA2K_AbortCDPowCDPW(instrSession, errorMessage);

        RSCMU_Status = RSCMU_CDMA2K_AbortCDPowPCDEP(instrSession, errorMessage);

         RSCMU_Status = RSCMU_CDMA2K_AbortCDPowCHPW(instrSession, errorMessage); 
   
   }
   // Configure Handoff for alternate network.
   sprintf( wrtBuf
          , CDMA[389].instrCommand
          , TargetName
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Perform Handoff to alternate network.
   RSCMU_Status = RSCMU_Query( instrSession
                             , "PROC:SIGN:ACT HAND"
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Delay 1 second to allow CMU to process the message.
   StartTime = clock();
   while( !TimerExpired )
   {
      DeltaTime = (clock() - StartTime);
      // Abort all measurements for the source session.
      if( DeltaTime >= (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10)?1000:500)
      {
         TimerExpired = RSCMU_TRUE;
      }
   }
   TimerExpired = RSCMU_FALSE;

   // Wait for handoff to be completed.
   RSCMU_Status = RSCMU_CDMA2K_ProcSigState( DestinationHandle
                                         , &state
                                         , errorMessage
                                         );
   StartTime = clock();
   while( (state != RSCMU_CDMA_STATE_CEST) && (RSCMU_Status == VI_SUCCESS) && !TimerExpired )
   {
      RSCMU_Status = RSCMU_CDMA2K_ProcSigState( DestinationHandle
                                            , &state
                                            , errorMessage
                                            );
      DeltaTime = (clock() - StartTime);
      if( DeltaTime  >= (Timeout * 1000) )
      {
         TimerExpired = RSCMU_TRUE;
      }
   }

   if( TimerExpired )
   {
      RSCMU_Status = RSCMU_CDMA_errorMessage( DestinationHandle, RSCMU_ERROR_TIMEOUT, errorMessage );
   }
   else if( RSCMU_Status != VI_SUCCESS )
   {
      RSCMU_Status = RSCMU_CDMA_errorMessage( DestinationHandle, RSCMU_ERROR_INVALID_HANDOVER_TARGET, errorMessage );
   }

   return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_Handoff

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_SenseMSInfo 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *protocal_revision, *MCC, *NMSI, *ESN, *EIRP
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SenseMSInfo (ViSession instrSession,
                                            ViInt32 *protocal_revision,
                                            ViChar MCC[], ViChar NMSI[],
                                            ViChar ESN[], ViChar EIRP[],
                                            ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[390].instrCommand
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
     {
       sscanf( tab[0], "%d", protocal_revision );
     }
   else
     {
        *protocal_revision = RSCMU_NAN;
     } 
     
   if( strcmp( tab[1], "INV" ) != 0 )
     {
       sscanf( tab[1], "%s", MCC );
     }
   else
     {
        *MCC = RSCMU_NAN;
     } 
     
   if( strcmp( tab[2], "INV" ) != 0 )
     {
       sscanf( tab[2], "%s", NMSI );
     }
   else
     {
        *NMSI = RSCMU_NAN;
     } 
     
   if( strcmp( tab[3], "INV" ) != 0 )
     {
       sscanf( tab[3], "%s", ESN );
     }
   else
     {
        *ESN = RSCMU_NAN;
     } 
     
   if( strcmp( tab[4], "INV" ) != 0 )
     {
       sscanf( tab[4], "%s", EIRP );
     }
   else
     {
        *EIRP = RSCMU_NAN;
     } 
   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_SenseMSInfo 


/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_SenseMSInfoPrev
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *protocal_revision
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SenseMSInfoPrev (ViSession instrSession,
                                          ViInt32 *protocal_revision,
                                          ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[391].instrCommand
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
     {
       sscanf( tab[0], "%d", protocal_revision );
     }
   else
     {
        *protocal_revision = RSCMU_NAN;
     } 
      
    return( RSCMU_Status );
}//end of RSCMU_CDMA2K_SenseMSInfoPrev

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_SenseMSInfoBCLSupport
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     bandClass[]
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SenseMSInfoBCLSupport (ViSession instrSession,
                                                ViInt32 bandClass[],
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[392].instrCommand
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
     {
       sscanf( tab[0], "%d", &bandClass[0] );
     }
   if( strcmp( tab[1], "INV" ) != 0 )
     {
       sscanf( tab[1], "%d", &bandClass[1] );
     }
   if( strcmp( tab[2], "INV" ) != 0 )
     {
       sscanf( tab[2], "%d", &bandClass[2] );
     }
   if( strcmp( tab[3], "INV" ) != 0 )
     {
       sscanf( tab[3], "%d", &bandClass[3] );
     }
   if( strcmp( tab[4], "INV" ) != 0 )
     {
       sscanf( tab[4], "%d", &bandClass[4] );
     }
   if( strcmp( tab[5], "INV" ) != 0 )
     {               
       sscanf( tab[5], "%d", &bandClass[5] );
     }
   if( strcmp( tab[6], "INV" ) != 0 )
     {               
       sscanf( tab[6], "%d", &bandClass[6] );
     }
   if( strcmp( tab[7], "INV" ) != 0 )
     {
       sscanf( tab[7], "%d", &bandClass[7] );
     }
   if( strcmp( tab[8], "INV" ) != 0 )
     {
       sscanf( tab[8], "%d", &bandClass[8] );
     }
   if( strcmp( tab[9], "INV" ) != 0 )
     {
       sscanf( tab[9], "%d", &bandClass[9] );
     }
   if( strcmp( tab[10], "INV" ) != 0 )
     {
       sscanf( tab[10], "%d",&bandClass[10] );
     }
    return( RSCMU_Status ); 
} //end of RSCMU_CDMA2K_SenseMSInfoBCLSupport

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_SenseMSInfoSCLSupport
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     subClass[]
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SenseMSInfoSCLSupport (ViSession instrSession,
                                                ViInt32 subClass[],
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[393].instrCommand
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
     {
       sscanf( tab[0], "%d", &subClass[0] );
     }
   if( strcmp( tab[1], "INV" ) != 0 )
     {
       sscanf( tab[1], "%d", &subClass[1] );
     }
   if( strcmp( tab[2], "INV" ) != 0 )
     {
       sscanf( tab[2], "%d", &subClass[2] );
     }
   if( strcmp( tab[3], "INV" ) != 0 )
     {
       sscanf( tab[3], "%d", &subClass[3] );
     }
   if( strcmp( tab[4], "INV" ) != 0 )
     {
       sscanf( tab[4], "%d", &subClass[4] );
     }
   if( strcmp( tab[5], "INV" ) != 0 )
     {               
       sscanf( tab[5], "%d", &subClass[5] );
     }
   if( strcmp( tab[6], "INV" ) != 0 )
     {               
       sscanf( tab[6], "%d", &subClass[6] );
     }
   if( strcmp( tab[7], "INV" ) != 0 )
     {
       sscanf( tab[7], "%d", &subClass[7] );
     }
  
    return( RSCMU_Status );  
}//end of RSCMU_CDMA2K_SenseMSInfoSCLSupport

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_SenseMSInfoTerminal
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *manufacturerCode, *modelNumber, *firmwareRevision,*localControl,serOption
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SenseMSInfoTerminal (ViSession instrSession,
                                              ViInt32 *manufacturerCode,
                                              ViInt32 *modelNumber,
                                              ViInt32 *firmwareRevision,
                                              ViInt32 *localControl,
                                              ViChar serOption[],
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[394].instrCommand
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
     {
       sscanf( tab[0], "%d", manufacturerCode );
     }
   else
     {
       *manufacturerCode = RSCMU_MS_INV;
     }
   
   if( strcmp( tab[1], "INV" ) != 0 )
     {
       sscanf( tab[1], "%d", modelNumber );
     }
   else
     {
       *modelNumber = RSCMU_MS_INV;
     }
     
   if( strcmp( tab[2], "INV" ) != 0 )
     {
       sscanf( tab[2], "%d", firmwareRevision );
     }
   else
     {
       *firmwareRevision = RSCMU_MS_INV;
     } 
   
   if( strcmp( tab[3], "NSUP" ) == 0 )
   {
      *localControl = RSCMU_LOCAL_CONTROL_NSUP;
   }
   else if( strcmp( tab[3], "SUP" ) == 0 )
   {
      *localControl = RSCMU_LOCAL_CONTROL_SUPP;
   }
   else
      *localControl = RSCMU_MS_INV;         
   
   if( strcmp( tab[4], "INV" ) != 0 )
     {
       sscanf( tab[4], "%s", serOption );
     }
   else
     {
       strcpy ( serOption, "INV" );
     }
   return( RSCMU_Status );  
   
} //end of RSCMU_CDMA2K_SenseMSInfoTerminal
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_SenseMSInfoAuth
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     authenticMode,authenticResponse,RANDC,callHistoryCount
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SenseMSInfoAuth (ViSession instrSession,
                                                ViInt32 *authenticMode,
                                                ViChar authenticResponse[],
                                                ViInt32 *RANDC,
                                                ViInt32 *callHistoryCount,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];   
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *) CDMA[604].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NSUP" ) == 0 )
     {
       *authenticMode = RSCMU_LOCAL_CONTROL_NSUP;    
     }
   else if( strcmp( tab[0], "SUPP" ) == 0 )
     {
       *authenticMode = RSCMU_LOCAL_CONTROL_SUPP;    
     }
     else
        *authenticMode = RSCMU_NAN;
   if( strcmp( tab[1], "NAN" ) != 0 )
     {
       sscanf( tab[1], "%s", authenticResponse );
     }
   else
     {
       *authenticResponse = RSCMU_NAN;
     }     
   if( strcmp( tab[2], "INV" ) != 0 )
     {
       sscanf( tab[2], "%d", RANDC );
     }
   else
     {
       *RANDC = RSCMU_NAN;
     }          
   if( strcmp( tab[3], "NAN" ) != 0 )
     {
       sscanf( tab[3], "%d", callHistoryCount );
     }
   else
     {
       *callHistoryCount = RSCMU_NAN;
     }    
     
   return( RSCMU_Status ); 
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SenseMSInfoMeid
 *
 * DESCRIPTION: This function returns the Mobile Equipment Identifier of the AT.   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SenseMSInfoMeid (ViSession instrSession,
                                                ViChar MEID[],
                                                ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf [RD_BUFFER_SIZE];
    
    CHKNULLP (MEID, RSCMU_ERROR_PARAMETER2);
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "MSS:MEID?",
                                    rdBuf,
                                    RD_BUFFER_SIZE,
                                    0));
    sscanf (rdBuf, "'%[^']", MEID);
    
    return RSCMU_Status;
}

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConnInfoDialedNumber
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     dialedNumber
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConnInfoDialedNumber (ViSession instrSession,
                                             ViChar dialedNumber[],
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[426].instrCommand
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
     {
       sscanf( tab[0], "%s", dialedNumber );
     }
   else
     {
       strcpy ( dialedNumber, "INV" ); 
     }
 
   return( RSCMU_Status );  
}  //end of RSCMU_CDMA2K_ConnInfoDialedNumber


/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConnInfoGlobalECall
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *globalEmergencyNumber
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConnInfoGlobalECall (ViSession instrSession,
                                                      ViInt32 *globalEmergencyNumber,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[427].instrCommand
          );

   //  JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
     {
       sscanf( tab[0], "%d", globalEmergencyNumber );
     }
   else
     {
       *globalEmergencyNumber = RSCMU_MS_INV;
     }
   return( RSCMU_Status );       
} //end of RSCMU_CDMA2K_ConnInfoGlobalECall

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConnInfoServiceOption
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *number_ofConnectedSO, SOName,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConnInfoServiceOption (ViSession instrSession,
                                              ViInt32 *number_ofConnectedSO,
                                              ViChar SOName[],
                                              ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[428].instrCommand
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
     {
       sscanf( tab[0], "%d", number_ofConnectedSO );
     }
   else
     {
       *number_ofConnectedSO = RSCMU_MS_INV;
     }
   
   if( strcmp( tab[1], "INV" ) != 0 )
     {
       sscanf( tab[1], "%s", SOName );
     }
   else
     {
       strcpy ( SOName, "INV" );
     }
   return( RSCMU_Status );  
   
} //end of RSCMU_CDMA2K_ConnInfoServiceOption    

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConnInfoFCHMUXOption
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     connectedFwdMUXOption, connectedRevMUXOption,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_ConnInfoFCHMUXOption (ViSession instrSession,
                                             ViChar connectedFwdMUXOption[],
                                             ViChar connectedRevMUXOption[],
                                             ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[429].instrCommand
          );

   
   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
     {
       sscanf( tab[0], "%s", connectedFwdMUXOption );
     }
   else
     {
       strcpy ( connectedFwdMUXOption, "INV" );    
     }
   
   if( strcmp( tab[1], "INV" ) != 0 )
     {
       sscanf( tab[1], "%s", connectedRevMUXOption );
     }
   else
     {
       strcpy ( connectedRevMUXOption, "INV" );
     }
   return( RSCMU_Status );  
       
}//end of RSCMU_CDMA2K_ConnInfoFCHMUXOption

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConnInfoSCHZeroMUXOpt
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     connectedFwdMUXOption, connectedRevMUXOption,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_ConnInfoSCHZeroMUXOpt (ViSession instrSession,
                                                 ViChar connectedFwdMUXOption[],
                                                 ViChar connectedRevMUXOption[],
                                                 ViChar errorMessage[])
                                                 
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[430].instrCommand
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
     {
       sscanf( tab[0], "%s", connectedFwdMUXOption );
     }
   else
     {
       strcpy ( connectedFwdMUXOption, "INV" );  
     }
   
   if( strcmp( tab[1], "INV" ) != 0 )
     {
       sscanf( tab[1], "%s", connectedRevMUXOption );
     }
   else
     {
       strcpy ( connectedRevMUXOption, "INV" );
     }
   return( RSCMU_Status );  
       
}//end of RSCMU_CDMA2K_ConnInfoSCHZeroMUXOpt

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConnInfoFCHRC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *connectedFwdRC, *connectredRevRC,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
 

ViStatus _VI_FUNC RSCMU_CDMA2K_ConnInfoFCHRC (ViSession instrSession,
                                      ViInt32 *connectedFwdRC,
                                      ViInt32 *connectredRevRC,
                                      ViChar errorMessage[])
{                                      
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[431].instrCommand
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
     {
       sscanf( tab[0], "%d", connectedFwdRC );
     }
   else
     {
       *connectedFwdRC = RSCMU_MS_INV;
     }
   
   if( strcmp( tab[1], "INV" ) != 0 )
     {
       sscanf( tab[1], "%d", connectredRevRC );
     }
   else
     {
       *connectredRevRC = RSCMU_MS_INV;  
     }
   return( RSCMU_Status );  
       
}//end of RSCMU_CDMA2K_ConnInfoFCHRC

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_ConnInfoSCHRC
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *connectedFwdRC, *connectredRevRC,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
 
ViStatus _VI_FUNC RSCMU_CDMA2K_ConnInfoSCHRC (ViSession instrSession,
                                      ViInt32 *connectedFwdRC,
                                      ViInt32 *connectredRevRC,
                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[432].instrCommand
          );

   // JMG 020930
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
     {
       sscanf( tab[0], "%d", connectedFwdRC );
     }
   else
     {
       *connectedFwdRC = RSCMU_MS_INV;
     }
   
   if( strcmp( tab[1], "INV" ) != 0 )
     {
       sscanf( tab[1], "%d", connectredRevRC );
     }
   else
     {
       *connectredRevRC = RSCMU_MS_INV;  
     }
   return( RSCMU_Status );  
       
}//end of RSCMU_CDMA2K_ConnInfoSCHRC

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_SensOverPPower
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     *reportedPilotPowerdB, *actualPilotPowerdB,
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SensOverPPower (ViSession instrSession,
                                         ViReal64 *reportedPilotPowerdB,
                                         ViReal64 *actualPilotPowerdB,
                                         ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[395].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

   // Get reported pilot power
   if( strcmp( tab[0], "NAN" ) != 0 )
   {
      sscanf( tab[0], "%lf", reportedPilotPowerdB );
   }
   else
   {
      *reportedPilotPowerdB = RSCMU_NAN;
   }

   // Get actual pilot power
   if( strcmp( tab[1], "NAN" ) != 0 )
   {
      sscanf( tab[1], "%lf", actualPilotPowerdB );
   }
   else
   {
      *actualPilotPowerdB = RSCMU_NAN;
   }

   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_SensOverPPower

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_SensOverPPower
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     lastOutgoingTimeStamp
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SenMINFSmsLoutTSTA (ViSession instrSession,
                                                   ViChar lastOutgoingTimeStamp[],
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];   
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *) CDMA[605].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
     {
       sscanf( tab[0], "%s", lastOutgoingTimeStamp );
     }
   else
     {
       *lastOutgoingTimeStamp = RSCMU_NAN;
     }

   return( RSCMU_Status );     
}//end of RSCMU_CDMA2K_SenMINFSmsLoutTSTA
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_SensOverPPower
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     lastOutgoingAcknowledge
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SenMINFSmsLoutACKN (ViSession instrSession,
                                                   ViInt32 *lastOutgoingAcknowledge,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];   
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *) CDMA[606].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "ACKN" ) == 0 )
       *lastOutgoingAcknowledge = RSCMU_LOUT_ACKN;
     
   else if ( strcmp( tab[0], "NACK" ) == 0 )
       *lastOutgoingAcknowledge = RSCMU_LOUT_NACK;
      
      else
         *lastOutgoingAcknowledge = RSCMU_LOUT_FAIL;  
     

   return( RSCMU_Status );         
}//end of RSCMU_CDMA2K_SenMINFSmsLoutACKN
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_SensOverPPower
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     lastOutgoingCauseCode
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_MINFSmsLoutCCOD (ViSession instrSession,
                                                ViInt32 *lastOutgoingCauseCode,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];   
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *) CDMA[607].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "NAN" ) != 0 )
       sscanf( tab[0], "%d", lastOutgoingCauseCode );     
   else
        *lastOutgoingCauseCode = RSCMU_NAN;
        
   return( RSCMU_Status );         
}//end of RSCMU_CDMA2K_MINFSmsLoutCCOD

/*****************************************************************************
 * Function: Last Received TimeStamp
 * Purpose:  This function returns the time stamp associated to the last 
 *           received short message, if available.
 *****************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_MINFSmsLrecTSTA (ViSession instrSession,
                                                ViChar lastReceivedTimeStamp[],
                                                ViChar errorMessage[])
{
   // Bullshit, rewrite!!!
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];   
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *) CDMA[608].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
       sscanf( tab[0], "%s", lastReceivedTimeStamp );     
   else
        *lastReceivedTimeStamp = RSCMU_INV;
        
   return( RSCMU_Status );          
}//end of RSCMU_CDMA2K_MINFSmsLrecTSTA

/*****************************************************************************
 * Function: Outgoing File SMS Encoding
 * Purpose:  This function returns the encoding of the outgoing SMS, which is
 *           either 7-bit (ASCII text), 8-bit (binary) or 16-bit (limited
 *           UTF-16).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsFilEnc (ViSession instrSession,
                                                        ViInt32 *outgoingEncoding,
                                                        ViChar errorMessage[])
{
    RETMSG (RSCMU_getViInt32 (instrSession,
                              "CONF:SCON:SCL1:WMT:SMS:FILE:ENC?",
                              outgoingEncoding,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Outgoing File SMS Text
 * Purpose:  Returns outgoing message text
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsFilText (ViSession instrSession,
                                                         ViChar outgoingText[],
                                                         ViChar errorMessage[])
{
    RETMSG (RSCMU_getViString (instrSession,
                              "CONF:SCON:SCL1:WMT:SMS:FILE:TEXT?",
                              outgoingText,
                              152,
                              RSCMU_ERROR_PARAMETER2));
    
}

/*****************************************************************************
 * Function: Incoming SMS Save
 * Purpose:  This function enables or disables the automatic saving of the
 *           incoming SMS message content in a file.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsIncSav (ViSession instrSession,
                                                        ViBoolean incomingSMSSave,
                                                        ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:SCON:SCL1:WMT:SMS:INC:SAV",
                           incomingSMSSave,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Incoming SMS Save Increment
 * Purpose:  Enables or disables the automatic incrementation of
 *           the filename.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsIncAinc (ViSession instrSession,
                                                         ViBoolean increment,
                                                         ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:SCON:SCL1:WMT:SMS:INC:AINC",
                           increment,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Last Saved SMS File
 * Purpose:  Returns the full path and filename of the last saved SMS.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSconSclWMTSmsIncLast (ViSession instrSession,
                                                         ViInt32 arraySize,
                                                         ViChar lastSavedSMS[],
                                                         ViChar errorMessage[])
{
    RETMSG (RSCMU_getViString (instrSession,
                              "CONF:SCON:SCL1:WMT:SMS:INC:LAST?",
                              lastSavedSMS,
                              arraySize,
                              RSCMU_ERROR_PARAMETER3));
}

/*****************************************************************************
 * Function: Last Received Text
 * Purpose:  This function returns the text of the last received short 
 *           message.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_MINFSmsLrecTEX (ViSession instrSession,
                                               ViChar lastReceivedText[],
                                               ViChar errorMessage[])
{
   // bullshit, rewrite !!!
   
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;
   ViChar    tab[48][30];   
   
     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
  if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10) 
  return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);    
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *) CDMA[609].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
       sscanf( tab[0], "%s", lastReceivedText );     
   else
        *lastReceivedText = RSCMU_INV;
        
   return( RSCMU_Status );     
}//end of RSCMU_CDMA2K_MINFSmsLrecTEX

/*****************************************************************************
 * Function: Last Received Encoding
 * Purpose:  This function returns the encoding of the last received SMS,
 *           which is either 7-bit (ASCII text), 8-bit (binary) or 16-bit
 *           (limited UTF-16).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_MINFSmsLrecENC (ViSession instrSession,
                                               ViInt32 *lastReceivedEncoding,
                                               ViChar errorMessage[])
{
    RETMSG (RSCMU_getViInt32 (instrSession,
                              "MINF:SMS:LREC:ENC?",
                              lastReceivedEncoding,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Last Received Length
 * Purpose:  Returns the length of the last received short message.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_MINFSmsLrecLEN (ViSession instrSession,
                                               ViInt32 *lastReceivedLength,
                                               ViChar errorMessage[])
{
    RETMSG (RSCMU_getViInt32 (instrSession,
                              "MINF:SMS:LREC:LENG?",
                              lastReceivedLength,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Default Settings
 * Purpose:  This function sets all parameters of the subsystem to their 
 *           default values.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_DefIpad(
    ViSession   instrSession,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_sendCmd (instrSession, "DEF:IPAD ON"));
}

/*****************************************************************************
 * Function: Type of CMU IP Addressing
 * Purpose:  This function specifies whether the IP address information is 
 *           assigned manually or automatically.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIpadMode(
    ViSession   instrSession,
    ViInt32 addressing,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:IPAD:MODE",
                           addressing,
                           ipadrModeArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Static IP Address
 * Purpose:  This function sets the static IP address of the CMU. The factory 
 *           setting for the address depends on the CMU serial number.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIpadStat(
    ViSession   instrSession,
    ViInt32 ipAddresspart1,
    ViInt32 ipAddresspart2,
    ViInt32 ipAddresspart3,
    ViInt32 ipAddresspart4,
 ViChar errorMessage[]
)
{
    ViChar  command[50];
    
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart1, 0, 255, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart2, 0, 255, RSCMU_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart3, 0, 255, RSCMU_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart4, 0, 255, RSCMU_ERROR_PARAMETER5, errorMessage);

    sprintf (command, "CONF:IPAD:STAT %ld,%ld,%ld,%ld", ipAddresspart1, ipAddresspart2, ipAddresspart3, ipAddresspart4);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Static Subnet Mask
 * Purpose:  This function sets the static subnet mask of the CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSmasStat(
    ViSession   instrSession,
    ViInt32 maskpart1,
    ViInt32 maskpart2,
    ViInt32 maskpart3,
    ViInt32 maskpart4,
 ViChar errorMessage[]
)
{
    ViChar  command[50];
    
    CHECK_VI_INT32_RANGE (instrSession, maskpart1, 0, 255, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, maskpart2, 0, 255, RSCMU_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, maskpart3, 0, 255, RSCMU_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, maskpart4, 0, 255, RSCMU_ERROR_PARAMETER5, errorMessage);

    sprintf (command, "CONF:SMAS:STAT %ld,%ld,%ld,%ld", maskpart1, maskpart2, maskpart3, maskpart4);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Static Default Gateway
 * Purpose:  This function sets the static default gateway of the CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfDgatStat(
    ViSession   instrSession,
    ViInt32 ipAddresspart1,
    ViInt32 ipAddresspart2,
    ViInt32 ipAddresspart3,
    ViInt32 ipAddresspart4,
 ViChar errorMessage[]
)
{
    ViChar  command[50];
    
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart1, 0, 255, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart2, 0, 255, RSCMU_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart3, 0, 255, RSCMU_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, ipAddresspart4, 0, 255, RSCMU_ERROR_PARAMETER5, errorMessage);

    sprintf (command, "CONF:DGAT:STAT %ld,%ld,%ld,%ld", ipAddresspart1, ipAddresspart2, ipAddresspart3, ipAddresspart4);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Host name
 * Purpose:  This function sets the hostname that is assigned to the CMU and 
 *           transferred to the DHCP server if dynamic IP addressing is 
 *           selected (CONFigure:IPADdress:MODE DYNamic).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfHnamDyn(
    ViSession   instrSession,
    ViString    hostname,
 ViChar errorMessage[]
)
{
    ViChar      command[50];
    
    sprintf (command, "CONF:HNAM:DYN '%s'", hostname);
    
    RETMSG (RSCMU_sendCmd (instrSession, command));
}

/*****************************************************************************
 * Function: Failure Code
 * Purpose:  This function returns the possible cause for an error during 
 *           dynamic allocation of the CMU’s IP address. The response is 0 
 *           unless dynamic IP address allocation failed (in which case the 
 *           query CONFigure:IPADdress:MODE? returns UDEF).
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SensIpadDynFcod(
    ViSession   instrSession,
    ViInt32*    failureCode,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_getViInt32 (instrSession,
                              "SENS:IPAD:DYN:FCOD?",
                              failureCode,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Dynamic Domain Name Server
 * Purpose:  This function returns the dynamically acquired CMU Domain Name 
 *           Server.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfDNSDyn(
    ViSession   instrSession,
    ViInt32*    ipAddresspart1,
    ViInt32*    ipAddresspart2,
    ViInt32*    ipAddresspart3,
    ViInt32*    ipAddresspart4,
 ViChar errorMessage[]
)
{
    ViStatus    RSCMU_Status;
    ViChar      buffer[RD_BUFFER_SIZE];
    ViChar      *str;
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "CONF:DNS:DYN?",
                                    buffer,
                                    RD_BUFFER_SIZE,
                                    0));
    
    GET_VI_INT32 (*ipAddresspart1, buffer, ",");
    GET_VI_INT32 (*ipAddresspart2, VI_NULL, ",");
    GET_VI_INT32 (*ipAddresspart3, VI_NULL, ",");
    GET_VI_INT32 (*ipAddresspart4, VI_NULL, ",");
    
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Dynamic IP Address
 * Purpose:  This function returns the dynamically acquired IP address of the 
 *           CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfIpadDyn(
    ViSession   instrSession,
    ViInt32*    ipAddresspart1,
    ViInt32*    ipAddresspart2,
    ViInt32*    ipAddresspart3,
    ViInt32*    ipAddresspart4,
 ViChar errorMessage[]
)
{
    ViStatus    RSCMU_Status;
    ViChar      buffer[RD_BUFFER_SIZE];
    ViChar      *str;
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "CONF:IPAD:DYN?",
                                    buffer,
                                    RD_BUFFER_SIZE,
                                    0));
    
    GET_VI_INT32 (*ipAddresspart1, buffer, ",");
    GET_VI_INT32 (*ipAddresspart2, VI_NULL, ",");
    GET_VI_INT32 (*ipAddresspart3, VI_NULL, ",");
    GET_VI_INT32 (*ipAddresspart4, VI_NULL, ",");
    
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Dynamic Subnet Mask
 * Purpose:  This function returns the dynamically acquired subnet mask of the 
 *           CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSmasDyn(
    ViSession   instrSession,
    ViInt32*    maskpart1,
    ViInt32*    maskpart2,
    ViInt32*    maskpart3,
    ViInt32*    maskpart4,
 ViChar errorMessage[]
)
{
    ViStatus    RSCMU_Status;
    ViChar      buffer[RD_BUFFER_SIZE];
    ViChar      *str;
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "CONF:SMAS:DYN?",
                                    buffer,
                                    RD_BUFFER_SIZE,
                                    0));
    
    GET_VI_INT32 (*maskpart1, buffer, ",");
    GET_VI_INT32 (*maskpart2, VI_NULL, ",");
    GET_VI_INT32 (*maskpart3, VI_NULL, ",");
    GET_VI_INT32 (*maskpart4, VI_NULL, ",");
    
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Dynamic Default Gateway
 * Purpose:  This function returns the dynamically acquired default gateway of 
 *           the CMU.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfDgatDyn(
    ViSession   instrSession,
    ViInt32*    ipAddresspart1,
    ViInt32*    ipAddresspart2,
    ViInt32*    ipAddresspart3,
    ViInt32*    ipAddresspart4,
 ViChar errorMessage[]
)
{
    ViStatus    RSCMU_Status;
    ViChar      buffer[RD_BUFFER_SIZE];
    ViChar      *str;
    
    CHECKRETMSG (RSCMU_getViString (instrSession,
                                    "CONF:DGAT:DYN?",
                                    buffer,
                                    RD_BUFFER_SIZE,
                                    0));
    
    GET_VI_INT32 (*ipAddresspart1, buffer, ",");
    GET_VI_INT32 (*ipAddresspart2, VI_NULL, ",");
    GET_VI_INT32 (*ipAddresspart3, VI_NULL, ",");
    GET_VI_INT32 (*ipAddresspart4, VI_NULL, ",");
    
    RETMSG (RSCMU_Status);
}

/*****************************************************************************
 * Function: Open Autom If Not Connected
 * Purpose:  This function qualifies whether the Connection Control menu is 
 *           automatically opened.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfMenuCctriAop(
    ViSession   instrSession,
    ViBoolean   openautomifnotconnected,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:MENU:CCTR:AOP",
                           openautomifnotconnected,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Close Autom If Not Connected
 * Purpose:  This function qualifies whether the Connection Control menu is 
 *           automatically closed.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfMenuCctriAcl(
    ViSession   instrSession,
    ViBoolean   closeautomifnotconnected,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:MENU:CCTR:ACL",
                           closeautomifnotconnected,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
}
/*****************************************************************************
 * Function: External Sync Mode
 * Purpose:  This function sets the type of external event that the system will 
 *           align with before the CDMA system time is synchronized.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfEsyncMode (ViSession instrSession,
                                              ViInt32 syncMode,
                                              ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:ESYN:MODE",
                           syncMode,
                           syncModeArr,
                           RSCMU_ERROR_PARAMETER2));    
}

/*****************************************************************************
 * Function: External Sync Timeout
 * Purpose:  This function sets the external sync timeout.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfEsyncTimeout (ViSession instrSession,
                                                 ViReal64 syncTimeout,
                                                 ViChar errorMessage[])
{
    RETMSG (RSCMU_setViReal64 (instrSession,
                               "CONF:ESYN:TOUT",
                               syncTimeout,
                               5, 1200,
                               RSCMU_ERROR_PARAMETER2));    
}

/*****************************************************************************
 * Function: Start Sync Process
 * Purpose:  This function starts the sync process.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitEsync (ViSession instrSession,
                                          ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession, "INIT:ESYN"));     
}

/*****************************************************************************
 * Function: Sync Status
 * Purpose:  This function returns the external sync state.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SensEsyncState (ViSession instrSession,
                                               ViInt32 *syncState,
                                               ViChar errorMessage[])
{
    RETMSG (RSCMU_getEnum (instrSession,
                           "SENS:ESYN:STAT?",
                           syncState,
                           syncStateArr,
                           RSCMU_ERROR_PARAMETER2));    
}

/*****************************************************************************
 * Function: Arm The System Time
 * Purpose:  This function starts the system time synchronization.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_InitEsyncSystTime (ViSession instrSession,
                                                  ViChar errorMessage[])
{
    RETMSG (RSCMU_sendCmd (instrSession,
                           "INIT:ESYN:SYST:TIME"));
    
}

/*****************************************************************************
 * Function: System Time State
 * Purpose:  This function returns the result of the
 *           INITiate:ESYNc:SYSTem:TIME command.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_SensEsyncSystTimeState (ViSession instrSession,
                                                       ViInt32 *systemTimeState,
                                                       ViChar errorMessage[])
{
    RETMSG (RSCMU_getEnum (instrSession,
                           "ESYN:SYST:TIME:STAT?",
                           systemTimeState,
                           esyncSysTimeStatusArr,
                           RSCMU_ERROR_PARAMETER2));
    
}

/*****************************************************************************
 * Function: Align With Event
 * Purpose:  This function sets the alignment with event.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfEsyncAlign (ViSession instrSession,
                                               ViInt32 alignWithEvent,
                                               ViChar errorMessage[])
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:ESYN:ALIG",
                           alignWithEvent,
                           syncStateArr,
                           RSCMU_ERROR_PARAMETER2));    
}

/*****************************************************************************
 * Function: 
 * Purpose:  
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_XtndPowMioResNban (ViSession instrumentHandle,
                                                  ViBoolean enable,
                                                  ViChar errorMessage[])
{
    RETMSG ( RSCMU_setEnum(instrumentHandle,
                           "XTND:POW:MIO:RES:NBAN",
                           (ViInt32)enable,
                           stateArr,
                           RSCMU_ERROR_PARAMETER2));
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_Close
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/



ViStatus _VI_FUNC
   RSCMU_CDMA2K_Close( ViSession instrSession
                   , ViChar    errorMessage[]
                   )                                     
{
   ViStatus RSCMU_Status = VI_SUCCESS;  
   struct RSCMU_CDMA_Globals *p_globalvarCDMA;

   if( (RSCMU_Status = viGetAttribute( instrSession
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarCDMA
                                     )) < 0 )
   {
      return RSCMU_CDMA_errorMessage( instrSession
                               , RSCMU_Status
                               , errorMessage
                               );
   }
   
   // Deallocate all system resources allocated to the GSMNSig Session:
   if( (RSCMU_Status = viClose( instrSession )) < 0 )
   {
      return( RSCMU_Status );
   }
    
   // Deallocate the space pointed by p_globalvarGSM:
   if( p_globalvarCDMA )
   {
      free( p_globalvarCDMA );
   }

   return( RSCMU_Status );

} // end of RSCMU_CDMA_Close()


/**************************************************************************
 *
 * NAME:        checkRange
 *
 * DESCRIPTION: This routine is responsible for range limiting the 
 *              parameters to be within the defined legal values for a
 *              variable number of arguments.
 *
 * INPUTS:      ViInt32 cmd - index into the CDMA command table
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       This routine is passed a variable number of parameters based
 *              on the command to be executed.
 *
 ***************************************************************************
 ***************************************************************************/


static void checkRange( ViInt32 cmd, ... )
{
   va_list     params;
   ViInt32     i;
   ViInt32     type;
   ViInt32    *iValue;
   ViReal64   *fValue;

   // init variable arguments
   va_start( params, cmd );
   
   // range check each parameter
   for( i = 0; i < CDMA[cmd].xmit->num; i++ )
   {
      // determine variable type
      type = CDMA[cmd].xmit->p[i].i.type;
      switch( type )
      {
      case INTEGER_TYPE:
         iValue = va_arg( params, ViInt32* );
      
         if( *iValue > CDMA[cmd].xmit->p[ i ].i.max )
         {
            *iValue = CDMA[cmd].xmit->p[ i ].i.max;
         }
         else if( *iValue < CDMA[cmd].xmit->p[ i ].i.min )
         {
            *iValue = CDMA[cmd].xmit->p[ i ].i.min;
         }
         break;
         
      case FLOAT_TYPE:
         fValue = va_arg( params, ViReal64* );
        
         if( *fValue > CDMA[cmd].xmit->p[ i ].i.max )
         {
            *fValue = CDMA[cmd].xmit->p[ i ].i.max;
         }
         else if( *fValue < CDMA[cmd].xmit->p[ i ].i.min )
         {
            *fValue = CDMA[cmd].xmit->p[ i ].i.min;
         }
         break;
         
      case STRING_30_TYPE:
      default:
         break;
      }
   }               
   
   // reset variable arguments
   va_end( params );
   
} // end of checkRange()


/**************************************************************************
 *
 * NAME:        getBuffers
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


static ViStatus 
   getBuffers( ViSession  instrSessionCDMA
             , ViChar    **wrtBuf
             , ViChar    **rdBuf
             , ViChar     errorMessage[]
             )
{
   ViStatus RSCMU_Status = VI_SUCCESS;  
   struct RSCMU_CDMA_Globals *p_globalvarCDMA;

   if( (RSCMU_Status = viGetAttribute( instrSessionCDMA
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarCDMA
                                     )) < 0 )
   {
      return RSCMU_CDMA_errorMessage( instrSessionCDMA
                               , RSCMU_Status
                               , errorMessage
                               );
   }
   
   *wrtBuf = &(p_globalvarCDMA->RSCMU_tGlobal.wrtBuf[0]);
   *rdBuf  = &(p_globalvarCDMA->RSCMU_tGlobal.rdBuf[0]);
   
   return( RSCMU_Status );

} // end of getBufers()

/*****************************************************************************
 * Function: System Time
 * Purpose:  This function sets the current system time. The time string must 
 *           use a special date/time format: "mm/dd/yyyy HH:MM:SS"
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfSystemTime (ViSession instrSession,
                                               ViInt32 month, ViInt32 day,
                                               ViInt32 year, ViInt32 hours,
                                               ViInt32 minutes, ViInt32 seconds,
                                               ViChar errorMessage[])
{
    ViChar  buffer[RD_BUFFER_SIZE];
    
    CHECK_VI_INT32_RANGE (instrSession, month, 1, 12, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, day, 1, 31, RSCMU_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, year, 1970, 2100, RSCMU_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, hours, 0, 23, RSCMU_ERROR_PARAMETER5, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, minutes, 0, 59, RSCMU_ERROR_PARAMETER6, errorMessage);
    CHECK_VI_INT32_RANGE (instrSession, seconds, 0, 9, RSCMU_ERROR_PARAMETER7, errorMessage);

    sprintf (buffer, "CONF:ESYN:SYST:TIME \"%02d/%02d/%d %02d:%02d:%02d\"", month, day, year,
                                                                       hours, minutes, seconds);
    
    RETMSG (RSCMU_sendCmd (instrSession, buffer));
}

/*****************************************************************************
 * Function: RF Selectivity
 * Purpose:  This function selects the bandwidth of the analog receiver 
 *           filter.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_ConfRFS(
    ViSession   instrSession,
    ViInt32 rfSelectivity,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:RFS",
                           rfSelectivity,
                           rfSelectivityArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: Save Configuration
 * Purpose:  This function saves the configuration of the current function 
 *           group and test mode to a configuration file.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2k_MmemSaveCurr (ViSession instrSession,
                                             ViChar fileName[],
                                             ViInt32 storageDevice,
                                             ViChar errorMessage[])
{
    ViChar  command [1024];
    
    sprintf (command, "MMEM:SAVE:CURR \"%s\",", fileName); 
    return RSCMU_setEnum (instrSession,
                          command,
                          storageDevice,
                          intextArr,
                          VI_ERROR_PARAMETER3);
}

/*****************************************************************************
 * Function: Recall Configuration
 * Purpose:  This function recalls the configuration of the current function 
 *           group and test mode from a configuration file.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2k_MmemRecCurr (ViSession instrSession,
                                            ViChar fileName[],
                                            ViInt32 storageDevice,
                                            ViChar errorMessage[])
{
    ViChar  command [1024];
    
    sprintf (command, "MMEM:REC:CURR \"%s\",",fileName); 
    return RSCMU_setEnum (instrSession,
                          command,
                          storageDevice,
                          intextArr,
                          VI_ERROR_PARAMETER3);
}

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2k_SysVerSwMMI
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     MMIVersionString
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2k_SysVerSwMMI (ViSession instrSession,
                                            ViChar MMIVersionString[],
                                            ViChar errorMessage[])
{   
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[533].instrCommand
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   if( strcmp( tab[0], "INV" ) != 0 )
     {
       sscanf( tab[0], "%s", MMIVersionString );
     }   
 
   return( RSCMU_Status );   
}//end of RSCMU_CDMA2k_SysVerSwMMI 
/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_Reset
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030107 
ViStatus _VI_FUNC RSCMU_CDMA2K_Reset (ViSession instrSession,
                                      ViUInt32  MAX_timeout_in_ms,  
                                      ViChar    errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViUInt32 timeout_in_ms;
   
   struct      RSCMU_CDMA_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage); 

   RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_TMO_VALUE, &timeout_in_ms);
   RSCMU_Status = viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, MAX_timeout_in_ms);
   

 
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[550].instrCommand  
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   RSCMU_Status = viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, timeout_in_ms);

   p_globalvarBase->RSCMU_XtndCQU   = VI_FALSE; 
   p_globalvarBase->RSCMU_XtndOVER  = VI_FALSE; 
   p_globalvarBase->RSCMU_XtndMOD   = VI_FALSE;      
   
   return( RSCMU_Status );
}//end of RSCMU_CDMA2K_Reset

/*===========================================================================*/
/* Function: Error Message
/* Purpose : This function translates the error return value from the
/*           instrument driver into a user-readable string.
/*===========================================================================*/
ViStatus _VI_FUNC  
   RSCMU_CDMA_errorMessage( ViSession       instrSession
                     , ViStatus        statusCode
                     , ViChar _VI_FAR  message[]
                     )
{
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViInt16  i;
    
    /*=======================================================================*/
    /* RSCMU_stringValPair is used in the RSCMU_errorMessage function
    /*=======================================================================*/
    typedef struct  RSCMU_stringValPair
    {
        ViStatus stringVal;
        ViString stringName;
    }  RSCMU_tStringValPair;
    
    #define CDMA_EXPAND(id, value, text) {id, text},
    RSCMU_tStringValPair statusDescArray[] = {
        RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES_CDMA
    };
    #define NUM_CDMA_ERRORS (sizeof(statusDescArray) / sizeof(RSCMU_tStringValPair))
    #undef CDMA_EXPAND

    #define EXPAND(id, value, text) {id, text},
    RSCMU_tStringValPair baseDescArray[] = {
        RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES
    };
    #define NUM_BASE_ERRORS (sizeof(baseDescArray) / sizeof(RSCMU_tStringValPair))
    #undef EXPAND

    strcpy( message, "No Error" );

    RSCMU_Status = viStatusDesc( instrSession, statusCode, message );
    if( RSCMU_Status == VI_WARN_UNKNOWN_STATUS )
    {
        // Search RSCMU base errors.
        for( i=0; (i < NUM_BASE_ERRORS) && baseDescArray[i].stringName; i++ )
        {
            if( baseDescArray[i].stringVal == statusCode )
            {
                strcpy( message, baseDescArray[i].stringName );
                return( statusCode );
            }
        }

        // Search CDMA specific errors.
        for( i=0; (i < NUM_CDMA_ERRORS) && statusDescArray[i].stringName; i++ )
        {
            if( statusDescArray[i].stringVal == statusCode )
            {
                strcpy( message, statusDescArray[i].stringName );
                return( statusCode );
            }
        }
        sprintf( message, "Unknown Error 0x%08lX", statusCode );
        return( VI_WARN_UNKNOWN_STATUS );
    }
    else if( RSCMU_Status == VI_ERROR_USER_BUF )
    {
      sprintf( message, "The user buffer is not valid for the required size." );
      return( VI_ERROR_USER_BUF );
    }
    
    // Here the call was successful:
    return( statusCode );
}//end of RSCMU_CDMA_errorMessage()


/*===========================================================================*/
/* Function: RSCMU_SeparateString                                                
/* Purpose : This function breaks a string into tokens, which are separated 
/*           by one specified delimiter character.                 
/*           The resulted strings are putted in 'Tokens'.              
/*===========================================================================*/
static ViInt32  RSCMU_SeparateString( ViChar StringToSeparate[]
                             , ViChar Delimiters[]
                             , ViChar Tokens[48][30]
                             )
{
   ViChar   *Token;
   ViInt16   Index = 0;
   ViInt32   cnt   = 0;

   Token = strtok( StringToSeparate, Delimiters );
  
   while( Token )
   {
      strcpy( Tokens[Index++], Token );
      Token = strtok( NULL, Delimiters );
      cnt++;
   }
  
   while( Index < 48 )
   {
      strcpy( Tokens[Index++], "" );
   }
  
   return( cnt );
   
}


/*===========================================================================*/
/* Function: RSCMU_ReturnFERResponse
/* Purpose : This function is call to return the values of FER response
/*===========================================================================*/
static ViStatus  RSCMU_ReturnFERResponse( ViInt32   count
                                 , ViChar    valuesTmp[669][20]
                                 , ViReal64  *FER
                                 , ViInt32  *frameErrors
                                 , ViInt32  *framesRxd
                                 , ViReal64  *confidenceLev
                                 )
{
   ViStatus RSCMU_Status = VI_SUCCESS;

   if( strcmp( valuesTmp[0], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[0], "%lf", FER );
   }
   else
   {
      *FER = RSCMU_NAN;
   }

   if( strcmp( valuesTmp[1], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[1], "%d", frameErrors );
   }
   else
   {
      *frameErrors = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[2], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[2], "%d", framesRxd );
   }
   else
   {
      *framesRxd = RSCMU_NAN_VI_INT32;
   }

   if( strcmp( valuesTmp[3], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[3], "%lf", confidenceLev );
   }
   else
   {
      *confidenceLev = RSCMU_NAN;
   }

   return( RSCMU_Status );

} // end of RSCMU_ReturnFERResponse()


/*===========================================================================*/
/* Function: RSCMU_ReturnLimits
/* Purpose : This function is call to return the values of CMU respone
/*===========================================================================*/
static ViStatus  RSCMU_ReturnLimits( ViChar        valuesTmp[3][30]
                            , ERROR_LIMITS *value
                            )
{
   ViStatus RSCMU_Status = VI_SUCCESS;

   if( strcmp( valuesTmp[0], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[0], "%lf", &value->Current );
   }
   else
   {
      value->Current = RSCMU_NAN;
   }
   
   if( strcmp( valuesTmp[1], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[1], "%lf", &value->Average );
   }
   else
   {
      value->Average = RSCMU_NAN;
   }

   if( strcmp( valuesTmp[2], "NAN" ) != 0 )
   {
      sscanf( valuesTmp[2], "%lf", &value->MaxMin );
   }
   else
   {
      value->MaxMin = RSCMU_NAN;
   }

   return RSCMU_Status;    
}// end of RSCMU_ReturnLimits()


/*===========================================================================*/
/* Function: RSCMU_MatchOneLimits
/* Purpose : This function is call to return the error limits for the
/*           scalar measured values.
/*===========================================================================*/
static ViStatus RSCMU_MatchOneLimits( ViChar        valuesTmp[1][30]
                          , ViInt32 *value
                          )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   
   // Current
   if( strcmp( valuesTmp[0], "NMAU" ) == 0 )
   {
      *value = RSCMU_NMAU;
   }
   else if( strcmp( valuesTmp[0], "NMAL" ) == 0 ) 
   {
      *value = RSCMU_NMAL;
   }
   else if( strcmp( valuesTmp[0], "OK" ) == 0 ) 
   {
         *value = RSCMU_OK;  
   }
   else  // Measurement Invalid
   {
      *value = RSCMU_INV;  
   }
   
   return RSCMU_Status;    
} //end of RSCMU_MatchOneLimits()

/*===========================================================================*/
/* Function: RSCMU_MatchLimits
/* Purpose : This function is call to return the error limits for the
/*           scalar measured values.
/*===========================================================================*/
static ViStatus RSCMU_MatchLimits( ViChar        valuesTmp[3][30]
                          , ERROR_LIMITS *value
                          )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
   
   // Current
   if( strcmp( valuesTmp[0], "NMAU" ) == 0 )
   {
      value->Current = RSCMU_NMAU;
   }
   else if( strcmp( valuesTmp[0], "NMAL" ) == 0 ) 
   {
      value->Current = RSCMU_NMAL;
   }
   else if( strcmp( valuesTmp[0], "OK" ) == 0 ) 
   {
         value->Current = RSCMU_OK;  
   }
   else  // Measurement Invalid
   {
      value->Current = RSCMU_INV;  
   }

   // Average
   if( strcmp( valuesTmp[1], "NMAU" ) == 0 )
   {
      value->Average = RSCMU_NMAU;
   }
   else if( strcmp( valuesTmp[1], "NMAL" ) == 0 ) 
   {
      value->Average = RSCMU_NMAL;
   }
   else if( strcmp( valuesTmp[1], "OK" ) == 0 ) 
   {
      value->Average = RSCMU_OK;  
   }
   else  // Measurement Invalid
   {
      value->Average = RSCMU_INV;  
   }

   // MaxMin
   if( strcmp( valuesTmp[2], "NMAU" ) == 0 )
   {
      value->MaxMin = RSCMU_NMAU;
   }
   else if( strcmp( valuesTmp[2], "NMAL" ) == 0 ) 
   {
      value->MaxMin = RSCMU_NMAL;
   }
   else if( strcmp( valuesTmp[2], "OK" ) == 0 ) 
   {
      value->MaxMin = RSCMU_OK;  
   }
   else  // Measurement Invalid
   {
      value->MaxMin = RSCMU_INV;  
   }
      
   return RSCMU_Status;    
} //end of RSCMU_MatchLimits()

/*===========================================================================*/
/* Function: RSCMU_GetMeasurementStatus
/* Purpose : This function is call to get the measurement status
/*===========================================================================*/
static ViStatus  RSCMU_GetMeasurementStatus( ViInt32 *MeasStatus
                                    , ViChar   tab[48][30]     
                                    , ViInt32  Index
                                    )
{
   ViStatus RSCMU_Status = VI_SUCCESS;
  
   if( strncmp( "OFF", tab[Index], 3 ) == 0 )  
   {
      *MeasStatus = RSCMU_MEAS_OFF;
   }
   else if( strncmp( "RUN", tab[Index], 3 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_RUN;
   }
   else if( strncmp( "STOP", tab[Index], 4 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STOP;
   }
   else if( strncmp( "ERR", tab[Index], 3 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_ERR;
   }
   else if( strncmp( "STEP", tab[Index], 4 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STEP;
   }
   else if( strncmp( "RDY", tab[Index], 3 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_RDY; 
   }
   else if( strncmp( "PASS", tab[Index], 4 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STATUS_PASS;
   }
   else if( strncmp( "FAIL", tab[Index], 4 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STATUS_FAIL;
   }
   else if( strncmp( "INV", tab[Index], 3 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STATUS_INV;
   }
   else if( strncmp( "TMER", tab[Index], 4 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STATUS_TMER;
   }
   else if( strncmp( "IMP", tab[Index], 3 ) == 0 )
   {
      *MeasStatus = RSCMU_MEAS_STATUS_IMP;
   }

  return RSCMU_Status;    
} // end of RSCMU_GetMeasurementStatus()


/*===========================================================================*/
/* Function: RSCMU_GetMeasureMatching
/* Purpose : This function is call to get the measure matching
/*===========================================================================*/
static ViStatus  RSCMU_GetMeasureMatching( ViInt32 *Match
                                  , ViChar   tab[48][30] 
                                  , ViInt32  NbBox
                                  )
{
   ViStatus RSCMU_Status = VI_SUCCESS;

   // For All Measured Values
   if( strncmp( "NMAU", tab[NbBox], 4 ) == 0 )
   {
      *Match = RSCMU_MEAS_MATCH_NMAU;
   }
   else if( strncmp( "NMAL", tab[NbBox], 4 ) == 0 )
   {
      *Match = RSCMU_MEAS_MATCH_NMAL;
   }
   else if( strncmp( "INV", tab[NbBox], 3 ) == 0 )
   {
      *Match = RSCMU_MEAS_MATCH_INV;
   }
   else if( strncmp( "OK", tab[NbBox], 2 ) == 0 )
   {
      *Match = RSCMU_MEAS_MATCH_OK;
   }

   // Burst Template Matching
   else if( strncmp( "MATC", tab[NbBox], 4 ) == 0 ) 
   {
      *Match = RSCMU_MATCH_MATC;
   }
   else if( strncmp( "NMAT", tab[NbBox], 4 ) == 0 ) 
   {
      *Match = RSCMU_MATCH_NMAT;
   }
   else if( strncmp( "INV", tab[NbBox], 3 ) == 0 )  
   {
      *Match = RSCMU_MATCH_INV; 
   }
   else if( strncmp( "NTSC", tab[NbBox], 4 ) == 0 )  
   {
      *Match = RSCMU_MATCH_NTSC; 
   }
   else if( strncmp( "OUT", tab[NbBox], 3 ) == 0 )  
   {
      *Match = RSCMU_MATCH_OUT;
   }
      
   return( RSCMU_Status );
}  // end of RSCMU_GetMeasureMatching()


/*===========================================================================*/
/* Function: RSCMU_ReturnArrayValues
/* Purpose : This function returns the values from the array string
/*===========================================================================*/
static void RSCMU_ReturnArrayValues( ViChar   inBuf[]
                            , ViReal64 values[]
                            )
{
   ViChar  *adr;
   ViInt32  i = 0;
   
   adr = strtok( inBuf, "," );
  
   while( adr )
   {
      if( strcmp(adr, "NAN") != 0 )                     
      {    
         sscanf( adr, "%lf", &values[i] ); 
      }
      else
      
      {
         values[i] = RSCMU_NAN;
      }
      adr = strtok( NULL, "," );
      i++;
   }

} //end of RSCMU_ReturnArrayValues()

/*===========================================================================*/
/* Function: RSCMU_CDMA2K_GetResourceName                                    */
/* Purpose:  This function returns resource descriptor for GSM Sig option .  */
/*           Session parameter must contain at least 256 elements ViChar[256]*/
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_CDMA2K_GetResourceName (ViSession instrSession,
                                              ViSession instrSessionBase,
                                              ViChar _VI_FAR sessionName[])
{
    ViStatus    RSCMU_Status    = VI_SUCCESS;  
    ViInt32     comp;

   struct RSCMU_Base_Globals  *p_globalvarBase;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

    /* Get a copy of the global data for base session. */
   if( (RSCMU_Status = viGetAttribute( instrSessionBase
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarBase
                                     )) < VI_SUCCESS )
   {
      return RSCMU_Status;
   }
   
   /* Get a copy of the global data for this session. */
   if( (RSCMU_Status = viGetAttribute( instrSession
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarCDMA
                                     )) < VI_SUCCESS )
   {
      return RSCMU_Status;
   }
   
      // Hardware Connection
      comp = strncmp( "GPIB"
                    , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                    , 4
                    ); 

    if( comp == 0 )
      {
         sprintf( sessionName
                , "%s::%d::%d::INSTR"
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address
                , p_globalvarCDMA->RSCMU_tGlobal.RSCMU_secondary_address
                );
      }
      else
      {
         sprintf( sessionName
                , "%s::INSTR"
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                );
      }

    return RSCMU_Status;
}

/*###########################################################################*/
/*                                                                           */
/*  VXI PLUG & PLAY COMPATIBILITY FUNCTIONS                                  */
/*                                                                           */
/*  These functions provide a VXIplug&play compatibily of this instrument    */
/*  driver with regard to the following documents:                           */
/*                                                                           */
/*  VPP-3.1: Instrument Drivers                                              */
/*      Architecture and Design                                              */
/*      Specification                                                        */
/*      Revision 4.0                                                         */
/*      February 5, 1996                                                     */
/*                                                                           */
/*  VPP-3.2: Instrument Driver                                               */
/*      Functional Body Specification                                        */
/*      Revision 4.0                                                         */
/*      February 2, 1996                                                     */
/*                                                                           */
/*  By: Jan Sima                                                             */                                                                      
/*                                                                           */
/*###########################################################################*/
#ifndef _REMVXIPNP

/*===========================================================================*/
/* Function: Initialize                                                      */
/* Purpose:  This function opens the instrument, queries the instrument      */
/*           for its ID, and initializes the instrument to a known state.    */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_init (ViRsrc resourceName, ViBoolean IDQuery,
                    ViBoolean resetDevice, ViPSession instrSession)
{
    ViStatus    RSCMU_status = VI_SUCCESS;
    ViString    p2str;
    ViInt32     board = 0,
                primaryAddr = 0,
                secondaryAddr = 0;
    ViChar      errorMessage[WR_BUFFER_SIZE];
    ViSession   rmHandle;
    
    /* --- Set standard "C" locale --- */
    {
       char *locale;

       locale = setlocale(LC_ALL, "C");
    }

    p2str = resourceName;
    
    if (strncmp (p2str, "GPIB", 4) != 0)
        return VI_ERROR_INV_RSRC_NAME;
        
    p2str += 4;

    if (p2str[0] >= '0' && p2str[0] <= '9')
        board = (p2str++)[0] - '0';
        
    if (strncmp (p2str, "::", 2) != 0)
        return VI_ERROR_INV_RSRC_NAME;
        
    if (sscanf (p2str += 2, "%ld", &primaryAddr) != 1)
        return VI_ERROR_INV_RSRC_NAME;

    p2str += (primaryAddr > 9) ? 2 : 1; 
    
    if (strlen (p2str) != 0 && strncmp (p2str, "::", 2) != 0)
        return VI_ERROR_INV_RSRC_NAME;
    
    if (strlen (p2str) != 0) {
        if (sscanf (p2str += 2, "%ld", &secondaryAddr) != 1)
            return VI_ERROR_INV_RSRC_NAME;
        
        p2str += (secondaryAddr > 9) ? 2 : 1;       
        
        if (strlen (p2str) != 0 && strcmp (p2str, "::INSTR") != 0)
            return VI_ERROR_INV_RSRC_NAME;
    }
        
    if (secondaryAddr == 0) {
        if ((RSCMU_status = RSCMU_Init_Base (instrSession, RSCMU_GPIB, board, primaryAddr,
                                             IDQuery, resetDevice, errorMessage)) < 0)
            return RSCMU_status;
    } else {        
        if ((RSCMU_status = viOpenDefaultRM (&rmHandle)) != 0)
            return RSCMU_status;
        
        if ((RSCMU_status = viOpen (rmHandle, resourceName, VI_NULL, VI_NULL, instrSession)) != 0) 
            return RSCMU_status;
    
        if ((RSCMU_status = viGpibControlREN (*instrSession, VI_GPIB_REN_ASSERT)) < 0)
            return RSCMU_status;
    }       
    
    return RSCMU_status;
}  //end of RSCMU_init()

ViStatus _VI_FUNC RSCMU_GetInstrumentHandle (ViSession instrSession,
                                             ViSession *instrHandle)
{
    *instrHandle = instrSession;
    return VI_SUCCESS;
}

/*===========================================================================*/
/* Function: Init CDMA                                                       */
/* Purpose:  This function initializes the CDMA module's                     */
/*           global data structures. This function is used in VEE where this */
/*           can not be a part of the VXIpnp init function.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_initCDMA2K (ViSession   instrSession,
                                    ViSession   BaseSession,
                                    ViUInt32    CDMA2KFunctionGroup)
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViInt32     secondAddr = 0, comp = 1;
    ViChar      FctGrpBuffer[128]= "";
    ViReal64    Flag = RSCMU_OFF;
    ViChar      errorMessage[WR_BUFFER_SIZE];
    ViSession   DefaultRM;

    struct RSCMU_Base_Globals  *p_globalvarBase;
    struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

    // Which Function Group does the User want?
      switch( CDMA2KFunctionGroup )
      {

      case RSCMU_CDMA2K450MS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2K450MS_NSig\"" );
         break;
         
      case RSCMU_CDMA2K450MS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2K450MS_Sig\"" );
         break;  
                     
      case RSCMU_CDMA2KCELLMS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KCellMS_NSig\"" );
         break;
         
      case RSCMU_CDMA2KCELLMS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KCellMS_Sig\"" );
         break;

      case RSCMU_CDMA2KPCSMS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KPCSMS_NSig\"" );
         break;

      case RSCMU_CDMA2KPCSMS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KPCSMS_Sig\"" );
         break;

      case RSCMU_CDMA2KIMT2KMS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KIMT2KMS_NSig\"" );
         break;   

      case RSCMU_CDMA2KIMT2KMS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KIMT2KMS_Sig\"" );
         break;

      default:
         break;
      }

    // Init the Error Message  
    strcpy (errorMessage, "No Error");

    // Get the current options (= Function Group Names) in the CMU.
    if ((RSCMU_Status = viGetAttribute (BaseSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
      return RSCMU_CDMA_errorMessage (BaseSession, RSCMU_Status, errorMessage);
      
    DefaultRM = p_globalvarBase->RSCMU_tGlobal.RSCMU_RmSessionDefault;  

    // Find the Secondary address
    while( (comp != 0) && (secondAddr < 30) )
    {
       secondAddr++;
       comp = strncmp( p_globalvarBase->RSCMU_tSecAddr[secondAddr].FctGrp
                     , FctGrpBuffer
                     , strlen( FctGrpBuffer )
                     );
       if( comp == 0 ) Flag = RSCMU_ON;
    }

    if( Flag == RSCMU_OFF )
       return RSCMU_CDMA_errorMessage( instrSession
                                , RSCMU_ERROR_INVALID_FCT_GRP
                                , errorMessage
                                );

    // Allocate space for "struct RSCMU_SESSION_Globals" 
    if( (p_globalvarCDMA =
          (struct RSCMU_CDMA_Globals *)
          malloc(sizeof(struct RSCMU_CDMA_Globals))) == 0 )
    {
       return RSCMU_initCleanUp( DefaultRM
                               , instrSession
                               , RSCMU_Status
                               );
    }
    
    if( (RSCMU_Status = viSetAttribute( instrSession
                                      , VI_ATTR_USER_DATA
                                      , (ViAttrState)p_globalvarCDMA
                                      )) < 0 )
    {
       return RSCMU_initCleanUp( DefaultRM
                               , instrSession
                               , RSCMU_Status
                               );
    }
    
      // Which Function Group does the User want?
      switch( CDMA2KFunctionGroup )
      {
      
      case RSCMU_CDMA2K450MS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2K450MS_NSig\"" );
         break;
         
      case RSCMU_CDMA2K450MS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2K450MS_Sig\"" );
         break;  
                     
      case RSCMU_CDMA2KCELLMS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KCellMS_NSig\"" );
         break;
         
      case RSCMU_CDMA2KCELLMS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KCellMS_Sig\"" );
         break;

      case RSCMU_CDMA2KPCSMS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KPCSMS_NSig\"" );
         break;

      case RSCMU_CDMA2KPCSMS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KPCSMS_Sig\"" );
         break;

      case RSCMU_CDMA2KIMT2KMS_NSIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KIMT2KMS_NSig\"" );
         break;   

      case RSCMU_CDMA2KIMT2KMS_SIG:
         // Record "Function Group Name" for the actual Session.
         strcpy( FctGrpBuffer, "\"CDMA2KIMT2KMS_Sig\"" );
         break;

      default:
         break;
      }
      
    // Set initial values of variables for function Group 'CDMA' .    
    strcpy( p_globalvarCDMA->RSCMU_tGlobal.FGrp_Name, FctGrpBuffer );
    strcpy (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_SCPIConnection, p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection);
    p_globalvarCDMA->RSCMU_tGlobal.RSCMU_primary_address   = p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address;
    p_globalvarCDMA->RSCMU_tGlobal.RSCMU_secondary_address = secondAddr;
    p_globalvarCDMA->RSCMU_tGlobal.RSCMU_SessionNb         = instrSession;
    p_globalvarCDMA->RSCMU_tGlobal.RSCMU_TRACE             = p_globalvarBase->RSCMU_tGlobal.RSCMU_TRACE;

    //*** If the RSCMU_Trace_ON has already been executed, record the characteristics of
    //*** the trace file, then the base can trace what's appening on the secondary address
    //*** initialized in THIS function (It was not the case before: we were obliged to 
    //*** set the trace to ON after, and only after initialization of All the secondary addresses
    //*** we want to trace)
    p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FileHandle        =
       p_globalvarBase->RSCMU_tGlobal.RSCMU_FileHandle;
    
    p_globalvarCDMA->RSCMU_tGlobal.RSCMU_AddrTargetFile    =
       (ViAddr) p_globalvarBase->RSCMU_tGlobal.RSCMU_AddrTargetFile;
    
    p_globalvarCDMA->RSCMU_tGlobal.RSCMU_StateTraceFile    =
       p_globalvarBase->RSCMU_tGlobal.RSCMU_StateTraceFile;
    //*** ht 22/09/2000
    
    // Record the execution of this Init Function.    
    p_globalvarBase->RSCMU_tSecAddr[secondAddr].SessionNb = instrSession;  

    // Timeout changed from 10s to 10 seconds 
    if( (RSCMU_Status = viSetAttribute( instrSession
                                      , VI_ATTR_TMO_VALUE
                                      , 30000
                                      )) < 0 )
                                      
    {
       return( RSCMU_Status );
    }

 return( RSCMU_Status );

} // end of RSCMU_InitCDMA()

/*===========================================================================*/
/* Function: Get Instrument Handle                                           */
/* Purpose:  This function passes the instrument handle from the first       */
/*           parameter to the second parameter. This function is used in VEE */
/*           where it allows to get the current instrument handle.           */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GetinstrSession (ViSession instrSession,
                                            ViSession *instrSessionOut)
{
    *instrSessionOut = instrSession;
    return 0;
} //end of RSCMU_GetinstrSession()

/*===========================================================================*/
/* Function: Reset                                                           */
/* Purpose:  This function resets the instrument.  If the reset function     */
/*           is not supported by the instrument, this function returns       */
/*           the warning VI_WARN_NSUP_RESET.                                 */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_reset (ViSession instrSession)
{
    return VI_WARN_NSUP_RESET;
} //end of RSCMU_reset() 

/*===========================================================================*/
/* Function: Self-Test                                                       */
/* Purpose:  This function executes the instrument self-test and returns     */
/*           the result. If the self test function is not supported by the   */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_SELF_TEST.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_self_test (ViSession instrSession,
                                    ViPInt16 testResult,
                                    ViChar _VI_FAR testMessage[])
{
    return VI_WARN_NSUP_SELF_TEST;
} //end of RSCMU_self_test()

/*===========================================================================*/
/* Function: Error Query                                                     */
/* Purpose:  This function queries the instrument error queue, and returns   */
/*           the result.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_error_query (ViSession instrSession,
                                      ViPInt32 errorCode,
                                      ViChar _VI_FAR errorMessage[])
{
    return VI_WARN_NSUP_ERROR_QUERY;
} //end of RSCMU_error_query() 

/*===========================================================================*/
/* Function: Error Message                                                   */
/* Purpose:  This function translates the error return value from the        */
/*           instrument driver into a user-readable string.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_error_message (ViSession instrSession,
                                        ViStatus statusCode,
                                        ViChar _VI_FAR errMessage[])
{
    return RSCMU_CDMA_errorMessage (instrSession, statusCode, errMessage);
}//end of RSCMU_error_message()

/*===========================================================================*/
/* Function: Revision Query                                                  */
/* Purpose:  This function returns the driver and instrument revisions.      */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_revision_query (ViSession instrSession,
                    ViChar _VI_FAR driverRev[], ViChar _VI_FAR instrRev[])
{
    strcpy (driverRev, RSCMUC2K_REVISION);
    if (instrRev != 0)
        {
        strcpy (instrRev, "Not defined");
        }

    return VI_SUCCESS;
} //end of RSCMU_revision_query()

/*===========================================================================*/
/* Function: Close                                                           */
/* Purpose:  This function closes the instrument.                            */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_close (ViSession instrSession)
{
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar  errorMessage[WR_BUFFER_SIZE];
    ViUInt16 secAddr;
    
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_GPIB_SECONDARY_ADDR, &secAddr)) < 0)
        return RSCMU_Status;

    if (secAddr == 0) {
        if ((RSCMU_Status = RSCMU_Close_Base (instrSession, errorMessage)) < 0)
            return RSCMU_Status;
    } else {
        struct RSCMU_CDMA_Globals *p_globalvarCDMA;

        if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
            return RSCMU_Status;

        // Deallocate all system resources
        if ((RSCMU_Status = viClose (instrSession)) < 0)
            return RSCMU_Status;
    
        // Deallocate the space pointed by p_globalvarCDMA
        if (p_globalvarCDMA)
            free (p_globalvarCDMA);
    }       
    return RSCMU_Status;
}  //end of RSCMU_close()

#endif   

/**************************************************************************
 *
 * NAME: RSCMU_CDMA2K_AbortALL 
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      abortAllApplications
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

// JMG 020924
ViStatus _VI_FUNC RSCMU_CDMA2K_AbortALL (ViSession  instrSession,
                                       ViInt32      abortAllApplications,
                                       ViChar       errorMessage[])
{
   ViStatus  RSCMU_Status   = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    Format[30]     = {NULL};
   ViInt32   SignalType     = 0;
   ViInt32   MeasType       = 0;
   
   // retreive addresse GPIB buffer
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );
    
   // Abort all measurements for the source session.
   strcpy(wrtBuf,"\0");
   
   // Abort SIgnaling
   switch (abortAllApplications)
   {
   case 0:
   
       // Abort SAPP
       strcpy(Format, CDMA[400].instrCommand);
       strcat(wrtBuf, Format);
       strcat(wrtBuf,";:\0");

       // Abort GATED OUTPUT
       strcpy(Format, CDMA[124].instrCommand);
       strcat(wrtBuf, Format);
       strcat(wrtBuf,";:\0");

       // Abort OLTR
       strcpy(Format, CDMA[409].instrCommand);
       strcat(wrtBuf, Format);
       strcat(wrtBuf,";:\0");

       // Abort CODE DOMAIN
       strcpy(Format, CDMA[154].instrCommand);
       strcat(wrtBuf, Format);
       strcat(wrtBuf,";:\0");

       strcpy(Format, CDMA[175].instrCommand);
       strcat(wrtBuf, Format);
       strcat(wrtBuf,";:\0");

       strcpy(Format, CDMA[195].instrCommand);
       strcat(wrtBuf, Format);
       strcat(wrtBuf,";:\0");
  
      // Abort FER FCH
      strcpy(Format, CDMA[306].instrCommand);
      strcat(wrtBuf, Format);
      strcat(wrtBuf,";:\0");

       // Abort FER SCH
      strcpy(Format, CDMA[517].instrCommand);
      strcat(wrtBuf, Format);
      strcat(wrtBuf,";:\0");
  
      // Abort OVER CQU
      strcpy(Format, CDMA[237].instrCommand);
      strcat(wrtBuf, Format);
      strcat(wrtBuf,";:\0");


       for(SignalType=0; SignalType<2; SignalType++) 
       {
        
            // ABORT OVER OVER  
            sprintf(Format, CDMA[222].instrCommand, signalType.list[SignalType]);
            strcat(wrtBuf, Format);
            strcat(wrtBuf,";:\0");

            // ABORT POW MAO
            sprintf(Format, CDMA[103].instrCommand, signalType.list[SignalType]);
            strcat(wrtBuf, Format);
            strcat(wrtBuf,";:\0");
    
  
            // ABORT POW MIO
            sprintf(Format, CDMA[83].instrCommand, signalType.list[SignalType]);
            strcat(wrtBuf, Format);
            strcat(wrtBuf,";:\0");
    
            // ABORT MOD
            for (MeasType=0; MeasType<4; MeasType++) 
            {
                sprintf(Format, CDMA[279].instrCommand, measType.list[MeasType], signalType.list[SignalType]);
                strcat(wrtBuf, Format);
                strcat(wrtBuf,";:\0");
    
            } // end of meas MOD type   loop

       } // end meas type OQPSK or HPSK
    
       // Abort NPOWER
      strcpy(Format, CDMA[64].instrCommand);
      strcat(wrtBuf, Format);
      strcat(wrtBuf,"\0");
   break;
    
   // Abort Non SIgnaling
   case 1:
      
      // Abort RFG
      strcpy(Format, CDMA[57].instrCommand);
      strcat(wrtBuf, Format);
      strcat(wrtBuf,";:\0");   
       
       for(SignalType=0; SignalType<3; SignalType++) 
       {
        
            // ABORT MOD QU
            sprintf(Format, CDMA[257].instrCommand, signalType2.list[SignalType]);
            strcat(wrtBuf, Format);
            strcat(wrtBuf,";:\0");     
      }
      
      
      // Abort NPOWER
      strcpy(Format, CDMA[64].instrCommand);
      strcat(wrtBuf, Format);
      strcat(wrtBuf,"\0");   
   
   break;
   
   }
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

    return RSCMU_Status;
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StatOperSymbEnab
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030117
ViStatus _VI_FUNC RSCMU_CDMA2K_StatOperSymbEnab (ViSession instrSession,
                                                 ViBoolean CFM, 
                                                 ViBoolean RFM,
                                                 ViBoolean LORL, 
                                                 ViBoolean MREG,
                                                 ViBoolean MINV,
                                                 ViBoolean AMES,
                                                 ViBoolean RFNS,
                                                 ViBoolean MDER, 
                                                 ViBoolean RMES,
                                                 ViBoolean FCH, 
                                                 ViBoolean PREP,
                                                 ViBoolean RFIO, 
                                                 ViBoolean RFIU,
                                                 ViBoolean XTND,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar   temp[80];
   
   struct      RSCMU_SESSION_Globals  *p_globalvarBase;    

   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;                                        

   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
       return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage); 

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   
   
   strcpy(temp, "\0");
   
   if (CFM != 65535)
     strcat(temp, SRS[RSCMU_CDMA2K_CFM]);

   if (RFM != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_CDMA2K_RFM]);
     
   }
   
   if (LORL != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_CDMA2K_LORL]);
     
   }   
   
   if (MREG != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_CDMA2K_MREG]);
     
   }

   if (MINV != 65535)
   {
     if (strlen(temp) != 0) 
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_CDMA2K_MINV]);
     
   }
   
   if (AMES != 65535)
   {
     if (strlen(temp) != 0) 
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_CDMA2K_AMES]);
     
   }
   
   if (RFNS != 65535)
   {
     if (strlen(temp) != 0) 
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_CDMA2K_RFNS]);
     
   }
   
   if (MDER != 65535)
   {
     if (strlen(temp) != 0) 
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_CDMA2K_MDER]);
     
   }

   if (RMES != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_CDMA2K_RMES]);
     
   }
   
   if (FCH != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_CDMA2K_FCH]);
     
   }

      
   if (PREP != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_CDMA2K_PREP]);
     
   }
   
   if (RFIO != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_CDMA2K_RFIO]);
     
   }
   

   if (RFIU != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_CDMA2K_RFIU]);
     
   }

   if (XTND != 65535)
   {
     if (strlen(temp) != 0)
        strcat(temp, ","); 
     
     strcat(temp, SRS[RSCMU_CDMA2K_XTND]);
     
   }

   if (strlen(temp) == 0) 
    sprintf(wrtBuf,CDMA[655].instrCommand,"NONE");
   else
    sprintf(wrtBuf,CDMA[655].instrCommand,temp);
   
   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    
   return( RSCMU_Status );

    
} // end of RSCMU_CDMA2K_StatOperSymbEnab   

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_StatOperSymbEvent
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
// JMG 030107
ViStatus _VI_FUNC RSCMU_CDMA2K_StatOperSymbEvent (ViSession instrSession,
                                                  ViInt32 *nb,
                                                  ViInt32 *statusOperEvent,
                                                  ViChar SstatusOperEvent[], 
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *rdBuf;
   ViChar   *wrtBuf;
   ViChar   Sevent[48][30];
   ViInt32  i;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[656].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   if( RSCMU_Status >= 0 )
   {
    
       // Separate the CMU response:
       *nb= RSCMU_SeparateString( rdBuf, ",", Sevent );
       
       *statusOperEvent = 0;
       strcpy(SstatusOperEvent, "\0");

       for (i=0;i<*nb;i++)
       {
           
           if (strncmp("NONE", Sevent[i], 4) == 0)
           {
                
                *statusOperEvent =  0;
                strcat(SstatusOperEvent, SRS[16]);
                strcat(SstatusOperEvent, ",\0");    
                
            }
                
           
           if ((strncmp(SRS[RSCMU_CDMA2K_CFM],Sevent[i],3) == 0)  || (strncmp("E1",Sevent[i],2) == 0))
           {
                *statusOperEvent    =  *statusOperEvent + 1;
                strcat(SstatusOperEvent, SRS[RSCMU_CDMA2K_CFM]);
                strcat(SstatusOperEvent,",\0");
           }
           
           if ((strncmp(SRS[RSCMU_CDMA2K_RFM],Sevent[i],3) == 0)  || (strncmp("E2", Sevent[i],2) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 2;
                strcat(SstatusOperEvent, SRS[RSCMU_CDMA2K_RFM]);
                strcat(SstatusOperEvent,",\0");
           }
    

           if ((strncmp(SRS[RSCMU_CDMA2K_LORL],Sevent[i],4) == 0) || (strncmp("E3", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 4;
                strcat(SstatusOperEvent, SRS[RSCMU_CDMA2K_LORL]);
                strcat(SstatusOperEvent,",\0");
           }
                
   
           if ((strncmp(SRS[RSCMU_CDMA2K_MREG],Sevent[i],4) == 0) || (strncmp("E4", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 8;
                strcat(SstatusOperEvent, SRS[RSCMU_CDMA2K_MREG]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if ((strncmp(SRS[RSCMU_CDMA2K_MINV],Sevent[i],4) == 0) || (strncmp("E5", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 16;
                strcat(SstatusOperEvent, SRS[RSCMU_CDMA2K_MINV]);
                strcat(SstatusOperEvent,",\0");
           }
                
            
           if ((strncmp(SRS[RSCMU_CDMA2K_AMES],Sevent[i],4) == 0) || (strncmp("E6", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 32;
                strcat(SstatusOperEvent, SRS[RSCMU_CDMA2K_AMES]);
                strcat(SstatusOperEvent,",\0");
           }
                
            
           if ((strncmp(SRS[RSCMU_CDMA2K_RFNS],Sevent[i],4) == 0) || (strncmp("E7", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 64;
                strcat(SstatusOperEvent, SRS[RSCMU_CDMA2K_RFNS]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if ((strncmp(SRS[RSCMU_CDMA2K_MDER],Sevent[i],4) == 0) || (strncmp("E8", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 128;
                strcat(SstatusOperEvent, SRS[RSCMU_CDMA2K_MDER]);
                strcat(SstatusOperEvent,",\0");
           }
            

           if ((strncmp(SRS[RSCMU_CDMA2K_RMES],Sevent[i],4) == 0) || (strncmp("E9", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 256;
                strcat(SstatusOperEvent, SRS[RSCMU_CDMA2K_RMES]);
                strcat(SstatusOperEvent,",\0");
           }
                
   
           if ((strncmp(SRS[RSCMU_CDMA2K_FCH],Sevent[i],3) == 0)  || (strncmp("E10", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 512;
                strcat(SstatusOperEvent, SRS[RSCMU_CDMA2K_FCH]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if ((strncmp(SRS[RSCMU_CDMA2K_PREP],Sevent[i],3) == 0)  || (strncmp("E11", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 1024;
                strcat(SstatusOperEvent, SRS[RSCMU_CDMA2K_PREP]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if ((strncmp(SRS[RSCMU_CDMA2K_RFIO],Sevent[i], 4) == 0) || (strncmp("E12", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 2048;   
                strcat(SstatusOperEvent, SRS[RSCMU_CDMA2K_RFIO]);
                strcat(SstatusOperEvent,",\0");
           }
                
    
           if ((strncmp(SRS[RSCMU_CDMA2K_RFIU], Sevent[i], 4) == 0) || (strncmp("E13", Sevent[i],2 ) == 0))
           {
                *statusOperEvent =  *statusOperEvent + 4096;   
                strcat(SstatusOperEvent, SRS[RSCMU_CDMA2K_RFIU]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if (strncmp("E14", Sevent[i],2 ) == 0)
           {
                *statusOperEvent =  *statusOperEvent + 8192;   
                strcat(SstatusOperEvent, SRS[13]);
                strcat(SstatusOperEvent,",\0");
           }
                
    
           if (strncmp("E15", Sevent[i],2 ) == 0)
           {
                *statusOperEvent =  *statusOperEvent + 16384; 
                strcat(SstatusOperEvent, SRS[14]);
                strcat(SstatusOperEvent,",\0");
           }
                

           if (strncmp("E16", Sevent[i],2 ) == 0)
           {
                *statusOperEvent =  *statusOperEvent + 32768;
                strcat(SstatusOperEvent, SRS[15]);
                strcat(SstatusOperEvent,",\0");
           }
                
        } 
        
        if (*statusOperEvent == 0) *nb = 0;
    }
    
   return( RSCMU_Status );
    
}  // end of RSCMU_CDMA2K_StatOperSymbEvent  

/*****************************************************************************
 * Function: XtndStatOperFgrEvent
 * Purpose:  This function reads and deletes the extended events reported in a 
 *           CDMA2000 function group.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_XtndStatOperFgrEvent(
    ViSession   instrSession,
    ViInt32*    statusOperEvent,
 ViChar errorMessage[]
)
{
    RETMSG (RSCMU_getViInt32 (instrSession,
                              "XTND:STAT:OPER:FGR?",
                              statusOperEvent,
                              RSCMU_ERROR_PARAMETER2));
}

/*****************************************************************************
 * Function: XtndStatOperSymbEvent
 * Purpose:  This function reads and deletes the extended events reported in a 
 *           CDMA2000 function group.
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_XtndStatOperSymbEvent(
    ViSession   instrSession,
    ViInt32 listofReportedEvents[],
 ViChar errorMessage[]
)
{
    ViChar  command[128];
    ViChar  *hugeBuf = VI_NULL;
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViInt32 i = 0;
    ViChar* str;
    
    strcpy (command, "XTND:STAT:OPER:SYMB?");
    
    CHECKRETMSG (RSCMU_viWrite(instrSession, command, strlen(command)));

    CHECKERR(RSCMU_ReadDataUnknownLength(instrSession, &hugeBuf, VI_NULL));
    
    if (RSCMU_Status < VI_SUCCESS)
        if (hugeBuf) free(hugeBuf);

    if (strcmp (hugeBuf, "NONE"))
        listofReportedEvents[0] = 0;
    else
    {
        while ((str = strtok (hugeBuf,",")) != NULL)
        {
            GET_VI_INT32 (listofReportedEvents[i++], VI_NULL,",");
        }
    }
        
    if (hugeBuf) 
        free(hugeBuf);

    RETMSG (RSCMU_Status);
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SetMeasEnvironment
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/


ViStatus _VI_FUNC RSCMU_CDMA2K_SetMeasEnvironment (ViSession instrSession,
                                                   ViBoolean measureEnvironment,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    
    
 // if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_20) 
 //     return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_20, errorMessage); 

   checkRange( 657, &measureEnvironment );
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[657].instrCommand
          , enable.list[measureEnvironment]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   return( RSCMU_Status );         
   
} //end of RSCMU_CDMA2K_SetMeasEnvironment

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_GPIB_Timeout
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/
ViStatus _VI_FUNC RSCMU_CDMA2K_GPIB_Timeout (ViSession instrSession,
                                             ViUInt32 timeout_in_ms,
                                             ViChar errorMessage[])
{
    ViStatus  RSCMU_Status = VI_SUCCESS;  
    

    RSCMU_Status = viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, timeout_in_ms);

    if (RSCMU_Status != VI_SUCCESS)
        viStatusDesc (instrSession, RSCMU_Status, errorMessage);    
        
    return( RSCMU_Status );     
    
}

/**************************************************************************
 *
 * NAME:        RSCMU_CDMA2K_SetCmuVersion
 *
 * DESCRIPTION: XXXXXXXXXXXXXXXXXXX   
 *
 * INPUTS:      NONE
 *
 * OUTPUTS:     NONE
 *
 * RETURN:      NONE
 *
 * CONSTRAINTS: NONE
 *
 * NOTES:       NONE
 *
 ***************************************************************************
 ***************************************************************************/

ViStatus _VI_FUNC RSCMU_CDMA2K_SetCmuVersion (ViSession instrSession,
                                              ViChar CmuFWVersion[],
                                              ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;
  struct RSCMU_CDMA_Globals  *p_globalvarCDMA;


     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;  
    

  strcpy (errorMessage, "No Error");

  strcpy (p_globalvarCDMA->RSCMU_tGlobal.CmuVersion, CmuFWVersion);

  return RSCMU_Status;    
}//end of RSCMU_CDMA2K_SetCmuVersion



ViStatus _VI_FUNC RSCMU_CDMA2K_ReadModMQuality_EX (ViSession instrSession,
                                                   ViReal64 MsPower[],
                                                   ViReal64 waveFormQuality[],
                                                   ViReal64 carrierFrequencyError[],
                                                   ViReal64 transmitTimeError[],
                                                   ViReal64 carrierFeedThrough[],
                                                   ViReal64 sidebandSuppressLower[],
                                                   ViReal64 sidebandSuppressUpper[],
                                                   ViReal64 meas_out_ofTolerance[],
                                                   ViInt32 signaltype,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ModQualOver Modulation;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                
   
   
   checkRange( 262, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[262].instrCommand
          , signalType2.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                             
//   index = strcspn (p_globalvarCDMA->rdABuf, "\n");
//   p_globalvarCDMA->rdABuf[index] = '\0';

   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[0], &Modulation.msPower);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[3], &Modulation.WaveFormQuality);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[6], &Modulation.CarrierFrequencyError);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[9], &Modulation.TransmitTimeError);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[12], &Modulation.CarrierFeedThrough);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[18], &Modulation.SideBandSuppresLower);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[21], &Modulation.SideBandSuppresUpper);
   
   //RSCMU_Status           = RSCMU_ReturnLimits( &tab[24], &Modulation.MeasOutOfTolerance); 
   RSCMU_ReturnArrayValues(tab[24], &Modulation.MeasOutOfTolerance);         

   MsPower[0]               = Modulation.msPower.Current;
   MsPower[1]               = Modulation.msPower.Average;
   MsPower[2]               = Modulation.msPower.MaxMin; 
   waveFormQuality[0]       = Modulation.WaveFormQuality.Current;
   waveFormQuality[1]       = Modulation.WaveFormQuality.Average;
   waveFormQuality[2]       = Modulation.WaveFormQuality.MaxMin; 
   carrierFrequencyError[0] = Modulation.CarrierFrequencyError.Current;
   carrierFrequencyError[1] = Modulation.CarrierFrequencyError.Average;
   carrierFrequencyError[2] = Modulation.CarrierFrequencyError.MaxMin;
   transmitTimeError[0]     = Modulation.TransmitTimeError.Current;
   transmitTimeError[1]     = Modulation.TransmitTimeError.Average;
   transmitTimeError[2]     = Modulation.TransmitTimeError.MaxMin;
   carrierFeedThrough[0]    = Modulation.CarrierFeedThrough.Current;
   carrierFeedThrough[1]    = Modulation.CarrierFeedThrough.Average;
   carrierFeedThrough[2]    = Modulation.CarrierFeedThrough.MaxMin; 
   sidebandSuppressLower[0] = Modulation.SideBandSuppresLower.Current;
   sidebandSuppressLower[1] = Modulation.SideBandSuppresLower.Average;
   sidebandSuppressLower[2] = Modulation.SideBandSuppresLower.MaxMin;
   sidebandSuppressUpper[0] = Modulation.SideBandSuppresUpper.Current;
   sidebandSuppressUpper[1] = Modulation.SideBandSuppresUpper.Average;       
   sidebandSuppressUpper[2] = Modulation.SideBandSuppresUpper.MaxMin;       
   meas_out_ofTolerance[0]  = Modulation.MeasOutOfTolerance; //.Current;
   meas_out_ofTolerance[1]  = Modulation.MeasOutOfTolerance; //.Average;
   meas_out_ofTolerance[2]  = Modulation.MeasOutOfTolerance; //.MaxMin;
   
   return( RSCMU_Status ); 
   
} //end of RSCMU_CDMA2K_ReadModMQuality_EX

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchModMQuality_EX (ViSession instrSession,
                                                    ViReal64 MsPower[],
                                                    ViReal64 waveFormQuality[],
                                                    ViReal64 carrierFrequencyError[],
                                                    ViReal64 transmitTimeError[],
                                                    ViReal64 carrierFeedThrough[],
                                                    ViReal64 sidebandSuppressLower[],
                                                    ViReal64 sidebandSuppressUpper[],
                                                    ViReal64 meas_out_ofTolerance[],
                                                    ViInt32 signaltype,
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ModQualOver Modulation;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                
   
   checkRange( 263, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                          
   // Separate the CMU response:
//   index = strcspn (p_globalvarCDMA->rdABuf, "\n");
//   p_globalvarCDMA->rdABuf[index] = '\0';
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );

   
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[0], &Modulation.msPower);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[3], &Modulation.WaveFormQuality);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[6], &Modulation.CarrierFrequencyError);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[9], &Modulation.TransmitTimeError);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[12], &Modulation.CarrierFeedThrough);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[18], &Modulation.SideBandSuppresLower);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[21], &Modulation.SideBandSuppresUpper);                                       
   //RSCMU_Status           = RSCMU_ReturnLimits( &tab[24], &Modulation.MeasOutOfTolerance); 
   RSCMU_ReturnArrayValues(tab[24], &Modulation.MeasOutOfTolerance);         

   
   MsPower[0]               = Modulation.msPower.Current;
   MsPower[1]               = Modulation.msPower.Average;
   MsPower[2]               = Modulation.msPower.MaxMin; 
   waveFormQuality[0]       = Modulation.WaveFormQuality.Current;
   waveFormQuality[1]       = Modulation.WaveFormQuality.Average;
   waveFormQuality[2]       = Modulation.WaveFormQuality.MaxMin; 
   carrierFrequencyError[0] = Modulation.CarrierFrequencyError.Current;
   carrierFrequencyError[1] = Modulation.CarrierFrequencyError.Average;
   carrierFrequencyError[2] = Modulation.CarrierFrequencyError.MaxMin;
   transmitTimeError[0]     = Modulation.TransmitTimeError.Current;
   transmitTimeError[1]     = Modulation.TransmitTimeError.Average;
   transmitTimeError[2]     = Modulation.TransmitTimeError.MaxMin;
   carrierFeedThrough[0]    = Modulation.CarrierFeedThrough.Current;
   carrierFeedThrough[1]    = Modulation.CarrierFeedThrough.Average;
   carrierFeedThrough[2]    = Modulation.CarrierFeedThrough.MaxMin; 
   sidebandSuppressLower[0] = Modulation.SideBandSuppresLower.Current;
   sidebandSuppressLower[1] = Modulation.SideBandSuppresLower.Average;
   sidebandSuppressLower[2] = Modulation.SideBandSuppresLower.MaxMin;
   sidebandSuppressUpper[0] = Modulation.SideBandSuppresUpper.Current;
   sidebandSuppressUpper[1] = Modulation.SideBandSuppresUpper.Average;       
   sidebandSuppressUpper[2] = Modulation.SideBandSuppresUpper.MaxMin;       
   meas_out_ofTolerance[0]  = Modulation.MeasOutOfTolerance; //.Current;
   meas_out_ofTolerance[1]  = Modulation.MeasOutOfTolerance; //.Average;
   meas_out_ofTolerance[2]  = Modulation.MeasOutOfTolerance; //.MaxMin;
    
   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_FetchModMQuality_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleModMQuality_EX (ViSession instrSession,
                                                     ViReal64 MsPower[],
                                                     ViReal64 waveFormQuality[],
                                                     ViReal64 carrierFrequencyError[],
                                                     ViReal64 transmitTimeError[],
                                                     ViReal64 carrierFeedThrough[],
                                                     ViReal64 sidebandSuppressLower[],
                                                     ViReal64 sidebandSuppressUpper[],
                                                     ViReal64 meas_out_ofTolerance[],
                                                     ViInt32 signaltype,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ModQualOver Modulation;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   // JMG 020930
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                
   
   checkRange( 264, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[264].instrCommand
          , signalType2.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );
                                          
   // Separate the CMU response:
//   index = strcspn (p_globalvarCDMA->rdABuf, "\n");
//   p_globalvarCDMA->rdABuf[index] = '\0';
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[0], &Modulation.msPower);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[3], &Modulation.WaveFormQuality);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[6], &Modulation.CarrierFrequencyError);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[9], &Modulation.TransmitTimeError);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[12], &Modulation.CarrierFeedThrough);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[18], &Modulation.SideBandSuppresLower);
   RSCMU_Status             = RSCMU_ReturnLimits( &tab[21], &Modulation.SideBandSuppresUpper);                                       
   //RSCMU_Status           = RSCMU_ReturnLimits( &tab[24], &Modulation.MeasOutOfTolerance); 
   RSCMU_ReturnArrayValues(tab[24], &Modulation.MeasOutOfTolerance);         
   
   MsPower[0]               = Modulation.msPower.Current;
   MsPower[1]               = Modulation.msPower.Average;
   MsPower[2]               = Modulation.msPower.MaxMin; 
   waveFormQuality[0]       = Modulation.WaveFormQuality.Current;
   waveFormQuality[1]       = Modulation.WaveFormQuality.Average;
   waveFormQuality[2]       = Modulation.WaveFormQuality.MaxMin; 
   carrierFrequencyError[0] = Modulation.CarrierFrequencyError.Current;
   carrierFrequencyError[1] = Modulation.CarrierFrequencyError.Average;
   carrierFrequencyError[2] = Modulation.CarrierFrequencyError.MaxMin;
   transmitTimeError[0]     = Modulation.TransmitTimeError.Current;
   transmitTimeError[1]     = Modulation.TransmitTimeError.Average;
   transmitTimeError[2]     = Modulation.TransmitTimeError.MaxMin;
   carrierFeedThrough[0]    = Modulation.CarrierFeedThrough.Current;
   carrierFeedThrough[1]    = Modulation.CarrierFeedThrough.Average;
   carrierFeedThrough[2]    = Modulation.CarrierFeedThrough.MaxMin; 
   sidebandSuppressLower[0] = Modulation.SideBandSuppresLower.Current;
   sidebandSuppressLower[1] = Modulation.SideBandSuppresLower.Average;
   sidebandSuppressLower[2] = Modulation.SideBandSuppresLower.MaxMin;
   sidebandSuppressUpper[0] = Modulation.SideBandSuppresUpper.Current;
   sidebandSuppressUpper[1] = Modulation.SideBandSuppresUpper.Average;       
   sidebandSuppressUpper[2] = Modulation.SideBandSuppresUpper.MaxMin;       
   meas_out_ofTolerance[0]  = Modulation.MeasOutOfTolerance;//.Current;
   meas_out_ofTolerance[1]  = Modulation.MeasOutOfTolerance;//.Average;
   meas_out_ofTolerance[2]  = Modulation.MeasOutOfTolerance;//.MaxMin;
    
   return( RSCMU_Status );  
} //end of RSCMU_CDMA2K_SampleModMQuality_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_CalcModMQualMatcLim_EX (ViSession instrSession,
                                                       ViReal64 waveFormQuality[],
                                                       ViReal64 carrierFrequencyError[],
                                                       ViReal64 transmitTimeError[],
                                                       ViReal64 carrierFeedThrough[],
                                                       ViReal64 sidebandSuppressLower[],
                                                       ViReal64 sidebandSuppressUpper[],
                                                       ViInt32 signaltype,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ModQualOver Modulation;
   
   checkRange( 265, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[265].instrCommand
          , signalType2.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query (instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   RSCMU_Status = RSCMU_MatchLimits( &tab[0], &Modulation.WaveFormQuality);
   RSCMU_Status = RSCMU_MatchLimits( &tab[3], &Modulation.CarrierFrequencyError);
   RSCMU_Status = RSCMU_MatchLimits( &tab[6], &Modulation.TransmitTimeError);
   RSCMU_Status = RSCMU_MatchLimits( &tab[9], &Modulation.CarrierFeedThrough);
   RSCMU_Status = RSCMU_MatchLimits( &tab[15], &Modulation.SideBandSuppresLower);
   RSCMU_Status = RSCMU_MatchLimits( &tab[18], &Modulation.SideBandSuppresUpper);                                       
   
   waveFormQuality[0] = Modulation.WaveFormQuality.Current;
   waveFormQuality[1] = Modulation.WaveFormQuality.Average;
   waveFormQuality[2] = Modulation.WaveFormQuality.MaxMin; 
   carrierFrequencyError[0] = Modulation.CarrierFrequencyError.Current;
   carrierFrequencyError[1] = Modulation.CarrierFrequencyError.Average;
   carrierFrequencyError[2] = Modulation.CarrierFrequencyError.MaxMin;
   transmitTimeError[0] = Modulation.TransmitTimeError.Current;
   transmitTimeError[1] = Modulation.TransmitTimeError.Average;
   transmitTimeError[2] = Modulation.TransmitTimeError.MaxMin;
   carrierFeedThrough[0] = Modulation.CarrierFeedThrough.Current;
   carrierFeedThrough[1] = Modulation.CarrierFeedThrough.Average;
   carrierFeedThrough[2] = Modulation.CarrierFeedThrough.MaxMin; 
   sidebandSuppressLower[0] = Modulation.SideBandSuppresLower.Current;
   sidebandSuppressLower[1] = Modulation.SideBandSuppresLower.Average;
   sidebandSuppressLower[2] = Modulation.SideBandSuppresLower.MaxMin;
   sidebandSuppressUpper[0] = Modulation.SideBandSuppresUpper.Current;
   sidebandSuppressUpper[1] = Modulation.SideBandSuppresUpper.Average;       
   sidebandSuppressUpper[2] = Modulation.SideBandSuppresUpper.MaxMin;       
   
   return( RSCMU_Status );   
}  //end of RSCMU_CDMA2K_CalcModMQualMatcLim_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowCDPW_EX (ViSession instrSession,
                                                     ViReal64 MSPower[],
                                                     ViReal64 carrierFeedThrough[],
                                                     ViReal64 frequencyError[],
                                                     ViReal64 Rho[],
                                                     ViReal64 *outOfTolerance,
                                                     ViInt32 *currentStatistics,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   CODE_DOMAIN_POWER CDPW;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[159].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
  
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW.msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW.CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW.FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW.rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW.OutOfTolerance);
   }
   else
   {
      CDPW.OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW.CurrentStatistics );
   }
   else
   {
      CDPW.CurrentStatistics = RSCMU_NAN;
   }
   
   MSPower[0] = CDPW.msPower.Current;
   MSPower[1] = CDPW.msPower.Average;
   MSPower[2] = CDPW.msPower.MaxMin; 
   carrierFeedThrough[0] = CDPW.CarrierFeedthrough.Current;   
   carrierFeedThrough[1] = CDPW.CarrierFeedthrough.Average;  
   carrierFeedThrough[2] = CDPW.CarrierFeedthrough.MaxMin;  
   frequencyError[0] = CDPW.FrequencyError.Current;  
   frequencyError[1] = CDPW.FrequencyError.Average;    
   frequencyError[2] = CDPW.FrequencyError.MaxMin;   
   Rho[0] = CDPW.rho.Current;  
   Rho[1] = CDPW.rho.Average;  
   Rho[2] = CDPW.rho.MaxMin;   
   *outOfTolerance = CDPW.OutOfTolerance;
   *currentStatistics = CDPW.CurrentStatistics;
     
   return( RSCMU_Status );    
    
} //end of RSCMU_CDMA2K_ReadScalCDPowCDPW_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowCDPW_EX (ViSession instrSession,
                                                      ViReal64 MSPower[],
                                                      ViReal64 carrierFeedThrough[],
                                                      ViReal64 frequencyError[],
                                                      ViReal64 Rho[],
                                                      ViReal64 *outOfTolerance,
                                                      ViInt32 *currentStatistics,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   CODE_DOMAIN_POWER CDPW;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[160].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
  
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW.msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW.CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW.FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW.rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW.OutOfTolerance);
   }
   else
   {
      CDPW.OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW.CurrentStatistics );
   }
   else
   {
      CDPW.CurrentStatistics = RSCMU_NAN;
   }
   
   MSPower[0] = CDPW.msPower.Current;
   MSPower[1] = CDPW.msPower.Average;
   MSPower[2] = CDPW.msPower.MaxMin; 
   carrierFeedThrough[0] = CDPW.CarrierFeedthrough.Current;   
   carrierFeedThrough[1] = CDPW.CarrierFeedthrough.Average;  
   carrierFeedThrough[2] = CDPW.CarrierFeedthrough.MaxMin;  
   frequencyError[0] = CDPW.FrequencyError.Current;  
   frequencyError[1] = CDPW.FrequencyError.Average;    
   frequencyError[2] = CDPW.FrequencyError.MaxMin;   
   Rho[0] = CDPW.rho.Current;  
   Rho[1] = CDPW.rho.Average;  
   Rho[2] = CDPW.rho.MaxMin;   
   *outOfTolerance = CDPW.OutOfTolerance;
   *currentStatistics = CDPW.CurrentStatistics;
     
   return( RSCMU_Status );    
    
} //end of RSCMU_CDMA2K_FetchScalCDPowCDPW_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowCDPW_EX (ViSession instrSession,
                                                       ViReal64 MSPower[],
                                                       ViReal64 carrierFeedThrough[],
                                                       ViReal64 frequencyError[],
                                                       ViReal64 Rho[],
                                                       ViReal64 *outOfTolerance,
                                                       ViInt32 *currentStatistics,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   CODE_DOMAIN_POWER CDPW;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[161].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
  
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW.msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW.CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW.FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW.rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW.OutOfTolerance);
   }
   else
   {
      CDPW.OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW.CurrentStatistics );
   }
   else
   {
      CDPW.CurrentStatistics = RSCMU_NAN;
   }
   
   MSPower[0] = CDPW.msPower.Current;
   MSPower[1] = CDPW.msPower.Average;
   MSPower[2] = CDPW.msPower.MaxMin; 
   carrierFeedThrough[0] = CDPW.CarrierFeedthrough.Current;   
   carrierFeedThrough[1] = CDPW.CarrierFeedthrough.Average;  
   carrierFeedThrough[2] = CDPW.CarrierFeedthrough.MaxMin;  
   frequencyError[0] = CDPW.FrequencyError.Current;  
   frequencyError[1] = CDPW.FrequencyError.Average;    
   frequencyError[2] = CDPW.FrequencyError.MaxMin;   
   Rho[0] = CDPW.rho.Current;  
   Rho[1] = CDPW.rho.Average;  
   Rho[2] = CDPW.rho.MaxMin;   
   *outOfTolerance = CDPW.OutOfTolerance;
   *currentStatistics = CDPW.CurrentStatistics;
     
   return( RSCMU_Status );    
    
}  //end of RSCMU_CDMA2K_SampleScalCDPowCDPW_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalCDPWMatcLim_EX (ViSession instrSession,
                                                       ViReal64 carrierFeedThrough[],
                                                       ViReal64 frequencyError[],
                                                       ViReal64 Rho[],
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   CODE_DOMAIN_POWER CDPW;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[162].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
 
   RSCMU_Status = RSCMU_MatchLimits( &tab[0], &CDPW.CarrierFeedthrough);
   RSCMU_Status = RSCMU_MatchLimits( &tab[3], &CDPW.FrequencyError);
   RSCMU_Status = RSCMU_MatchLimits( &tab[6], &CDPW.rho);
   
   carrierFeedThrough[0] = CDPW.CarrierFeedthrough.Current;   
   carrierFeedThrough[1] = CDPW.CarrierFeedthrough.Average;  
   carrierFeedThrough[2] = CDPW.CarrierFeedthrough.MaxMin;  
   frequencyError[0] = CDPW.FrequencyError.Current;  
   frequencyError[1] = CDPW.FrequencyError.Average;    
   frequencyError[2] = CDPW.FrequencyError.MaxMin;   
   Rho[0] = CDPW.rho.Current;  
   Rho[1] = CDPW.rho.Average;  
   Rho[2] = CDPW.rho.MaxMin;   
     
   return( RSCMU_Status );    
    
}  //end of RSCMU_CDMA2K_CalcScalCDPWMatcLim_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowPCDEP_EX (ViSession instrSession,
                                                      ViReal64 MSPower[],
                                                      ViReal64 carrierFeedThrough[],
                                                      ViReal64 frequencyError[],
                                                      ViReal64 Rho[],
                                                      ViReal64 *outOfTolerance,
                                                      ViInt32 *currentStatistics,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   CODE_DOMAIN_POWER CDPW;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[180].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
  
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW.msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW.CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW.FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW.rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW.OutOfTolerance);
   }
   else
   {
      CDPW.OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW.CurrentStatistics );
   }
   else
   {
      CDPW.CurrentStatistics = RSCMU_NAN;
   }
   
   MSPower[0] = CDPW.msPower.Current;
   MSPower[1] = CDPW.msPower.Average;
   MSPower[2] = CDPW.msPower.MaxMin; 
   carrierFeedThrough[0] = CDPW.CarrierFeedthrough.Current;   
   carrierFeedThrough[1] = CDPW.CarrierFeedthrough.Average;  
   carrierFeedThrough[2] = CDPW.CarrierFeedthrough.MaxMin;  
   frequencyError[0] = CDPW.FrequencyError.Current;  
   frequencyError[1] = CDPW.FrequencyError.Average;    
   frequencyError[2] = CDPW.FrequencyError.MaxMin;   
   Rho[0] = CDPW.rho.Current;  
   Rho[1] = CDPW.rho.Average;  
   Rho[2] = CDPW.rho.MaxMin;   
   *outOfTolerance = CDPW.OutOfTolerance;
   *currentStatistics = CDPW.CurrentStatistics;
     
   return( RSCMU_Status );    
    
} //end of RSCMU_CDMA2K_ReadScalCDPowPCDEP_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowPCDEP_EX (ViSession instrSession,
                                                       ViReal64 MSPower[],
                                                       ViReal64 carrierFeedThrough[],
                                                       ViReal64 frequencyError[],
                                                       ViReal64 Rho[],
                                                       ViReal64 *outOfTolerance,
                                                       ViInt32 *currentStatistics,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   CODE_DOMAIN_POWER CDPW;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[181].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
  
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW.msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW.CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW.FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW.rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW.OutOfTolerance);
   }
   else
   {
      CDPW.OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW.CurrentStatistics );
   }
   else
   {
      CDPW.CurrentStatistics = RSCMU_NAN;
   }
   
   MSPower[0] = CDPW.msPower.Current;
   MSPower[1] = CDPW.msPower.Average;
   MSPower[2] = CDPW.msPower.MaxMin; 
   carrierFeedThrough[0] = CDPW.CarrierFeedthrough.Current;   
   carrierFeedThrough[1] = CDPW.CarrierFeedthrough.Average;  
   carrierFeedThrough[2] = CDPW.CarrierFeedthrough.MaxMin;  
   frequencyError[0] = CDPW.FrequencyError.Current;  
   frequencyError[1] = CDPW.FrequencyError.Average;    
   frequencyError[2] = CDPW.FrequencyError.MaxMin;   
   Rho[0] = CDPW.rho.Current;  
   Rho[1] = CDPW.rho.Average;  
   Rho[2] = CDPW.rho.MaxMin;   
   *outOfTolerance = CDPW.OutOfTolerance;
   *currentStatistics = CDPW.CurrentStatistics;
     
   return( RSCMU_Status );    
    
}  //end of RSCMU_CDMA2K_FetchScalCDPowPCDEP_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowPCDEP_EX (ViSession instrSession,
                                                        ViReal64 MSPower[],
                                                        ViReal64 carrierFeedThrough[],
                                                        ViReal64 frequencyError[],
                                                        ViReal64 Rho[],
                                                        ViReal64 *outOfTolerance,
                                                        ViInt32 *currentStatistics,
                                                        ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   CODE_DOMAIN_POWER CDPW;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[182].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
  
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW.msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW.CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW.FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW.rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW.OutOfTolerance);
   }
   else
   {
      CDPW.OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW.CurrentStatistics );
   }
   else
   {
      CDPW.CurrentStatistics = RSCMU_NAN;
   }
   
   MSPower[0] = CDPW.msPower.Current;
   MSPower[1] = CDPW.msPower.Average;
   MSPower[2] = CDPW.msPower.MaxMin; 
   carrierFeedThrough[0] = CDPW.CarrierFeedthrough.Current;   
   carrierFeedThrough[1] = CDPW.CarrierFeedthrough.Average;  
   carrierFeedThrough[2] = CDPW.CarrierFeedthrough.MaxMin;  
   frequencyError[0] = CDPW.FrequencyError.Current;  
   frequencyError[1] = CDPW.FrequencyError.Average;    
   frequencyError[2] = CDPW.FrequencyError.MaxMin;   
   Rho[0] = CDPW.rho.Current;  
   Rho[1] = CDPW.rho.Average;  
   Rho[2] = CDPW.rho.MaxMin;   
   *outOfTolerance = CDPW.OutOfTolerance;
   *currentStatistics = CDPW.CurrentStatistics;
     
   return( RSCMU_Status );    
    
} //end of RSCMU_CDMA2K_SampleScalCDPowPCDEP_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalPCDEPMatLim_EX (ViSession instrSession,
                                                       ViReal64 carrierFeedThrough[],
                                                       ViReal64 frequencyError[],
                                                       ViReal64 Rho[],
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   CODE_DOMAIN_POWER CDPW;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[183].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
 
   RSCMU_Status = RSCMU_MatchLimits( &tab[0], &CDPW.CarrierFeedthrough);
   RSCMU_Status = RSCMU_MatchLimits( &tab[3], &CDPW.FrequencyError);
   RSCMU_Status = RSCMU_MatchLimits( &tab[6], &CDPW.rho);
   
   carrierFeedThrough[0] = CDPW.CarrierFeedthrough.Current;   
   carrierFeedThrough[1] = CDPW.CarrierFeedthrough.Average;  
   carrierFeedThrough[2] = CDPW.CarrierFeedthrough.MaxMin;  
   frequencyError[0] = CDPW.FrequencyError.Current;  
   frequencyError[1] = CDPW.FrequencyError.Average;    
   frequencyError[2] = CDPW.FrequencyError.MaxMin;   
   Rho[0] = CDPW.rho.Current;  
   Rho[1] = CDPW.rho.Average;  
   Rho[2] = CDPW.rho.MaxMin;   
     
   return( RSCMU_Status );    
    
}  //end of RSCMU_CDMA2K_CalcScalPCDEPMatLim_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadScalCDPowCHPW_EX (ViSession instrSession,
                                                     ViReal64 MSPower[],
                                                     ViReal64 carrierFeedThrough[],
                                                     ViReal64 frequencyError[],
                                                     ViReal64 Rho[],
                                                     ViReal64 *outOfTolerance,
                                                     ViInt32 *currentStatistics,
                                                     ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   CODE_DOMAIN_POWER CDPW;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[200].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
  
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW.msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW.CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW.FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW.rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW.OutOfTolerance);
   }
   else
   {
      CDPW.OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW.CurrentStatistics );
   }
   else
   {
      CDPW.CurrentStatistics = RSCMU_NAN;
   }
   
   MSPower[0] = CDPW.msPower.Current;
   MSPower[1] = CDPW.msPower.Average;
   MSPower[2] = CDPW.msPower.MaxMin; 
   carrierFeedThrough[0] = CDPW.CarrierFeedthrough.Current;   
   carrierFeedThrough[1] = CDPW.CarrierFeedthrough.Average;  
   carrierFeedThrough[2] = CDPW.CarrierFeedthrough.MaxMin;  
   frequencyError[0] = CDPW.FrequencyError.Current;  
   frequencyError[1] = CDPW.FrequencyError.Average;    
   frequencyError[2] = CDPW.FrequencyError.MaxMin;   
   Rho[0] = CDPW.rho.Current;  
   Rho[1] = CDPW.rho.Average;  
   Rho[2] = CDPW.rho.MaxMin;   
   *outOfTolerance = CDPW.OutOfTolerance;
   *currentStatistics = CDPW.CurrentStatistics;
     
   return( RSCMU_Status );    
    
    
}  //end of RSCMU_CDMA2K_ReadScalCDPowCHPW_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchScalCDPowCHPW_EX (ViSession instrSession,
                                                      ViReal64 MSPower[],
                                                      ViReal64 carrierFeedThrough[],
                                                      ViReal64 frequencyError[],
                                                      ViReal64 Rho[],
                                                      ViReal64 *outOfTolerance,
                                                      ViInt32 *currentStatistics,
                                                      ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   CODE_DOMAIN_POWER CDPW;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[201].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
  
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW.msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW.CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW.FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW.rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW.OutOfTolerance);
   }
   else
   {
      CDPW.OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW.CurrentStatistics );
   }
   else
   {
      CDPW.CurrentStatistics = RSCMU_NAN;
   }
   
   MSPower[0] = CDPW.msPower.Current;
   MSPower[1] = CDPW.msPower.Average;
   MSPower[2] = CDPW.msPower.MaxMin; 
   carrierFeedThrough[0] = CDPW.CarrierFeedthrough.Current;   
   carrierFeedThrough[1] = CDPW.CarrierFeedthrough.Average;  
   carrierFeedThrough[2] = CDPW.CarrierFeedthrough.MaxMin;  
   frequencyError[0] = CDPW.FrequencyError.Current;  
   frequencyError[1] = CDPW.FrequencyError.Average;    
   frequencyError[2] = CDPW.FrequencyError.MaxMin;   
   Rho[0] = CDPW.rho.Current;  
   Rho[1] = CDPW.rho.Average;  
   Rho[2] = CDPW.rho.MaxMin;   
   *outOfTolerance = CDPW.OutOfTolerance;
   *currentStatistics = CDPW.CurrentStatistics;
     
   return( RSCMU_Status );    
    
} //end of RSCMU_CDMA2K_FetchScalCDPowCHPW_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleScalCDPowCHPW_EX (ViSession instrSession,
                                                       ViReal64 MSPower[],
                                                       ViReal64 carrierFeedThrough[],
                                                       ViReal64 frequencyError[],
                                                       ViReal64 Rho[],
                                                       ViReal64 *outOfTolerance,
                                                       ViInt32 *currentStatistics,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   CODE_DOMAIN_POWER CDPW;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[202].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
  
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &CDPW.msPower
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &CDPW.CarrierFeedthrough  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &CDPW.FrequencyError  
                                       );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &CDPW.rho
                                       );
   // Get Measurement out of tolerance
   if( strcmp( tab[12], "NAN" ) != 0 )
   {
      sscanf( tab[12], "%lf", &CDPW.OutOfTolerance);
   }
   else
   {
      CDPW.OutOfTolerance = RSCMU_NAN;
   }
   
   // Get Current Statistics
   if( strcmp( tab[13], "NAN" ) != 0 )
   {
      sscanf( tab[13], "%d", &CDPW.CurrentStatistics );
   }
   else
   {
      CDPW.CurrentStatistics = RSCMU_NAN;
   }
   
   MSPower[0] = CDPW.msPower.Current;
   MSPower[1] = CDPW.msPower.Average;
   MSPower[2] = CDPW.msPower.MaxMin; 
   carrierFeedThrough[0] = CDPW.CarrierFeedthrough.Current;   
   carrierFeedThrough[1] = CDPW.CarrierFeedthrough.Average;  
   carrierFeedThrough[2] = CDPW.CarrierFeedthrough.MaxMin;  
   frequencyError[0] = CDPW.FrequencyError.Current;  
   frequencyError[1] = CDPW.FrequencyError.Average;    
   frequencyError[2] = CDPW.FrequencyError.MaxMin;   
   Rho[0] = CDPW.rho.Current;  
   Rho[1] = CDPW.rho.Average;  
   Rho[2] = CDPW.rho.MaxMin;   
   *outOfTolerance = CDPW.OutOfTolerance;
   *currentStatistics = CDPW.CurrentStatistics;
     
   return( RSCMU_Status );    
    
} //end of RSCMU_CDMA2K_SampleScalCDPowCHPW_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_CalcScalCHPWMatcLim_EX (ViSession instrSession,
                                                       ViReal64 carrierFeedThrough[],
                                                       ViReal64 frequencyError[],
                                                       ViReal64 Rho[],
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   CODE_DOMAIN_POWER CDPW;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   RSCMU_Status = RSCMU_Query( instrSession
                             , (ViChar *)CDMA[203].instrCommand
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
 
   RSCMU_Status = RSCMU_MatchLimits( &tab[3], &CDPW.CarrierFeedthrough);
   RSCMU_Status = RSCMU_MatchLimits( &tab[6], &CDPW.FrequencyError);
   RSCMU_Status = RSCMU_MatchLimits( &tab[9], &CDPW.rho);
   
   carrierFeedThrough[0] = CDPW.CarrierFeedthrough.Current;   
   carrierFeedThrough[1] = CDPW.CarrierFeedthrough.Average;  
   carrierFeedThrough[2] = CDPW.CarrierFeedthrough.MaxMin;  
   frequencyError[0] = CDPW.FrequencyError.Current;  
   frequencyError[1] = CDPW.FrequencyError.Average;    
   frequencyError[2] = CDPW.FrequencyError.MaxMin;   
   Rho[0] = CDPW.rho.Current;  
   Rho[1] = CDPW.rho.Average;  
   Rho[2] = CDPW.rho.MaxMin;   
     
   return( RSCMU_Status );    
    
} //end of RSCMU_CDMA2K_CalcScalCHPWMatcLim_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadOverview_EX (ViSession instrSession,
                                                ViReal64 ExpectedMSPower[],
                                                ViReal64 MeasuredMSPower[],
                                                ViReal64 CarrierFreqError[],
                                                ViReal64 ExpectedCarrierFreq[],
                                                ViReal64 TxTimeError[],
                                                ViReal64 WaveFormQuality[],
                                                ViReal64 SidebandSuppressionLowerACP[],
                                                ViReal64 SidebandSuppressionUpperACP[],
                                                ViInt32 signaltype,
                                                ViChar errorMessage[])
{
   ViStatus     RSCMU_Status = VI_SUCCESS;  
   ViChar       *wrtBuf;
   ViChar       *rdBuf;
   ViChar       tab[48][30]; 
   OVERVIEW_C2K Overview;
   ViInt32      index;
   struct       RSCMU_CDMA_Globals  *p_globalvarCDMA; 

  // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;
    
   checkRange( 227, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[227].instrCommand
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0], &Overview.expectedMSPower);
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    Overview.expectedMSPower.Average = Overview.expectedMSPower.Current;
    Overview.expectedMSPower.MaxMin = Overview.expectedMSPower.Current;
    index = 1;
   }
   else
    index = 3;
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.measuredMSPower);
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    index = 4;
   }
   else
    index = 6;
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.expectedCarrierFreq);
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    Overview.expectedCarrierFreq.Average = Overview.expectedCarrierFreq.Current;
    Overview.expectedCarrierFreq.MaxMin =  Overview.expectedCarrierFreq.Current;
    index = 5;
   }
   else
    index = 9;
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.carrierFreqError);

   index = index + 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.transmitTimeErr);
   
   index = index + 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.waveformQuality);
   
   index = index + 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.sidebandSuppressionLower);                                       
   
   index = index + 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.sidebandSuppressionUpper);
   
   // JMG 030113
   // Enure backward compatibility with older FW 
   // Index is only incremented is FW is ate least 3.10 and Extended OverOverview is set to ON
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
    index = index + 3;
   else 
    index = index - 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionLower2
                                    );
   index = index + 3;                     
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionUpper2
                                    );           
   
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
    index = index + 3;
   else 
    index = index - 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionLower3
                                    );
   index = index +3;                                        
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionUpper3
                                    ); 

   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
    index = index + 3;
   else 
    index = index - 3;

   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionLower4
                                    );
   index = index +3;                                        
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionUpper4
                                    ); 
     
   
   ExpectedMSPower[0]               = Overview.expectedMSPower.Current; 
   ExpectedMSPower[1]               = Overview.expectedMSPower.Average;
   ExpectedMSPower[2]               = Overview.expectedMSPower.MaxMin;
   MeasuredMSPower[0]               = Overview.measuredMSPower.Current;
   MeasuredMSPower[1]               = Overview.measuredMSPower.Average;
   MeasuredMSPower[2]               = Overview.measuredMSPower.MaxMin; 
   CarrierFreqError[0]              = Overview.carrierFreqError.Current;
   CarrierFreqError[1]              = Overview.carrierFreqError.Average;
   CarrierFreqError[2]              = Overview.carrierFreqError.MaxMin;  
   ExpectedCarrierFreq[0]           = Overview.expectedCarrierFreq.Current;
   ExpectedCarrierFreq[1]           = Overview.expectedCarrierFreq.Average; 
   ExpectedCarrierFreq[2]           = Overview.expectedCarrierFreq.MaxMin;
   TxTimeError[0]                   = Overview.transmitTimeErr.Current; 
   TxTimeError[1]                   = Overview.transmitTimeErr.Average;
   TxTimeError[2]                   = Overview.transmitTimeErr.MaxMin;
   WaveFormQuality[0]               = Overview.waveformQuality.Current;
   WaveFormQuality[1]               = Overview.waveformQuality.Average; 
   WaveFormQuality[2]               = Overview.waveformQuality.MaxMin; 
   SidebandSuppressionLowerACP[0]   = Overview.sidebandSuppressionLower.Current; 
   SidebandSuppressionLowerACP[1]   = Overview.sidebandSuppressionLower.Average;
   SidebandSuppressionLowerACP[2]   = Overview.sidebandSuppressionLower.MaxMin;
   SidebandSuppressionUpperACP[0]   = Overview.sidebandSuppressionUpper.Current;
   SidebandSuppressionUpperACP[1]   = Overview.sidebandSuppressionUpper.Average; 
   SidebandSuppressionUpperACP[2]   = Overview.sidebandSuppressionUpper.MaxMin; 
   SidebandSuppressionLowerACP[3]   = Overview.sidebandSuppressionLower2.Current; 
   SidebandSuppressionLowerACP[4]   = Overview.sidebandSuppressionLower2.Average;
   SidebandSuppressionLowerACP[5]   = Overview.sidebandSuppressionLower2.MaxMin;
   SidebandSuppressionUpperACP[3]   = Overview.sidebandSuppressionUpper2.Current;
   SidebandSuppressionUpperACP[4]   = Overview.sidebandSuppressionUpper2.Average; 
   SidebandSuppressionUpperACP[5]   = Overview.sidebandSuppressionUpper2.MaxMin; 
   SidebandSuppressionLowerACP[6]   = Overview.sidebandSuppressionLower3.Current; 
   SidebandSuppressionLowerACP[7]   = Overview.sidebandSuppressionLower3.Average;
   SidebandSuppressionLowerACP[8]   = Overview.sidebandSuppressionLower3.MaxMin;
   SidebandSuppressionUpperACP[6]   = Overview.sidebandSuppressionUpper3.Current;
   SidebandSuppressionUpperACP[7]   = Overview.sidebandSuppressionUpper3.Average; 
   SidebandSuppressionUpperACP[8]   = Overview.sidebandSuppressionUpper3.MaxMin; 
   SidebandSuppressionLowerACP[9]   = Overview.sidebandSuppressionLower4.Current; 
   SidebandSuppressionLowerACP[10]  = Overview.sidebandSuppressionLower4.Average;
   SidebandSuppressionLowerACP[11]  = Overview.sidebandSuppressionLower4.MaxMin;
   SidebandSuppressionUpperACP[9]   = Overview.sidebandSuppressionUpper4.Current;
   SidebandSuppressionUpperACP[10]  = Overview.sidebandSuppressionUpper4.Average; 
   SidebandSuppressionUpperACP[11]  = Overview.sidebandSuppressionUpper4.MaxMin;    
  
   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_ReadOverview_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchOverview_EX (ViSession instrSession,
                                                 ViReal64 ExpectedMSPower[],
                                                 ViReal64 MeasuredMSPower[],
                                                 ViReal64 CarrierFreqError[],
                                                 ViReal64 ExpectedCarrierFreq[],
                                                 ViReal64 TxTimeError[],
                                                 ViReal64 WaveFormQuality[],
                                                 ViReal64 SidebandSuppressionLowerACP[],
                                                 ViReal64 SidebandSuppressionUpperACP[],
                                                 ViInt32 signaltype,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   OVERVIEW_C2K Overview;
   ViInt32    index;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA; 

   // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;   
   
   checkRange( 228, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[228].instrCommand
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0], &Overview.expectedMSPower);
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    Overview.expectedMSPower.Average = Overview.expectedMSPower.Current;
    Overview.expectedMSPower.MaxMin = Overview.expectedMSPower.Current;
    index = 1;
   }
   else
    index = 3;
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.measuredMSPower);
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    index = 4;
   }
   else
    index = 6;
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.expectedCarrierFreq);
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    Overview.expectedCarrierFreq.Average = Overview.expectedCarrierFreq.Current;
    Overview.expectedCarrierFreq.MaxMin =  Overview.expectedCarrierFreq.Current;
    index = 5;
   }
   else
    index = 9;
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.carrierFreqError);

   index = index + 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.transmitTimeErr);
   index = index + 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.waveformQuality);
   index = index + 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.sidebandSuppressionLower);                                       
   index = index + 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.sidebandSuppressionUpper);
   
   // JMG 030113
   // Enure backward compatibility with older FW 
   // Index is only incremented is FW is ate least 3.10 and Extended OverOverview is set to ON
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
    index = index + 3;
   else 
    index = index - 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionLower2
                                    );
   index = index + 3;                     
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionUpper2
                                    );           
   
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
    index = index + 3;
   else 
    index = index - 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionLower3
                                    );
   index = index +3;                                        
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionUpper3
                                    ); 

   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
    index = index + 3;
   else 
    index = index - 3;

   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionLower4
                                    );
   index = index +3;                                        
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionUpper4
                                    ); 
     
   
   ExpectedMSPower[0]               = Overview.expectedMSPower.Current; 
   ExpectedMSPower[1]               = Overview.expectedMSPower.Average;
   ExpectedMSPower[2]               = Overview.expectedMSPower.MaxMin;
   MeasuredMSPower[0]               = Overview.measuredMSPower.Current;
   MeasuredMSPower[1]               = Overview.measuredMSPower.Average;
   MeasuredMSPower[2]               = Overview.measuredMSPower.MaxMin; 
   CarrierFreqError[0]              = Overview.carrierFreqError.Current;
   CarrierFreqError[1]              = Overview.carrierFreqError.Average;
   CarrierFreqError[2]              = Overview.carrierFreqError.MaxMin;  
   ExpectedCarrierFreq[0]           = Overview.expectedCarrierFreq.Current;
   ExpectedCarrierFreq[1]           = Overview.expectedCarrierFreq.Average; 
   ExpectedCarrierFreq[2]           = Overview.expectedCarrierFreq.MaxMin;
   TxTimeError[0]                   = Overview.transmitTimeErr.Current; 
   TxTimeError[1]                   = Overview.transmitTimeErr.Average;
   TxTimeError[2]                   = Overview.transmitTimeErr.MaxMin;
   WaveFormQuality[0]               = Overview.waveformQuality.Current;
   WaveFormQuality[1]               = Overview.waveformQuality.Average; 
   WaveFormQuality[2]               = Overview.waveformQuality.MaxMin; 
   SidebandSuppressionLowerACP[0]   = Overview.sidebandSuppressionLower.Current; 
   SidebandSuppressionLowerACP[1]   = Overview.sidebandSuppressionLower.Average;
   SidebandSuppressionLowerACP[2]   = Overview.sidebandSuppressionLower.MaxMin;
   SidebandSuppressionUpperACP[0]   = Overview.sidebandSuppressionUpper.Current;
   SidebandSuppressionUpperACP[1]   = Overview.sidebandSuppressionUpper.Average; 
   SidebandSuppressionUpperACP[2]   = Overview.sidebandSuppressionUpper.MaxMin; 
   SidebandSuppressionLowerACP[3]   = Overview.sidebandSuppressionLower2.Current; 
   SidebandSuppressionLowerACP[4]   = Overview.sidebandSuppressionLower2.Average;
   SidebandSuppressionLowerACP[5]   = Overview.sidebandSuppressionLower2.MaxMin;
   SidebandSuppressionUpperACP[3]   = Overview.sidebandSuppressionUpper2.Current;
   SidebandSuppressionUpperACP[4]   = Overview.sidebandSuppressionUpper2.Average; 
   SidebandSuppressionUpperACP[5]   = Overview.sidebandSuppressionUpper2.MaxMin; 
   SidebandSuppressionLowerACP[6]   = Overview.sidebandSuppressionLower3.Current; 
   SidebandSuppressionLowerACP[7]   = Overview.sidebandSuppressionLower3.Average;
   SidebandSuppressionLowerACP[8]   = Overview.sidebandSuppressionLower3.MaxMin;
   SidebandSuppressionUpperACP[6]   = Overview.sidebandSuppressionUpper3.Current;
   SidebandSuppressionUpperACP[7]   = Overview.sidebandSuppressionUpper3.Average; 
   SidebandSuppressionUpperACP[8]   = Overview.sidebandSuppressionUpper3.MaxMin; 
   SidebandSuppressionLowerACP[9]   = Overview.sidebandSuppressionLower4.Current; 
   SidebandSuppressionLowerACP[10]  = Overview.sidebandSuppressionLower4.Average;
   SidebandSuppressionLowerACP[11]  = Overview.sidebandSuppressionLower4.MaxMin;
   SidebandSuppressionUpperACP[9]   = Overview.sidebandSuppressionUpper4.Current;
   SidebandSuppressionUpperACP[10]  = Overview.sidebandSuppressionUpper4.Average; 
   SidebandSuppressionUpperACP[11]  = Overview.sidebandSuppressionUpper4.MaxMin;    
   
   return( RSCMU_Status );   
}//end of RSCMU_CDMA2K_FetchOverview_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleOverview_EX (ViSession instrSession,
                                                  ViReal64 ExpectedMSPower[],
                                                  ViReal64 MeasuredMSPower[],
                                                  ViReal64 CarrierFreqError[],
                                                  ViReal64 ExpectedCarrierFreq[],
                                                  ViReal64 TxTimeError[],
                                                  ViReal64 WaveFormQuality[],
                                                  ViReal64 SidebandSuppressionLowerACP[],
                                                  ViReal64 SidebandSuppressionUpperACP[],
                                                  ViInt32 signaltype,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   OVERVIEW_C2K Overview;
   ViInt32    index;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;   

     // Get the global structure
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status;
      
   
   checkRange( 229, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[229].instrCommand
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   RSCMU_Status = RSCMU_ReturnLimits( &tab[0], &Overview.expectedMSPower);
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    Overview.expectedMSPower.Average = Overview.expectedMSPower.Current;
    Overview.expectedMSPower.MaxMin = Overview.expectedMSPower.Current;
    index = 1;
   }
   else
    index = 3;
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.measuredMSPower);
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    index = 4;
   }
   else
    index = 6;
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.expectedCarrierFreq);
   if (p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_07) 
   {
    Overview.expectedCarrierFreq.Average = Overview.expectedCarrierFreq.Current;
    Overview.expectedCarrierFreq.MaxMin =  Overview.expectedCarrierFreq.Current;
    index = 5;
   }
   else
    index = 9;
   
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.carrierFreqError);

   index = index + 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.transmitTimeErr);
   index = index + 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.waveformQuality);
   index = index + 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.sidebandSuppressionLower);                                       
   index = index + 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index], &Overview.sidebandSuppressionUpper);
   
   // JMG 030113
   // Enure backward compatibility with older FW 
   // Index is only incremented is FW is ate least 3.10 and Extended OverOverview is set to ON
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
    index = index + 3;
   else 
    index = index - 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionLower2
                                    );
   index = index + 3;                     
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionUpper2
                                    );           
   
   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
    index = index + 3;
   else 
    index = index - 3;
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionLower3
                                    );
   index = index +3;                                        
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionUpper3
                                    ); 

   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
    index = index + 3;
   else 
    index = index - 3;

   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionLower4
                                    );
   index = index +3;                                        
   RSCMU_Status = RSCMU_ReturnLimits( &tab[index]
                                    , &Overview.sidebandSuppressionUpper4
                                    ); 
     
   
   ExpectedMSPower[0]               = Overview.expectedMSPower.Current; 
   ExpectedMSPower[1]               = Overview.expectedMSPower.Average;
   ExpectedMSPower[2]               = Overview.expectedMSPower.MaxMin;
   MeasuredMSPower[0]               = Overview.measuredMSPower.Current;
   MeasuredMSPower[1]               = Overview.measuredMSPower.Average;
   MeasuredMSPower[2]               = Overview.measuredMSPower.MaxMin; 
   CarrierFreqError[0]              = Overview.carrierFreqError.Current;
   CarrierFreqError[1]              = Overview.carrierFreqError.Average;
   CarrierFreqError[2]              = Overview.carrierFreqError.MaxMin;  
   ExpectedCarrierFreq[0]           = Overview.expectedCarrierFreq.Current;
   ExpectedCarrierFreq[1]           = Overview.expectedCarrierFreq.Average; 
   ExpectedCarrierFreq[2]           = Overview.expectedCarrierFreq.MaxMin;
   TxTimeError[0]                   = Overview.transmitTimeErr.Current; 
   TxTimeError[1]                   = Overview.transmitTimeErr.Average;
   TxTimeError[2]                   = Overview.transmitTimeErr.MaxMin;
   WaveFormQuality[0]               = Overview.waveformQuality.Current;
   WaveFormQuality[1]               = Overview.waveformQuality.Average; 
   WaveFormQuality[2]               = Overview.waveformQuality.MaxMin; 
   SidebandSuppressionLowerACP[0]   = Overview.sidebandSuppressionLower.Current; 
   SidebandSuppressionLowerACP[1]   = Overview.sidebandSuppressionLower.Average;
   SidebandSuppressionLowerACP[2]   = Overview.sidebandSuppressionLower.MaxMin;
   SidebandSuppressionUpperACP[0]   = Overview.sidebandSuppressionUpper.Current;
   SidebandSuppressionUpperACP[1]   = Overview.sidebandSuppressionUpper.Average; 
   SidebandSuppressionUpperACP[2]   = Overview.sidebandSuppressionUpper.MaxMin; 
   SidebandSuppressionLowerACP[3]   = Overview.sidebandSuppressionLower2.Current; 
   SidebandSuppressionLowerACP[4]   = Overview.sidebandSuppressionLower2.Average;
   SidebandSuppressionLowerACP[5]   = Overview.sidebandSuppressionLower2.MaxMin;
   SidebandSuppressionUpperACP[3]   = Overview.sidebandSuppressionUpper2.Current;
   SidebandSuppressionUpperACP[4]   = Overview.sidebandSuppressionUpper2.Average; 
   SidebandSuppressionUpperACP[5]   = Overview.sidebandSuppressionUpper2.MaxMin; 
   SidebandSuppressionLowerACP[6]   = Overview.sidebandSuppressionLower3.Current; 
   SidebandSuppressionLowerACP[7]   = Overview.sidebandSuppressionLower3.Average;
   SidebandSuppressionLowerACP[8]   = Overview.sidebandSuppressionLower3.MaxMin;
   SidebandSuppressionUpperACP[6]   = Overview.sidebandSuppressionUpper3.Current;
   SidebandSuppressionUpperACP[7]   = Overview.sidebandSuppressionUpper3.Average; 
   SidebandSuppressionUpperACP[8]   = Overview.sidebandSuppressionUpper3.MaxMin; 
   SidebandSuppressionLowerACP[9]   = Overview.sidebandSuppressionLower4.Current; 
   SidebandSuppressionLowerACP[10]  = Overview.sidebandSuppressionLower4.Average;
   SidebandSuppressionLowerACP[11]  = Overview.sidebandSuppressionLower4.MaxMin;
   SidebandSuppressionUpperACP[9]   = Overview.sidebandSuppressionUpper4.Current;
   SidebandSuppressionUpperACP[10]  = Overview.sidebandSuppressionUpper4.Average; 
   SidebandSuppressionUpperACP[11]  = Overview.sidebandSuppressionUpper4.MaxMin;    
   
   return( RSCMU_Status );    
} //end of RSCMU_CDMA2K_SampleOverview_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_CalcOverviewMatcLim_EX (ViSession instrSession,
                                                       ViReal64 CarrierFreqError[],
                                                       ViReal64 TxTimeError[],
                                                       ViReal64 WaveFormQuality[],
                                                       ViReal64 SidebandSuppressionLowerACP[],
                                                       ViReal64 SidebandSuppressionUpperACP[],
                                                       ViInt32 signaltype,
                                                       ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ViInt32  index;
   OVERVIEW_C2K     Overview;
   struct RSCMU_CDMA_Globals  *p_globalvarCDMA;     
   
   // Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
    return RSCMU_Status; 
   
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[230].instrCommand
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
   RSCMU_Status = RSCMU_MatchLimits( &tab[0], &Overview.carrierFreqError);
   RSCMU_Status = RSCMU_MatchLimits( &tab[3], &Overview.transmitTimeErr);
   RSCMU_Status = RSCMU_MatchLimits( &tab[6], &Overview.waveformQuality);

   if ((p_globalvarCDMA->RSCMU_tGlobal.RSCMU_FW_Version > RSCMU200_V3_09) && (p_globalvarCDMA->RSCMU_XtndOVER == VI_TRUE))
   ;
   else
   for (index=9;index<48;index++) strcpy(tab[index],"NAN");

   RSCMU_Status = RSCMU_MatchLimits( &tab[9]
                                    , &Overview.sidebandSuppressionLower
                                    );

   RSCMU_Status = RSCMU_MatchLimits( &tab[12]
                                    , &Overview.sidebandSuppressionUpper
                                    );

                                    
   RSCMU_Status = RSCMU_MatchLimits( &tab[15]
                                    , &Overview.sidebandSuppressionLower2
                                    );
   
   RSCMU_Status = RSCMU_MatchLimits( &tab[18]
                                    , &Overview.sidebandSuppressionUpper2
                                    );           
                                    
   RSCMU_Status = RSCMU_MatchLimits( &tab[21]
                                    , &Overview.sidebandSuppressionLower3
                                    );
   
   RSCMU_Status = RSCMU_MatchLimits( &tab[24]
                                    , &Overview.sidebandSuppressionUpper3
                                    ); 


   RSCMU_Status = RSCMU_MatchLimits( &tab[27]
                                    , &Overview.sidebandSuppressionLower4
                                    );

   RSCMU_Status = RSCMU_MatchLimits( &tab[30]
                                    , &Overview.sidebandSuppressionUpper4
                                    ); 

 
   CarrierFreqError[0]              = Overview.carrierFreqError.Current;
   CarrierFreqError[1]              = Overview.carrierFreqError.Average;
   CarrierFreqError[2]              = Overview.carrierFreqError.MaxMin;  
   TxTimeError[0]                   = Overview.transmitTimeErr.Current; 
   TxTimeError[1]                   = Overview.transmitTimeErr.Average;
   TxTimeError[2]                   = Overview.transmitTimeErr.MaxMin;
   WaveFormQuality[0]               = Overview.waveformQuality.Current;
   WaveFormQuality[1]               = Overview.waveformQuality.Average; 
   WaveFormQuality[2]               = Overview.waveformQuality.MaxMin; 
   SidebandSuppressionLowerACP[0]   = Overview.sidebandSuppressionLower.Current; 
   SidebandSuppressionLowerACP[1]   = Overview.sidebandSuppressionLower.Average;
   SidebandSuppressionLowerACP[2]   = Overview.sidebandSuppressionLower.MaxMin;
   SidebandSuppressionUpperACP[0]   = Overview.sidebandSuppressionUpper.Current;
   SidebandSuppressionUpperACP[1]   = Overview.sidebandSuppressionUpper.Average; 
   SidebandSuppressionUpperACP[2]   = Overview.sidebandSuppressionUpper.MaxMin; 
   SidebandSuppressionLowerACP[3]   = Overview.sidebandSuppressionLower2.Current; 
   SidebandSuppressionLowerACP[4]   = Overview.sidebandSuppressionLower2.Average;
   SidebandSuppressionLowerACP[5]   = Overview.sidebandSuppressionLower2.MaxMin;
   SidebandSuppressionUpperACP[3]   = Overview.sidebandSuppressionUpper2.Current;
   SidebandSuppressionUpperACP[4]   = Overview.sidebandSuppressionUpper2.Average; 
   SidebandSuppressionUpperACP[5]   = Overview.sidebandSuppressionUpper2.MaxMin; 
   SidebandSuppressionLowerACP[6]   = Overview.sidebandSuppressionLower3.Current; 
   SidebandSuppressionLowerACP[7]   = Overview.sidebandSuppressionLower3.Average;
   SidebandSuppressionLowerACP[8]   = Overview.sidebandSuppressionLower3.MaxMin;
   SidebandSuppressionUpperACP[6]   = Overview.sidebandSuppressionUpper3.Current;
   SidebandSuppressionUpperACP[7]   = Overview.sidebandSuppressionUpper3.Average; 
   SidebandSuppressionUpperACP[8]   = Overview.sidebandSuppressionUpper3.MaxMin; 
   SidebandSuppressionLowerACP[9]   = Overview.sidebandSuppressionLower4.Current; 
   SidebandSuppressionLowerACP[10]  = Overview.sidebandSuppressionLower4.Average;
   SidebandSuppressionLowerACP[11]  = Overview.sidebandSuppressionLower4.MaxMin;
   SidebandSuppressionUpperACP[9]   = Overview.sidebandSuppressionUpper4.Current;
   SidebandSuppressionUpperACP[10]  = Overview.sidebandSuppressionUpper4.Average; 
   SidebandSuppressionUpperACP[11]  = Overview.sidebandSuppressionUpper4.MaxMin;     
   
   return( RSCMU_Status );   
} //end of RSCMU_CDMA2K_CalcOverviewMatcLim_EX()

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadMod_Error_Ex (ViSession instrSession,
                                               ViReal64 peak[], 
                                               ViReal64 RMS[],
                                               ViReal64 carrierFeedthrough[],
                                               ViReal64 IQImbalance[],
                                               ViReal64 freqErr[],
                                               ViReal64 transmitTimeError[],
                                               ViReal64 waveformQuality[],
                                               ViReal64 MSPower[],
                                               ViInt32 *measCount,
                                               ViReal64 *measOutOfTolerance,
                                               ViInt32 type, 
                                               ViInt32 signaltype,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ERROR_MOD Modulation;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   checkRange( 284, &type, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[284].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Modulation.Peak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Modulation.RMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Modulation.CarrierFeedthrough
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Modulation.IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Modulation.FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Modulation.TransmitTimeError
                                       );                                       
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Modulation.WaveformQuality
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Modulation.MSPower
                                       );                                       
      if( strcmp( tab[24], "NAN" ) != 0 )
      {
         sscanf( tab[24], "%d", &Modulation.MeasCount );
      }
      else
      {
         Modulation.MeasCount = RSCMU_NAN;
      } 
      
      if( strcmp( tab[25], "NAN" ) != 0 )
      {
         sscanf( tab[25], "%lf", &Modulation.MeasOutOfTolerance );
      }
      else
      {
         Modulation.MeasOutOfTolerance = RSCMU_NAN;
      }     
   
    peak[0] = Modulation.Peak.Current;
    peak[1] = Modulation.Peak.Average;
    peak[2] = Modulation.Peak.MaxMin;
    RMS[0] = Modulation.RMS.Current;
    RMS[1] = Modulation.RMS.Average;
    RMS[2] = Modulation.RMS.MaxMin; 
    carrierFeedthrough[0] = Modulation.CarrierFeedthrough.Current;
    carrierFeedthrough[1] = Modulation.CarrierFeedthrough.Average;
    carrierFeedthrough[2] = Modulation.CarrierFeedthrough.MaxMin; 
    IQImbalance[0] = Modulation.IQImbalance.Current;
    IQImbalance[1] = Modulation.IQImbalance.Average;
    IQImbalance[2] = Modulation.IQImbalance.MaxMin; 
    freqErr[0] = Modulation.FreqErr.Current;
    freqErr[1] = Modulation.FreqErr.Average;
    freqErr[2] = Modulation.FreqErr.MaxMin; 
    transmitTimeError[0] = Modulation.TransmitTimeError.Current;
    transmitTimeError[1] = Modulation.TransmitTimeError.Average;
    transmitTimeError[2] = Modulation.TransmitTimeError.MaxMin; 
    waveformQuality[0] = Modulation.WaveformQuality.Current;
    waveformQuality[1] = Modulation.WaveformQuality.Average;
    waveformQuality[2] = Modulation.WaveformQuality.MaxMin; 
    MSPower[0] = Modulation.MSPower.Current;
    MSPower[1] = Modulation.MSPower.Average;
    MSPower[2] = Modulation.MSPower.MaxMin; 
    *measCount = Modulation.MeasCount;
    *measOutOfTolerance = Modulation.MeasOutOfTolerance;
    
   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ReadMod_Error_Ex()


ViStatus _VI_FUNC RSCMU_CDMA2K_ReadMod_Overview_Ex (ViSession instrSession,
                                                  ViReal64 EVM[],
                                                  ViReal64 modError[],
                                                  ViReal64 phaseError[],
                                                  ViReal64 carrierFeedthrough[],
                                                  ViReal64 IQImbalance[],
                                                  ViReal64 frequencyError[],
                                                  ViReal64 transmitTimeError[],
                                                  ViReal64 waveformQuality[],
                                                  ViReal64 MSPower[],
                                                  ViInt32 *measCount,
                                                  ViReal64 *measOutOfTolerance,
                                                  ViInt32 signaltype,
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   OVERVIEW Overview;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;

   //Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        
  
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[284].instrCommand
          , measType.list[RSCMU_OVERVIEW] 
          , signalType.list[signaltype]
          );
   
   RSCMU_Status = RSCMU_Query_Array( instrSession
                                     , wrtBuf
                                     , &p_globalvarCDMA->rdABuf[0]
                                     , RSCMU_STB_ON
                                     , errorMessage
                                     );
   
   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
    
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Overview.EVMPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Overview.EVMRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Overview.MErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Overview.MErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Overview.PErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Overview.PErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Overview.CarrierFeedthrough
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Overview.IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[24]
                                       , &Overview.FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[27]
                                       , &Overview.TransmitTimeError
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[30]
                                       , &Overview.WaveformQuality
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[33]
                                       , &Overview.MSPower
                                       );                                       
      if( strcmp( tab[36], "NAN" ) != 0 )
      {
         sscanf( tab[36], "%d", &Overview.MeasCount );
      }
      else
      {
         Overview.MeasCount = RSCMU_NAN;
      } 
      
      if( strcmp( tab[37], "NAN" ) != 0 )
      {
         sscanf( tab[37], "%lf", &Overview.MeasOutOfTolerance );
      }
      else
      {
         Overview.MeasOutOfTolerance = RSCMU_NAN;
      }     
   
      EVM[0] = Overview.EVMPeak.Current;
      EVM[1] = Overview.EVMPeak.Average;
      EVM[2] = Overview.EVMPeak.MaxMin; 
      EVM[3] = Overview.EVMRMS.Current;
      EVM[4] = Overview.EVMRMS.Average;
      EVM[5] = Overview.EVMRMS.MaxMin; 
      modError[0] = Overview.MErrPeak.Current;
      modError[1] = Overview.MErrPeak.Average;
      modError[2] = Overview.MErrPeak.MaxMin; 
      modError[3] = Overview.MErrRMS.Current;
      modError[4] = Overview.MErrRMS.Average;
      modError[5] = Overview.MErrRMS.MaxMin; 
      phaseError[0] = Overview.PErrPeak.Current;
      phaseError[1] = Overview.PErrPeak.Average;
      phaseError[2] = Overview.PErrPeak.MaxMin; 
      phaseError[3] = Overview.PErrRMS.Current;
      phaseError[4] = Overview.PErrRMS.Average;
      phaseError[5] = Overview.PErrRMS.MaxMin; 
      carrierFeedthrough[0] = Overview.CarrierFeedthrough.Current;
      carrierFeedthrough[1] = Overview.CarrierFeedthrough.Average;
      carrierFeedthrough[2] = Overview.CarrierFeedthrough.MaxMin; 
      IQImbalance[0] = Overview.IQImbalance.Current;
      IQImbalance[1] = Overview.IQImbalance.Average;
      IQImbalance[2] = Overview.IQImbalance.MaxMin; 
      frequencyError[0] = Overview.FreqErr.Current;
      frequencyError[1] = Overview.FreqErr.Average;
      frequencyError[2] = Overview.FreqErr.MaxMin; 
      transmitTimeError[0] = Overview.TransmitTimeError.Current;
      transmitTimeError[1] = Overview.TransmitTimeError.Average;
      transmitTimeError[2] = Overview.TransmitTimeError.MaxMin; 
      waveformQuality[0] = Overview.WaveformQuality.Current;
      waveformQuality[1] = Overview.WaveformQuality.Average;
      waveformQuality[2] = Overview.WaveformQuality.MaxMin; 
      MSPower[0] = Overview.MSPower.Current;
      MSPower[1] = Overview.MSPower.Average;
      MSPower[2] = Overview.MSPower.MaxMin; 
      *measCount = Overview.MeasCount;
      *measOutOfTolerance = Overview.MeasOutOfTolerance;
   
   return( RSCMU_Status ); 
}//end of RSCMU_CDMA2K_ReadMod_Overview_Ex()

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchMod_Error_Ex (ViSession instrSession,
                                                ViReal64 peak[], 
                                                ViReal64 RMS[],
                                                ViReal64 carrierFeedthrough[],
                                                ViReal64 IQImbalance[],
                                                ViReal64 freqErr[],
                                                ViReal64 transmitTimeError[],
                                                ViReal64 waveformQuality[],
                                                ViReal64 MSPower[],
                                                ViInt32 *measCount,
                                                ViReal64 *measOutOfTolerance,
                                                ViInt32 type, 
                                                ViInt32 signaltype,
                                                ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ERROR_MOD Modulation;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   checkRange( 285, &type, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[285].instrCommand
          , measType.list[type] 
          , signalType.list[signaltype]
          );
   
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   
     RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Modulation.Peak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Modulation.RMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Modulation.CarrierFeedthrough
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Modulation.IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Modulation.FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Modulation.TransmitTimeError
                                       );                                       
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Modulation.WaveformQuality
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Modulation.MSPower
                                       );                                       
      if( strcmp( tab[24], "NAN" ) != 0 )
      {
         sscanf( tab[24], "%d", &Modulation.MeasCount );
      }
      else
      {
         Modulation.MeasCount = RSCMU_NAN;
      } 
      
      if( strcmp( tab[25], "NAN" ) != 0 )
      {
         sscanf( tab[25], "%lf", &Modulation.MeasOutOfTolerance );
      }
      else
      {
         Modulation.MeasOutOfTolerance = RSCMU_NAN;
      }     
   
    peak[0] = Modulation.Peak.Current;
    peak[1] = Modulation.Peak.Average;
    peak[2] = Modulation.Peak.MaxMin;
    RMS[0] = Modulation.RMS.Current;
    RMS[1] = Modulation.RMS.Average;
    RMS[2] = Modulation.RMS.MaxMin; 
    carrierFeedthrough[0] = Modulation.CarrierFeedthrough.Current;
    carrierFeedthrough[1] = Modulation.CarrierFeedthrough.Average;
    carrierFeedthrough[2] = Modulation.CarrierFeedthrough.MaxMin; 
    IQImbalance[0] = Modulation.IQImbalance.Current;
    IQImbalance[1] = Modulation.IQImbalance.Average;
    IQImbalance[2] = Modulation.IQImbalance.MaxMin; 
    freqErr[0] = Modulation.FreqErr.Current;
    freqErr[1] = Modulation.FreqErr.Average;
    freqErr[2] = Modulation.FreqErr.MaxMin; 
    transmitTimeError[0] = Modulation.TransmitTimeError.Current;
    transmitTimeError[1] = Modulation.TransmitTimeError.Average;
    transmitTimeError[2] = Modulation.TransmitTimeError.MaxMin; 
    waveformQuality[0] = Modulation.WaveformQuality.Current;
    waveformQuality[1] = Modulation.WaveformQuality.Average;
    waveformQuality[2] = Modulation.WaveformQuality.MaxMin; 
    MSPower[0] = Modulation.MSPower.Current;
    MSPower[1] = Modulation.MSPower.Average;
    MSPower[2] = Modulation.MSPower.MaxMin; 
    *measCount = Modulation.MeasCount;
    *measOutOfTolerance = Modulation.MeasOutOfTolerance;

   return( RSCMU_Status );
} //end of RSCMU_CDMA2K_FetchMod_Error_Ex()

ViStatus _VI_FUNC RSCMU_CDMA2K_FetchMod_Overview_Ex (ViSession instrSession,
                                                   ViReal64 EVM[],
                                                   ViReal64 modError[],
                                                   ViReal64 phaseError[],
                                                   ViReal64 carrierFeedthrough[],
                                                   ViReal64 IQImbalance[],
                                                   ViReal64 frequencyError[],
                                                   ViReal64 transmitTimeError[],
                                                   ViReal64 waveformQuality[],
                                                   ViReal64 MSPower[],
                                                   ViInt32 *measCount,
                                                   ViReal64 *measOutOfTolerance,
                                                   ViInt32  signaltype,
                                                   ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   OVERVIEW Overview;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[285].instrCommand
          , measType.list[RSCMU_OVERVIEW] 
          , signalType.list[signaltype]
          );
          
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
    
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Overview.EVMPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Overview.EVMRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Overview.MErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Overview.MErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Overview.PErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Overview.PErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Overview.CarrierFeedthrough
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Overview.IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[24]
                                       , &Overview.FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[27]
                                       , &Overview.TransmitTimeError
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[30]
                                       , &Overview.WaveformQuality
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[33]
                                       , &Overview.MSPower
                                       );                                       
      if( strcmp( tab[36], "NAN" ) != 0 )
      {
         sscanf( tab[36], "%d", &Overview.MeasCount );
      }
      else
      {
         Overview.MeasCount = RSCMU_NAN;
      } 
      
      if( strcmp( tab[37], "NAN" ) != 0 )
      {
         sscanf( tab[37], "%lf", &Overview.MeasOutOfTolerance );
      }
      else
      {
         Overview.MeasOutOfTolerance = RSCMU_NAN;
      }     
   
      EVM[0] = Overview.EVMPeak.Current;
      EVM[1] = Overview.EVMPeak.Average;
      EVM[2] = Overview.EVMPeak.MaxMin; 
      EVM[3] = Overview.EVMRMS.Current;
      EVM[4] = Overview.EVMRMS.Average;
      EVM[5] = Overview.EVMRMS.MaxMin; 
      modError[0] = Overview.MErrPeak.Current;
      modError[1] = Overview.MErrPeak.Average;
      modError[2] = Overview.MErrPeak.MaxMin; 
      modError[3] = Overview.MErrRMS.Current;
      modError[4] = Overview.MErrRMS.Average;
      modError[5] = Overview.MErrRMS.MaxMin; 
      phaseError[0] = Overview.PErrPeak.Current;
      phaseError[1] = Overview.PErrPeak.Average;
      phaseError[2] = Overview.PErrPeak.MaxMin; 
      phaseError[3] = Overview.PErrRMS.Current;
      phaseError[4] = Overview.PErrRMS.Average;
      phaseError[5] = Overview.PErrRMS.MaxMin; 
      carrierFeedthrough[0] = Overview.CarrierFeedthrough.Current;
      carrierFeedthrough[1] = Overview.CarrierFeedthrough.Average;
      carrierFeedthrough[2] = Overview.CarrierFeedthrough.MaxMin; 
      IQImbalance[0] = Overview.IQImbalance.Current;
      IQImbalance[1] = Overview.IQImbalance.Average;
      IQImbalance[2] = Overview.IQImbalance.MaxMin; 
      frequencyError[0] = Overview.FreqErr.Current;
      frequencyError[1] = Overview.FreqErr.Average;
      frequencyError[2] = Overview.FreqErr.MaxMin; 
      transmitTimeError[0] = Overview.TransmitTimeError.Current;
      transmitTimeError[1] = Overview.TransmitTimeError.Average;
      transmitTimeError[2] = Overview.TransmitTimeError.MaxMin; 
      waveformQuality[0] = Overview.WaveformQuality.Current;
      waveformQuality[1] = Overview.WaveformQuality.Average;
      waveformQuality[2] = Overview.WaveformQuality.MaxMin; 
      MSPower[0] = Overview.MSPower.Current;
      MSPower[1] = Overview.MSPower.Average;
      MSPower[2] = Overview.MSPower.MaxMin; 
      *measCount = Overview.MeasCount;
      *measOutOfTolerance = Overview.MeasOutOfTolerance;
   
   return( RSCMU_Status );
}//end of RSCMU_CDMA2K_FetchMod_Overview_Ex()

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleMod_Error_Ex (ViSession instrSession,
                                                 ViReal64 peak[], 
                                                 ViReal64 RMS[],
                                                 ViReal64 carrierFeedthrough[],
                                                 ViReal64 IQImbalance[],
                                                 ViReal64 freqErr[],
                                                 ViReal64 transmitTimeError[],
                                                 ViReal64 waveformQuality[],
                                                 ViReal64 MSPower[],
                                                 ViInt32 *measCount,
                                                 ViReal64 *measOutOfTolerance,
                                                 ViInt32 measurementType,
                                                 ViInt32 signaltype,
                                                 ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   ERROR_MOD Modulation;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   checkRange( 286, &measurementType, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[286].instrCommand
          , measType.list[measurementType] 
          , signalType.list[signaltype]
          );
   
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
   
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Modulation.Peak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Modulation.RMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Modulation.CarrierFeedthrough
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Modulation.IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Modulation.FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Modulation.TransmitTimeError
                                       );                                       
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Modulation.WaveformQuality
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Modulation.MSPower
                                       );                                       
      if( strcmp( tab[24], "NAN" ) != 0 )
      {
         sscanf( tab[24], "%d", &Modulation.MeasCount );
      }
      else
      {
         Modulation.MeasCount = RSCMU_NAN;
      } 
      
      if( strcmp( tab[25], "NAN" ) != 0 )
      {
         sscanf( tab[25], "%lf", &Modulation.MeasOutOfTolerance );
      }
      else
      {
         Modulation.MeasOutOfTolerance = RSCMU_NAN;
      }     
   
    peak[0] = Modulation.Peak.Current;
    peak[1] = Modulation.Peak.Average;
    peak[2] = Modulation.Peak.MaxMin;
    RMS[0] = Modulation.RMS.Current;
    RMS[1] = Modulation.RMS.Average;
    RMS[2] = Modulation.RMS.MaxMin; 
    carrierFeedthrough[0] = Modulation.CarrierFeedthrough.Current;
    carrierFeedthrough[1] = Modulation.CarrierFeedthrough.Average;
    carrierFeedthrough[2] = Modulation.CarrierFeedthrough.MaxMin; 
    IQImbalance[0] = Modulation.IQImbalance.Current;
    IQImbalance[1] = Modulation.IQImbalance.Average;
    IQImbalance[2] = Modulation.IQImbalance.MaxMin; 
    freqErr[0] = Modulation.FreqErr.Current;
    freqErr[1] = Modulation.FreqErr.Average;
    freqErr[2] = Modulation.FreqErr.MaxMin; 
    transmitTimeError[0] = Modulation.TransmitTimeError.Current;
    transmitTimeError[1] = Modulation.TransmitTimeError.Average;
    transmitTimeError[2] = Modulation.TransmitTimeError.MaxMin; 
    waveformQuality[0] = Modulation.WaveformQuality.Current;
    waveformQuality[1] = Modulation.WaveformQuality.Average;
    waveformQuality[2] = Modulation.WaveformQuality.MaxMin; 
    MSPower[0] = Modulation.MSPower.Current;
    MSPower[1] = Modulation.MSPower.Average;
    MSPower[2] = Modulation.MSPower.MaxMin; 
    *measCount = Modulation.MeasCount;
    *measOutOfTolerance = Modulation.MeasOutOfTolerance;

   return( RSCMU_Status );
}  //end of RSCMU_CDMA2K_SampleMod_Error_Ex()

ViStatus _VI_FUNC RSCMU_CDMA2K_SampleMod_Overview_Ex (ViSession instrSession,
                                                    ViReal64 EVM[],
                                                    ViReal64 modError[],
                                                    ViReal64 phaseError[],
                                                    ViReal64 carrierFeedthrough[],
                                                    ViReal64 IQImbalance[],
                                                    ViReal64 frequencyError[],
                                                    ViReal64 transmitTimeError[],
                                                    ViReal64 waveformQuality[],
                                                    ViReal64 MSPower[],
                                                    ViInt32 *measCount,
                                                    ViReal64 *measOutOfTolerance,
                                                    ViInt32 signaltype,  
                                                    ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30]; 
   OVERVIEW Overview;
   struct   RSCMU_CDMA_Globals  *p_globalvarCDMA;
  

   //Get the global structure
   if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarCDMA)) < 0)
     return RSCMU_Status;                                        

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[286].instrCommand
          , measType.list[RSCMU_OVERVIEW] 
          , signalType.list[signaltype]
          );
   
   RSCMU_Status = RSCMU_Query_Array( instrSession
                             , wrtBuf
                             , &p_globalvarCDMA->rdABuf[0]
                             , RSCMU_STB_ON
                             , errorMessage
                             );

   // Separate the CMU response:
   RSCMU_SeparateString( p_globalvarCDMA->rdABuf, ",", tab );
    
      RSCMU_Status = RSCMU_ReturnLimits( &tab[0]
                                       , &Overview.EVMPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[3]
                                       , &Overview.EVMRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[6]
                                       , &Overview.MErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[9]
                                       , &Overview.MErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[12]
                                       , &Overview.PErrPeak
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[15]
                                       , &Overview.PErrRMS
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[18]
                                       , &Overview.CarrierFeedthrough
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[21]
                                       , &Overview.IQImbalance
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[24]
                                       , &Overview.FreqErr
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[27]
                                       , &Overview.TransmitTimeError
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[30]
                                       , &Overview.WaveformQuality
                                       );
      RSCMU_Status = RSCMU_ReturnLimits( &tab[33]
                                       , &Overview.MSPower
                                       );                                       
      if( strcmp( tab[36], "NAN" ) != 0 )
      {
         sscanf( tab[36], "%d", &Overview.MeasCount );
      }
      else
      {
         Overview.MeasCount = RSCMU_NAN;
      } 
      
      if( strcmp( tab[37], "NAN" ) != 0 )
      {
         sscanf( tab[37], "%lf", &Overview.MeasOutOfTolerance );
      }
      else
      {
         Overview.MeasOutOfTolerance = RSCMU_NAN;
      }     
   
      EVM[0] = Overview.EVMPeak.Current;
      EVM[1] = Overview.EVMPeak.Average;
      EVM[2] = Overview.EVMPeak.MaxMin; 
      EVM[3] = Overview.EVMRMS.Current;
      EVM[4] = Overview.EVMRMS.Average;
      EVM[5] = Overview.EVMRMS.MaxMin; 
      modError[0] = Overview.MErrPeak.Current;
      modError[1] = Overview.MErrPeak.Average;
      modError[2] = Overview.MErrPeak.MaxMin; 
      modError[3] = Overview.MErrRMS.Current;
      modError[4] = Overview.MErrRMS.Average;
      modError[5] = Overview.MErrRMS.MaxMin; 
      phaseError[0] = Overview.PErrPeak.Current;
      phaseError[1] = Overview.PErrPeak.Average;
      phaseError[2] = Overview.PErrPeak.MaxMin; 
      phaseError[3] = Overview.PErrRMS.Current;
      phaseError[4] = Overview.PErrRMS.Average;
      phaseError[5] = Overview.PErrRMS.MaxMin; 
      carrierFeedthrough[0] = Overview.CarrierFeedthrough.Current;
      carrierFeedthrough[1] = Overview.CarrierFeedthrough.Average;
      carrierFeedthrough[2] = Overview.CarrierFeedthrough.MaxMin; 
      IQImbalance[0] = Overview.IQImbalance.Current;
      IQImbalance[1] = Overview.IQImbalance.Average;
      IQImbalance[2] = Overview.IQImbalance.MaxMin; 
      frequencyError[0] = Overview.FreqErr.Current;
      frequencyError[1] = Overview.FreqErr.Average;
      frequencyError[2] = Overview.FreqErr.MaxMin; 
      transmitTimeError[0] = Overview.TransmitTimeError.Current;
      transmitTimeError[1] = Overview.TransmitTimeError.Average;
      transmitTimeError[2] = Overview.TransmitTimeError.MaxMin; 
      waveformQuality[0] = Overview.WaveformQuality.Current;
      waveformQuality[1] = Overview.WaveformQuality.Average;
      waveformQuality[2] = Overview.WaveformQuality.MaxMin; 
      MSPower[0] = Overview.MSPower.Current;
      MSPower[1] = Overview.MSPower.Average;
      MSPower[2] = Overview.MSPower.MaxMin; 
      *measCount = Overview.MeasCount;
      *measOutOfTolerance = Overview.MeasOutOfTolerance;
   
   return( RSCMU_Status );
} //end of RSCMU_CDMA2K_SampleMod_Overview_Ex()

ViStatus _VI_FUNC RSCMU_CDMA2K_CalcMod_Error_Ex (ViSession instrSession,
                                               ViReal64 peak[], 
                                               ViReal64 RMS[],
                                               ViReal64 carrierFeedthrough[],
                                               ViReal64 IQImbalance[],
                                               ViReal64 freqErr[],
                                               ViReal64 transmitTimeError[],
                                               ViReal64 waveformQuality[],
                                               ViReal64 MSPower[],
                                               ViInt32 measurementType,
                                               ViInt32 signaltype,
                                               ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];
   ERROR_MOD Modulation;

   checkRange( 287, &measurementType, &signaltype);
   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[287].instrCommand
          , measType.list[measurementType] 
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
    // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );

      RSCMU_Status = RSCMU_MatchLimits( &tab[0]
                                      , &Modulation.Peak
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[3]
                                      , &Modulation.RMS
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[6]
                                      , &Modulation.CarrierFeedthrough
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[9]
                                      , &Modulation.IQImbalance
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[12]
                                      , &Modulation.FreqErr
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[15]
                                       , &Modulation.TransmitTimeError
                                       );
      RSCMU_Status = RSCMU_MatchLimits( &tab[18]
                                      , &Modulation.WaveformQuality
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[21]
                                      , &Modulation.MSPower
                                      );                                       

    peak[0]                 = Modulation.Peak.Current;
    peak[1]                 = Modulation.Peak.Average;
    peak[2]                 = Modulation.Peak.MaxMin;
    RMS[0]                  = Modulation.RMS.Current;
    RMS[1]                  = Modulation.RMS.Average;
    RMS[2]                  = Modulation.RMS.MaxMin; 
    carrierFeedthrough[0]   = Modulation.CarrierFeedthrough.Current;
    carrierFeedthrough[1]   = Modulation.CarrierFeedthrough.Average;
    carrierFeedthrough[2]   = Modulation.CarrierFeedthrough.MaxMin; 
    IQImbalance[0]          = Modulation.IQImbalance.Current;
    IQImbalance[1]          = Modulation.IQImbalance.Average;
    IQImbalance[2]          = Modulation.IQImbalance.MaxMin; 
    freqErr[0]              = Modulation.FreqErr.Current;
    freqErr[1]              = Modulation.FreqErr.Average;
    freqErr[2]              = Modulation.FreqErr.MaxMin; 
    transmitTimeError[0]    = Modulation.TransmitTimeError.Current;
    transmitTimeError[1]    = Modulation.TransmitTimeError.Average;
    transmitTimeError[2]    = Modulation.TransmitTimeError.MaxMin;
    waveformQuality[0]      = Modulation.WaveformQuality.Current;
    waveformQuality[1]      = Modulation.WaveformQuality.Average;
    waveformQuality[2]      = Modulation.WaveformQuality.MaxMin; 
    MSPower[0]              = Modulation.MSPower.Current;
    MSPower[1]              = Modulation.MSPower.Average;
    MSPower[2]              = Modulation.MSPower.MaxMin; 

   return( RSCMU_Status );

}//end of RSCMU_CDMA2K_CalcMod_Error_Ex()


ViStatus _VI_FUNC RSCMU_CDMA2K_CalcMod_Overview_Ex (ViSession instrSession,
                                                  ViReal64 EVM[],
                                                  ViReal64 modError[],
                                                  ViReal64 phaseError[],
                                                  ViReal64 carrierFeedthrough[],
                                                  ViReal64 IQImbalance[],
                                                  ViReal64 frequencyError[],
                                                  ViReal64 transmitTimeError[],
                                                  ViReal64 waveformQuality[],
                                                  ViReal64 MSPower[],
                                                  ViInt32 signaltype,  
                                                  ViChar errorMessage[])
{
   ViStatus  RSCMU_Status = VI_SUCCESS;  
   ViChar   *wrtBuf;
   ViChar   *rdBuf;
   ViChar    tab[48][30];
   OVERVIEW Overview;

   getBuffers( instrSession
             , &wrtBuf
             , &rdBuf
             , errorMessage
             );

   sprintf( wrtBuf
          , CDMA[287].instrCommand
          , measType.list[RSCMU_OVERVIEW] 
          , signalType.list[signaltype]
          );

   RSCMU_Status = RSCMU_Query( instrSession
                             , wrtBuf
                             , rdBuf
                             , RSCMU_STB_ON
                             , errorMessage
                             );
   
    // Separate the CMU response:
   RSCMU_SeparateString( rdBuf, ",", tab );
   
      RSCMU_Status = RSCMU_MatchLimits( &tab[0]
                                      , &Overview.PErrPeak
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[3]
                                      , &Overview.PErrRMS
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[6]
                                      , &Overview.MErrPeak
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[9]
                                      , &Overview.MErrRMS
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[12]
                                      , &Overview.EVMPeak
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[15]
                                      , &Overview.EVMRMS
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[18]
                                      , &Overview.CarrierFeedthrough
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[21]
                                      , &Overview.IQImbalance
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[24]
                                      , &Overview.TransmitTimeError
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[27]
                                      , &Overview.WaveformQuality
                                      );
      RSCMU_Status = RSCMU_MatchLimits( &tab[30]
                                      , &Overview.MSPower
                                      );                                       

      EVM[0] = Overview.EVMPeak.Current;
      EVM[1] = Overview.EVMPeak.Average;
      EVM[2] = Overview.EVMPeak.MaxMin; 
      EVM[3] = Overview.EVMRMS.Current;
      EVM[4] = Overview.EVMRMS.Average;
      EVM[5] = Overview.EVMRMS.MaxMin; 
      modError[0] = Overview.MErrPeak.Current;
      modError[1] = Overview.MErrPeak.Average;
      modError[2] = Overview.MErrPeak.MaxMin; 
      modError[3] = Overview.MErrRMS.Current;
      modError[4] = Overview.MErrRMS.Average;
      modError[5] = Overview.MErrRMS.MaxMin; 
      phaseError[0] = Overview.PErrPeak.Current;
      phaseError[1] = Overview.PErrPeak.Average;
      phaseError[2] = Overview.PErrPeak.MaxMin; 
      phaseError[3] = Overview.PErrRMS.Current;
      phaseError[4] = Overview.PErrRMS.Average;
      phaseError[5] = Overview.PErrRMS.MaxMin; 
      carrierFeedthrough[0] = Overview.CarrierFeedthrough.Current;
      carrierFeedthrough[1] = Overview.CarrierFeedthrough.Average;
      carrierFeedthrough[2] = Overview.CarrierFeedthrough.MaxMin; 
      IQImbalance[0] = Overview.IQImbalance.Current;
      IQImbalance[1] = Overview.IQImbalance.Average;
      IQImbalance[2] = Overview.IQImbalance.MaxMin; 
      transmitTimeError[0] = Overview.TransmitTimeError.Current;
      transmitTimeError[1] = Overview.TransmitTimeError.Average;
      transmitTimeError[2] = Overview.TransmitTimeError.MaxMin; 
      waveformQuality[0] = Overview.WaveformQuality.Current;
      waveformQuality[1] = Overview.WaveformQuality.Average;
      waveformQuality[2] = Overview.WaveformQuality.MaxMin; 
      MSPower[0] = Overview.MSPower.Current;
      MSPower[1] = Overview.MSPower.Average;
      MSPower[2] = Overview.MSPower.MaxMin; 
     
    return( RSCMU_Status );    
} //end of RSCMU_CDMA2K_CalcMod_Overview_Ex()

ViStatus _VI_FUNC RSCMU_CDMA2K_ReadRQFpc_Ex (ViSession instrSession,
                                             ViReal64 *actualOutputPower,
                                             ViReal64 FER[],
                                             ViInt32 frameError[],
                                             ViInt32 transmitFrame[],
                                             ViReal64 confidence_level[],
                                             ViReal64 adjustLevel[],
                                             ViReal64 fwdChannelLevel[],
                                             ViReal64 currentSetPoint[],
                                             ViReal64 BSCalEbNt[],
                                             ViChar errorMessage[])
{
    ViStatus RSCMU_Status = VI_SUCCESS;
    tFPC    fpc;
    
    RSCMU_Status = RSCMU_CDMA2K_ReadRQFpc (instrSession, &fpc, errorMessage);
    if(RSCMU_Status == VI_SUCCESS)
    {
        *actualOutputPower = fpc.actualOutputPower;
        FER[0] = fpc.FCH.FER; 
        FER[1] = fpc.DCCH.FER; 
        FER[2] = fpc.SCH0.FER; 
        FER[3] = fpc.SCH1.FER; 

        frameError[0] = fpc.FCH.FrameError; 
        frameError[1] = fpc.DCCH.FrameError; 
        frameError[2] = fpc.SCH0.FrameError; 
        frameError[3] = fpc.SCH1.FrameError; 

        transmitFrame[0] = fpc.FCH.TransmitFrame; 
        transmitFrame[1] = fpc.DCCH.TransmitFrame; 
        transmitFrame[2] = fpc.SCH0.TransmitFrame; 
        transmitFrame[3] = fpc.SCH1.TransmitFrame; 
                                                                     
        confidence_level[0] = fpc.FCH.ConfidenceLevel; 
        confidence_level[1] = fpc.DCCH.ConfidenceLevel; 
        confidence_level[2] = fpc.SCH0.ConfidenceLevel; 
        confidence_level[3] = fpc.SCH1.ConfidenceLevel; 

        adjustLevel[0] = fpc.FCH.AdjustLevel; 
        adjustLevel[1] = fpc.DCCH.AdjustLevel; 
        adjustLevel[2] = fpc.SCH0.AdjustLevel; 
        adjustLevel[3] = fpc.SCH1.AdjustLevel;
        
        fwdChannelLevel[0] = fpc.FCH.FwdChLevel;
        fwdChannelLevel[1] = fpc.DCCH.FwdChLevel;
        fwdChannelLevel[2] = fpc.SCH0.FwdChLevel;
        fwdChannelLevel[3] = fpc.SCH1.FwdChLevel;
        
        currentSetPoint[0] = fpc.FCH.CurrentSetPoint;
        currentSetPoint[1] = fpc.DCCH.CurrentSetPoint;
        currentSetPoint[2] = fpc.SCH0.CurrentSetPoint;
        currentSetPoint[3] = fpc.SCH1.CurrentSetPoint;
        
        BSCalEbNt[0] = fpc.FCH.BSCalEbNt;
        BSCalEbNt[1] = fpc.DCCH.BSCalEbNt;
        BSCalEbNt[2] = fpc.SCH0.BSCalEbNt;
        BSCalEbNt[3] = fpc.SCH1.BSCalEbNt;
    }
    
    return RSCMU_Status;
}

ViStatus _VI_FUNC RSCMU_CDMA2K_FetcRQFpc_Ex (ViSession instrSession,
                                             ViReal64 *actualOutputPower,
                                             ViReal64 FER[],
                                             ViInt32 frameError[],
                                             ViInt32 transmitFrame[],
                                             ViReal64 confidence_level[],
                                             ViReal64 adjustLevel[],
                                             ViReal64 fwdChannelLevel[],
                                             ViReal64 currentSetPoint[],
                                             ViReal64 BSCalEbNt[],
                                             ViChar errorMessage[])
{
    ViStatus RSCMU_Status = VI_SUCCESS;
    tFPC    fpc;
    
    RSCMU_Status = RSCMU_CDMA2K_FetchRQFpc (instrSession, &fpc, errorMessage);
    if(RSCMU_Status == VI_SUCCESS)
    {
        *actualOutputPower = fpc.actualOutputPower;
        FER[0] = fpc.FCH.FER; 
        FER[1] = fpc.DCCH.FER; 
        FER[2] = fpc.SCH0.FER; 
        FER[3] = fpc.SCH1.FER; 

        frameError[0] = fpc.FCH.FrameError; 
        frameError[1] = fpc.DCCH.FrameError; 
        frameError[2] = fpc.SCH0.FrameError; 
        frameError[3] = fpc.SCH1.FrameError; 

        transmitFrame[0] = fpc.FCH.TransmitFrame; 
        transmitFrame[1] = fpc.DCCH.TransmitFrame; 
        transmitFrame[2] = fpc.SCH0.TransmitFrame; 
        transmitFrame[3] = fpc.SCH1.TransmitFrame; 

        confidence_level[0] = fpc.FCH.ConfidenceLevel; 
        confidence_level[1] = fpc.DCCH.ConfidenceLevel; 
        confidence_level[2] = fpc.SCH0.ConfidenceLevel; 
        confidence_level[3] = fpc.SCH1.ConfidenceLevel; 

        adjustLevel[0] = fpc.FCH.AdjustLevel; 
        adjustLevel[1] = fpc.DCCH.AdjustLevel; 
        adjustLevel[2] = fpc.SCH0.AdjustLevel; 
        adjustLevel[3] = fpc.SCH1.AdjustLevel;
        
        fwdChannelLevel[0] = fpc.FCH.FwdChLevel;
        fwdChannelLevel[1] = fpc.DCCH.FwdChLevel;
        fwdChannelLevel[2] = fpc.SCH0.FwdChLevel;
        fwdChannelLevel[3] = fpc.SCH1.FwdChLevel;
        
        currentSetPoint[0] = fpc.FCH.CurrentSetPoint;
        currentSetPoint[1] = fpc.DCCH.CurrentSetPoint;
        currentSetPoint[2] = fpc.SCH0.CurrentSetPoint;
        currentSetPoint[3] = fpc.SCH1.CurrentSetPoint;
        
        BSCalEbNt[0] = fpc.FCH.BSCalEbNt;
        BSCalEbNt[1] = fpc.DCCH.BSCalEbNt;
        BSCalEbNt[2] = fpc.SCH0.BSCalEbNt;
        BSCalEbNt[3] = fpc.SCH1.BSCalEbNt;
    }
    
    return RSCMU_Status;
}

ViStatus _VI_FUNC RSCMU_CDMA2K_SampRQFpc_Ex (ViSession instrSession,
                                             ViReal64 *actualOutputPower,
                                             ViReal64 FER[],
                                             ViInt32 frameError[],
                                             ViInt32 transmitFrame[],
                                             ViReal64 confidence_level[],
                                             ViReal64 adjustLevel[],
                                             ViReal64 fwdChannelLevel[],
                                             ViReal64 currentSetPoint[],
                                             ViReal64 BSCalEbNt[],
                                             ViChar errorMessage[])
{
    ViStatus RSCMU_Status = VI_SUCCESS;
    tFPC    fpc;
    
    RSCMU_Status = RSCMU_CDMA2K_SampleRQFpc (instrSession, &fpc, errorMessage);
    if(RSCMU_Status == VI_SUCCESS)
    {
        *actualOutputPower = fpc.actualOutputPower;
        FER[0] = fpc.FCH.FER; 
        FER[1] = fpc.DCCH.FER; 
        FER[2] = fpc.SCH0.FER; 
        FER[3] = fpc.SCH1.FER; 

        frameError[0] = fpc.FCH.FrameError; 
        frameError[1] = fpc.DCCH.FrameError; 
        frameError[2] = fpc.SCH0.FrameError; 
        frameError[3] = fpc.SCH1.FrameError; 

        transmitFrame[0] = fpc.FCH.TransmitFrame; 
        transmitFrame[1] = fpc.DCCH.TransmitFrame; 
        transmitFrame[2] = fpc.SCH0.TransmitFrame; 
        transmitFrame[3] = fpc.SCH1.TransmitFrame; 

        confidence_level[0] = fpc.FCH.ConfidenceLevel; 
        confidence_level[1] = fpc.DCCH.ConfidenceLevel; 
        confidence_level[2] = fpc.SCH0.ConfidenceLevel; 
        confidence_level[3] = fpc.SCH1.ConfidenceLevel; 

        adjustLevel[0] = fpc.FCH.AdjustLevel; 
        adjustLevel[1] = fpc.DCCH.AdjustLevel; 
        adjustLevel[2] = fpc.SCH0.AdjustLevel; 
        adjustLevel[3] = fpc.SCH1.AdjustLevel;
        
        fwdChannelLevel[0] = fpc.FCH.FwdChLevel;
        fwdChannelLevel[1] = fpc.DCCH.FwdChLevel;
        fwdChannelLevel[2] = fpc.SCH0.FwdChLevel;
        fwdChannelLevel[3] = fpc.SCH1.FwdChLevel;
        
        currentSetPoint[0] = fpc.FCH.CurrentSetPoint;
        currentSetPoint[1] = fpc.DCCH.CurrentSetPoint;
        currentSetPoint[2] = fpc.SCH0.CurrentSetPoint;
        currentSetPoint[3] = fpc.SCH1.CurrentSetPoint;
        
        BSCalEbNt[0] = fpc.FCH.BSCalEbNt;
        BSCalEbNt[1] = fpc.DCCH.BSCalEbNt;
        BSCalEbNt[2] = fpc.SCH0.BSCalEbNt;
        BSCalEbNt[3] = fpc.SCH1.BSCalEbNt;
    }
    
    return RSCMU_Status;
}
